/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(wb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function ub(vb){var s=vb.a;var t=s.a;var u=t.buffer;t.grow=sb;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=NaN;var O=Infinity;var P=s.b;var Q=s.c;var R=s.d;var S=s.e;var T=s.f;var U=s.g;var V=s.h;var W=s.i;var X=s.j;var Y=s.k;var Z=s.l;var _=s.m;var $=s.n;var aa=s.o;var ba=s.p;var ca=s.q;var da=s.r;var ea=s.s;var fa=s.t;var ga=s.u;var ha=s.v;var ia=s.w;var ja=s.x;var ka=s.y;var la=s.z;var ma=s.A;var na=s.B;var oa=s.C;var pa=s.D;var qa=s.E;var ra=s.F;var sa=s.G;var ta=s.H;var ua=s.I;var va=s.J;var wa=s.K;var xa=s.L;var ya=s.M;var za=s.N;var Aa=s.O;var Ba=s.P;var Ca=s.Q;var Da=s.R;var Ea=s.S;var Fa=s.T;var Ga=s.U;var Ha=s.V;var Ia=s.W;var Ja=s.X;var Ka=s.Y;var La=s.Z;var Ma=s._;var Na=s.$;var Oa=s.aa;var Pa=s.ba;var Qa=s.ca;var Ra=s.da;var Sa=s.ea;var Ta=s.fa;var Ua=s.ga;var Va=s.ha;var Wa=s.ia;var Xa=s.ja;var Ya=s.ka;var Za=s.la;var _a=s.ma;var $a=s.na;var ab=s.oa;var bb=s.pa;var cb=s.qa;var db=s.ra;var eb=s.sa;var fb=s.ta;var gb=s.ua;var hb=5711840;var ib=0;var jb=0;var kb=0;var lb=0;
// EMSCRIPTEN_START_FUNCS
function fJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,T=0,V=E(0),W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=E(0),Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=E(0),Za=0;ba=hb-32|0;hb=ba;e=ba+24|0;x[e>>2]=49484;x[e>>2]=49384;h=eJ(ba+16|0);f=eJ(ba+8|0);da=b;la=c;ma=e;na=x[h>>2];Da=y[h+4|0];oa=x[f>>2];Ea=y[f+4|0];c=0;T=hb-112|0;hb=T;d=a;pa=a+24604|0;a=pa;a:{if(!x[a+16>>2]){break a}b=x[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){c=T+96|0;pM(c,9035,12860,220,45);a=hb-48|0;hb=a;b=Vb(a+16|0,17572);x[23420]=0;U(5,a|0,1,17235);e=x[23420];x[23420]=0;b:{c:{d:{e:{if((e|0)!=1){x[23420]=0;U(2,a+32|0,b|0,a|0);e=x[23420];x[23420]=0;if((e|0)==1){break e}x[23420]=0;ea(798,a|0,c|0,1,a|0,a+32|0);c=x[23420];x[23420]=0;if((c|0)!=1){break b}c=P()|0;yb(a+32|0);break d}c=P()|0;break c}c=P()|0}yb(a)}yb(b);S(c|0);p()}yb(a+32|0);yb(a);yb(b);hb=a+48|0}qa=d+8204|0;ra=d+397452|0;sa=d+397448|0;$=d+393352|0;I=d+397456|0;_=d+12|0;Fa=d+1074376|0;Ga=d+1298420|0;Ha=d+1074365|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!da|a&512)){h:{if(x[d+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}r=0;j=hb-48|0;hb=j;J=hb-32|0;hb=J;n=d+1074312|0;e=d+1074992|0;f=d+1298264|0;l=d+1074424|0;t=d+484360|0;m=d+1074448|0;s=d+1074376|0;b=x[d+1074392>>2];u=d+480188|0;G=d+480180|0;i=d+484376|0;o=d+484348|0;C=d+480210|0;H=d+484364|0;j:{k:{l:while(1){m:{a=b+1|0;x[d+1074392>>2]=a;if(Rk(s)>>>0>a>>>0){break m}FN(J+24|0,x[G>>2],z[u>>1],s,(x[d+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(y[d+480208|0]&32){g=x[o>>2];q=x[d+484344>>2];b=z[d+1074446>>1];break r}b=65535;a=x[d+484360>>2];k=y[i|0];c=Yb(a,k);h=x[c>>2];g=Mc(h,x[c+4>>2]);c=z[d+1074448>>1];if(g>>>0>c>>>0){b=z[bc(h,c)>>1]}w[d+1074446>>1]=b;s:{t:{q=x[d+484344>>2];g=x[o>>2];h=b&65535;if(of(q,g)>>>0<=h>>>0){break t}h=_b(q,h);if(Pb(x[h>>2],x[h+4>>2])){break t}h=0;break s}h=1}while(1){u:{v:{w:{if(!h){b=65534;w[d+1074446>>1]=65534;break w}h=b&65535;if(of(q,g)>>>0>h>>>0){break v}x:{y:{z:{if((h|0)==65535){g=Yb(a,k);break z}g=Yb(a,k);if(Mc(x[g>>2],x[g+4>>2])>>>0>(c&65535)>>>0){break y}}b=z[g+28>>1];A:{if(b){h=x[g>>2];q=Mc(h,x[g+4>>2]);break A}b=0;h=x[g>>2];q=Mc(h,x[g+4>>2]);a=c&65535;if(q>>>0<a>>>0|!a){break A}while(1){a=c;c=a-1|0;k=c&65535;if(!k){break A}if(z[bc(h,k)>>1]!=65535){continue}break}b=a}w[d+1074448>>1]=b;x[d+480208>>2]=x[d+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=q>>>0){break q}if(z[bc(h,a)>>1]==65534){b=b+1|0;w[m>>1]=b;continue}break}if(!oq(g,a)){break q}c=z[d+1074448>>1];a=x[d+484360>>2];k=y[i|0];g=Yb(a,k);break x}c=c+1|0;w[m>>1]=c}b=65535;h=c&65535;if(Mc(x[g>>2],x[g+4>>2])>>>0>h>>>0){b=z[bc(x[Yb(a,k)>>2],h)>>1]}w[d+1074446>>1]=b;q=x[d+484344>>2];g=x[o>>2];h=b&65535;if(of(q,g)>>>0<=h>>>0){break w}h=_b(q,h);if(!Pb(x[h>>2],x[h+4>>2])){break u}}h=1;continue}w[d+1074450>>1]=c;break r}h=0;continue}}a=b&65535;if(!oe(q,g,a)){break k}b=x[l>>2];if(b>>>0>=A[_b(q,a)+12>>2]){x[l>>2]=0;b=0}if(x[d+480208>>2]&32?x[d+480272>>2]!=-1:0){break n}if(!dt(f,z[m>>1],b,Bp(J+16|0,e),y[J+24|0])){break n}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Wn(f,1);dt(f,z[m>>1],x[l>>2],Bp(J+16|0,e),y[J+24|0]);break n}if(!(y[C|0]&64)){break q}b=0;if(WN(f,m,l)){break o}x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;c=jj(x[d+484360>>2],x[H>>2])-1|0;a=y[i|0];if((c|0)>(a|0)){break p}zi(t,0)}Wn(f,1);break k}zi(t,a+1&255);Wn(f,1)}while(1){if((b|0)==256){gM(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Yb(x[d+484360>>2],y[i|0]);h=x[c>>2];if(Mc(h,x[c+4>>2])>>>0>a>>>0){Wa=d,Xa=z[bc(h,a)>>1],w[Wa+1074446>>1]=Xa}dt(f,a,b,Bp(J+16|0,e),y[J+24|0]);if(!oe(x[d+484344>>2],x[o>>2],z[d+1074446>>1])){break k}}else{_n((D(b,872)+d|0)+1074992|0,d,b&65535,134217728);b=b+1|0;continue}break}}EN(d,s,(x[d+480208>>2]&32)>>>5|0);a=_b(x[d+484344>>2],z[d+1074446>>1]);c=ed(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);h=e+D(z[u>>1],872)|0;b=e;while(1){if((b|0)==(h|0)){B:{C:{a=x[d+484344>>2];b=z[d+1074446>>1];if(zm(a,x[d+484348>>2],b)){a=_b(a,b);c=x[a+16>>2];b=x[a+20>>2];if(AN(c,b)){break C}}x[d+1074408>>2]=x[d+480216>>2];b=x[d+480220>>2];break B}x[d+1074408>>2]=c}x[d+1074412>>2]=b;if(!y[J+24|0]){break m}b=x[d+1074416>>2];x[d+1074392>>2]=b;continue l}Ab(J+16|0,n,82);D:{if(!Bb(x[x[J+16>>2]>>2],x[J+20>>2])|y[b+805|0]!=1){break D}a=y[c+3|0];if((a|0)!=2&(a|0)!=3){break D}Wa=b,Xa=Qg(d,y[b+800|0],w[b+772>>1],x[b+704>>2]),x[Wa+700>>2]=Xa}Ab(J+16|0,n,91);E:{if(!Bb(x[x[J+16>>2]>>2],x[J+20>>2])){break E}if(Uc(y[c|0])){break E}a=y[b+788|0];if(!Uc(a)|y[b+791|0]!=19){break E}g=y[b+793|0];if((g&240)!=208|A[d+1074416>>2]>(g&15)>>>0){break E}Wa=b,Xa=Qg(d,a,w[b+772>>1],0),x[Wa+700>>2]=Xa}Ab(J+16|0,n,92);F:{if(!Bb(x[x[J+16>>2]>>2],x[J+20>>2])){break F}Ab(J+8|0,n,5);if(Bb(x[x[J+8>>2]>>2],x[J+12>>2])|x[d+1074416>>2]!=1|y[b+791|0]!=17){break F}v[J+16|0]=1;Wa=d,Xa=D(y[_e(J+16|0,b+793|0)|0],1e4),x[Wa+1074420>>2]=Xa}a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[b+788|0]=a;v[b+789|0]=a>>>8;v[b+790|0]=a>>>16;v[b+791|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[b+792|0]=a;v[b+793|0]=a>>>8;a=x[b+676>>2];x[b+20>>2]=x[b+672>>2];x[b+24>>2]=a;x[b+88>>2]=x[b+88>>2]&-393217;Ab(J+16|0,n,21);if(!Bb(x[x[J+16>>2]>>2],x[J+20>>2])){v[b+831|0]=0}x[b+860>>2]=0;v[b+805|0]=0;c=c+6|0;b=b+872|0;continue}}break}c=x[d+1074416>>2];if(!c){x[d+1074416>>2]=1;c=1}a=x[d+480208>>2];e=x[d+1074392>>2];G:{H:{if(e){b=a&-4097;x[d+480208>>2]=b;h=x[d+480180>>2];if(h&1048580|!(a&2097152)&(h|0)==1){break G}if(Rk(s)>>>0<=e>>>0){break G}if(!((e>>>0)%(x[d+1074400>>2]+c>>>0)|0)){break H}break G}b=a&-528385}x[d+480208>>2]=b|4096}i=hb-16|0;hb=i;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;G=d+480180|0;Z=d+1075809|0;t=d+1074312|0;C=d+480208|0;K=d+1074376|0;Q=d+480188|0;W=d+480210|0;Y=d+480190|0;M=d+480192|0;while(1){if(z[Q>>1]<=r>>>0){I:{if(!(y[C+1|0]&16)){break I}if(!tN(d,K,Yb(x[d+484360>>2],y[d+484376|0]),1)){break I}x[C>>2]=x[C>>2]|524288}hb=i+16|0}else{o=D(r,872)+d|0;n=o+1075785|0;g=y[n|0];k=o+1075784|0;u=y[k|0];R=o+1075781|0;e=y[R|0];a=x[d+1074392>>2];c=x[d+1074400>>2];h=x[d+1074416>>2];N=o+1075782|0;f=y[N|0];l=o+1075783|0;q=y[l|0];b=at(f,q);m=o+1075843|0;v[m|0]=x[C>>2]>>>12&1|y[m|0]&254;h=(a>>>0)%(c+h>>>0)|0;L=o+1075780|0;c=y[L|0];J:{K:{L:{if((c|0)==252){s=Sj(f,u);H=Sj(q,g);c=252;if((e-1&255)>>>0>249){break L}a=x[(D(e,160)+d|0)+906140>>2];if(!a){break L}mb[x[x[a>>2]+44>>2]](a,s,E(E(H>>>0)/E(999)));c=y[L|0]}if((c&255)==251){break K}}if(B[o+1075852>>2]==E(0)|q){break J}}s=x[C>>2]&4096;M:{if(!s){a=y[o+1075862|0];break M}a=y[R|0];v[o+1075862|0]=a}if((a-1&255)>>>0>249){break J}H=(D(a&255,160)+d|0)+906140|0;a=x[H>>2];if(!a){break J}N:{if(!s){c=z[o+1075860>>1];break N}c=Oy(y[N|0],y[k|0]);w[o+1075860>>1]=c;V=E(E(Oy(y[l|0],y[n|0])>>>0)/E(999));B[o+1075856>>2]=V;Wa=o+1075852|0,Ya=E(E(V-E(mb[x[x[a>>2]+48>>2]](a,c)))/E(Rk(K)>>>0)),B[Wa>>2]=Ya;a=x[H>>2]}n=c;c=(x[d+1074392>>2]+1|0)==(Rk(K)|0);mb[x[x[a>>2]+(c?44:104)>>2]](a,n,B[(c?o+1075856|0:o+1075852|0)>>2]);c=y[L|0]}n=o+1074992|0;if(iN(c&255)){b=hb-16|0;hb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Sh(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[n+788|0]=c;v[n+789|0]=c>>>8;v[n+790|0]=c>>>16;v[n+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[n+792|0]=a;v[n+793|0]=a>>>8;hb=b+16|0;q=0;u=0;f=0;e=0;g=0;b=0}O:{if(!(y[C+1|0]&16)){PM(d,n);break O}if(!e){break O}x[o+1075752>>2]=0}P:{Q:{if((q|0)==33){Ab(i+8|0,t,30);c=g>>>4|0;Fy(d,r&65535,c+(g&15)|0,Bb(x[x[i+8>>2]>>2],x[i+12>>2]));break Q}c=0;if((q-19&255)>>>0>1){break Q}R:{if(!(!(x[G>>2]&16777250)|g)){g=y[o+1075825|0];break R}v[o+1075825|0]=g}a=g&240;if((a|0)==208){a=g&15;if(!a){a=x[G>>2];if(a&16777248){c=1;break Q}if((a|0)!=2){break Q}break P}if(a>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Ab(i+8|0,t,14);c=a;if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Q}if(!e){break P}v[o+1075795|0]=e;break P}c=a;break Q}if(!(y[C+1|0]&16)|(a|0)!=224){break Q}a=x[G>>2];if(x[d+1074396>>2]?a&16777250:0){break Q}s=a&2;a=g&15;if(a?0:s){break Q}x[d+1074396>>2]=a+1}a=c;c=x[G>>2]==16&(q|0)==19&(g&240)==208;H=c?0:a;S:{if(!H|y[L|0]!=255|y[N|0]!=2){break S}Ab(i+8|0,t,74);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break S}v[N|0]=0}X=g&15;a=x[d+1074392>>2];Ab(i+8|0,t,72);T:{if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){l=0;if(H>>>0>=A[d+1074416>>2]){break T}}Ab(i+8|0,t,88);l=(h|0)==(H|0)|(a|0)==(H|0);if(!(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!H)){break T}l=(a|0)==(H|0)}Ab(i+8|0,t,44);g=c?X|144:g;U:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){a=y[m|0];break U}a=y[m|0]&-2|(h|0)==(H|0)}v[m|0]=a&253|(l?2:0);Ab(i+8|0,t,66);h=(!H|Bb(x[x[i+8>>2]>>2],x[i+12>>2])^1)&b;V:{W:{X:{if(!(x[d+1074392>>2]|(!(y[W|0]&32)|!e))){x[o+1075652>>2]=0;if(l){b=y[L|0];break X}if(!pi(x[n+8>>2],x[n+12>>2])){break V}v[o+1075795|0]=e;if(z[Y>>1]<e>>>0){break V}a=D(e,104)+d|0;x[o+1075680>>2]=z[a+484410>>1];w[o+1075764>>1]=v[a+484417|0];break V}if(!l){break V}b=y[L|0];if(!e){break W}}v[o+1075795|0]=e}Y:{Z:{a=b&255;if(!Uc(a)){break Z}Ab(i+8|0,t,67);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Z}c=w[o+1075762>>1];_:{if(!e|h){break _}k=Ty(d,a,e);if(!k){break _}c=v[_j(d,k)+36|0]}b=(a+c|0)-132>>>0>=4294967176?b:0;break Y}if(!(x[G>>2]&25165856)){break Y}c=z[M>>1];if(!c){break Y}if(a){a=Uc(a)}else{a=1}if(!a){break Y}a=e;$:{if(!a){a=y[o+1075796|0];if(!a){break $}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=c>>>0:0){break Y}b=0}e=0}if(!((q|0)!=25|g)){Ab(i+8|0,t,55);a=Bb(x[x[i+8>>2]>>2],x[i+12>>2]);e=a?0:e;b=a?0:b}Ab(i+8|0,t,65);c=(e|0)!=0;a=b&255;s=!a;aa=Bb(x[x[i+8>>2]>>2],x[i+12>>2]);O=1;aa:{if(x[G>>2]&16777248){break aa}Ab(i+8|0,t,107);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break aa}Ab(i,t,85);O=0;if(!Bb(x[x[i>>2]>>2],x[i+4>>2])){break aa}if(pi(x[n+8>>2],x[n+12>>2])){break aa}O=1;k=x[o+1075096>>2];if(!k){break aa}O=Td(x[k>>2],x[k+20>>2])^1}k=c&s;s=c&aa;ba:{ca:{da:{ea:{fa:{ga:{if(!(x[G>>2]&1048580)){break ga}ha:{if((a|0)!=255){break ha}if(!(!((f|0)==1|e)&(q|0)!=13)){Ab(i+8|0,t,55);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break ha}}c=x[o+1075648>>2];if(v[c+60|0]&1?c:0){break ha}x[o+1075680>>2]=0;a=o+1075080|0;x[a>>2]=x[a>>2]|2097152;ia:{if(!(x[C>>2]&4096)){break ia}Ab(i+8|0,t,86);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break ia}x[a>>2]=x[a>>2]|4096}e=0;b=0;a=0;c=0;k=1;if(s){break ca}break ba}Ab(i+8|0,t,59);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|x[C>>2]&4096){break ga}ja:{if(!a){b=y[o+1075789|0]-y[o+1075762|0]|0;break ja}if(a>>>0>250){O=0;s=1;b=0;break ja}ka:{if(e){break ka}Ab(i+8|0,t,98);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break ka}e=0;break ja}O=1;s=1}c=b;h=0;break fa}c=0;if(!k){break ea}}Ab(i+8|0,t,65);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break da}b=c;c=1}a=b;k=1;if(s){break ca}break ba}b=c;c=1;k=s}la:{ma:{if(!z[M>>1]){if(z[Y>>1]<e>>>0){break la}a=(D(e,104)+d|0)+484380|0;break ma}a=x[o+1075096>>2];if(!a){break la}}na:{if(w[a+34>>1]<0){break na}if(x[G>>2]==2){if(!Td(x[a>>2],x[a+20>>2])){break na}}x[o+1075680>>2]=z[a+30>>1]}if(!k){break la}Ip(n,z[a+28>>1],d)}a=b}Ab(i+8|0,t,71);if(!(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!e)){v[o+1075831|0]=32}oa:{if(!z[M>>1]){break oa}Ab(i+8|0,t,100);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!e){break oa}if(Uc(a&255)){break oa}b=x[C>>2];pa:{if(h){if(b&8){break pa}break oa}if(!(b&4)){break oa}}Zl(n);x[o+1075688>>2]=65536;b=o+1075080|0;x[b>>2]=x[b>>2]|2097152}if(c){Ab(i+8|0,t,11);qa:{ra:{sa:{if(!(Bb(x[x[i+8>>2]>>2],x[i+12>>2])|x[G>>2]==268435456)){b=z[M>>1];break sa}Ab(i+8|0,t,87);c=0;if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){c=pi(x[n+8>>2],x[n+12>>2])^1}b=z[M>>1];ta:{if(b){if(b>>>0<e>>>0){break ra}if(x[o+1075648>>2]!=x[((e<<2)+d|0)+900380>>2]|c){break ta}break ra}if((c^-1)&x[o+1075096>>2]==((D(e,104)+d|0)+484380|0)){break qa}}a=y[o+1075789|0]}if(!(b&65535)){break qa}}if(!(x[G>>2]&1048588)){break qa}Zl(n);v[o+1075810|0]=0;x[o+1075748>>2]=0;x[o+1075688>>2]=65536;b=o+1075080|0;x[b>>2]=x[b>>2]&-2101249|2097152;Ab(i+8|0,t,86);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break qa}x[b>>2]=x[b>>2]&-2049}e=O?e:0}k=a&255;ua:{if(k>>>0<251){break ua}Ab(i+8|0,t,50);va:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!e){break va}b=Ty(d,y[o+1075791|0],e);if(!b){break va}b=D(b,104)+d|0;if(w[b+484414>>1]<0){break va}x[o+1075680>>2]=z[b+484410>>1]}Ab(i+8|0,t,100);if(Wa=Bb(x[x[i+8>>2]>>2],x[i+12>>2]),Xa=0,Za=x[C>>2]&4,Za?Wa:Xa){break ua}e=0}b=Uc(k);if(b){v[o+1075794|0]=a;v[o+1075791|0]=a;if(!h){QM(d,r&65535,e,k,0)}iP(n)}wa:{xa:{ya:{za:{Aa:{if(e){c=o+1075096|0;s=x[c>>2];Ap(d,n,e,h,1,1);a=x[c>>2];Ba:{if(!a|!(y[a+35|0]&2)){break Ba}O=x[d+1298300>>2];if(!wd(O)){break Ba}lz(O,r&65535,a+68|0)}Ca:{Da:{if(x[G>>2]==1){if(!h){break Da}Ab(i+8|0,t,85);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Da}break Ca}Ab(i+8|0,t,50);if((b|Bb(x[x[i+8>>2]>>2],x[i+12>>2])^1)!=1){break Ca}}v[o+1075795|0]=0}Ab(i+8|0,t,42);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!b|(s|0)==x[c>>2]){break za}break Aa}if(x[G>>2]&16777248){a=0;if(b&(s|0)!=x[c>>2]){break ya}}Ab(i+8|0,t,107);Ea:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|(!(b^1|h)|(s|0)==x[c>>2])){break Ea}a=o+1075068|0;if(A[a>>2]>=A[n+4>>2]){break Ea}x[a>>2]=0;break za}Ab(i+8|0,t,85);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break za}if(!pi(x[n+8>>2],x[n+12>>2])){break Aa}break za}if(!k){a=h;break wa}c=0;s=o+1075795|0;a=y[s|0];if(!(!a|b^1)){Ap(d,n,a,h,!(x[o+1075096>>2]?1:x[o+1075648>>2]),!(x[G>>2]&1048580));v[s|0]=0;c=1}a=h;break xa}x[n>>2]=0;x[n+4>>2]=0}a=h}c=0;if(!k){break wa}}b=x[o+1075096>>2];Fa:{if(!b|!(y[b+35|0]&2)){break Fa}h=x[d+1298300>>2];if(!wd(h)){break Fa}if(!c){if(RM(h,r&65535)){break Fa}}lz(h,r&65535,b+68|0)}b=r&65535;$s(d,n,k,a,!(x[G>>2]&1048580),0,b);yN(x[G>>2],z[Q>>1],K,b);if(!(!a|(!(x[G>>2]&1048580)|!e))){c=o+1075080|0;x[c>>2]=x[c>>2]|2097152;Zl(n);v[o+1075810|0]=0;x[o+1075748>>2]=0}if(!(x[o+1075080>>2]&512)){break wa}if(!wd(x[d+1298300>>2])){break wa}if(k>>>0<=253){if((k|0)!=253){break wa}Ab(i+8|0,t,99);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break wa}}Ab(i+8|0,t,110);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){mz(x[d+1298300>>2],b,0,1,0)}Tj(x[d+1298300>>2],b)}Ga:{Ha:{switch(f-1|0){case 0:u=u>>>0>=64?64:u;x[o+1075680>>2]=u<<2;b=o+1075080|0;x[b>>2]=x[b>>2]|2097152;break Ga;case 1:break Ha;default:break Ga}}$l(d,n,u,6)}if(z[M>>1]){OM(d,r&65535)}h=a}Ab(i+8|0,t,77);if(Wa=Bb(x[x[i+8>>2]>>2],x[i+12>>2]),Xa=0,Za=x[((r<<5)+d|0)+480280>>2]&1024,Za?Wa:Xa){break P}a=x[d+1074392>>2];Ab(i+8|0,t,75);c=a>>>0>=H>>>0;Ia:{Ja:{Ka:{La:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!H){break La}b=x[d+1074392>>2];if(!b){break Ka}c=1;if((b|0)!=(H|0)){break La}c=!y[R|0]&(f|0)!=11}a=f;if(!c|a>>>0<3){break Ka}if((a|0)==11){a=i+8|0;Sy(a,d,y[L+3|0],y[L+4|0],H);a=y[Ue(a)|0];Nn(d,n,z[i+8>>1]);if(a){break Ja}f=11;break Ka}Ab(i+8|0,t,62);Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{if(!(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|u)){u=0;f=0;Ta:{switch(a-8|0){case 0:break Sa;case 1:break Ta;default:break Ka}}if(y[C+1|0]&16){break Ka}x[o+1075684>>2]=0;break Ka}Ab(i+8|0,t,41);Ua:{if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ua}if(u){v[o+1075826|0]=u;break Ua}u=y[o+1075826|0]}Va:{switch(a-3|0){case 0:case 1:Wa:{Xa:{if(u){break Xa}Ab(i+8|0,t,41);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Xa}u=y[o+1075826|0];if(u){break Wa}u=0;break Ka}v[o+1075826|0]=u}Tn(d,n,((a|0)==3?u<<4:u)&255);break Ka;case 2:if((H|0)!=x[d+1074392>>2]){Ab(i+8|0,t,41);f=5;if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ka}}Ab(i+8|0,t,41);Sn(d,n,u,Bb(x[x[i+8>>2]>>2],x[i+12>>2]));f=5;break Ka;case 3:if((H|0)!=x[d+1074392>>2]){Ab(i+8|0,t,41);f=6;if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ka}}Ab(i+8|0,t,41);Rn(d,n,u,Bb(x[x[i+8>>2]>>2],x[i+12>>2]));f=6;break Ka;case 11:break Ma;case 12:break Na;case 10:break Oa;case 9:break Pa;case 7:break Qa;case 6:break Ra;case 5:break Sa;case 4:break Va;default:break Ka}}Ab(i+8|0,t,53);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){v[o+1075815|0]=u&15;f=7;break Ka}Qk(n,u<<4);f=7;break Ka}Qk(n,u);f=8;break Ka}Ab(i+8|0,t,62);Ey(d,n,u,Bb(x[x[i+8>>2]>>2],x[i+12>>2])^1);f=9;break Ka}Ab(i+8|0,t,62);Ey(d,n,u<<4&240,Bb(x[x[i+8>>2]>>2],x[i+12>>2])^1);f=10;break Ka}f=12;Ab(i+8|0,t,12);NM(d,r&65535,u<<2&252,Bb(x[x[i+8>>2]>>2],x[i+12>>2]));break Ka}Ab(i+8|0,t,12);MM(d,r&65535,u<<2&252,Bb(x[x[i+8>>2]>>2],x[i+12>>2]));f=13;break Ka}f=15;if(!l){break Ka}a=x[o+1075096>>2];if(!a|u>>>0>9){break Ka}Ya:{if(!u){e=x[o+1075656>>2];break Ya}e=x[Cb(a+68|0,u-1|0)>>2];x[o+1075656>>2]=e}Un(d,n,e);break Ka}f=14;if(u>>>0>1){break Ka}v[m|0]=y[m|0]&247|!u<<3}e=g;Za:{_a:{$a:{ab:{switch(q-1|0){case 12:if(!(y[C+1|0]&16)){break Ja}a=D(r,872)+d|0;x[a+1075680>>2]=g>>>0>=64?256:g<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ja;case 1:if(!g){e=0;if(v[G|0]&1){break Ia}}NM(d,r&65535,g,0);break Ja;case 2:if(!g){e=0;if(v[G|0]&1){break Ia}}MM(d,r&65535,g,0);break Ja;case 10:if(!g){e=0;if(x[G>>2]==1){break Ia}}Tn(d,n,g);break Ja;case 3:Nn(d,n,g);break Ja;case 5:if(!(!g&x[G>>2]==1)){Tn(d,n,g)}Nn(d,n,0);break Ja;case 4:Qk(n,g);break Ja;case 6:if(!(!g&x[G>>2]==1)){Tn(d,n,g)}Qk(n,0);break Ja;case 15:if(!(y[C+1|0]&16)){break Ja}break Za;case 16:Ab(i+8|0,t,5);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!(y[C+1|0]&16)){break Ja}if(g){break Za}break Ja}e=Qn(d,z[d+1074446>>1],x[d+1074424>>2],r&65535,0);bb:{if(!(x[d+480180>>2]&16777250)){break bb}if(e){v[(D(r,872)+d|0)+1075827|0]=e;break bb}e=y[(D(r,872)+d|0)+1075827|0]}x[i+8>>2]=D(e,1e4);xc(i+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=hb-16|0;hb=a;c=x[i+8>>2];x[a+8>>2]=c;b=x[d+8>>2];cb:{if(c>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){c=x[d+480208>>2];Ab(a,d+1074312|0,92);if((Bb(x[x[a>>2]>>2],x[a+4>>2])|0)==((c&4096)>>>12|0)){break cb}x[a>>2]=D(x[b+24>>2],1e4);Wa=d+1074420|0,Xa=x[Hb(a+8|0,a)>>2],x[Wa>>2]=Xa;break cb}if(y[d+480209|0]&16){break cb}h=d+1074420|0;c=(c>>>0)/1e4|0;f=D(c&15,1e4);x[h>>2]=x[h>>2]+((c&240)==16?f:0-f|0);c=x[b+20>>2];b=x[b+24>>2];Ab(a,d+1074312|0,8);Eo(h,D(c,1e4),Bb(x[x[a>>2]>>2],x[a+4>>2])?255e4:D(b,1e4))}hb=a+16|0;break Ia;case 9:if(!l|x[G>>2]==4&h){break Ja}xN(d,n,r&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ja;case 43:if(!l){break Ja}b=Wia(x[(D(r,872)+d|0)+1075068>>2],0,g,0);a=lb;f=a>>>8|0;Un(d,n,Vc((a&255)<<24|b>>>8,f));break Ja;case 0:if(x[d+1074392>>2]){break Ja}a=D(r,872)+d|0;db:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break db}a=x[a+1075648>>2];if(a){if(mj(y[a+31|0])){break db}}Ab(i+8|0,t,13);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break db}if(x[G>>2]&16777248){break Ja}}if(!g){e=0;if(y[G|0]&5){break Ia}v[(D(r,872)+d|0)+1075797|0]=1;break Ia}a=D(r,872)+d|0;v[a+1075798|0]=g;v[a+1075797|0]=1;break Ja;case 14:if(x[G>>2]&1048580){g=g&240?g:y[(D(r,872)+d|0)+1075799|0]&240|g;if(!(g&15)){g=y[(D(r,872)+d|0)+1075799|0]&15|g}e=g|256}else{e=g}Ab(i+8|0,t,23);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){b=d;c=r&65535;if(e){v[(D(r,872)+d|0)+1075799|0]=e;a=e}else{a=y[(D(r,872)+d|0)+1075799|0]}Dy(b,c,a&255,(f|0)==15?u+1|0:0);break Ia}eb:{if(e){v[(D(r,872)+d|0)+1075799|0]=e;break eb}e=y[(D(r,872)+d|0)+1075799|0]}Dy(d,r&65535,e,(f|0)==15?u+1|0:0);break Ia;case 17:if(!(y[C+1|0]&16)){break Ja}Ab(i+8|0,t,22);fb:{gb:{if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!g){g=0;break gb}if(y[C|0]&4){break gb}a=g&240?g-16|0:g;g=a-((a&15)!=0)|0;v[(D(r,872)+d|0)+1075832|0]=g;break gb}Ab(i+8|0,t,71);if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break fb}}a=(D(r,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(r,872)+d|0;v[a+1075797|0]=18;if(!g){e=0;break Ia}v[a+1075832|0]=g;break Ja;case 22:if(!(y[C+1|0]&16)){break Ja}a=x[G>>2];e=g<<!(a&59593760);if(e>>>0<=128){x[d+1074456>>2]=e<<1;break Ia}if(a&16777250){break Ia}x[d+1074456>>2]=256;break Ia;case 23:Ab(i+8|0,t,9);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){LM(d,g,(D(r,872)+d|0)+1075809|0);break Ja}LM(d,g,Z);break Ja;case 8:if(!(y[C+1|0]&16)){break Ja}$l(d,n,g,8);break Ja;case 28:Ey(d,n,g,1);break Ja;case 7:oN(n,g);break Ja;case 25:pN(d,n,g);break Ja;case 18:h=d+1074376|0;c=r&65535;e=D(c,872);b=(h+e|0)+616|0;a=g&15;hb:{ib:{switch(g>>>4|0){case 0:b=(g&1)<<14;c=z[d+480188>>1];a=0;while(1){if((a|0)==(c|0)){break hb}e=(D(a,872)+d|0)+1075080|0;x[e>>2]=(b|x[e>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(a){By(d,b,a);break hb}if(!(x[d+480180>>2]&1048580)){break hb}By(d,b,0);break hb;case 2:if(a){Ay(d,b,a);break hb}if(!(x[d+480180>>2]&1048580)){break hb}Ay(d,b,0);break hb;case 3:b=(d+e|0)+1075080|0;x[b>>2]=x[b>>2]&-1048577|((a|0)!=0)<<20;break hb;case 4:v[(d+e|0)+1075814|0]=g&7;break hb;case 5:if(!(y[d+480209|0]&16)){break hb}e=x[d+480180>>2];if(e&69206025){b=D(c,872)+d|0;w[b+1075764>>1]=a<<28>>24;e=b+1075692|0;if(!x[e>>2]){break hb}if(!Uc(y[b+1075780|0])){break hb}b=D(c,872)+d|0;Wa=e,Xa=Qg(d,y[b+1075789|0],a<<28>>24,x[b+1075696>>2]),x[Wa>>2]=Xa;break hb}b=Uc(y[(D(c,872)+d|0)+1075780|0]);if((e|0)==16){if(!b){break hb}b=D(c,872)+d|0;e=x[b+1075096>>2];if(!e){break hb}v[e+37|0]=a;w[b+1075764>>1]=a;b=b+1075692|0;if(!x[b>>2]){break hb}e=b;b=D(c,872)+d|0;Wa=e,Xa=Qg(d,y[b+1075789|0],a,x[b+1075696>>2]),x[Wa>>2]=Xa;break hb}if(!b){break hb}a=D(c,872)+d|0;b=(g<<4^-128)<<24>>24;w[a+1075764>>1]=b;c=a+1075692|0;if(!x[c>>2]){break hb}Wa=c,Xa=Qg(d,y[a+1075789|0],b,x[a+1075696>>2]),x[Wa>>2]=Xa;break hb;case 6:if(!(y[d+480209|0]&16)){break hb}Ry(d,h,b,a);break hb;case 7:v[(d+e|0)+1075817|0]=g&7;break hb;case 8:if(!(y[d+480209|0]&16)){break hb}$l(d,b,a,4);break hb;case 9:Dy(d,c,a,0);break hb;case 10:if(a){Sn(d,b,a,0);break hb}if(!(x[d+480180>>2]&1048580)){break hb}Sn(d,b,0,0);break hb;case 11:if(a){Rn(d,b,a,0);break hb}if(!(x[d+480180>>2]&1048580)){break hb}Rn(d,b,0,0);break hb;case 12:Fy(d,c,a,0);break hb;case 15:break ib;default:break hb}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break hb}PM(d,b);break hb}v[(D(c,872)+d|0)+1075836|0]=a}break Ja;case 19:KM(d,r&65535,g);break Ja;case 24:Ab(i+8|0,t,55);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){if(x[d+1074392>>2]!=(g|0)){break Ja}a=x[(D(r,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break _a}if(!(!(y[R|0]|y[N|0])|g)){a=(D(r,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break _a}a=D(r,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break _a}if(y[C+1|0]&16){break _a}break Ja;case 27:a=(g&240)-16>>>4|0;if(a>>>0>9){break Ja}if(!(1<<a&880)){if(!a){break $a}if((a|0)!=1){break Ja}JM(d,n,g&15);break Ja}Ab(i+8|0,t,58);if(Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ja}KM(d,r&65535,g);break Ja;case 34:case 35:if(!(y[C+1|0]&16)&(q|0)!=36){break Ja}b=r&65535;uN(d,b,K,(q|0)==36);a=Ts(d,x[n+88>>2],x[n+656>>2]);if(!a){break Ja}mb[x[x[a>>2]+80>>2]](a,w[n+774>>1]+32768>>>2|0,b);break Ja;case 20:if(!(y[C+1|0]&16)|g>>>0>64){break Ja}a=D(r,872)+d|0;x[a+1075740>>2]=g;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ja;case 21:h=x[G>>2];e=x[C>>2];a=g;jb:{if(a){v[n+816|0]=a;break jb}a=y[n+816|0]}b=a&15;c=a&255;kb:{lb:{if(!((b|0)!=15|c>>>0<16)){if(!(e&4096)){break kb}a=c>>>4|0;break lb}e=e&4096;f=c&240;if(!(!b|(f|0)!=240)){if(!e){break kb}a=0-b|0;break lb}if(e){break kb}if(b){a=0-b|0;if(!(h&25690144)|!f){break lb}break kb}if((a&255)>>>0<16){break kb}a=c>>>4|0}Wa=n,Xa=Xb(a+x[n+748>>2]|0,0,64),x[Wa+748>>2]=Xa}break Ja;case 26:nN(n,g);break Ja;case 29:if(!(y[C+1|0]&16)){break Ja}a=D(r,872)+d|0;x[a+1075716>>2]=g;Ab(i+8|0,t,60);if(Wa=0,Xa=Bb(x[x[i+8>>2]>>2],x[i+12>>2]),Za=y[a+1075722|0]&4,Za?Wa:Xa){break Ja}a=D(r,872)+d|0;x[a+1075732>>2]=g;x[a+1075724>>2]=g;break Ja;case 11:sN(d,K,r&65535);break Ja;case 13:a=qN(d,K,r&65535,g);if((a|0)==-1){break Ja}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ja}w[d+1074444>>1]=z[d+1074448>>1];break Ja;case 37:case 38:case 39:case 40:b=(q|0)==38|(q|0)==40;c=(q&254)==40;mb:{nb:{ob:{if(y[d+480209|0]&16){a=y[n+848|0];e=g&240;if(e){a=e|a&15;v[n+848|0]=a}e=g&15;if(e){a=e|a&-16;v[n+848|0]=a}v[n+849|0]=(a&240)>>>4;if(x[d+480180>>2]!=32768){break mb}break ob}if(x[d+480180>>2]==32768){break ob}a=y[n+849|0]-1|0;v[n+849|0]=a;if(a&255){break mb}a=y[n+848|0];break nb}a=y[n+848|0];if((a&240)==16){break nb}if(!(y[d+480209|0]&16)){break mb}}v[n+849|0]=(a&240)>>>4;a=a&15;a=b?a:0-a|0;b=x[n+656>>2];pb:{if(nj(b)){x[n+852>>2]=x[n+852>>2]+D(a,x[x[b+44>>2]+36>>2]);break pb}Wa=n,Xa=Qg(d,Ss(d,x[n+700>>2],w[n+772>>1],x[n+704>>2])+a|0,w[n+772>>1],x[n+704>>2]),x[Wa+700>>2]=Xa}if(!c){break mb}x[n>>2]=0;x[n+4>>2]=0}break Ja;case 41:wN(n,g);break Ja;case 42:if(x[d+1074392>>2]|X>>>0>1|g>>>0>47){break Ja}a=(g&240)==16;c=a?z[d+480188>>1]-1|0:r;e=a?0:r;a=((X|0)==1)<<26;while(1){b=e&65535;if(b>>>0>(c&65535)>>>0){break Ja}h=((b<<5)+d|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;b=(D(b,872)+d|0)+1075080|0;x[b>>2]=a|x[b>>2]&-67108865;e=e+1|0;continue};case 44:break ab;default:break Ia}}vN(n,g);break Ja}IM(d,n,g&15);break Ja}Pn(d,n);break Ja}CN(d,K,g)}e=g}Ab(i+8|0,t,78);if(!(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])|!e)){kN(n,e&255)}a=y[R|0];if(!a){break P}v[o+1075796|0]=a}r=r+1|0;continue}break}a=1;break j}a=0}hb=J+32|0;L=!x[d+1074420>>2]|a^1;qb:{if(L){break qb}a=zN(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Wd(z[d+480188>>1],1,31);rb:{if(Rd(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}n=((D(x[d+480228>>2],a)<<1&-128)>>>0)/y[(b>>>1|0)+31984|0]|0;break rb}n=x[d+480228>>2]}w[d+480212>>1]=0;o=d+1074312|0;M=d+1074365|0;u=d+480180|0;H=d+480210|0;O=d+480209|0;R=d+1074366|0;N=d+1074364|0;X=d+1074360|0;s=0;while(1){if((s|0)==256){b=x[d+24608>>2];h=z[d+480212>>1];if(b>>>0>h>>>0){break qb}e=hb-16|0;hb=e;x[e+8>>2]=d;a=d+1074478|0;c=a;h=a+(h<<1)|0;sb:{b=a+(b<<1)|0;if((a|0)==(b|0)){break sb}tb:{a=b-c|0;if((a|0)<3){break tb}f=a>>1;a=f-2>>>1|0;while(1){if((a|0)<0){break tb}iy(c,x[e+8>>2],f,c+(a<<1)|0);a=a-1|0;continue}}f=b-c>>1;a=b;while(1){if((a|0)==(h|0)){a=b-c>>1;while(1){if((a|0)>1){b=b-2|0;jy(c,b);a=a-1|0;iy(c,x[e+8>>2],a,c);continue}break}break sb}if(sp(x[e+8>>2],z[a>>1],z[c>>1])){jy(a,c);iy(c,x[e+8>>2],f,c)}a=a+2|0;continue}}hb=e+16|0}else{l=D(s,872)+d|0;i=l+1075080|0;ub:{if(!(x[i>>2]&4096)|(x[l+1075016>>2]|(x[l+1075012>>2]|x[l+1075688>>2]))){break ub}Ab(j+16|0,o,64);if(Bb(x[x[j+16>>2]>>2],x[j+20>>2])){break ub}x[l+1075068>>2]=0;a=l+1075084|0;x[a>>2]=0;x[a+4>>2]=0}a=z[d+480188>>1];c=x[i>>2];vb:{if(x[l+1075068>>2]|a>>>0>s>>>0?c&1024:1){if(a>>>0>s>>>0){YL(d,s&65535)}w[l+1075834>>1]=0;break vb}e=0;K=l+1075712|0;x[K>>2]=0;G=l+1075672|0;x[G>>2]=0;t=l+1075e3|0;b=t;x[b>>2]=0;x[b+4>>2]=0;x[l+1075092>>2]=0;x[j+44>>2]=1065353216;w[j+42>>1]=0;C=l+1075648|0;J=x[C>>2];x[j+36>>2]=0;b=0;r=l+1075692|0;b=x[r>>2]?x[l+1075068>>2]!=0:b;g=l+1074992|0;wb:{xb:{yb:{if(a>>>0<=s>>>0){break yb}if(y[((s<<5)+d|0)+480288|0]){break xb}if(!J){break yb}e=y[J+34|0]!=0}if((b|e)!=1){break wb}}x[j+8>>2]=x[l+1075680>>2];x[j+32>>2]=x[l+1075744>>2];Ab(j+16|0,o,28);c=j+8|0;a=Bb(x[x[j+16>>2]>>2],x[j+20>>2])?j+32|0:c;e=hb-16|0;hb=e;h=d+1074312|0;Ab(e+8|0,h,28);zb:{if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){x[a>>2]=x[a>>2]+w[g+776>>1];ge(a,0,64);break zb}Ab(e+8|0,h,1);h=w[g+776>>1];if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){x[a>>2]=h+x[a>>2];ge(a,0,256);break zb}x[g+688>>2]=h+x[g+688>>2];ge(g+688|0,0,256);x[a>>2]=x[g+688>>2];w[g+776>>1]=0}hb=e+16|0;a=hb-16|0;hb=a;e=d+1074312|0;Ab(a+8|0,e,28);Ab:{Bb:{if(!Bb(x[x[a+8>>2]>>2],x[a+12>>2])){Ab(a,e,1);if(!Bb(x[x[a>>2]>>2],x[a+4>>2])){break Bb}}x[g+684>>2]=x[g+692>>2]+w[g+778>>1];ge(g+684|0,0,256);break Ab}x[g+692>>2]=x[g+692>>2]+w[g+778>>1];ge(g+692|0,0,256);w[g+778>>1]=0;x[g+684>>2]=x[g+692>>2]}hb=a+16|0;e=hb-16|0;hb=e;Cb:{if(!(y[g+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break Cb}Db:{if(x[c>>2]<=0){Ab(e+8|0,d+1074312|0,21);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break Db}}q=5;if(!(x[d+480180>>2]&5)){Ab(e+8|0,d+1074312|0,21);q=Bb(x[x[e+8>>2]>>2],x[e+12>>2])?5:6}a=my(d,y[g+825|0],y[g+820|0]);Eb:{if((y[g+825|0]&3)!=1){break Eb}Ab(e+8|0,d+1074312|0,89);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break Eb}a=y[g+819|0];f=y[g+820|0];h=f<<2&124;a=(!(y[g+90|0]&2)|y[d+480209|0]&16?a:y[g+823|0]+a|0)&32?h^127:h;a=f&32?0-a|0:a}if(x[d+480180>>2]!=131072){a=x[c>>2]+((D(y[g+827|0],a)|0)/(1<<q)|0)|0}else{h=64-a|0;a=x[c>>2];a=((D(y[g+827|0],D(h,a))|0)/-8192|0)+a|0}x[c>>2]=a}a=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|a&4?a&4096:0){break Cb}Ab(e+8|0,d+1074312|0,21);a=y[g+826|0];h=y[g+820|0];f=Bb(x[x[e+8>>2]>>2],x[e+12>>2]);v[g+820|0]=(f?a<<2:h)+(f?h:a)}hb=e+16|0;h=s&65535;m=hb-16|0;hb=m;a=d+1074312|0;Ab(m+8|0,a,71);Fb:{if(Bb(x[x[m+8>>2]>>2],x[m+12>>2])){a=(D(h,872)+d|0)+1075831|0;e=v[a|0];if((e|0)>=0){break Fb}if(!(y[d+480209|0]&16|y[(D(h,872)+d|0)+1075797|0]!=18)){Gb:{Hb:{if((e&-33)!=-64){e=e&223;if((e|0)!=128){break Hb}e=y[(D(h,872)+d|0)+1075832|0]>>>4|-64;break Gb}e=y[(D(h,872)+d|0)+1075832|0]&15|-128;break Gb}e=e-1|0}v[a|0]=e;a=(D(h,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}if((e&224)!=128){break Fb}x[c>>2]=0;break Fb}if(y[(D(h,872)+d|0)+1075797|0]!=18){break Fb}Ab(m+8|0,a,22);Ib:{if(Bb(x[x[m+8>>2]>>2],x[m+12>>2])){k=D(h,872)+d|0;a=k+1075831|0;f=y[a|0];e=f<<24>>24;if(!((e|0)>=0|!x[k+1075068>>2])){Jb:{Kb:{if((f|0)!=192){if((f|0)!=128){break Kb}e=y[(D(h,872)+d|0)+1075832|0]>>>4|-64;break Jb}e=y[(D(h,872)+d|0)+1075832|0]&15|-128;break Jb}e=e-1|0}v[a|0]=e}if((e&192)!=128){break Ib}x[c>>2]=0;break Ib}a=y[(D(h,872)+d|0)+1075832|0];f=a>>>4|0;k=f+(a&15)|0;q=x[d+480180>>2];if(!(y[d+480208|0]&4?0:q&16777248)){k=k+2|0;f=f+1|0}a=(D(h,872)+d|0)+1075831|0;e=y[a|0];if(!(q&4)){e=(e&255)>>>0<k>>>0?e:0;if((e&255)>>>0>=f>>>0){x[c>>2]=0}v[a|0]=e+1;break Ib}Lb:{if(y[d+480209|0]&16){e=e&255?e-1|0:0;break Lb}v[a|0]=e+1}if(((e&255)>>>0)%(k>>>0)>>>0<f>>>0){break Ib}x[c>>2]=0}a=(D(h,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|2097152}a=D(h,872)+d|0;Mb:{if(y[a+1075797|0]!=18){break Mb}e=x[a+1075648>>2];if(!e){break Mb}a=y[e+34|0];if(!a|y[e+15|0]&2){break Mb}f=D(h,872)+d|0;if(x[f+1075080>>2]&134218752){break Mb}f=f+1075791|0;k=y[f|0];if(!Uc(k)){break Mb}a=x[(D(a,160)+d|0)+906140>>2];if(!a){break Mb}k=mb[x[x[a>>2]+100>>2]](a,k,h)|0;q=x[c>>2];if(!(!k|q)){mb[x[x[a>>2]+92>>2]](a,e,y[f|0]+255|0,0,h);break Mb}if(k|!q){break Mb}mb[x[x[a>>2]+92>>2]](a,e,y[f|0],z[(D(h,872)+d|0)+1075680>>1],h)}hb=m+16|0;ge(c,0,256);x[j+8>>2]=x[j+8>>2]<<6;Nb:{if(J){Ab(j+16|0,o,31);if(Bb(x[x[j+16>>2]>>2],x[j+20>>2])){Ys(d,g)}c=j+8|0;a=hb-16|0;hb=a;Ob:{if(!ky(d,g,0)){break Ob}f=x[g+656>>2];k=d+1074312|0;Ab(a+8|0,k,31);Pb:{if(Bb(x[x[a+8>>2]>>2],x[a+12>>2])){e=x[g+724>>2];if(e){break Pb}break Ob}e=x[g+724>>2]}Ab(a+8|0,k,31);q=e-Bb(x[x[a+8>>2]>>2],x[a+12>>2])|0;e=Hp(f+48|0,q,256,64);Q=y[f+65|0];Qb:{if((Q|0)==255){break Qb}m=w[g+728>>1];if((m|0)==-1){break Qb}Q=Cb(x[f+48>>2],Q);f=y[Q+2|0];Q=z[Q>>1];Ab(a+8|0,k,94);k=f<<2;e=(q|0)==(Q|0)?k:e;if(Bb(x[x[a+8>>2]>>2],x[a+12>>2])){e=m+(e-k<<1)|0;break Qb}if(!f){e=0;break Qb}e=(D(e,m)|0)/(k|0)|0}Wa=c,Xa=(D(Xb(e,0,512),x[c>>2])|0)/256|0,x[Wa>>2]=Xa}hb=a+16|0;dN(g,c);a=hb-16|0;hb=a;Rb:{if(!ky(d,g,1)){break Rb}c=x[g+656>>2];f=d+1074312|0;Ab(a+8|0,f,31);Sb:{if(Bb(x[x[a+8>>2]>>2],x[a+12>>2])){e=x[g+732>>2];if(e){break Sb}break Rb}e=x[g+732>>2]}Ab(a+8|0,f,31);e=Hp(c+68|0,e-Bb(x[x[a+8>>2]>>2],x[a+12>>2])|0,64,64)-32|0;c=x[g+684>>2];Wa=g,Xa=Xb(((D(e,(c|0)>127?256-c|0:c)|0)/32|0)+c|0,0,256),x[Wa+684>>2]=Xa}hb=a+16|0;Ab(j+16|0,o,115);if(Bb(x[x[j+16>>2]>>2],x[j+20>>2])){break Nb}c=y[l+1075789|0];if(!c){break Nb}a=x[C>>2];if(!a|!y[a+26|0]){break Nb}gN(l+1075676|0,c,y[a+26|0],y[a+27|0]);break Nb}if(!(y[i+1|0]&16)){break Nb}x[l+1075688>>2]=0;x[j+8>>2]=0}Tb:{if(y[l+1075843|0]&8){q=0;x[j+8>>2]=0;break Tb}q=x[j+8>>2];if(!q){q=0;break Tb}if(y[i+3|0]&8){x[G>>2]=0;break Tb}if(Rd(y[M|0])){a=D(x[j+32>>2],x[l+1075740>>2]);c=a;e=a>>31;a=q<<8;Wa=G,Xa=Hc(Xia(Wia(c,e,a,a>>31),lb,1048576,0),lb),x[Wa>>2]=Xa;break Tb}a=D(x[j+32>>2],x[l+1075740>>2]);c=a;e=a>>31;a=D(x[d+1074456>>2],q);Wa=G,Xa=Hc(Xia(Wia(c,e,a,a>>31),lb,1048576,0),lb),x[Wa>>2]=Xa}x[K>>2]=q;Ub:{Vb:{q=x[r>>2];if(!(x[u>>2]==2|(q|0)>=x[d+480260>>2])){if(!gj(d)){break Vb}q=x[r>>2]}if((q|0)<x[d+480264>>2]){break Ub}Ab(j+16|0,o,113);if(!Bb(x[x[j+16>>2]>>2],x[j+20>>2])){break Ub}if(gj(d)){break Ub}x[r>>2]=x[d+480264>>2];break Ub}x[r>>2]=x[d+480260>>2]}Ab(j+16|0,o,73);a=x[r>>2];x[j+36>>2]=a;Wb:{if((x[i>>2]&1572864)!=1572864){break Wb}c=x[d+480208>>2];if(c&2097152){if(!at(y[l+1075782|0],y[l+1075783|0])|c&4096){break Wb}}c=l+1075704|0;Xb:{if((a|0)==x[c>>2]){q=x[l+1075708>>2];break Xb}x[c>>2]=a;e=a;a=l+1075764|0;c=l+1075696|0;q=Qg(d,Ss(d,e,w[a>>1],x[c>>2]),w[a>>1],x[c>>2]);x[l+1075708>>2]=q}x[j+36>>2]=q}k=hb-16|0;hb=k;Q=D(h,872)+d|0;Y=Q+1075648|0;a=x[Y>>2];Yb:{if(!a){break Yb}c=y[a+34|0];if(!c|y[a+15|0]&2|(!x[(D(c,160)+d|0)+906140>>2]|x[(D(h,872)+d|0)+1075080>>2]&134218752)){break Yb}e=D(h,872)+d|0;Z=e+1075783|0;q=y[Z|0];c=0;f=y[e+1075791|0];if(Uc(f)){c=y[Kb(a+108|0,f-1|0)|0]}m=e+1075780|0;Zb:{_b:{if((q|0)==1){f=0;$b:{ac:{switch((A[d+1074392>>2]%3|0)-1|0){case 0:f=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break $b;case 1:break ac;default:break $b}}f=y[(D(h,872)+d|0)+1075798|0]&15}a=D(h,872)+d|0;v[a+1075793|0]=c;if(y[a+1075792|0]==(c+f|0)){break Zb}a=c;if(!(y[d+480209|0]&16)){break _b}a=c;if(!Uc(y[m|0])){break _b}break Zb}f=0;if(y[m|0]){break Zb}a=D(h,872)+d|0;if(!y[a+1075792|0]){break Zb}a=y[a+1075793|0]}Xl(d,h,(a&255)+f|0,z[(D(h,872)+d|0)+1075680>>1])}a=(D(h,872)+d|0)+1075792|0;e=y[a|0];bc:{if(!e){if(!(y[d+480209|0]&16)|(q|0)!=1){break bc}if(Uc(y[m|0])){break bc}e=c;if(!Uc(e)){break bc}}Xl(d,h,(e&255)+255|0,0)}v[a|0]=y[Z|0]==1?y[(D(h,872)+d|0)+1075793|0]+f|0:0}cc:{if(y[Q+1075797|0]!=1){break cc}if(nj(x[Y>>2])){f=0;dc:{ec:{fc:{switch(A[d+1074392>>2]%3|0){case 1:f=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break ec;case 0:break ec;case 2:break fc;default:break dc}}f=y[(D(h,872)+d|0)+1075798|0]&15}w[j+42>>1]=f}a=(D(h,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break cc}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(h,872)+d|0;c=Qg(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[j+36>>2]=c;x[a+1075692>>2]=c}a=d+1074312|0;Ab(k+8|0,a,13);if(Bb(x[x[k+8>>2]>>2],x[k+12>>2])){f=y[(D(h,872)+d|0)+1075798|0];if(!f){break cc}a=65536;gc:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:a=x[((f&240)<<2)+37136>>2];break;default:break gc}}h=gj(d);c=x[j+36>>2];e=c;c=e>>31;if(h){a=Wia(e,c,a,a>>31)+32768|0;h=lb;a=Xia(a,a>>>0<32768?h+1|0:h,65536,0)}else{h=(a|0)/2|0;f=h>>31;m=c<<16|e>>>16;e=e<<16;c=e+h|0;m=f+m|0;a=Xia(c,c>>>0<e>>>0?m+1|0:m,a,a>>31)}c=lb;Wa=j,Xa=Hc(a,c),x[Wa+36>>2]=Xa;break cc}Ab(k+8|0,a,51);if(Bb(x[x[k+8>>2]>>2],x[k+12>>2])){if(y[d+480209|0]&16){break cc}hc:{ic:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break ic}if((a|0)==16){break cc}c=0;jc:{switch((a|0)%3|0){case 0:break cc;case 2:break ic;case 1:break jc;default:break hc}}c=y[(D(h,872)+d|0)+1075798|0]>>>4|0;break hc}c=y[(D(h,872)+d|0)+1075798|0]&15}e=c;a=D(h,872)+d|0;c=a+1075764|0;a=a+1075696|0;e=e+Ss(d,x[j+36>>2],w[c>>1],x[a>>2])|0;c=Qg(d,e,w[c>>1],x[a>>2]);x[j+36>>2]=c;if(e>>>0<109){break cc}x[k+8>>2]=c;Wa=k,Xa=Qg(d,109,0,x[a>>2]),x[Wa+4>>2]=Xa;Wa=j,Xa=x[Yc(k+8|0,k+4|0)>>2],x[Wa+36>>2]=Xa;break cc}f=x[d+1074392>>2];m=d+480180|0;e=x[m>>2];kc:{if((e|0)!=1){c=y[(D(h,872)+d|0)+1075789|0];break kc}c=D(h,872)+d|0;c=Ss(d,x[j+36>>2],w[c+1075764>>1],x[c+1075696>>2]);e=x[m>>2]}lc:{mc:{switch((((e&67633152?f+2|0:f)>>>0)%3|0)-1|0){case 0:c=(y[(D(h,872)+d|0)+1075798|0]>>>4|0)+c|0;break lc;case 1:break mc;default:break lc}}c=(y[(D(h,872)+d|0)+1075798|0]&15)+c|0}if(!(e&67633408|y[(D(h,872)+d|0)+1075789|0]!=(c&255))){Ab(k+8|0,a,82);if(!Bb(x[x[k+8>>2]>>2],x[k+12>>2])){break cc}}if(y[d+480210|0]&32){e=c&255;if((e|0)==85){x[j+36>>2]=2147483647;break cc}c=e>>>0>85?c-37|0:c}e=D(h,872)+d|0;f=Qg(d,c&255,w[e+1075764>>1],x[e+1075696>>2]);x[j+36>>2]=f;if(x[d+480180>>2]&71860480){x[e+1075692>>2]=f;break cc}Ab(k+8|0,a,82);if(!Bb(x[x[k+8>>2]>>2],x[k+12>>2])){break cc}v[(D(h,872)+d|0)+1075792|0]=c}hb=k+16|0;if(!(!(y[H|0]&33)|x[j+36>>2]==2147483647)){nc:{if(x[u>>2]==2){q=452;a=3424;break nc}a=D(z[l+1075764>>1]>>>4&15,24);c=z[a+32870>>1]>>>1|0;q=c>>>0<=452?452:c;a=z[a+32848>>1]<<1}ge(j+36|0,q,a);ge(r,q,a)}lN(d,g);c=x[i>>2]}oc:{if(!(c&256)|y[O|0]&64){break oc}Ab(j+16|0,o,37);if(!Bb(x[x[j+16>>2]>>2],x[j+20>>2])){break oc}x[l+1075676>>2]=128}r=s&65535;YL(d,r);pc:{if(!b){break pc}a=eN(d,g,j+36|0);if((a|0)<0|!(y[i+1|0]&2)){break pc}c=x[d+1298300>>2];if(!wd(c)){break pc}Gp(c,r,a>>>2&255,1)}qc:{if(y[l+1075782|0]!=8){break qc}rc:{sc:{a=y[l+1075783|0];switch(a-5|0){case 1:break qc;case 0:case 2:break rc;default:break sc}}if((a|0)!=26){break qc}}a=x[u>>2];if((a|0)==4){if(y[O|0]&16){break qc}a=l+1075811|0;v[a|0]=y[a|0]+y[l+1075815|0];break qc}if(!(a&16777248)){break qc}Qk(g,y[l+1075784|0]);XL(d,r,j+36|0,j+44|0)}XL(d,r,j+36|0,j+44|0);tc:{if(!b){break tc}x[j+32>>2]=0;c=j+36|0;f=hb-16|0;hb=f;h=x[g+104>>2];uc:{if(!h|!y[h+40|0]){break uc}m=nj(x[g+656>>2]);k=gj(d);Ab(f+8|0,d+1074312|0,21);a=k?38160:37136;e=k?37136:38160;if(!(m|!Bb(x[x[f+8>>2]>>2],x[f+12>>2])|x[d+480180>>2]==1048576)){q=y[h+41|0];if(!q){break uc}b=y[g+818|0];x[f+4>>2]=x[g+756>>2]+y[h+39|0];Vh(f+4|0,y[h+40|0]<<8);m=x[f+4>>2];v[g+818|0]=b+q;x[g+756>>2]=m;m=(m|0)/256|0;vc:{wc:{switch(y[h+38|0]-1|0){case 3:h=VL(On(d))+-64|0;break vc;case 2:h=64-(b+1>>>1|0)|0;break vc;case 1:h=(b+1>>>1|0)+-64|0;break vc;case 0:h=(b^-1)>>>1&64;break vc;default:break wc}}h=v[b+33440|0]}Vh(c,8388607);b=x[c>>2]<<8;x[c>>2]=b;Q=D(h,m);m=(Q|0)/64|0;h=m>>31;h=(h^m)-h|0;m=h&3;q=h>>>2|0;h=b>>31;xc:{yc:{if((Q|0)<=-64){a=x[(q<<2)+a>>2];a=Hc(Xia(Wia(a,a>>31,b,h),lb,65536,0),lb)-b|0;if(!m){break xc}e=k?37072:37008;break yc}a=x[e+(q<<2)>>2];a=Hc(Xia(Wia(a,a>>31,b,h),lb,65536,0),lb)-b|0;if(!m){break xc}e=k?37008:37072}k=a;a=x[(m<<2)+e>>2];a=(k+Hc(Xia(Wia(b,h,a,a>>31),lb,65536,0),lb)|0)-b|0}x[c>>2]=(a+b|0)/256;x[j+32>>2]=a&255;break uc}k=x[d+480180>>2]&16777248;b=y[h+39|0];zc:{if(!(k|b)){x[g+756>>2]=y[h+40|0]<<8;break zc}Ac:{Bc:{if(k){q=b<<1;k=x[g+756>>2];b=g+756|0;break Bc}if(y[g+89|0]&8){break Ac}k=((y[h+40|0]<<8&65280)>>>0)/(b>>>0)|0;q=x[g+756>>2];b=g+756|0}x[b>>2]=k+q}Vh(g+756|0,y[h+40|0]<<8)}b=y[g+818|0]+y[h+41|0]|0;v[g+818|0]=b;b=b<<24>>24;Cc:{Dc:{switch(y[h+38|0]-1|0){case 3:v[g+818|0]=b+1;k=v[(b&63)+33376|0];break Cc;case 2:k=(64-(b>>>1|0)&127)+-64|0;break Cc;case 1:k=((b>>>1|0)- -64&127)+-64|0;break Cc;case 0:k=(b|0)>=0?-64:64;break Cc;default:break Dc}}k=0-v[(b&255)+33440|0]|0;if(x[d+480180>>2]!=1048576){break Cc}k=(64-v[(b+-64&255)+33440|0]|0)/2<<16>>16}b=k;k=D(b,x[g+756>>2]);q=(k|0)/256|0;if(m){B[j+44>>2]=B[j+44>>2]+E(E(E(E(y[h+40|0])*E(.05000000074505806))*E(b|0))*E(.000244140625));v[g+851|0]=y[g+851|0]|64;break uc}if(x[d+480180>>2]!=4){Ec:{if((k|0)<=-256){q=0-q|0;e=q>>>8|0;b=(e<<2)+a|0;break Ec}a=e;e=q>>>8|0;b=a+(e<<2)|0}h=x[c>>2];e=x[((e<<2)+a|0)+4>>2];a=x[b>>2];a=((D(e-a|0,q>>>2&63)|0)/64|0)+a|0;a=Hc(Xia(Wia(h,h>>31,a,a>>31),lb,256,0),lb);x[c>>2]=a;x[j+32>>2]=a&255;x[c>>2]=x[c>>2]/256;break uc}x[c>>2]=x[c>>2]+((k|0)/16384|0)}hb=f+16|0;b=x[j+36>>2];if((b|0)<=x[d+480260>>2]){Ab(j+16|0,o,81);if(Bb(x[x[j+16>>2]>>2],x[j+20>>2])){x[l+1075068>>2]=0}b=x[d+480260>>2];x[j+36>>2]=b}Fc:{if(!nj(x[g+656>>2])){break Fc}a=l+1075843|0;c=y[a|0];if(!(x[d+1074392>>2]|!(c&32)?c&64:1)){break Fc}hP(g,B[j+44>>2],w[j+42>>1],d);c=a;a=y[a|0];v[c|0]=(a&64?-65:-33)&a}a=j+16|0;Uy(a,d,g,b,x[j+32>>2]);b=Fb(a);a=Wia(x[j+16>>2],x[j+20>>2],x[d+480240>>2],0);f=lb;c=Xia(a,f,65536,0);e=lb;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;x[j+16>>2]=c;a=a?0:e;x[j+20>>2]=a;x[t>>2]=c;x[t+4>>2]=a;if((x[i>>2]&134219264)!=512){break tc}if(!wd(x[d+1298300>>2])){break tc}Ab(j+8|0,o,99);Gc:{Hc:{if(Wa=Bb(x[x[j+8>>2]>>2],x[j+12>>2]),Xa=1,Za=y[i+1|0]&16,Za?Wa:Xa){a=x[u>>2];break Hc}a=x[u>>2];if((a|0)!=2){break Gc}}c=x[i>>2];h=c&2048;Ic:{if(h?(a|0)==2:0){break Ic}a=Wia(x[b>>2],0,261625,0)+66904|0;e=lb;b=Vc(Zia(a,a>>>0<66904?e+1|0:e,133808,0),lb);a=1;Jc:{if(h){break Jc}a=0;if(!(c&4096)){break Jc}a=!x[l+1075688>>2]}Ab(j+8|0,o,110);if(Wa=Bb(x[x[j+8>>2]>>2],x[j+12>>2]),Xa=0,Za=a,Za?Wa:Xa){break Ic}c=x[d+1298300>>2];Ab(j+8|0,o,95);mz(c,r,b,a,Bb(x[x[j+8>>2]>>2],x[j+12>>2]))}b=x[d+1298300>>2];a=Wia(D(x[l+1075744>>2],D(x[l+1075740>>2],x[K>>2])),0,63,0)+33554432|0;f=lb;f=a>>>0<33554432?f+1|0:f;Gp(b,r,Vc((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=l+1075676|0;h=a;c=x[a>>2];b=0;a=x[d+1298300>>2];e=Xk(a,r);Kc:{if((e|0)==255){break Kc}f=x[a>>2];if(Uj(f)){break Kc}b=Kb(Hd(a+318|0,e),10);m=x[a+4>>2];e=it(e)|192;a=y[b|0]&-49;a=(c|0)<171?a|16:a;a=(c|0)>84?a|32:a;Sg(f,m,r,e,a&255);b=(a>>>5&1)+(a<<27>>31)|0}x[h>>2]=(b<<7)+128}Lc:{a=x[C>>2];if(!a|(y[a+60|0]&7)!=1){break Lc}b=x[a+48>>2];a=x[a+52>>2];if(uc(b,a)){break Lc}b=x[WL(g,0)>>2];a=Jn(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Lc}ij(x[d+1298300>>2],r,1);Ab(j+8|0,o,109);a=x[i>>2];Wa=i,Xa=(Bb(x[x[j+8>>2]>>2],x[j+12>>2])?a:a&-4609)|4096,x[Wa>>2]=Xa;x[l+1075688>>2]=0;break tc}Ab(j+8|0,o,99);if(!Bb(x[x[j+8>>2]>>2],x[j+12>>2])|!(y[i+1|0]&16)|x[l+1075688>>2]){break tc}ij(x[d+1298300>>2],r,1);x[i>>2]=x[i>>2]&-513}Mc:{if(!J){break Mc}Ab(j+16|0,o,31);if(Bb(x[x[j+16>>2]>>2],x[j+20>>2])){break Mc}Ys(d,g)}b=x[i>>2];a=b&-65537;f=x[G>>2];m=l+1075016|0;r=l+1075012|0;q=f|(x[m>>2]|x[r>>2])?(a|b<<7&65536)^65536:a;x[i>>2]=q;G=l+1075664|0;a=G;x[a>>2]=0;x[a+4>>2]=0;h=l+1075834|0;a=y[h|0];b=a-4|0;c=a>>>0>=b>>>0?b:0;v[h|0]=c;k=l+1075835|0;a=y[k|0];b=a-4|0;a=a>>>0>=b>>>0?b:0;v[k|0]=a;Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{Vc:{b=x[l+1075096>>2];Wc:{if(!b){break Wc}e=x[b>>2];b=x[b+20>>2];if(!Td(e,b)|!x[l+1075068>>2]){break Wc}if(pi(x[g+8>>2],x[g+12>>2])){break Vc}}x[l+1075008>>2]=0;break Uc}x[l+1075008>>2]=b;if(b){break Tc}}if(!Rj(x[g+656>>2])){break Sc}b=0;if(q&6144){break Sc}}J=x[l+1075676>>2];e=(D(f,256-J|0)|0)/16384|0;e=e>>>0>=127?127:e;if(c<<24>>24<0){v[h|0]=e;W=e}else{W=c}c=e>>>1|0;if((W&255)>>>0<c>>>0){v[h|0]=c}c=(D(f,J)|0)/16384|0;e=c>>>0>=127?127:c;c=e>>>1|0;if(a<<24>>24<0){v[k|0]=e;a=e}if((a&255)>>>0<c>>>0){break Rc}break Qc}if((c&255)>>>0>=129){v[h|0]=0}b=0;c=0;if((a&255)>>>0<129){break Pc}}v[k|0]=c}if(!b){break Pc}b=128;h=x[d+24624>>2];if(h>>>0>=2){b=Xb(x[l+1075676>>2],0,256)}x[j+16>>2]=b;c=D(f,n)>>>(Rd(y[R|0])?7:8)|0;Xc:{Yc:{Zc:{switch(y[N|0]){case 0:if(!(y[d+24616|0]&16)){break Yc}case 1:if((b|0)<=127){a=c>>>1|0;c=(D(b,c)|0)/256|0;break Xc}a=(D(c,256-b|0)|0)/256|0;c=c>>>1|0;break Xc;case 3:break Zc;default:break Yc}}Vh(j+16|0,255);b=x[j+16>>2];if((b|0)<=0){a=65536}else{a=z[(0-b<<1)+39696>>1]}a=D(a,c)>>>16|0;c=D(c,z[(b<<1)+39184>>1])>>>16|0;break Xc}a=(D(c,256-b|0)|0)/256|0;c=(D(b,c)|0)/256|0}b=x[C>>2];_c:{if(b){b=y[b+14|0];if(wo(b)){break _c}}b=y[d+480268|0];if(wo(b)){break _c}b=y[d+24648|0];b=y[H|0]&128?x[d+24668>>2]?-1:b:b}f=l+1075668|0;k=l+1075786|0;v[k|0]=b;e=x[t>>2];m=x[t+4>>2];if(!(q&131072|((e|0)!=0|(m|0)!=1)|(x[l+1075748>>2]|(b&255)==255))){v[k|0]=0}b=a;a=1<<x[X>>2];x[G>>2]=(b|0)/(a|0);a=(c|0)/(a|0)|0;x[f>>2]=(q&256)>>>8|0?(h|0)==2?0-a|0:a:a;if(q&128){x[t>>2]=0-e;x[t+4>>2]=0-(((e|0)!=0)+m|0)}q=0;k=hb-16|0;hb=k;x[g+28>>2]=0;x[g+32>>2]=0;Vh(g+672|0,524287);Vh(g+676|0,524287);$c:{ad:{c=x[g+88>>2];if(!(c&65536)){b=x[g+676>>2];a=x[g+672>>2];break ad}a=x[g+20>>2];h=x[g+672>>2];bd:{if((a|0)!=(h|0)){b=x[g+24>>2];e=x[g+676>>2];break bd}b=x[g+24>>2];e=x[g+676>>2];if((b|0)==(e|0)){break ad}}c=x[d+24620>>2];e=(a|0)<(h|0)|(b|0)<(e|0);cd:{if(e){a=nt(c,x[d+24636>>2]);break cd}a=nt(c,x[d+24640>>2])}Ab(k,d+1074312|0,4);if(!(!Bb(x[x[k>>2]>>2],x[k+4>>2])|!(x[d+480180>>2]&4))){a=x[d+24620>>2];a=Wia(a,a>>31,5,0)+500|0;h=lb;a=Hc(Xia(a,a>>>0<500?h+1|0:h,1e3,0),lb)}c=x[g+656>>2];dd:{if(!c){b=a;break dd}b=a;if(!e){break dd}c=z[c+12>>1];if(c){b=(D(c,x[d+24620>>2])>>>0)/1e5|0}q=(c|0)!=0}f=b?b:1;e=x[g+672>>2];m=x[g+20>>2];r=e-m<<12;t=g;c=x[g+676>>2];b=x[g+24>>2];h=c-b<<12;if(!(y[g+90|0]&32|(!(c|e)|(!(b|m)|q)))){x[k+12>>2]=x[d+1074380>>2];ge(k+12|0,a,2048);f=x[k+12>>2]}h=(h|0)/(f|0)|0;x[t+32>>2]=h;m=(r|0)/(f|0)|0;x[g+28>>2]=m;b=c+((D(f,h)|0)/-4096|0)|0;x[g+24>>2]=b;a=e+((D(f,m)|0)/-4096|0)|0;x[g+20>>2]=a;if(h|m){x[g+100>>2]=f;c=x[g+88>>2];break $c}x[g+24>>2]=c;x[g+20>>2]=e;b=c;a=e;c=x[g+88>>2]&-65537;break $c}x[g+24>>2]=b;x[g+20>>2]=a;c=c&-65537}x[g+88>>2]=c&-2097153;x[g+40>>2]=b<<12;x[g+36>>2]=a<<12;hb=k+16|0;q=x[i>>2];if(!(q&512)){break Oc}break Nc}x[r>>2]=0;x[m>>2]=0;x[l+1075068>>2]=0;if(x[l+1075088>>2]){break Oc}if(!x[l+1075084>>2]){break Nc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=s}x[l+1075660>>2]=q}s=s+1|0;continue}break}}hb=j+48|0;if(L^1){a=x[d+480208>>2];break h}if(Rd(y[Ga|0])){b=x[d+480208>>2]|512;break i}k=0;ed:{a=x[d+24620>>2]/10|0;c=Hc(a,a>>31);if(!c){break ed}b=c>>>0>=1048576?1048576:c;x[d+1074380>>2]=b;h=z[d+480212>>1];e=d+1074376|0;while(1){if((h|0)==(k|0)){break ed}a=e+D(z[(e+(k<<1)|0)+102>>1],872)|0;f=a+1288|0;x[f>>2]=0;x[f+4>>2]=0;x[a+716>>2]=b;f=x[a+640>>2]<<12;x[a+656>>2]=f;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(b|0);x[a+648>>2]=(0-f|0)/(b|0);k=k+1|0;continue}}a=x[d+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;x[d+480208>>2]=a}if(!(a&512)){break g}Wa=d+1074392|0,Xa=Rk(Fa),x[Wa>>2]=Xa}hb=T+112|0;break f}x[T+96>>2]=512;a=x[d+1074380>>2];x[T+104>>2]=da;x[T+100>>2]=a;n=AB(T+96|0);if(x[d+24632>>2]){m=0;a=hb-48|0;hb=a;b=n<<2;while(1){if((m|0)==4){fd:{m=0;while(1){if((m|0)==4){break fd}x[(a+32|0)+(m<<2)>>2]=((m<<11)+d|0)+16396;m=m+1|0;continue}}}else{x[a+32>>2]=0;c=((m<<11)+d|0)+16396|0;Gz(c,b+c|0,a+32|0);m=m+1|0;continue}break}b=Vg(a+16|0,a+32|0,x[d+24632>>2],n);c=x[x[ma>>2]+8>>2];x[a+8>>2]=x[b+8>>2];e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;mb[c|0](ma,a);hb=a+48|0}if(Rd(Ea)){a=0;while(1){if((a|0)==4){a=Vg(T+80|0,T+96|0,x[d+24632>>2],n);b=x[x[oa>>2]+8>>2];x[T+40>>2]=x[a+8>>2];c=x[a+4>>2];x[T+32>>2]=x[a>>2];x[T+36>>2]=c;mb[b|0](oa,T+32|0)}else{x[(T+96|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}aa=0;fa=0;C=hb-48|0;hb=C;if(n){r=d+12|0;t=d+24592|0;u=d+24588|0;Jm(r,n,t,u);if(A[d+24624>>2]>=3){Jm(d+8204|0,n,d+24600|0,d+24596|0)}w[C+42>>1]=0;ta=d+1074312|0;Ia=d+24648|0;Ja=d+24596|0;Ka=d+24600|0;La=d+8204|0;G=d+397452|0;J=d+397448|0;q=d+393352|0;ua=d+397456|0;ia=d+1074376|0;Ma=d+480190|0;while(1){if(z[d+480212>>1]<=aa>>>0){Wa=d,Xa=z[Ve(d+480214|0,C+42|0)>>1],w[Wa+480214>>1]=Xa}else{h=ia+(aa<<1)|0;m=z[h+102>>1];a=D(m,872);L=a+ia|0;gd:{hd:{if(x[L+632>>2]){break hd}b=a+d|0;if(x[b+1075088>>2]){break hd}if(!x[b+1075084>>2]){break gd}}j=a+d|0;a=y[j+1075786|0]+1&255;if(a>>>0<=5){g=x[(a<<2)+27616>>2]}else{g=0}H=j+1075080|0;f=x[H>>2];id:{if(!(!(f&16777216)&y[d+24612|0]>>>5)){a=t;b=u;c=f;e=r;if(!(c&8388608)){break id}}a=J;b=G;if(!y[ua+12|0]){Jm(q,n,a,b)}v[ua+12|0]=1;m=z[h+102>>1];c=x[H>>2];e=q}h=b;b=c>>>8&A[d+24624>>2]>2;R=b?Ja:h;N=b?Ka:a;c=b?La:e;ja=ul(d,ia,m,2,1);va=(ja-1&255)>>>0>249;jd:{if(va){break jd}b=x[(D(ja,160)+d|0)+906140>>2];if(!b){break jd}a=x[b+24>>2];if(!a){break jd}R=b+36|0;N=b+40|0;if(!(v[b+28|0]&1)){Jm(a,n,N,R);x[b+28>>2]=x[b+28>>2]|1}c=a}k=L+616|0;if(y[j+1075843|0]&8){aD(k,c,n);a=j+1075084|0;x[N>>2]=x[N>>2]+x[a>>2];x[R>>2]=x[R>>2]+x[j+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break gd}O=0;e=hb-16|0;hb=e;a=C+16|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;b=e+8|0;h=d+1074312|0;Ab(b,h,33);Wa=a,Xa=Bb(x[x[e+8>>2]>>2],x[e+12>>2]),v[Wa+16|0]=Xa;Ab(b,h,116);Wa=a,Xa=Bb(x[x[e+8>>2]>>2],x[e+12>>2])^1,v[Wa+17|0]=Xa;if(x[k+16>>2]){$C(a,k);l=x[k+8>>2];m=x[k+12>>2];b=m>>31;m=(b^m)-((b>>>0>(b^l)>>>0)+b|0)|0;b=m;x[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Na=f>>>12&8|(f>>>5&2|(g|f&1));Oa=fa&65535;Pa=j+1075795|0;Qa=j+1075778|0;Ra=j+1075688|0;Sa=j+1075024|0;Ta=j+1075020|0;Ua=j+1075668|0;Va=j+1075664|0;X=j+1075088|0;Q=j+1075084|0;wa=j+1075016|0;xa=j+1075012|0;ga=j+1075096|0;Y=j+1075076|0;M=j+1075068|0;K=j+1075e3|0;ha=j+1075072|0;Z=j+1075092|0;hb=e+16|0;o=a;a=n;while(1){kd:{b=x[Z>>2];ca=b?a>>>0>b>>>0?b:a:a;x[C+8>>2]=ca;ld:{md:{if(!ca){break md}g=x[K>>2];e=x[K+4>>2];if(!(g|e)){break md}f=x[M>>2];if(!f){break md}h=x[o>>2];if(!h){break md}b=x[H>>2];m=x[ha>>2];x[L+632>>2]=h;j=x[k>>2];nd:{od:{l=m&b<<30>>31;h=x[k+4>>2];s=h;if((l|0)>(h|0)){if((e|0)<0){j=Fg(0,l<<1,j,h);x[k>>2]=j;h=lb;x[k+4>>2]=h;if(!((h|0)>=(l|0)&h>>>0<f+l>>>1>>>0)){j=0;x[k>>2]=j;h=l;x[k+4>>2]=h}pd:{if(b&4){b=b&-129;x[H>>2]=b;e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e;break pd}x[k>>2]=j;h=f-1|0;x[k+4>>2]=h}if(!(b&2)){break md}if(f>>>0>h>>>0){break nd}break md}if((h|0)>0|(h|0)>=0){break nd}h=0;break od}if(f>>>0>s>>>0){break nd}if(!(b&2)){break md}if(b&4){if(!!g&(e|0)>=0|(e|0)>0){e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e}b=b|128;x[H>>2]=b;if(y[C+33|0]){s=y[C+32|0];i=x[Y>>2]-(s+m|0)|0;h=Fg(j,h,0,f);j=lb;if(j>>>0<i>>>0){j=Fg(0,f-s|0,h,j);h=lb;break od}h=m;j=0;break od}h=1-((j|0)!=0)|0;j=0-j|0;i=(f<<1)-(h+s|0)|0;s=j;x[k>>2]=j;W=0;h=W|i;x[k+4>>2]=h;if(i>>>0>m>>>0&f>>>0>i>>>0){break nd}x[C+44>>2]=y[C+32|0]+1;j=s;h=W|f-x[Hb(M,C+44|0)>>2];break od}if((e|0)<0){e=0-(((g|0)!=0)+e|0)|0;g=0-g|0;x[K>>2]=g;x[K+4>>2]=e}Rb(k,0,l-f|0);b=x[H>>2]|8192;x[H>>2]=b;j=x[k>>2];h=x[k+4>>2];break nd}x[k>>2]=j;x[k+4>>2]=h}W=h;qd:{if((h|0)<(l|0)){if((e|h)<0){break md}x[C+44>>2]=ca;f=g;m=e;break qd}f=x[M>>2];if(f>>>0<W>>>0|(!!g&(e|0)>=0|(e|0)>0)&(f|0)==(W|0)){break md}x[C+44>>2]=ca;f=e>>31;m=f;i=f^g;f=i-f|0;m=(e^m)-((i>>>0<m>>>0)+m|0)|0}s=f;i=m;xc(C+8|0,x[C+28>>2]);f=x[ha>>2];ya=f+16|0;za=x[C+8>>2];Hf(j,h,$e(g,e,za-1|0),lb);m=lb;Aa=f>>>0>W>>>0;if(!(!Aa&W>>>0<ya>>>0)){b=b&-8193;x[H>>2]=b}rd:{sd:{ka=x[C+20>>2];td:{if(ka){f=x[C+24>>2];if(f>>>0<=W>>>0){ud:{if((e|0)<0){g=0;e=f;break ud}g=j;e=h;j=0;h=x[Y>>2]}Wa=C,Xa=Fo(Fg(Fg(j,h,g,e),lb,1,0),lb,s,i)+1|0,x[Wa+44>>2]=Xa;x[L+632>>2]=ka;break rd}if(!(!(b&8192)|Aa|W>>>0>=ya>>>0)){Wa=C,Xa=Fo(Fg(Fg(0,l+16|0,j,h),lb,1,0),lb,s,i)+1|0,x[Wa+44>>2]=Xa;Wa=L,Xa=D(x[Y>>2]-l|0,lk(z[x[ga>>2]+34>>1]))+ka|0,x[Wa+632>>2]=Xa;break rd}if(!g&(e|0)<=0|(e|0)<0){break td}if(ca>>>0<2|f>>>0>m>>>0){break sd}Wa=C,Xa=Fo(Fg(Fg(0,f,j,h),lb,1,0),lb,s,i)+1|0,x[Wa+44>>2]=Xa;break rd}if((e|0)>0|(e|0)>=0){break sd}}if((l|0)<=(m|0)){break rd}Wa=C,Xa=Fo(Fg(Fg(j,h,0,l),lb,1,0),lb,s,i)+1|0,x[Wa+44>>2]=Xa;break rd}b=x[M>>2];if((b|0)>(m|0)){break rd}Wa=C,Xa=Fo(Fg(Fg(0,b,j,h),lb,1,0),lb,s,i)+1|0,x[Wa+44>>2]=Xa}Eo(C+44|0,1,za);h=x[C+44>>2];if((h|0)>0){break ld}}x[L+632>>2]=0;x[M>>2]=0;x[k>>2]=0;x[k+4>>2]=0;x[Z>>2]=0;aD(k,c,a);x[N>>2]=x[N>>2]+x[Q>>2];x[R>>2]=x[R>>2]+x[X>>2];x[X>>2]=0;x[Q>>2]=0;x[H>>2]=x[H>>2]&-129;break kd}vd:{wd:{if(A[d+24608>>2]>Oa>>>0){b=4;if(x[Z>>2]){break wd}b=0;if(x[wa>>2]|x[xa>>2]){break wd}}Rb(k,$e(x[K>>2],x[K+4>>2],h),lb);O=0;x[X>>2]=0;x[Q>>2]=0;c=(h<<3)+c|0;break vd}e=(h<<3)+c|0;f=e-8|0;x[Q>>2]=0-x[f>>2];g=e-4|0;x[X>>2]=0-x[g>>2];mb[x[((b|Na)<<2)+27232>>2]](k,Ia,c,h);x[Q>>2]=x[Q>>2]+x[f>>2];x[X>>2]=x[X>>2]+x[g>>2];O=1;c=e}b=x[Z>>2];xd:{if(!b){break xd}if(b>>>0<=h>>>0){x[Z>>2]=0;x[xa>>2]=x[Va>>2];x[wa>>2]=x[Ua>>2];x[Ta>>2]=0;x[Sa>>2]=0;if(x[Ra>>2]|!(y[H+1|0]&16)){break xd}x[M>>2]=0;x[L+632>>2]=0;break xd}x[Z>>2]=b-h}f=0;m=0;b=x[k+4>>2];m=b>>>0>=A[Y>>2]?(y[H|0]&2)>>>1|0:m;e=b;b=x[M>>2];f=e>>>0<b>>>0|(!b|y[H|0]&2)?f:!z[Qa>>1];a=a-h|0;Ab(C+8|0,ta,85);yd:{zd:{Ad:{if(!Bb(x[x[C+8>>2]>>2],x[C+12>>2])){break Ad}b=y[Pa|0];if(!b){break Ad}if(b>>>0<=z[Ma>>1]){break zd}}b=0;break yd}g=x[ga>>2];e=D(b,104)+d|0;h=e+484380|0;b=(g|0)!=(h|0);if((g|0)==(h|0)|(f|m)!=1){break yd}x[ga>>2]=h;x[L+632>>2]=x[e+484400>>2];b=z[e+484414>>1];x[H>>2]=b|x[H>>2]&-768;h=b<<30>>31;b=x[e+484388>>2];x[M>>2]=h&b;e=x[e+484384>>2];x[ha>>2]=e;x[Y>>2]=b;x[k+4>>2]=e;$C(o,k);if(!x[L+632>>2]){break kd}if((a|0)>0){continue}break kd}Bd:{if(!m|b){break Bd}Ab(C+8|0,ta,83);if(!Bb(x[x[C+8>>2]>>2],x[C+12>>2])|x[ha>>2]){break Bd}x[k>>2]=x[k>>2];x[k+4>>2]=0;b=x[x[ga>>2]+8>>2];x[M>>2]=b;x[Y>>2]=b}if((a|0)>0){continue}}break}x[L+632>>2]=x[o>>2];fa=O+fa|0;w[C+42>>1]=fa;if(!O|va){break gd}a=x[(D(ja,160)+d|0)+906140>>2];if(!a){break gd}mb[x[x[a>>2]+148>>2]](a)}aa=aa+1|0;continue}break}}hb=C+48|0;o=x[d+1298300>>2];if(wd(o)){a=_;b=n;c=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=hb-16|0;hb=k;Cd:{if(!y[o+534|0]){break Cd}h=Wia(c,0,6169,0);c=lb;e=c>>>16|0;q=Vc((c&65535)<<16|h>>>16,e);while(1){if(!b){break Cd}g=x[o>>2];h=x[g>>2];c=x[g+4>>2];while(1){if((c|0)>=(h|0)){x[g+8>>2]=x[g+12>>2];h=0;j=0;m=0;c=hb-16|0;hb=c;while(1){if((m|0)==18){e=(h|0)>=32767?32767:h;w[g+12>>1]=(e|0)<=-32768?-32768:e;e=(j|0)>=32767?32767:j;w[g+14>>1]=(e|0)<=-32768?-32768:e;w[g+3832>>1]=z[g+3832>>1]+1;e=(z[g+3834>>1]+1>>>0)%13440|0;w[g+3834>>1]=e;e=e>>>0<6720?e:13440-e|0;w[g+3836>>1]=e>>>8;if(!y[g+3843|0]){w[g+3836>>1]=e>>>10}e=z[g+3838>>1]+1|0;w[g+3838>>1]=e;if((e&65535)>>>0>=1024){w[g+3838>>1]=0;w[g+3840>>1]=z[g+3840>>1]+1&7}hb=c+16|0}else{f=g+D(m,44)|0;Dd:{if(!y[f+56|0]){w[c+12>>1]=0;w[c+14>>1]=0;break Dd}l=x[f+32>>2];e=z[l+3840>>1];if(e&3){l=(z[f+36>>1]>>>7&7)>>>(y[l+3844|0]^1)>>>(e&1)<<z[f+38>>1];e=e&4?0-l|0:l}else{e=0}l=x[f+52>>2];Ed:{if(l){t=z[l+32>>1];r=z[f+48>>1];l=Zf(x[f+16>>2],x[f+40>>2],e<<16>>16,0,w[f+46>>1]);s=x[f+40>>2];i=x[f+20>>2];if(!t){if(!r){e=e<<16>>16;l=Zf(i,s,e,l,0);l=Zf(x[f+24>>2],x[f+40>>2],e,l,0);e=Zf(x[f+28>>2],x[f+40>>2],e,l,0);break Ed}e=e<<16>>16;s=Zf(i,s,e,0,0);s=Zf(x[f+24>>2],x[f+40>>2],e,s,0);e=Zf(x[f+28>>2],x[f+40>>2],e,s,0)+l|0;break Ed}if(!r){e=e<<16>>16;l=Zf(i,s,e,l,0);s=Zf(x[f+24>>2],x[f+40>>2],e,0,0);e=Zf(x[f+28>>2],x[f+40>>2],e,s,0)+l|0;break Ed}e=e<<16>>16;s=Zf(i,s,e,0,0);e=(Zf(x[f+24>>2],x[f+40>>2],e,s,0)+l|0)+Zf(x[f+28>>2],x[f+40>>2],e,0,0)|0;break Ed}r=z[f+48>>1];e=e<<16>>16;l=Zf(x[f+16>>2],x[f+40>>2],e,0,w[f+46>>1]);s=x[f+40>>2];i=x[f+20>>2];if(!r){e=Zf(i,s,e,l,0);break Ed}e=Zf(i,s,e,0,0)+l|0}w[c+14>>1]=y[f+57|0]?e:0;w[c+12>>1]=y[f+58|0]?e:0}m=m+1|0;j=w[c+12>>1]+j|0;h=w[c+14>>1]+h|0;continue}break}h=x[g>>2];c=x[g+4>>2]-h|0;x[g+4>>2]=c;continue}break}e=h-c|0;w[k+14>>1]=(D(w[g+12>>1],c)+D(e,w[g+8>>1])|0)/(h|0);w[k+12>>1]=(D(w[g+14>>1],c)+D(e,w[g+10>>1])|0)/(h|0);x[g+4>>2]=c+49716;x[a>>2]=x[a>>2]+D(q,w[k+14>>1]);x[a+4>>2]=x[a+4>>2]+D(q,w[k+12>>1]);a=a+8|0;b=b-1|0;continue}}hb=k+16|0}a=y[I+12|0];if(a|x[I+16>>2]){if(!a){Jm($,n,sa,ra)}a=x[I>>2];b=x[I+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[I+98>>1]=c;w[I+96>>1]=c;c=x[I+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;h=e+127>>>3|0;w[I+49946>>1]=h;e=e+255>>>4|0;w[I+49944>>1]=e;w[I+49942>>1]=e;w[I+49940>>1]=h;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;m=0;while(1){if((n|0)!=(m|0)){b=m<<3;c=b+_|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);b=b|4;c=b+_|0;x[c>>2]=x[c>>2]+D(a,x[b+$>>2]>>4);m=m+1|0;continue}break}l=I+68|0;k=0;b=w[I+84>>1];c=x[I+40>>2];g=x[I+36>>2];while(1){if((k|0)==(n|0)){x[I+40>>2]=c;x[I+36>>2]=g;h=n}else{a=(k<<3)+$|0;e=x[a>>2]>>12;g=(D(b,e-g|0)>>15)+e|0;x[a>>2]=g;e=a;a=x[a+4>>2]>>12;c=(D(b,a-c|0)>>15)+a|0;x[e+4>>2]=c;k=k+1|0;continue}break}if(h){b=$;a=h;r=x[l>>2]-1|0;s=z[l+22>>1];c=z[l+20>>1];e=w[l+26>>1];f=w[l+24>>1];i=w[l+18>>1];o=w[l+16>>1];m=x[l+4>>2];g=l+32928|0;while(1){if(a){j=fd(x[b>>2]);k=fd(x[b+4>>2]);c=fd((c<<16>>16)-j|0);s=fd((s<<16>>16)-k|0);c=Xc(fd((D(c,o)|0)/65536<<1)+j|0);s=Xc(fd((D(i,s)|0)/65536<<1)+k|0);k=g+(m<<2)|0;q=w[k>>1];j=Xc(((D(q,f)|0)/-65536|0)+c|0);m=m+1&127;t=g+(m<<2)|0;k=w[k+2>>1];u=Xc(((D(k,e)|0)/-65536|0)+s|0);w[t+2>>1]=u;w[t>>1]=j;r=r+1&8191;t=l+(r<<2)|0;Wa=t,Xa=Xc(q+((D(f,j)|0)/65536|0)|0),w[Wa+160>>1]=Xa;Wa=t,Xa=Xc(k+((D(e,u)|0)/65536|0)|0),w[Wa+162>>1]=Xa;b=b+8|0;a=a-1|0;continue}break}w[l+22>>1]=s;w[l+20>>1]=c;x[l+4>>2]=m}j=I+49892|0;J=I+33508|0;b=h;a=$;while(1){if(b){e=x[I+76>>2];f=e&4095;s=J+(f<<2)|0;c=a;f=4096-f|0;t=e-x[I+49892>>2]&4095;e=4096-t|0;e=e>>>0>f>>>0?f:e;e=b>>>0<e>>>0?b:e;g=e>>>0>=64?64:e;m=g;e=0;i=hb-32|0;hb=i;f=x[l>>2];while(1){if((e|0)==7){Fd:{q=w[l+28>>1]/8<<16>>16;Gd:while(1){if(!m){break Fd}m=m-1|0;e=0;k=0;f=0;while(1)if((e|0)==4){e=4;r=0;u=Xc((f|0)/32768|0);G=Xc((k|0)/32768|0);k=0;while(1)if((e|0)==7){e=Xc(u+((k|0)/32768|0)|0);w[s>>1]=e;x[c>>2]=D(e,q);e=Xc(G+((r|0)/32768|0)|0);w[s+2>>1]=e;x[c+4>>2]=D(e,q);c=c+8|0;s=s+4|0;continue Gd}else{f=i+(e<<2)|0;o=x[f>>2]+1&8191;x[f>>2]=o;o=l+(o<<2)|0;C=w[o+160>>1];f=l+(e<<4)|0;o=w[o+162>>1];r=(D(C,w[f+44>>1])+r|0)+D(o,w[f+46>>1])|0;k=(D(C,w[f+40>>1])+k|0)+D(o,w[f+42>>1])|0;e=e+1|0;continue}}else{o=i+(e<<2)|0;r=x[o>>2]+1&8191;x[o>>2]=r;G=k;k=l+(r<<2)|0;r=w[k+160>>1];o=l+(e<<4)|0;u=w[k+162>>1];k=(G+D(r,w[o+44>>1])|0)+D(u,w[o+46>>1])|0;f=(D(r,w[o+40>>1])+f|0)+D(u,w[o+42>>1])|0;e=e+1|0;continue}}}}else{x[i+(e<<2)>>2]=f+(x[(l+(e<<4)|0)+32>>2]^-1);e=e+1|0;continue}break}hb=i+32|0;m=J+(t<<2)|0;e=a;c=g;f=x[j+4>>2];k=j+8256|0;s=j- -64|0;i=j+24640|0;o=j+16448|0;while(1){q=f&2047;if(c){C=w[k+((f+1206&2047)<<2)>>1];H=w[(k+((f+754&2047)<<2)|0)+2>>1];G=w[(s+((f+1602&2047)<<2)|0)+2>>1];O=w[s+((f+1750&2047)<<2)>>1];r=w[m>>1];t=w[m+2>>1];u=i+((f+502&2047)<<2)|0;K=w[u>>1];L=fd(w[j+32>>1]-K|0);u=w[u+2>>1];M=fd(w[j+34>>1]-u|0);R=w[j+26>>1];N=i+((f+22&2047)<<2)|0;X=w[N>>1];Q=fd(w[j+36>>1]-X|0);Y=w[j+28>>1];N=w[N+2>>1];Z=fd(w[j+38>>1]-N|0);W=w[j+30>>1];K=Xc(fd((D(L,w[j+24>>1])|0)/65536<<1)+K|0);w[j+32>>1]=K;Wa=j,Xa=Xc(fd((D(M,R)|0)/65536<<1)+u|0),w[Wa+34>>1]=Xa;Wa=j,Xa=Xc(fd((D(Q,Y)|0)/65536<<1)+X|0),w[Wa+36>>1]=Xa;u=Xc(fd((D(Z,W)|0)/65536<<1)+N|0);w[j+38>>1]=u;K=fd((D(K,w[j+16>>1])|0)/32768|0);u=fd((D(u,w[j+22>>1])|0)/32768|0);K=fd(K+((r|0)/4<<16>>16)|0);L=fd(u+((t|0)/4<<16>>16)|0);r=w[j+8>>1];M=fd(K+((D(r,O)|0)/-65536|0)|0);t=q<<2;R=t+s|0;u=w[j+10>>1];N=fd(L+((D(u,G)|0)/-65536|0)|0);w[R+2>>1]=N;w[R>>1]=M;O=fd(O+((D(r,M)|0)/65536|0)|0);M=o+t|0;G=fd(G+((D(u,N)|0)/65536|0)|0);w[M+2>>1]=G;w[M>>1]=O;O=fd(K+O|0);K=fd(G+L|0);G=o+((f+682&2047)<<2)|0;L=w[G+2>>1];M=w[G>>1];G=fd((D(L,w[j+42>>1])+D(M,w[j+40>>1])|0)/32768|0);f=o+((f+426&2047)<<2)|0;R=w[f+2>>1];N=w[f>>1];f=fd((D(R,w[j+46>>1])+D(N,w[j+44>>1])|0)/32768|0);M=fd(fd(M+O|0)-G|0);L=fd(fd(K+L|0)-f|0);O=fd(fd(O+N|0)-G|0);K=fd(fd(K+R|0)-f|0);G=fd(G+((D(r,C)|0)/-65536|0)|0);R=k+t|0;N=fd(f+((D(u,H)|0)/-65536|0)|0);w[R+2>>1]=N;w[R>>1]=G;r=(D(r,G)|0)/65536|0;f=fd(r+C|0);t=i+t|0;u=(D(u,N)|0)/65536|0;G=fd(u+H|0);w[t+2>>1]=G;w[t>>1]=f;Wa=e,Xa=(x[e>>2]+D(fd(f+M|0),w[j+48>>1])|0)+D(fd(G+L|0),w[j+50>>1])|0,x[Wa>>2]=Xa;Wa=e,Xa=(x[e+4>>2]+D(fd(fd(r)+O|0),w[j+52>>1])|0)+D(fd(fd(u)+K|0),w[j+54>>1])|0,x[Wa+4>>2]=Xa;e=e+8|0;f=q+1|0;m=m+4|0;c=c-1|0;continue}break}x[j+4>>2]=q;x[I+76>>2]=g+x[I+76>>2]&4095;x[I+68>>2]=g+x[I+68>>2]&8191;b=b-g|0;a=(g<<3)+a|0;continue}break}x[I+68>>2]=x[I+68>>2]&8191;k=$;e=_;c=h;g=0;f=0;j=x[I+56>>2];b=x[I- -64>>2];m=x[I+52>>2];a=x[I+60>>2];while(1){if(c){g=x[k>>2];f=x[k+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+j|0;x[e+4>>2]=b+x[e+4>>2];a=a-g|0;a=(((a|0)/1024|0)-a|0)+m|0;x[e>>2]=a+x[e>>2];j=b+((b|0)/-512|0)|0;m=a+((a|0)/-512|0)|0;e=e+8|0;k=k+8|0;c=c-1|0;a=g;b=f;continue}break}x[I+64>>2]=f;x[I+60>>2]=g;x[I+56>>2]=j;x[I+52>>2]=m;a=x[I+20>>2];Hd:{if(y[I+12|0]){break Hd}a=x[I+16>>2];if(a>>>0>h>>>0){a=a-h|0;break Hd}dK(I,sa,ra);a=0}v[I+12|0]=0;x[I+16>>2]=a}if(x[d+946300>>2]){Id:{f=0;e=0;h=n<<2;s=z[d+480214>>1]!=0;Ba=B[d+1074336>>2];V=B[d+1074332>>2];while(1)if((f|0)==250){g=d+12|0;m=d+12300|0;l=d+14348|0;gv(g,m,l,n,V);a=d+1074476|0;t=y[a|0];v[a|0]=0;a=l;c=m;while(1){Jd:{Kd:{Ld:{if((e|0)!=250){i=(D(e,160)+d|0)+906300|0;k=x[i>>2];if(!k|!x[k+24>>2]){break Jd}if(!Uh(k+44|0)){break Jd}j=k;Md:{if(fv(y[i+24|0])){break Md}b=mb[x[x[k>>2]+144>>2]](k)|0;j=x[i>>2];if(b){break Md}f=0;if(y[j+28|0]&2){break Md}while(1){if((e|0)==(f|0)){break Jd}b=D(f,160);f=f+1|0;if((Hm(x[(b+d|0)+906328>>2])|0)!=(e|0)){continue}break}}b=x[k+44>>2];o=Ec(b,0);r=Ec(b,1);q=(c|0)==(o|0);c=q?m:c;b=c;a=q?l:a;f=x[i+28>>2];h=a;Nd:{if(!f){break Nd}b=c;f=Hm(f);h=a;if(f>>>0<=e>>>0){break Nd}h=a;if(f>>>0>249){break Nd}f=x[(D(f,160)+d|0)+906300>>2];h=a;if(!f){break Nd}if(!(y[j+28|0]&4)){mb[x[x[f>>2]+148>>2]](f)}h=a;if(!Uh(f+44|0)){break Nd}h=x[f+44>>2];b=Ec(h,0);h=Ec(h,1)}if(!fv(y[i+24|0])){break Kd}f=0;Od:{if(q){break Od}while(1){if((f|0)==(n|0)){break Od}q=f<<2;u=q+o|0;G=c+q|0;B[u>>2]=B[G>>2]+B[u>>2];u=q+r|0;q=a+q|0;B[u>>2]=B[q>>2]+B[u>>2];x[G>>2]=0;x[q>>2]=0;f=f+1|0;continue}}a=h;c=b;if(!(s&1)){break Kd}a=x[i>>2];if(a){mb[x[x[a>>2]+148>>2]](a)}f=Hm(x[i+28>>2]);a=e;while(1){c=f;f=c&255;if(f>>>0>249|f>>>0<=(a&255)>>>0){break Ld}q=D(f,160)+d|0;f=Hm(x[q+906328>>2]);a=c;c=x[q+906300>>2];if(!c){continue}mb[x[x[c>>2]+148>>2]](c);continue}}b=0;while(1){if((b|0)!=(n|0)){V=E(B[c>>2]*Ba);Pd:{if(E(F(V))<E(2147483648)){e=~~V;break Pd}e=-2147483648}x[g>>2]=e;V=E(B[a>>2]*Ba);Qd:{if(E(F(V))<E(2147483648)){e=~~V;break Qd}e=-2147483648}x[g+4>>2]=e;b=b+1|0;g=g+8|0;a=a+4|0;c=c+4|0;continue}break}break Id}a=h;c=b}f=0;Rd:{Sd:{q=y[i+24|0];if(!((q&2)>>>1|0)){if(!YC(q)|!(y[j+28|0]&4)){break Sd}}while(1){if((f|0)==(n|0)){break Rd}k=f<<2;i=k+b|0;B[i>>2]=B[k+o>>2]+B[i>>2];i=h+k|0;B[i>>2]=B[k+r>>2]+B[i>>2];f=f+1|0;continue}}if(t){mb[x[x[k>>2]+128>>2]](k)}mb[x[x[k>>2]+60>>2]](k,b,h,n);x[j+32>>2]=n+x[j+32>>2];if(!YC(y[i+24|0])){break Rd}if((mb[x[x[k>>2]+156>>2]](k)|0)<=0|A[j+32>>2]<x[d+24620>>2]<<2>>>0){break Rd}Td:{while(1){if((f|0)==(n|0)){break Td}k=f<<2;V=B[k+b>>2];Ud:{if(V>=E(1.1920928955078125e-7)|V<=E(-1.1920928955078125e-7)){break Ud}V=B[h+k>>2];if(V>=E(1.1920928955078125e-7)){break Ud}f=f+1|0;if(!(V<=E(-1.1920928955078125e-7))){continue}}break}x[j+32>>2]=0;break Rd}x[j+28>>2]=x[j+28>>2]|4}x[j+28>>2]=x[j+28>>2]&-3}e=e+1|0;continue}}else{g=(D(f,160)+d|0)+906300|0;a=x[g>>2];Vd:{if(!a|!x[a+24>>2]){break Vd}if(!Uh(a+44|0)){break Vd}if(!(mb[x[x[a>>2]+112>>2]](a)|0)){mb[x[x[a>>2]+108>>2]](a,1);mb[x[x[a>>2]+120>>2]](a)}c=x[a+44>>2];b=Ec(c,0);c=Ec(c,1);Wd:{if(v[a+28|0]&1){gv(x[a+24>>2],b,c,n,V);break Wd}j=a+40|0;if(x[j>>2]|x[a+36>>2]){Jm(x[a+24>>2],n,j,a+36|0);gv(x[a+24>>2],b,c,n,V);break Wd}Tb(b,0,h);Tb(c,0,h)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(fv(y[g+24|0])){break Vd}s=!(a&4)|s}f=f+1|0;continue}}}if(x[d+24624>>2]==1){b=0;while(1){if((b|0)!=(n|0)){a=(b<<3)+_|0;x[(b<<2)+_>>2]=(x[a+4>>2]+x[a>>2]|0)/2;b=b+1|0;continue}break}}if(Rd(y[Ha|0])){c=0;h=hb-16|0;hb=h;Xd:{if(!x[d+1074376>>2]){k=d+1074460|0;a=k;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Xd}a=x[d+1074456>>2];b=x[d+1074468>>2];Yd:{if((a|0)==(b|0)){e=x[d+1074460>>2];break Yd}x[d+1074468>>2]=a;e=x[d+24620>>2];g=d+1074460|0;Zd:{if((a|0)>(b|0)){e=nt(e,x[d+24636>>2]);break Zd}e=nt(e,x[d+24640>>2])}x[g>>2]=e;x[d+1074464>>2]=e;b=a}k=d+1074460|0;if((e|0)<=0){break Xd}b=(b<<12)-x[d+1074472>>2]|0;c=(b|0)/(e|0)|0;if(y[d+1074368|0]!=2){break Xd}x[h+12>>2]=50;f=x[d+1074464>>2];x[h+8>>2]=1e4/(f+1|0);g=x[Le(h+12|0,h+8|0)>>2];while(1){j=c>>31;if((g|0)>=((j^c)-j|0)){break Xd}e=e+f|0;x[k>>2]=e;c=(b|0)/(e|0)|0;continue}}_d:{$d:{switch(x[d+24624>>2]-1|0){case 0:b=0;g=(n|0)>0?n:0;j=a<<12;e=d+12|0;m=a>>31;while(1){if((b|0)==(g|0)){break _d}ae:{if(x[k>>2]>0){f=x[d+1074472>>2]+c|0;x[d+1074472>>2]=f;l=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(l,l>>31,f,f>>31),lb,1048576,0),lb),x[Wa>>2]=Xa;x[d+1074460>>2]=x[d+1074460>>2]-1;break ae}f=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(f,f>>31,a,m),lb,256,0),lb),x[Wa>>2]=Xa;x[d+1074472>>2]=j}b=b+1|0;e=e+4|0;continue};case 1:b=0;j=(n|0)>0?n:0;m=a<<12;e=d+12|0;f=a>>31;while(1){if((b|0)==(j|0)){break _d}be:{if(x[k>>2]>0){g=x[d+1074472>>2]+c|0;x[d+1074472>>2]=g;l=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(l,l>>31,g,g>>31),lb,1048576,0),lb),x[Wa>>2]=Xa;g=x[d+1074472>>2];s=g;l=g>>31;g=x[e+4>>2];Wa=e,Xa=Hc(Xia(Wia(s,l,g,g>>31),lb,1048576,0),lb),x[Wa+4>>2]=Xa;x[d+1074460>>2]=x[d+1074460>>2]-1;break be}g=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(g,g>>31,a,f),lb,256,0),lb),x[Wa>>2]=Xa;g=x[e+4>>2];Wa=e,Xa=Hc(Xia(Wia(g,g>>31,a,f),lb,256,0),lb),x[Wa+4>>2]=Xa;x[d+1074472>>2]=m}b=b+1|0;e=e+8|0;continue};case 3:break $d;default:break _d}}f=0;m=(n|0)>0?n:0;l=a<<12;e=d+8204|0;b=d+12|0;g=a>>31;while(1){if((f|0)==(m|0)){break _d}ce:{if(x[k>>2]>0){j=x[d+1074472>>2]+c|0;x[d+1074472>>2]=j;s=x[b>>2];Wa=b,Xa=Hc(Xia(Wia(s,s>>31,j,j>>31),lb,1048576,0),lb),x[Wa>>2]=Xa;j=x[d+1074472>>2];s=j;i=j>>31;j=x[b+4>>2];Wa=b,Xa=Hc(Xia(Wia(s,i,j,j>>31),lb,1048576,0),lb),x[Wa+4>>2]=Xa;j=x[d+1074472>>2];s=j;i=j>>31;j=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(s,i,j,j>>31),lb,1048576,0),lb),x[Wa>>2]=Xa;j=x[d+1074472>>2];s=j;i=j>>31;j=x[e+4>>2];Wa=e,Xa=Hc(Xia(Wia(s,i,j,j>>31),lb,1048576,0),lb),x[Wa+4>>2]=Xa;x[d+1074460>>2]=x[d+1074460>>2]-1;break ce}j=x[b>>2];Wa=b,Xa=Hc(Xia(Wia(j,j>>31,a,g),lb,256,0),lb),x[Wa>>2]=Xa;j=x[b+4>>2];Wa=b,Xa=Hc(Xia(Wia(j,j>>31,a,g),lb,256,0),lb),x[Wa+4>>2]=Xa;j=x[e>>2];Wa=e,Xa=Hc(Xia(Wia(j,j>>31,a,g),lb,256,0),lb),x[Wa>>2]=Xa;j=x[e+4>>2];Wa=e,Xa=Hc(Xia(Wia(j,j>>31,a,g),lb,256,0),lb),x[Wa+4>>2]=Xa;x[d+1074472>>2]=l}f=f+1|0;e=e+8|0;b=b+8|0;continue}}hb=h+16|0}if(x[pa>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];de:{if((a|0)==128|e>>>0<2){break de}TL(b,n,a);if(e>>>0<4){break de}TL(c,n,a)}}if(x[d+24624>>2]==4){a=n;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+_|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+qa>>2];x[b+8>>2]=x[c+qa>>2];x[b+4>>2]=x[e+_>>2];x[b>>2]=x[c+_>>2];continue}break}}if(Rd(Da)){a=Vg(T- -64|0,_,x[d+24624>>2],n);b=x[x[na>>2]+8>>2];x[T+24>>2]=x[a+8>>2];c=x[a+4>>2];x[T+16>>2]=x[a>>2];x[T+20>>2]=c;mb[b|0](na,T+16|0)}a=Vg(T+48|0,_,x[d+24624>>2],n);b=x[x[la>>2]+8>>2];x[T+8>>2]=x[a+8>>2];c=x[a+4>>2];x[T>>2]=x[a>>2];x[T+4>>2]=c;mb[b|0](la,T);x[d+1074380>>2]=x[d+1074380>>2]-n;x[d+1074376>>2]=n+x[d+1074376>>2];da=da-n|0;Ca=n+Ca|0;continue}break}hb=ba+32|0;return Ca}function kg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,m=0,o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0;k=hb-2288|0;hb=k;a:{b:{c:{d:{e:{f:{if(iv(x[c>>2])){xc(b,268435456);K=x[c+8>>2];H=k+2264|0;e=H;x[e>>2]=0;x[e+4>>2]=0;Qb(e+8|0);x[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{e=y[a+3|0];m:{n:{if((e-4&255)>>>0<=4){x[23420]=0;d=T(190,c|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}x[k+2260>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(y[a|0]){break o}break n}e=0;f=UA(a,x[b>>2]);x[23420]=0;U(191,k+96|0,c|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break k}d=k+96|0;f=x[d+4>>2];x[H>>2]=x[d>>2];x[H+4>>2]=f;rm(H+8|0,d+8|0);Oc(d);f=xe(H);d=x[H>>2];x[k+2260>>2]=d;if(!f){break g}}e=y[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!y[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=x[b>>2];if(!(g>>>0<262145|h)){e=e&255;x[k+96>>2]=((e|0)==10)<<4;h=d-x[Hb(k+96|0,k+2260|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(y[a|0]&7)){break j}}e=(h|0)<0?-1:h<<1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}x[23420]=0;Q(176,c|0,4)|0;d=x[23420];x[23420]=0;if((d|0)==1){break l}x[23420]=0;e=T(145,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[k+96>>2]=e;x[k+72>>2]=x[k+2260>>2];d=x[Hb(k+96|0,k+72|0)>>2];mg(c,8);e=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break i}a=P()|0;break a}e=8/(aq(y[a+1|0])>>>0)|0;Wia(e,0,d,0);e=lb?-1:D(e,d);break i}a=P()|0;break a}a=P()|0;break a}g=0;d=aq(y[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=y[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=D(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}xc(b,e);g=x[b>>2]}if(!g){e=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Ag(b)){e=0;x[b>>2]=0;break g}u:{if(ee(a,_c(k+96|0,8,1,0,10))){x[23420]=0;d=Q(192,c|0,k+96|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){e=0;if(!d){break u}a=x[b>>2];d=0;x[23420]=0;x[k+72>>2]=a+1>>>1;e=T(190,c|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break b}xc(k+72|0,e);a=f+16|0;b=x[b+20>>2];h=x[k+72>>2];e=h;while(1)if(e){g=k+96|0;f=d+y[g|y[a|0]&15]|0;v[b|0]=f;d=y[g|y[a|0]>>>4]+(f&255)|0;v[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=y[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}x[23420]=0;b=fa(193,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break f}zb(b);e=x[c+8>>2]-K|0;break u}if(y[a+1|0]!=1){break C}x[23420]=0;Q(176,c|0,4)|0;a=x[23420];x[23420]=0;if((a|0)==1){break f}x[23420]=0;f=T(145,c|0)|0;a=x[23420];x[23420]=0;I:{J:{K:{if((a|0)!=1){x[23420]=0;x[k+72>>2]=f;h=T(194,c|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break K}x[23420]=0;U(195,k+96|0,c|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break I}xc(k+72|0,x[k+96>>2]);g=x[k+72>>2];e=xe(k+96|0);d=z[b+34>>1];f=x[b+20>>2];b=x[b>>2];a=x[k+96>>2];x[23420]=0;ea(196,e|0,a|0,f|0,uj(b,d)|0,h<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break J}a=P()|0;Oc(k+96|0);break a}a=P()|0;break a}a=P()|0;break a}e=g+9|0;Oc(k+96|0);break u}a=P()|0;break a}if(y[a+1|0]!=1|y[a|0]!=16){break C}e=x[k+2260>>2];d=am(k+1160|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];h=hb-16|0;hb=h;x[h+12>>2]=e>>>1;x[h+8>>2]=a;d=x[Hb(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=y[f|0]+g|0;g=a+y[f+1|0]|0;w[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=h+16|0;e=d<<1;break u}if(y[a+1|0]!=1|y[a|0]>16){break C}d=x[c+8>>2];f=x[c>>2];e=0;x[23420]=0;d=W(144,f|0,d|0,8)|0;f=x[23420];x[23420]=0;if((f|0)==1){break f}if(!d){break u}x[23420]=0;d=T(145,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break f}x[k+2260>>2]=d;if(d>>>0<4){break u}x[23420]=0;U(178,k+72|0,c|0,d|0);f=x[23420];x[23420]=0;if((f|0)==1){break c}f=k+72|0;t=dr(k+96|0,f);zb(f);f=x[t>>2];x[23420]=0;d=T(197,f|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}e=d+4|0;q=y[a|0];m=(q|0)!=16;g=0;h=0;while(1){if(A[b>>2]<=h>>>0){break w}L:{if(m){break L}x[23420]=0;s=Q(152,t|0,8)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break L}a=V(30320)|0;break x}x[23420]=0;i=Q(152,t|0,1)|0;a=x[23420];x[23420]=0;if((a|0)==1){break y}x[23420]=0;f=Q(152,t|0,1)|0;a=x[23420];x[23420]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){x[23420]=0;d=Q(152,t|0,1)|0;a=x[23420];x[23420]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}x[23420]=0;a=Q(152,t|0,3)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break N}break y}x[23420]=0;d=Q(152,t|0,4)|0;a=x[23420];x[23420]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((q|0)!=16){v[x[b+20>>2]+h|0]=g;break P}w[x[b+20>>2]+(h<<1)>>1]=s&255|g<<8}h=h+1|0;continue}break}a=V(30320)|0;break x}if(y[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(y[a+1|0]==1){break A}}e=y[a|0];break z}e=y[a|0];if(e>>>0>16){break z}e=0;if(A[k+2260>>2]<5){break u}d=z[b+34>>1];f=x[b+20>>2];a=x[b>>2];x[23420]=0;e=W(198,c|0,f|0,uj(a,d)|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=y[a+1|0];if((d-1&255)>>>0>1){break Q}L=k,M=D(x[b>>2],aq(d)),x[L+96>>2]=M;xc(k+96|0,x[k+2260>>2]);a=x[b+20>>2];e=x[k+96>>2];if((g|0)==16){b=e;while(1){if(!b){break u}L=a,M=z[bc(30352,y[f|0])>>1],w[L>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}L=a,M=z[bc(30864,y[f|0])>>1],w[L>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|y[a+1|0]!=1)){R:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};hb=d+16|0;e=a;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2];x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};hb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=x[k+2260>>2];d=Yy(k- -64|0);a=x[b>>2];b=x[b+20>>2];g=y[d|0];d=hb-16|0;hb=d;x[d+12>>2]=e;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=y[f|0]+g|0;v[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}hb=d+16|0;e=a;break u}if(!(y[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=hb-16|0;hb=i;e=x[k+2260>>2];x[i+12>>2]=e;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=e-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};hb=i+16|0;e=e+g|0;break u;case 1:i=hb-16|0;hb=i;e=x[k+2260>>2];x[i+12>>2]=e;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Hb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=e-g;e=x[Hb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+f|0;a=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};hb=i+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=x[k+2260>>2];e=y[Yy(k+56|0)|0];q=hb-16|0;hb=q;x[q+12>>2]=h;g=x[b>>2];x[q+8>>2]=g;d=q+8|0;i=x[Hb(d,q+12|0)>>2];x[q+8>>2]=g;x[q+4>>2]=h-i;h=x[Hb(d,q+4|0)>>2];m=b;s=x[b+20>>2];d=e;b=i;g=f;while(1){if(b){d=y[g|0]+d|0;v[s|0]=d;s=s+2|0;g=g+1|0;b=b-1|0;continue}break}s=x[m+20>>2]+1|0;g=x[m>>2]+f|0;b=h;while(1){if(b){e=y[g|0]+e|0;v[s|0]=e;s=s+2|0;g=g+1|0;b=b-1|0;continue}break}hb=q+16|0;e=h+i|0;if(y[a+3|0]!=11){break u}a=x[m+20>>2];b=a+(x[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|y[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0];v[b+1|0]=y[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){v[b|0]=y[f|0]^128;v[b+1|0]=y[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=x[k+2260>>2];a=Yy(k+48|0);d=x[b>>2];g=x[b+20>>2];a=y[a|0];h=hb-16|0;hb=h;x[h+12>>2]=e>>>1;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=y[f|0]+a|0;v[g|0]=a;b=y[f+1|0]+b|0;v[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}hb=h+16|0;e=e<<1;break u}if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=1))){U:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=y[f|0]|y[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=(y[f|0]|y[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=x[k+2260>>2];d=am(k+40|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=hb-16|0;hb=d;x[d+12>>2]=e>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(y[f|0]+g|0)+(y[f+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|y[a+1|0]!=1|y[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<1;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>1;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=x[k+2260>>2];d=am(k+32|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=hb-16|0;hb=d;x[d+12>>2]=e>>>1;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(y[f+1|0]+g|0)+(y[f|0]<<8)|0;w[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<1;break u}h=a;if(!(y[a+2|0]|((d|0)!=16|y[a+1|0]!=3))){W:{switch(g|0){case 0:m=hb-16|0;hb=m;d=x[k+2260>>2];x[m+12>>2]=d;i=x[b>>2]<<1;x[m+8>>2]=i;a=m+8|0;g=x[Hb(a,m+12|0)>>2];x[m+8>>2]=i;x[m+4>>2]=d-g;a=x[Hb(a,m+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){w[e>>1]=y[d|0]|y[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=y[e|0]|y[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=m+16|0;e=a+h<<1;break u;case 1:m=hb-16|0;hb=m;d=x[k+2260>>2];x[m+12>>2]=d;i=x[b>>2]<<1;x[m+8>>2]=i;a=m+8|0;g=x[Hb(a,m+12|0)>>2];x[m+8>>2]=i;x[m+4>>2]=d-g;a=x[Hb(a,m+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){w[e>>1]=(y[d|0]|y[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=(y[e|0]|y[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=x[k+2260>>2];a=z[am(k+24|0)>>1];t=hb-16|0;hb=t;x[t+12>>2]=g;q=x[b>>2]<<1;x[t+8>>2]=q;d=t+8|0;e=x[Hb(d,t+12|0)>>2];x[t+8>>2]=q;x[t+4>>2]=g-e;m=x[Hb(d,t+4|0)>>2];g=b;d=x[g+20>>2];b=a;i=e>>>1|0;s=i;e=f;while(1){if(s){b=(y[e|0]+b|0)+(y[e+1|0]<<8)|0;w[d>>1]=b;d=d+4|0;e=e+2|0;s=s-1|0;continue}break}e=f+q|0;d=x[g+20>>2]+2|0;b=m>>>1|0;s=b;while(1){if(s){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[d>>1]=a;d=d+4|0;e=e+2|0;s=s-1|0;continue}break}hb=t+16|0;e=b+i<<1;if(y[h+3|0]!=11){break u}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|y[h+1|0]!=3|y[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:q=hb-16|0;hb=q;d=x[k+2260>>2];x[q+12>>2]=d;m=x[b>>2]<<1;x[q+8>>2]=m;a=q+8|0;g=x[Hb(a,q+12|0)>>2];x[q+8>>2]=m;x[q+4>>2]=d-g;i=x[Hb(a,q+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[e|0]|y[e+1|0]<<8;w[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=q+16|0;e=b+h<<1;break u;case 1:q=hb-16|0;hb=q;d=x[k+2260>>2];x[q+12>>2]=d;m=x[b>>2]<<1;x[q+8>>2]=m;a=q+8|0;g=x[Hb(a,q+12|0)>>2];x[q+8>>2]=m;x[q+4>>2]=d-g;i=x[Hb(a,q+4|0)>>2];e=x[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[e|0]|y[e+1|0]<<8;w[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};hb=q+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=x[k+2260>>2];a=z[am(k+16|0)>>1];s=hb-16|0;hb=s;x[s+12>>2]=e;q=x[b>>2]<<1;x[s+8>>2]=q;d=s+8|0;g=x[Hb(d,s+12|0)>>2];x[s+8>>2]=q;x[s+4>>2]=e-g;m=x[Hb(d,s+4|0)>>2];e=b;h=x[b+20>>2];b=a;i=g>>>1|0;d=i;g=f;while(1){if(d){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+q|0;h=x[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}hb=s+16|0;e=b+i<<1;break u}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=y[f|0]|y[f+1|0]<<8;w[b+2>>1]=y[f+2|0]|y[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=x[k+2260>>2]>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){w[b>>1]=(y[f|0]|y[f+1|0]<<8)^32768;w[b+2>>1]=(y[f+2|0]|y[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=x[k+2260>>2];a=am(k+8|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=hb-16|0;hb=h;x[h+12>>2]=e>>>2;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(y[f|0]+a|0)+(y[f+1|0]<<8)|0;w[g>>1]=a;b=(y[f+2|0]+b|0)+(y[f+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}hb=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|y[h+1|0]!=2|y[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=a<<8|a>>>8;a=y[f+2|0]|y[f+3|0]<<8;w[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<2;break u;case 1:a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=x[k+2260>>2]>>>2;x[g+8>>2]=a;d=x[Hb(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=y[f|0]|y[f+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;a=y[f+2|0]|y[f+3|0]<<8;w[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};hb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=x[k+2260>>2];a=am(k);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=hb-16|0;hb=h;x[h+12>>2]=e>>>2;x[h+8>>2]=d;b=a;e=x[Hb(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(y[f+1|0]+a|0)+(y[f|0]<<8)|0;w[g>>1]=a;b=(y[f+3|0]+b|0)+(y[f+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}hb=h+16|0;e=e<<2;break u}if(!(g|y[h+1|0]!=1|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[L>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}hb=g+16|0;e=D(b,3);break u}g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[L>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}hb=g+16|0;e=D(b,3);break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24,16),w[L>>1]=M;L=a,M=hd(y[f+4|0]<<16|y[f+3|0]<<8|y[f+5|0]<<24,16),w[L+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}hb=g+16|0;e=D(b,6);break u}g=hb-16|0;hb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24,16),w[L>>1]=M;L=a,M=hd(y[f+4|0]<<16|y[f+5|0]<<8|y[f+3|0]<<24,16),w[L+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}hb=g+16|0;e=D(b,6);break u}if(!(g|y[h+1|0]!=1|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);L=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=hd(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),16),w[L>>1]=M;L=a,M=hd(y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),16),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);L=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);L=a,M=hd(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}if(!(g|y[h+1|0]!=1|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=Qc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}i=hb-16|0;hb=i;x[i+12>>2]=b>>>3;x[i+8>>2]=d;d=x[Hb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);L=a,M=Qc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=i+16|0;e=d<<3;break u}a=e&255;if(!(g|y[h+1|0]!=2|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>4;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){L=a,M=Qc(y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24),y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24),48),w[L>>1]=M;L=a,M=Qc(y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24),y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24),48),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<4;break u}i=hb-16|0;hb=i;x[i+12>>2]=b>>>4;x[i+8>>2]=d;d=x[Hb(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);L=a,M=Qc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),w[L>>1]=M;h=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);b=h<<24|h<<8&16711680|((g<<24|h>>>8)&65280|(g<<8|h>>>24)&255);L=a,M=Qc(((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24),b,48),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=i+16|0;e=d<<4;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=xf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));_:{if(E(F(j))<E(2147483648)){d=~~j;break _}d=-2147483648}L=a,M=Xc(d),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));$:{if(E(F(j))<E(2147483648)){d=~~j;break $}d=-2147483648}L=a,M=Xc(d),w[L>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<2;break u}a=e&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=xf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));aa:{if(E(F(j))<E(2147483648)){d=~~j;break aa}d=-2147483648}L=a,M=Xc(d),w[L>>1]=M;j=xf((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ba:{if(E(F(j))<E(2147483648)){d=~~j;break ba}d=-2147483648}L=a,M=Xc(d),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}g=hb-16|0;hb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Hb(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ca:{if(E(F(j))<E(2147483648)){d=~~j;break ca}d=-2147483648}L=a,M=Xc(d),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(eg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));da:{if(E(F(j))<E(2147483648)){d=~~j;break da}d=-2147483648}L=a,M=Xc(d),w[L+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=b<<3;break u}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-32|0;hb=g;x[g+24>>2]=b>>>3;x[g+16>>2]=d;d=x[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,b|0);o=dg(+n());L=g,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=fe(C[yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(F(o)<2147483648){b=~~o;break ea}b=-2147483648}L=a,M=Xc(b),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=g+32|0;e=d<<3;break u}m=hb-32|0;hb=m;x[m+24>>2]=b>>>3;x[m+16>>2]=d;h=x[Hb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);g=b<<24|b<<8&16711680;s=b>>>8|0;i=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);d=s|i<<24;b=b>>>24|0;l(0,(s|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=dg(+n());L=m,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=fe(C[yg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(F(o)<2147483648){b=~~o;break fa}b=-2147483648}L=a,M=Xc(b),w[L>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}hb=m+32|0;e=h<<3;break u}a=e&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2260>>2];if(!y[h+2|0]){g=hb-32|0;hb=g;x[g+24>>2]=b>>>4;x[g+16>>2]=d;d=x[Hb(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,b|0);o=dg(+n());L=g,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=fe(C[yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(F(o)<2147483648){b=~~o;break ga}b=-2147483648}L=a,M=Xc(b),w[L>>1]=M;b=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);l(0,y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24));l(1,b|0);o=dg(+n());L=g,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;o=fe(C[yg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(o)<2147483648){b=~~o;break ha}b=-2147483648}L=a,M=Xc(b),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=g+32|0;e=d<<4;break u}m=hb-32|0;hb=m;x[m+24>>2]=b>>>4;x[m+16>>2]=d;h=x[Hb(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=b<<24|b<<8&16711680;i=b>>>8|0;g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);b=b>>>24|0;d=d|((i|g<<24)&65280|(b|g<<8)&255);l(0,(i|(g&255)<<24)&-16777216|(b|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|0);o=dg(+n());L=m,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=fe(C[yg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(F(o)<2147483648){b=~~o;break ia}b=-2147483648}L=a,M=Xc(b),w[L>>1]=M;b=y[f+8|0]|y[f+9|0]<<8|(y[f+10|0]<<16|y[f+11|0]<<24);g=b<<24|b<<8&16711680;s=b>>>8|0;i=y[f+12|0]|y[f+13|0]<<8|(y[f+14|0]<<16|y[f+15|0]<<24);d=s|i<<24;b=b>>>24|0;l(0,(s|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=dg(+n());L=m,N=bf(o)?o>=0?1:-1:o,C[L+24>>3]=N;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;o=fe(C[yg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(F(o)<2147483648){b=~~o;break ja}b=-2147483648}L=a,M=Xc(b),w[L+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}hb=m+32|0;e=h<<4;break u}ka:{if((a|0)==24){if((g|0)!=15|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=-2147483648;a=x[k+2260>>2];la:{if(!y[h+2|0]){s=k+96|0;e=0;t=hb-16|0;hb=t;L=t,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(t+12|0,(a>>>0)/3|0);a=f;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;ma:{na:{oa:{if((i|0)>=0){d=i;break oa}d=-2147483648;if((i|0)==-2147483648){break na}d=0-i|0}if(d>>>0<=e>>>0){break ma}}e=d}h=h-1|0;a=a+3|0;continue}else{pa:{if(!e){break pa}q=e-1|0;m=e>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break pa}d=y[f+1|0]<<16|y[f|0]<<8|y[f+2|0]<<24;i=d&-2147483648|d>>>1;d=m|d<<31;qa:{if((i|0)>0|(i|0)>=0){d=Zia(d,i,e,0);i=lb;break qa}i=Zia(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}L=h,M=hd(Hc(d,i),16),w[L>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=e}hb=t+16|0;e=D(g,3);break la}s=k+96|0;e=0;t=hb-16|0;hb=t;L=t,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(t+12|0,(a>>>0)/3|0);a=f;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;ra:{sa:{ta:{if((i|0)>=0){d=i;break ta}d=-2147483648;if((i|0)==-2147483648){break sa}d=0-i|0}if(d>>>0<=e>>>0){break ra}}e=d}h=h-1|0;a=a+3|0;continue}else{ua:{if(!e){break ua}q=e-1|0;m=e>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break ua}d=y[f+1|0]<<16|y[f+2|0]<<8|y[f|0]<<24;i=d&-2147483648|d>>>1;d=m|d<<31;va:{if((i|0)>0|(i|0)>=0){d=Zia(d,i,e,0);i=lb;break va}i=Zia(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}L=h,M=hd(Hc(d,i),16),w[L>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=e}hb=t+16|0;e=D(g,3)}if(!e){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}f=Wia(z[b+32>>1],0,a,0)+1073741824|0;a=lb;a=f>>>0<1073741824?a+1|0:a;L=b,M=Wd(Vc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[L+32>>1]=M;w[b+34>>1]=z[b+34>>1]|8192;break u}a=e&255;if((a|0)==32){if(!((g|0)!=15|(y[h+1|0]-1&255)>>>0>1)){x[k+96>>2]=-2147483648;d=x[k+2260>>2];wa:{if(!y[h+2|0]){s=k+96|0;a=0;t=hb-16|0;hb=t;L=t,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(t+12|0,d>>>2|0);e=f;h=f;g=x[t+12>>2];f=g;while(1){if(f){i=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}q=a-1|0;m=a>>>1|0;h=x[b+20>>2];f=g;while(1){if(!f){break Aa}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=d&-2147483648|d>>>1;d=m|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=Zia(d,i,a,0);i=lb;break Ba}i=Zia(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}L=h,M=hd(Hc(d,i),16),w[L>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=a}hb=t+16|0;e=g<<2;break wa}s=k+96|0;a=0;t=hb-16|0;hb=t;L=t,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(t+12|0,d>>>2|0);e=f;h=f;g=x[t+12>>2];f=g;while(1){if(f){d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}q=a-1|0;m=a>>>1|0;h=x[b+20>>2];f=g;while(1){if(!f){break Fa}d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);i=d&-2147483648|d>>>1;d=m|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=Zia(d,i,a,0);i=lb;break Ga}i=Zia(q-d|0,0-((d>>>0>q>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(lb+((i|0)!=0)|0)|0}L=h,M=hd(Hc(d,i),16),w[L>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(s){x[s>>2]=a}hb=t+16|0;e=g<<2}if(!e){break u}a=x[k+96>>2];if((a|0)==-2147483648){break u}f=Wia(z[b+32>>1],0,a,0)+1073741824|0;a=lb;a=f>>>0<1073741824?a+1|0:a;L=b,M=Wd(Vc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),w[L+32>>1]=M;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1){break ka}x[k+96>>2]=1065353216;a=x[k+2260>>2];Ha:{if(!y[h+2|0]){e=k+96|0;h=hb-16|0;hb=h;L=h,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(h+12|0,a>>>2|0);g=f;d=x[h+12>>2];a=d;while(1){if(a){j=xf((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));j=E(F(eg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ia:{a=u==E(0);if(a){break Ia}I=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ia}j=xf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=Ph(E(Fd(E(I*(eg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ja:{if(E(F(j))<E(2147483648)){i=~~j;break Ja}i=-2147483648}L=g,M=Xc(i),w[L>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){B[e>>2]=u}hb=h+16|0;e=d<<2}break}break Ha}e=k+96|0;i=hb-16|0;hb=i;L=i,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+12>>2]=M;xc(i+12|0,a>>>2|0);g=f;d=x[i+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);j=xf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),r()));j=E(F(eg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ka:{a=u==E(0);if(a){break Ka}I=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ka}h=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=xf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),r()));j=Ph(E(Fd(E(I*(eg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));La:{if(E(F(j))<E(2147483648)){h=~~j;break La}h=-2147483648}L=g,M=Xc(h),w[L>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){B[e>>2]=u}hb=i+16|0;e=d<<2}break}}if(!e){break u}j=B[k+96>>2];if(j==E(1)){break u}j=Ph(Xy(E(j*E(z[b+32>>1])),E(1),E(64)));a=65535;Ma:{if(j>=E(65535)){break Ma}a=0;if(j<=E(0)){break Ma}a=~~j>>>0;if(j<E(4294967296)&j>=E(0)){break Ma}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1|(a|0)!=64){break ka}x[k+96>>2]=0;x[k+100>>2]=1072693248;a=x[k+2260>>2];Na:{if(!y[h+2|0]){h=k+96|0;i=hb-32|0;hb=i;L=i,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+4>>2]=M;xc(i+4|0,a>>>3|0);d=f;e=x[i+4>>2];a=e;while(1){if(a){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);o=dg(+n());o=F(bf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Oa:{a=G==0;if(a){break Oa}J=a?1:1/G;d=x[b+20>>2];a=e;while(1){if(!a){break Oa}g=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);l(0,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24));l(1,g|0);o=dg(+n());L=i,N=J*(bf(o)?o>=0?1:-1:o),C[L+24>>3]=N;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;o=fe(C[yg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(F(o)<2147483648){g=~~o;break Pa}g=-2147483648}L=d,M=Xc(g),w[L>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){C[h>>3]=G}hb=i+32|0;e=e<<3}break}break Na}i=k+96|0;q=hb-32|0;hb=q;L=q,M=D(x[b>>2],Gd(z[b+34>>1])),x[L+4>>2]=M;xc(q+4|0,a>>>3|0);d=f;g=x[q+4>>2];a=g;while(1){if(a){e=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);h=e<<24|e<<8&16711680;s=e>>>8|0;m=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);e=e>>>24|0;h=h|((s|m<<24)&65280|(e|m<<8)&255);l(0,(s|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=dg(+n());o=F(bf(o)?o>=0?1:-1:o);G=o>G?o:G;a=a-1|0;d=d+8|0;continue}else{Qa:{a=G==0;if(a){break Qa}J=a?1:1/G;d=x[b+20>>2];a=g;while(1){if(!a){break Qa}m=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);e=m<<24|m<<8&16711680;s=m>>>8|0;h=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);m=m>>>24|0;e=e|((s|h<<24)&65280|(m|h<<8)&255);l(0,(s|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=dg(+n());L=q,N=J*(bf(o)?o>=0?1:-1:o),C[L+24>>3]=N;x[q+16>>2]=0;x[q+20>>2]=-1074790400;x[q+8>>2]=0;x[q+12>>2]=1072693248;o=fe(C[yg(q+24|0,q+16|0,q+8|0)>>3]*32768);Ra:{if(F(o)<2147483648){e=~~o;break Ra}e=-2147483648}L=d,M=Xc(e),w[L>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){C[i>>3]=G}hb=q+32|0;e=g<<3}break}}if(!e){break u}o=C[k+96>>3];if(o==1){break u}o=fe(Wy(o*+z[b+32>>1],1,64));a=65535;Sa:{if(o>=65535){break Sa}a=0;if(o<=0){break Sa}a=~~o>>>0;if(o<4294967296&o>=0){break Sa}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break u}Ta:{Ua:{Va:{Wa:{a=(e&255)!=32;Xa:{if(!(a|(y[h+1|0]!=1|(g|0)!=12))){u=E(30517578125e-15);e=x[k+2260>>2];if(!y[h+2|0]){break Xa}break Ta}if(!(y[h+1|0]!=2|(g|0)!=12|a)){u=E(30517578125e-15);e=x[k+2260>>2];if(!y[h+2|0]){break Va}break Ua}a=(e&255)!=32;if(a|(y[h+1|0]!=1|(g|0)!=13)){break Wa}u=E(1.1920928955078125e-7);e=x[k+2260>>2];if(y[h+2|0]){break Ta}}a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=e>>>2;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=xf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Ya:{if(E(F(j))<E(2147483648)){g=~~j;break Ya}g=-2147483648}L=b,M=Xc(g),w[L>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<2;break u}e=0;if(y[h+1|0]!=2|(g|0)!=13|a){break u}u=E(1.1920928955078125e-7);e=x[k+2260>>2];if(y[h+2|0]){break Ua}}a=x[b>>2];b=x[b+20>>2];d=hb-16|0;hb=d;x[d+12>>2]=e>>>3;x[d+8>>2]=a;a=x[Hb(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=xf((l(2,y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Za:{if(E(F(j))<E(2147483648)){g=~~j;break Za}g=-2147483648}L=b,M=Xc(g),w[L>>1]=M;j=xf((l(2,y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));_a:{if(E(F(j))<E(2147483648)){g=~~j;break _a}g=-2147483648}L=b,M=Xc(g),w[L+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}hb=d+16|0;e=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=e>>>3;x[g+8>>2]=a;a=x[Hb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));$a:{if(E(F(j))<E(2147483648)){d=~~j;break $a}d=-2147483648}L=b,M=Xc(d),w[L>>1]=M;d=y[f+4|0]|y[f+5|0]<<8|(y[f+6|0]<<16|y[f+7|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));ab:{if(E(F(j))<E(2147483648)){d=~~j;break ab}d=-2147483648}L=b,M=Xc(d),w[L+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}hb=g+16|0;e=a<<3;break u}a=x[b>>2];b=x[b+20>>2];g=hb-16|0;hb=g;x[g+12>>2]=e>>>2;x[g+8>>2]=a;a=x[Hb(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);j=xf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),r()));j=Ph(E(Fd(E((eg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));bb:{if(E(F(j))<E(2147483648)){d=~~j;break bb}d=-2147483648}L=b,M=Xc(d),w[L>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}hb=g+16|0;e=a<<2;break u}a=V(30320)|0}if((ib|0)!=(da(30320)|0)){break d}_(a|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break v}}zb(t);break u}a=P()|0;break d}x[23420]=0;Q(143,c|0,e+K|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break f}}Oc(H)}hb=k+2288|0;return e|0}a=P()|0;break a}a=P()|0}zb(t);break a}a=P()|0;break a}a=P()|0}Oc(H);S(a|0);p()}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=hb-640|0;hb=d;zc(b);f=hb-16|0;hb=f;g=d+448|0;zq(f+8|0,g);j=x[f+12>>2];h=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){$b(h,x[f+12>>2])}hb=f+16|0;b=(b|0)==(j|0);if(!b){cT(g)}a:{b:{c:{if(!b){break c}if(!eT(d+448|0)){break c}if(!Nb(x[h>>2],x[h+8>>2],Vc(dT(d+448|0),lb))){break c}if(!c){e=1;break c}Dd(a,32);v[d+447|0]=0;j=Jb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Ob(d+448|0,16099,4)){x[23420]=0;R(351,a|0,16777216);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=x[h>>2];x[23420]=0;b=T(148,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}x[23420]=0;Q(143,h|0,b-4|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;B=T(145,h|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((z[d+488>>1]-2185&65535)>>>0>1910){break q}b=x[h>>2];x[23420]=0;b=T(148,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}x[23420]=0;Q(143,h|0,b-4|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;B=T(145,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}if(B>>>0<256){break q}b=x[h>>2];x[23420]=0;b=T(148,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}if(b>>>0<=B>>>0){break q}x[23420]=0;b=Q(143,h|0,B|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}if(!b){break q}x[23420]=0;b=T(352,h|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}if(!b){break q}x[23420]=0;R(351,a|0,16777216);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=z[d+488>>1];if(b>>>0>=4096){x[23420]=0;c=Q(1,d+168|0,16314)|0;b=x[23420];x[23420]=0;if((b|0)==1){break j}a=x[a+1298464>>2];x[23420]=0;U(353,a|0,1,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(c);e=0;break d}b=P()|0;yb(c);break a}if(b>>>0<2194){break q}x[23420]=0;e=Q(1,d+416|0,15838)|0;b=x[23420];x[23420]=0;if((b|0)==1){break p}b=x[a+1298464>>2];x[23420]=0;U(353,b|0,4,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break o}yb(e)}if(x[a+480180>>2]!=32){break k}b=z[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Ob(d+508|0,13461,4)){break n}v[d+447|0]=1;break m}b=P()|0;break a}b=P()|0;yb(e);break a}if(b>>>0<297){break m}e=z[d+508>>1]|e}x[a+1074308>>2]=e;break k}e=z[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){v[d+447|0]=1;x[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(x[d+508>>2]|((b|0)!=768|(e|0)!=768)|(z[d+480>>1]!=256|y[d+500|0]!=128)){break k}if(y[d+501|0]){break k}x[a+1074308>>2]=18285088;v[d+447|0]=1;break k;case 3:if(x[d+508>>2]|(e|0)!=512){break k}s:{if(YA(d+512|0,255,64)){x[a+1074308>>2]=18219008;x[23420]=0;b=Q(1,d+400|0,14668)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break s}b=P()|0;break a}x[a+1074308>>2]=18284544;x[23420]=0;b=Q(1,d+400|0,16688)|0;e=x[23420];x[23420]=0;if((e|0)==1){break i}}Gb(j,b);yb(b);v[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(x[d+508>>2]|(e|0)!=514){break k}x[a+1074308>>2]=17367040;x[23420]=0;b=Q(1,d+400|0,14560)|0;e=x[23420];x[23420]=0;if((e|0)==1){break f}Gb(j,b);yb(b);v[d+447|0]=1}b=z[d+492>>1];e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Rq(b,d+448|4);x[23420]=0;R(210,d+168|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break h}b=d+168|0;Ac(a+1298308|0,b);xb(b);if(!(!(y[d+494|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+478|0];x[a+480220>>2]=y[d+479|0]}b=y[d+496|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+498|0];if(b){x[a+480196>>2]=b}v[d+168|0]=31;v[d+280|0]=y[d+499|0];b=d+168|0;e=d+280|0;J=a,K=D(y[_e(b,e)|0],1e4),x[J+480204>>2]=K;v[d+168|0]=y[d+497|0];v[d+280|0]=128;J=a,K=y[Wb(b,e)|0],x[J+480228>>2]=K;e=0;while(1){if((e|0)==64){t:{x[23420]=0;Q(143,h|0,192)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&(z[d+488>>1]-2187&65535)>>>0<=2){break t}b=y[a+484376|0];e=x[a+484360>>2];x[23420]=0;ea(326,Yb(e,b)|0,h|0,z[d+480>>1],255,254);b=x[23420];x[23420]=0;if((b|0)==1){break b}break e}}else{g=(d+448|0)+e|0;i=g- -64|0;u:{if(y[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;Te(b);J=f+480286|0,K=Wd(y[g+128|0],0,64),w[J>>1]=K;g=v[i|0];if((g|0)<0){x[b>>2]=x[b>>2]|1024}g=g&127;if(g>>>0<=64){w[f+480284>>1]=g<<2;break u}if((g|0)!=100){break u}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[23420]=0;b=T(182,h|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break g}if(b){break d}x[23420]=0;b=T(145,h|0)|0;f=x[23420];x[23420]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=y[a+484376|0];g=x[a+484360>>2];x[23420]=0;b=W(354,Yb(g,f)|0,h|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}t=Qb(d+384|0);q=Qb(d+368|0);e=0;n=Qb(d+352|0);x[23420]=0;b=W(355,h|0,t|0,z[d+482>>1])|0;f=x[23420];x[23420]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}x[23420]=0;b=W(355,h|0,q|0,z[d+484>>1])|0;f=x[23420];x[23420]=0;if((f|0)==1){break y}if(!b){break w}x[23420]=0;b=W(355,h|0,n|0,z[d+486>>1])|0;f=x[23420];x[23420]=0;if((f|0)==1){break y}if(!b){break w}x[d+348>>2]=-1;J=d,K=Db(x[t>>2]),x[J+168>>2]=K;e=Db(x[t+4>>2]);while(1){b=x[d+168>>2];if(Pb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Ce(d+168|0);continue}else{J=d,K=Db(x[q>>2]),x[J+168>>2]=K;e=Db(x[q+4>>2]);while(1){b=x[d+168>>2];if(Pb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Ce(d+168|0);continue}else{J=d,K=Db(x[n>>2]),x[J+168>>2]=K;e=Db(x[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=x[d+168>>2];if(Pb(b,e)){b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!(!b|b>>>0>=A[d+348>>2])){x[d+348>>2]=b}Ce(d+168|0);continue}else{if(v[d+494|0]&1){x[d+168>>2]=x[d+504>>2];J=d,K=x[Hb(d+348|0,d+168|0)>>2],x[J+348>>2]=K}e=0;if(z[d+490>>1]!=532){break H}b=z[d+488>>1];if(y[d+479|0]|(b?(b|0)!=532:0)|(y[d+478|0]|y[d+501|0])){break H}if(x[d+508>>2]|y[d+492|0]&192){break H}if(z[d+482>>1]){break I}f=z[d+484>>1];if(!f){break I}if((x[h+8>>2]+(vc(x[q>>2],x[q+4>>2])<<2)|0)+2>>>0>A[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[23420]=0;b=T(145,h|0)|0;f=x[23420];x[23420]=0;J:{if((f|0)!=1){if(!b){break J}mg(h,((e&65535)<<2)+4|0);break I}b=P()|0;break x}e=e+1|0;f=z[d+484>>1];continue}break}x[23420]=0;b=Q(1,d+336|0,14818)|0;e=x[23420];x[23420]=0;if((e|0)==1){break G}Gb(j,b);yb(b)}e=1;if(z[d+488>>1]){break H}x[23420]=0;b=Q(1,d+320|0,15179)|0;f=x[23420];x[23420]=0;if((f|0)==1){break F}Gb(j,b);yb(b)}b=z[d+494>>1];K:{if(b&2){x[23420]=0;f=T(182,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break A}b=x[h+8>>2];g=x[h>>2];x[23420]=0;i=b;b=f<<3;g=W(144,g|0,i|0,b|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break A}if(!(!g|A[d+348>>2]<b+x[h+8>>2]>>>0)){x[23420]=0;b=a+1298408|0;R(356,b|0,f|0);g=x[23420];x[23420]=0;if((g|0)==1){break A}J=d,K=Db(x[b>>2]),x[J+280>>2]=K;g=Db(x[a+1298412>>2]);L:{M:{while(1){b=x[d+280>>2];if(!Pb(b,g)){if(!(!f&e)){break K}if(!(y[d+494|0]&4)){break L}x[23420]=0;b=Q(1,d+304|0,15212)|0;e=x[23420];x[23420]=0;if((e|0)==1){break M}Gb(j,b);yb(b);break K}x[23420]=0;R(357,h|0,d+168|0);i=x[23420];x[23420]=0;if((i|0)!=1){Tb(b,0,44);i=y[d+168|0]|y[d+169|0]<<8;if(i|(y[d+170|0]|y[d+171|0]<<8)){x[b+20>>2]=((i&65024)>>>9|0)+80;J=b,K=Xb((y[d+168|0]|y[d+169|0]<<8)>>>5&15,1,12)-1|0,x[J+16>>2]=K;J=b,K=Xb((y[d+168|0]|y[d+169|0]<<8)&31,1,31),x[J+12>>2]=K;J=b,K=Xb((y[d+170|0]|y[d+171|0]<<8)>>>11|0,0,23),x[J+8>>2]=K;J=b,K=Xb((y[d+170|0]|y[d+171|0]<<8)>>>5&63,0,59),x[J+4>>2]=K;J=b,K=Xb((y[d+170|0]|y[d+171|0]<<8)<<1&62,0,59),x[J>>2]=K}x[b+44>>2]=y[d+172|0]|y[d+173|0]<<8|(y[d+174|0]<<16|y[d+175|0]<<24);x[d+280>>2]=x[d+280>>2]+48;continue}break}b=P()|0;break x}b=P()|0;break x}x[23420]=0;b=Q(1,d+304|0,14845)|0;e=x[23420];x[23420]=0;if((e|0)!=1){Gb(j,b);yb(b);break K}b=P()|0;break x}mg(h,2);break K}if(!(b>>>0<2&e)){break K}x[23420]=0;b=T(182,h|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break z}if(!b){x[23420]=0;b=Q(1,d+304|0,14818)|0;e=x[23420];x[23420]=0;if((e|0)!=1){Gb(j,b);yb(b);break K}b=P()|0;break x}mg(h,2)}N:{if(!(y[d+492|0]&128|y[d+494|0]&8)){break N}x[23420]=0;b=a+901404|0;e=Q(358,h|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break E}if(!e){break N}XA(b)}if(z[d+488>>1]<=531){bq(a+901404|0)}x[23420]=0;C=T(162,d+280|0)|0;b=x[23420];x[23420]=0;O:{P:{Q:{if((b|0)!=1){x[23420]=0;b=Q(348,h|0,13698)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Q}if(b){x[23420]=0;b=T(145,h|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break P}x[23420]=0;U(178,d+256|0,h|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break P}b=d+256|0;e=jc(d+168|0,b);bd(C,e);zb(e);zb(b)}w[a+480188>>1]=1;x[23420]=0;b=Q(348,h|0,13703)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Q}if(!b){break C}x[23420]=0;b=T(145,h|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;U(178,d+256|0,h|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break O}}b=P()|0;break B}b=P()|0;break x}b=P()|0;break B}b=P()|0;break B}b=d+256|0;f=jc(d+168|0,b);zb(b);b=x[f>>2];x[23420]=0;b=T(148,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break D}w[d+256>>1]=(b>>>0)/20;b=z[Zc(26484,d+256|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){zb(f);break C}x[23420]=0;U(359,f|0,((e<<5)+a|0)+480289|0,20);g=x[23420];x[23420]=0;if((g|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;break x}b=P()|0;break x}b=P()|0;break x}b=P()|0;zb(f);break B}R:{b=x[d+348>>2];e=x[h+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}x[23420]=0;e=T(190,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break R}}x[23420]=0;U(178,d+168|0,h|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break R}b=d+168|0;E=jc(d+256|0,b);zb(b);x[23420]=0;F=Q(360,a|0,E|0)|0;b=x[23420];x[23420]=0;T:{U:{V:{if((b|0)==1){break V}if(!(v[d+494|0]&1)|!z[d+502>>1]){break U}x[23420]=0;b=Q(143,h|0,x[d+504>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break V}if(!b){break U}x[23420]=0;X(317,a+1298332|0,h|0,z[d+502>>1],4);b=x[23420];x[23420]=0;if((b|0)!=1){break U}}b=P()|0;break T}g=a+480192|0;w[g>>1]=0;f=0;if(y[d+492|0]&4){w[d+168>>1]=z[d+482>>1];w[d+96>>1]=255;f=z[Zc(d+168|0,d+96|0)>>1];w[g>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){x[d+252>>2]=0;e=z[d+484>>1];if(e){b=Cb(x[q>>2],e-1|0);x[d+252>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+168>>1]=e;w[d+96>>1]=3999;r=a+480190|0;f=z[Zc(d+168|0,d+96|0)>>1];w[r>>1]=f;m=c&2;o=d+188|0;u=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Cb(x[q>>2],e);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);if(!f){break Y}x[23420]=0;f=Q(143,h|0,f|0)|0;g=x[23420];x[23420]=0;da:{ea:{fa:{ga:{ha:{if((g|0)==1){break ha}if(!f){break Y}x[23420]=0;f=Q(361,h|0,d+168|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break ha}if(!f){break Y}x[23420]=0;i=e+1|0;f=D(i,104)+a|0;g=f+484380|0;k=Q(362,d+168|0,g|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break ga}l=d+152|0;Rq(l,o);x[23420]=0;R(210,d+96|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break fa}l=d+96|0;Dc(((i<<5)+a|0)+946304|0,l);xb(l);x[23420]=0;k=Q(143,h|0,k|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break ga}if(!k){break Y}f=z[f+484414>>1];if(!(f&512)){break ea}x[23420]=0;f=Q(363,h|0,d+96|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break ca}if(!f){break da}x[d+8>>2]=x[d+104>>2];f=x[d+100>>2];x[d>>2]=x[d+96>>2];x[d+4>>2]=f;il(g,1,d);break da}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}if(!(f&16384)){s=z[d+488>>1];k=y[d+186|0];l=k&2;f=y[d+214|0];i=_c(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|s>>>0<532)){yo(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){v[i+2|0]=1}if(f&4){Rf(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}Rf(i,k)}if(m){f=0;x[23420]=0;W(207,d+96|0,g|0,h|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){break _}break X}f=1;i=y[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(y[d+96|0]){break $}break _}x[23420]=0;R(364,h|0,d+80|0);f=x[23420];x[23420]=0;if((f|0)==1){break aa}g=x[d+80>>2];if(!(!m|!g)){f=Jb(d+96|0);x[23420]=0;U(255,h|0,f|0,g|0);g=x[23420];x[23420]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((g|0)!=1){x[23420]=0;R(365,d+136|0,16236);g=x[23420];x[23420]=0;if((g|0)==1){break qa}x[d+64>>2]=i;x[23420]=0;U(11,d+120|0,0,f|0);g=x[23420];x[23420]=0;if((g|0)==1){break pa}x[23420]=0;X(366,d+152|0,d+136|0,d- -64|0,d+120|0);g=x[23420];x[23420]=0;if((g|0)==1){break oa}g=x[u>>2];x[23420]=0;U(353,g|0,2,d+152|0);g=x[23420];x[23420]=0;if((g|0)==1){break na}yb(d+152|0);yb(d+120|0);cc(d+136|0);xb(f);break da}b=P()|0;break ka}b=P()|0;break ka}b=P()|0;break la}b=P()|0;break ma}b=P()|0;yb(d+152|0)}yb(d+120|0)}cc(d+136|0)}xb(f);break T}x[23420]=0;Q(176,h|0,g|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break aa}}f=0;break Z}w[d+168>>1]=1;w[d+96>>1]=f;J=a+480190|0,K=z[Ve(d+168|0,d+96|0)>>1],w[J>>1]=K;if(!(z[d+488>>1]==516&b)|z[d+490>>1]!=512|(z[d+494>>1]|x[d+508>>2])){break ba}if((z[d+492>>1]&65527)!=21|y[d+496|0]!=128|(y[d+497|0]!=48|y[d+500|0]!=128)){break ba}if(y[d+501|0]|z[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}x[23420]=0;b=Q(1,d+152|0,9771)|0;e=x[23420];x[23420]=0;if((e|0)==1){break ra}Gb(j,b);yb(b);break ba}}else{e=!y[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;break T}else{e=y[f|0]==64&e;f=f+1|0;continue}}else{e=(y[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;break T}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=vc(x[n>>2],x[n+4>>2]);w[d+168>>1]=b;r=z[Zc(d+168|0,x[a+8>>2]+10|0)>>1];w[d+118>>1]=r;sa:{ta:{ua:{va:{if((b|0)!=(r|0)){x[23420]=0;Y(367,d+96|0);b=x[23420];x[23420]=0;if((b|0)==1){break sa}b=x[n+4>>2];e=x[n>>2];x[23420]=0;J=d,K=vc(e,b),x[J+136>>2]=K;X(368,d+168|0,d+96|0,d+136|0,d+118|0);b=x[23420];x[23420]=0;if((b|0)==1){break ua}b=x[a+1298464>>2];x[23420]=0;U(353,b|0,2,d+168|0);b=x[23420];x[23420]=0;if((b|0)==1){break va}yb(d+168|0);cc(d+96|0)}if(!(c&1)){w[d+118>>1]=0;r=0}m=a+480188|0;i=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((i|0)==(r|0)){Da:{Ea:{b=x[d+252>>2];if(!b){break Ea}x[23420]=0;Q(143,h|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Da}if(!(s&1)){break Ea}while(1){Fa:{b=x[h+8>>2];c=x[h>>2];x[23420]=0;b=W(144,c|0,b|0,4)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Fa}if(!b){break Ea}x[23420]=0;b=Q(348,h|0,13672)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Fa}Ga:{if(!b){x[23420]=0;b=Q(348,h|0,13677)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Fa}if(!b){break Ga}}x[23420]=0;b=T(145,h|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){mg(h,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;break T}x[23420]=0;b=T(182,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Fa}x[23420]=0;Q(176,h|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}b=P()|0;break T}x[23420]=0;b=Q(369,a|0,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Da}b=b|y[d+447|0];v[d+447|0]=b;if(!(!(b&255)|F)){cu(a+1074312|0);v[a+1074368|0]=0}x[23420]=0;X(370,a|0,h|0,0,d+447|0);b=x[23420];x[23420]=0;if((b|0)==1){break Da}x[23420]=0;o=a+484344|0;R(213,o|0,r|0);b=x[23420];x[23420]=0;if((b|0)==1){break Da}u=a+480188|0;I=a+480183|0;i=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((i|0)!=(r|0)){b=Cb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[23420]=0;b=Q(143,h|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ab}if(b){break $a}}x[23420]=0;b=W(214,o|0,i&65535,64)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ab}if(b){break bb}w[d+48>>1]=i;x[23420]=0;Y(371,d+96|0);b=x[23420];x[23420]=0;if((b|0)==1){break fb}x[23420]=0;U(372,d+168|0,d+96|0,d+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break eb}b=x[a+1298464>>2];x[23420]=0;U(353,b|0,2,d+168|0);b=x[23420];x[23420]=0;if((b|0)==1){break db}yb(d+168|0);cc(d+96|0)}if(!x[a+1074308>>2]){e=z[d+488>>1];if((e|0)!=2184){break Za}x[a+1074308>>2]=18284544}if(!eh(x[j+4>>2],y[j+11|0])){break _a}x[23420]=0;c=Q(1,d+96|0,17433)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Ra}b=x[a+1074308>>2];x[23420]=0;R(128,d- -64|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ta}x[23420]=0;U(2,d+168|0,c|0,d- -64|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ua}e=d+168|0;b=Gb(j,e);yb(e);yb(d- -64|0);yb(c);if(!Ob(d+508|0,13461,4)|(z[d+488>>1]&61440)!=20480){break Ya}x[23420]=0;c=Q(1,d+168|0,16700)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Va}x[23420]=0;Q(87,b|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Wa}yb(c);break Xa}b=P()|0;break T}b=P()|0;break cb}b=P()|0;yb(d+168|0)}cc(d+96|0);break T}b=x[o>>2];x[23420]=0;R(373,_b(b,i)|0,C|0);b=x[23420];x[23420]=0;if((b|0)!=1){break Pa}}b=P()|0;break T}x[23420]=0;b=T(182,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Ha}x[23420]=0;G=T(182,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Ia}x[23420]=0;c=Q(176,h|0,4)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23420]=0;c=W(214,o|0,i&65535,G|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Ia}if(!c){break Pa}x[23420]=0;U(178,d+96|0,h|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ja}b=d+96|0;m=jc(d+168|0,b);zb(b);b=x[o>>2];x[23420]=0;R(373,_b(b,i)|0,C|0);b=x[23420];x[23420]=0;if((b|0)==1){break La}b=z[u>>1];x[23420]=0;l=Q(374,d+120|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Ma}b=z[u>>1];c=d+96|0;Rh(c);x[23420]=0;k=W(375,d+80|0,b|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Oa}J=d,K=Db(x[_b(x[o>>2],i)>>2]),x[J+64>>2]=K;s=0;while(1){gb:{hb:{ib:{jb:{if(s>>>0>=G>>>0){break jb}b=x[m>>2];x[23420]=0;b=W(144,b|0,x[d+176>>2],1)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Qa}if(!b){break jb}x[23420]=0;b=T(194,m|0)|0;c=x[23420];x[23420]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}pT(d- -64|0,z[u>>1]);s=s+1|0;continue}break Qa}lb:{c=b&127;g=c?c-1&65535:0;if(Wc(x[l>>2],x[d+124>>2])>>>0>g>>>0){break lb}x[23420]=0;v[d+96|0]=0;c=g+1|0;U(376,l|0,c|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)==1){break Qa}e=d+96|0;Rh(e);x[23420]=0;U(377,k|0,c|0,e|0);c=x[23420];x[23420]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){x[23420]=0;b=T(194,m|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Qa}J=Kb(x[l>>2],g),K=b,v[J|0]=K}f=d+96|0;Rh(f);if(g>>>0<z[u>>1]){f=Cd(x[d+64>>2],g)}b=Kb(x[l>>2],g);e=y[b|0];if(e&16){J=f,K=y[Cd(x[k>>2],g)|0],v[J|0]=K;e=y[b|0]}if(e&32){J=f,K=y[Cd(x[k>>2],g)+1|0],v[J+1|0]=K;e=y[b|0]}if(e&64){c=Cd(x[k>>2],g);v[f+2|0]=y[c+2|0];v[f+4|0]=y[c+4|0];e=y[b|0]}if(e<<24>>24<0){c=Cd(x[k>>2],g);v[f+3|0]=y[c+3|0];v[f+5|0]=y[c+5|0];e=y[b|0]}if(e&1){x[23420]=0;b=T(194,m|0)|0;c=x[23420];x[23420]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(v[I|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)!=253?b:0}v[f|0]=c;J=Cd(x[k>>2],g),K=c,v[J|0]=K;b=Kb(x[l>>2],g)}if(y[b|0]&2){x[23420]=0;b=T(194,m|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Qa}v[f+1|0]=b;J=Cd(x[k>>2],g),K=b,v[J+1|0]=K;b=Kb(x[l>>2],g)}if(!(y[b|0]&4)){break gb}x[23420]=0;b=T(194,m|0)|0;c=x[23420];x[23420]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}v[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;v[f+2|0]=2;b=b^-128;v[f+4|0]=b;break hb}if(b>>>0<=74){e=5;v[f+2|0]=5;b=b-65|0;v[f+4|0]=b;break hb}if(b>>>0<=84){e=6;v[f+2|0]=6;b=b-75|0;v[f+4|0]=b;break hb}if(b>>>0<=94){e=3;v[f+2|0]=3;b=b-85|0;v[f+4|0]=b;break hb}if(b>>>0<=104){e=4;v[f+2|0]=4;b=b-95|0;v[f+4|0]=b;break hb}if(b>>>0<=114){e=13;v[f+2|0]=13;b=b-105|0;v[f+4|0]=b;break hb}if(b>>>0<=124){e=12;v[f+2|0]=12;b=b-115|0;v[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){v[f+4|0]=c;e=11;v[f+2|0]=11;b=c;break hb}c=b+53|0;H=c&255;if(H>>>0<=9){v[f+4|0]=c;e=8;v[f+2|0]=8;if(!H){b=0;break hb}if(x[a+1074308>>2]-1>>>0>18285139){break ib}e=7;v[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=y[f+4|0];e=y[f+2|0];break hb}v[f+4|0]=b;e=15}v[f+2|0]=e;break hb}ek(k);dc(l);zb(m);break Pa}b=c}c=Cd(x[k>>2],g);v[c+4|0]=b;v[c+2|0]=e;b=Kb(x[l>>2],g)}if(!(y[b|0]&8)){continue}x[23420]=0;R(247,d+32|0,m|0);b=x[23420];x[23420]=0;if((b|0)!=1){v[f+3|0]=y[d+32|0];J=f,K=y[jd(d+32|0)|0],v[J+5|0]=K;VA(f,1);b=Cd(x[k>>2],g);v[b+3|0]=y[f+3|0];v[b+5|0]=y[f+5|0];continue}break}break Qa}e=z[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(F){x[23420]=0;b=Q(1,d+168|0,8258)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=z[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(z[d+494>>1]|z[d+492>>1]!=9|(y[d+479|0]|y[d+478|0])){break Mb}if(z[d+482>>1]|z[d+480>>1]!=(z[d+486>>1]+1|0)|(y[d+496|0]!=128|y[d+497|0]!=100)){break Mb}if(y[d+498|0]!=1|y[d+500|0]!=128|(y[d+501|0]|z[d+502>>1])){break Mb}if(x[d+504>>2]|x[d+508>>2]){break Mb}x[23420]=0;b=Q(1,d+168|0,9752)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}e=532;if(x[d+508>>2]|(y[d+479|0]|y[d+478|0])){break Jb}x[a+1074308>>2]=16777381;x[23420]=0;b=Q(1,d+168|0,14749)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);v[d+447|0]=1;break Xa}b=P()|0;break T}if(!Ob(d+508|0,13937,4)){x[23420]=0;b=Q(1,d+168|0,8296)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);e=a+1074312|0;f=38;break vb}b=P()|0;break T}e=532;if(y[d+501|0]|z[d+494>>1]>1|(x[d+508>>2]|(z[d+492>>1]&4294)!=4)){break Lb}if(!z[a+480190>>1]){break Lb}x[23420]=0;e=Q(54,d+96|0,13326)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Hb}b=hb-32|0;hb=b;c=hb-16|0;hb=c;$u(c+8|0,a+484527|0);PS(b+24|0,x[c+8>>2],x[c+12>>2]);hb=c+16|0;ue(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Lc(x[b+24>>2],x[b+28>>2],b+8|0);hb=b+32|0;xb(e);if(c){break Ib}e=z[d+488>>1]}if(e&65535){break Lb}if(eh(x[j+4>>2],y[j+11|0])){break Fb}}f=z[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!eh(x[j+4>>2],y[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}x[23420]=0;b=Q(1,d- -64|0,14782)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Eb}Gb(j,b);yb(b);break Cb}x[23420]=0;b=Q(1,d+168|0,8322)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Gb}Gb(j,b);yb(b);break Xa}b=P()|0;break T}b=P()|0;break T}x[23420]=0;b=Q(1,d+168|0,9642)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if((e&65535)>>>0>=533){x[23420]=0;R(378,d- -64|0,3976);b=x[23420];x[23420]=0;Nb:{if((b|0)!=1){x[23420]=0;x[d+48>>2]=z[d+488>>1]-532;U(379,d+168|0,d- -64|0,d+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break Nb}b=d+168|0;Gb(j,b);yb(b);cc(d- -64|0);break Cb}b=P()|0;break T}b=P()|0;cc(d- -64|0);break T}x[23420]=0;R(253,d- -64|0,4275);b=x[23420];x[23420]=0;if((b|0)==1){break Bb}b=z[d+488>>1];x[d+32>>2]=b>>>8&15;x[23420]=0;x[d+16>>2]=b&255;R(380,d+48|0,d+16|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ab}x[23420]=0;X(366,d+168|0,d- -64|0,d+32|0,d+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break zb}b=d+168|0;Gb(j,b);yb(b);yb(d+48|0);cc(d- -64|0)}b=a+1298408|0;if(!uc(x[b>>2],x[a+1298412>>2])){break Xa}c=x[d+508>>2];if(!c){break Xa}c=PC(z[d+488>>1],c);e=qq(d+168|0);x[e+44>>2]=c;x[23420]=0;R(381,b|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break Xa}b=P()|0;break T}b=P()|0;break T}b=P()|0;break yb}b=P()|0;yb(d+48|0)}cc(d- -64|0);break T}c=x[d+508>>2];x[23420]=0;U(382,d+168|0,b|0,x[d+508>>2]);e=x[23420];x[23420]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((e|0)!=1){e=d+168|0;Gb(j,e);yb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Tb}f=x[a+480208>>2];if(!(f&16)){break Sb}x[23420]=0;Q(252,a+1074312|0,7)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break Rb}break qb}b=P()|0;break T}if(b>>>0>4200){break Pb}f=x[a+480208>>2]}if(!(f&16)){x[23420]=0;Q(252,a+1074312|0,7)|0;c=x[23420];x[23420]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Qb}}x[23420]=0;Q(252,a+1074312|0,38)|0;b=x[23420];x[23420]=0;if((b|0)==1){break qb}}x[23420]=0;b=Q(252,a+1074312|0,102)|0;c=x[23420];x[23420]=0;if((c|0)==1){break qb}x[23420]=0;Q(252,b|0,48)|0;b=x[23420];x[23420]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4383){break Xa}}x[23420]=0;e=W(251,a+1074312|0,116,1)|0;b=x[23420];x[23420]=0;f=115;if((b|0)==1){break qb}}x[23420]=0;Q(252,e|0,f|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break qb}break Xa}x[23420]=0;Y(383,d+96|0);b=x[23420];x[23420]=0;Ub:{Vb:{Wb:{if((b|0)!=1){b=z[d+488>>1];x[d+48>>2]=b>>>8&15;x[23420]=0;x[d+32>>2]=b&255;R(380,d- -64|0,d+32|0);b=x[23420];x[23420]=0;if((b|0)==1){break Wb}x[23420]=0;X(366,d+168|0,d+96|0,d+48|0,d- -64|0);b=x[23420];x[23420]=0;if((b|0)==1){break Vb}b=d+168|0;Gb(j,b);yb(b);yb(d- -64|0);cc(d+96|0);break Xa}b=P()|0;break T}b=P()|0;break Ub}b=P()|0;yb(d- -64|0)}cc(d+96|0);break T}x[23420]=0;b=Q(1,d+168|0,8258)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}if(!((b|0)!=32767|z[d+490>>1]!=533)){x[23420]=0;b=Q(1,d+168|0,5003)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}x[23420]=0;R(125,d+96|0,4111);b=x[23420];x[23420]=0;Xb:{if((b|0)!=1){b=z[d+488>>1];x[d+64>>2]=b>>>8&15;x[d+48>>2]=b>>>4&15;x[23420]=0;x[d+32>>2]=b&15;ea(126,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=x[23420];x[23420]=0;if((b|0)==1){break Xb}b=d+168|0;Gb(j,b);yb(b);cc(d+96|0);break Xa}b=P()|0;break T}b=P()|0;cc(d+96|0);break T}x[23420]=0;b=Q(1,d+168|0,6084)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(j,b);yb(b);break Xa}b=P()|0;break T}b=P()|0;break T}if(!WD(x[a+1074308>>2])){break Xa}x[23420]=0;c=Q(1,d+168|0,16936)|0;e=x[23420];x[23420]=0;Yb:{if((e|0)!=1){x[23420]=0;Q(87,b|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Yb}yb(c);break Xa}b=P()|0;break T}b=P()|0;yb(c);break T}e=x[a+480180>>2];if(!((e|0)!=16777216|z[d+488>>1]<2186)){x[23420]=0;b=Q(143,h|0,B|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Da}if(b){x[23420]=0;U(384,a|0,h|0,z[d+488>>1]);b=x[23420];x[23420]=0;if((b|0)==1){break Da}}e=x[a+480180>>2]}Zb:{_b:{$b:{ac:{bc:{cc:{if((e|0)==16777216){x[23420]=0;Q(1,d+48|0,13645)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break cc}b=P()|0;break T}x[23420]=0;R(253,d+32|0,4275);b=x[23420];x[23420]=0;if((b|0)==1){break bc}b=z[d+490>>1];x[d+28>>2]=b>>>8;x[23420]=0;x[d+12>>2]=b&255;R(380,d+16|0,d+12|0);b=x[23420];x[23420]=0;if((b|0)==1){break ac}x[23420]=0;X(366,d+48|0,d+32|0,d+28|0,d+16|0);b=x[23420];x[23420]=0;if((b|0)==1){break $b}}b=d+48|0;Gb(a+1298344|0,b);yb(b);if((e|0)!=16777216){yb(d+16|0);cc(d+32|0)}b=x[a+480180>>2];x[23420]=0;b=Q(1,d+48|0,((b|0)==16777216?10016:6088)|0)|0;c=x[23420];x[23420]=0;e=1;if((c|0)==1){break Zb}Gb(a+1298356|0,b);yb(b);Gb(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;zb(E);zb(C);break w}b=P()|0;break T}b=P()|0;break _b}b=P()|0;yb(d+16|0)}cc(d+32|0);break T}b=P()|0;break T}b=P()|0;yb(c);break T}b=P()|0;break T}b=P()|0;yb(d- -64|0);break Sa}b=P()|0}yb(c);break T}b=P()|0;break T}b=P()|0;ek(k);break Na}i=i+1|0;continue}break}b=P()|0}dc(l);break Ka}b=P()|0;break Ka}b=P()|0}zb(m);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}dc:{b=Cb(x[n>>2],i);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);ec:{if(!b){break ec}x[23420]=0;b=Q(143,h|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Ba}if(!b){break ec}x[23420]=0;b=T(182,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break wa}x[23420]=0;l=T(182,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break ec}x[23420]=0;c=Q(176,h|0,4)|0;e=x[23420];x[23420]=0;if((e|0)==1){break xa}if(!c){break ec}x[23420]=0;U(178,d+96|0,h|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break ya}b=d+96|0;f=jc(d+168|0,b);zb(b);c=z[m>>1];b=0;x[23420]=0;g=Q(374,d+136|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Aa}fc:{while(1){if(b>>>0>=l>>>0){break fc}c=x[f>>2];x[23420]=0;c=W(144,c|0,x[d+176>>2],1)|0;e=x[23420];x[23420]=0;if((e|0)==1){break dc}if(!c){break fc}x[23420]=0;c=T(194,f|0)|0;e=x[23420];x[23420]=0;gc:{if((e|0)!=1){c=c<<24>>24;if(c){break gc}b=b+1|0;continue}break Ca}hc:{e=c&127;o=e?e-1|0:0;k=o&65535;if(Wc(x[g>>2],x[d+140>>2])>>>0>k>>>0){break hc}x[23420]=0;v[d+96|0]=0;U(376,g|0,k+1|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)!=1){break hc}break Ca}ic:{if((c|0)<0){x[23420]=0;c=T(194,f|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break ic}J=Kb(x[g>>2],k),K=c,v[J|0]=K}e=Kb(x[g>>2],k);c=y[e|0];if(!(!(c&15)|k>>>0<z[m>>1])){w[m>>1]=o+1;c=y[e|0]}if(c&1){x[23420]=0;Q(176,f|0,1)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ic}e=Kb(x[g>>2],k)}if(y[e|0]&2){x[23420]=0;Q(176,f|0,1)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ic}e=Kb(x[g>>2],k)}if(y[e|0]&4){x[23420]=0;Q(176,f|0,1)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ic}e=Kb(x[g>>2],k)}if(!(y[e|0]&8)){continue}x[23420]=0;Q(176,f|0,2)|0;c=x[23420];x[23420]=0;if((c|0)!=1){continue}}break}break Ca}x[d+96>>2]=x[h+8>>2];J=d,K=x[Yc(d+252|0,d+96|0)>>2],x[J+252>>2]=K;dc(g);zb(f)}i=i+1|0;continue}}break}b=P()|0;dc(g);break za}b=P()|0;break T}b=P()|0}zb(f);break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;break T}b=P()|0;yb(d+168|0);break ta}b=P()|0}cc(d+96|0);break T}b=P()|0;break T}b=P()|0;break T}f=0;i=UA(d+96|0,x[g>>2]);x[23420]=0;Q(176,h|0,i|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break X}}if(y[d+99|0]!=1){break Z}b=x[g>>2]!=0|b}x[d+96>>2]=x[h+8>>2];J=d,K=x[Yc(d+252|0,d+96|0)>>2],x[J+252>>2]=K;s=(f|0)!=0}e=e+1|0;f=z[r>>1];continue}break}b=P()|0;break T}jc:{b=Cb(x[t>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);kc:{if(!b){break kc}x[23420]=0;b=Q(143,h|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break jc}if(!b){break kc}b=x[h+8>>2];f=x[h>>2];x[23420]=0;b=W(144,f|0,b|0,554)|0;f=x[23420];x[23420]=0;if((f|0)==1){break jc}if(!b){break kc}x[23420]=0;b=W(239,a|0,e+1&65535,0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break W}if(!b){break kc}x[23420]=0;X(385,a|0,h|0,b|0,z[d+490>>1]);f=x[23420];x[23420]=0;if((f|0)==1){break W}v[b+33|0]=y[d+501|0]}e=e+1|0;f=z[g>>1];continue}break}b=P()|0;break T}b=P()|0}zb(E);break B}b=P()|0}zb(C);break x}b=P()|0;break x}b=P()|0;break x}}}}}b=P()|0}tc(n);tc(q);tc(t);break a}tc(n);tc(q);tc(t)}yb(j)}hb=d+640|0;return e|0}b=P()|0}yb(j);S(b|0);p()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;e=hb-1760|0;hb=e;zc(b);a:{if(!Yh(b,e+1752|0)){break a}if(!_R(e+1752|0)){break a}if(!c){g=1;break a}o=y[e+1755|0];v[e+1751|0]=o;x[e+1744>>2]=-1;x[e+1740>>2]=1048576;if(o>>>0>=5){d=pg(b);x[e+1744>>2]=d;if(!Nb(x[b>>2],x[b+8>>2],d)){break a}x[e+320>>2]=134217727;N=e,O=x[Hb(e+320|0,e+1744|0)>>2]<<5,x[N+1740>>2]=O}C=Qb(e+1728|0);x[e+320>>2]=x[e+1756>>2];d=x[Hb(e+1740|0,e+320|0)>>2];x[23420]=0;R(489,C|0,d|0);d=x[23420];x[23420]=0;b:{c:{d:{e:{f:{if((d|0)!=1){x[23420]=0;d=W(490,b|0,C|0,x[e+1756>>2])|0;f=x[23420];x[23420]=0;g:{if((f|0)==1){break g}if(!d){break b}if(o>>>0>=5){x[23420]=0;Q(143,b|0,x[e+1744>>2]+12|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}}x[23420]=0;R(234,a|0,0);d=x[23420];x[23420]=0;if((d|0)==1){break g}Cg(a);ke(e+1696|0,x[C>>2],x[C+4>>2]);d=$d(e+1688|0);x[23420]=0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;m=wg(491,e+1704|0,x[e+1696>>2],x[e+1700>>2],e+88|0);d=x[23420];x[23420]=0;h:{i:{j:{if((d|0)!=1){x[23420]=0;U(336,m|0,a+1298308|0,-1);d=x[23420];x[23420]=0;if((d|0)==1){break j}x[23420]=0;U(336,m|0,a+1298332|0,-1);d=x[23420];x[23420]=0;if((d|0)==1){break j}x[23420]=0;d=Q(492,m|0,e+1264|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break f}if(!d){break c}d=v[e+1264|0];if((d|0)<=0|(y[e+1273|0]|y[e+1274|0]<<8)>>>0>255|(y[e+1275|0]|y[e+1276|0]<<8)>>>0>3999){break c}E=a+480188|0;w[E>>1]=d&255;Ze(Yb(x[a+484360>>2],y[a+484376|0]),y[e+1267|0]|y[e+1268|0]<<8);w[a+480192>>1]=y[e+1273|0]|y[e+1274|0]<<8;w[a+480190>>1]=y[e+1275|0]|y[e+1276|0]<<8;d=y[e+1277|0];x[a+480196>>2]=d?d:6;d=y[e+1278|0];x[a+480204>>2]=D(d?d:125,1e4);f=y[e+1279|0]|y[e+1280|0]<<8|(y[e+1281|0]<<16|y[e+1282|0]<<24);d=32;k:{if(f&256){break k}d=2;if(f&2){break k}d=1;if(f&128){break k}d=f&8?16:4}x[23420]=0;R(351,a|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break f}g=x[a+480208>>2];f=g|16777216;x[a+480208>>2]=f;d=y[e+1279|0]|y[e+1280|0]<<8|(y[e+1281|0]<<16|y[e+1282|0]<<24);if(d&1){f=g|16777232;x[a+480208>>2]=f}j=x[a+480180>>2];l=(j|0)==32;g=l&!(d&1024);r=(j|0)==2;h=r&d>>>4;q=d&2097152;r=r&d>>>2;l=l&!(d&2048);if(g|(q|r|(l|h))){f=h?f|65536:f;f=r?f|2:f;f=l?f|4:f;x[a+480208>>2]=q>>>6|(g?f|8:f)}if(d&524288){x[23420]=0;W(251,a+1074312|0,5,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}j=x[a+480180>>2]}if((j|0)==2){break i}if((j|0)!=32){break h}v[e+320|0]=y[e+1283|0];v[e+240|0]=128;N=a,O=y[Wb(e+320|0,e+240|0)|0]<<1,x[N+480200>>2]=O;break h}d=P()|0;break d}d=P()|0;break e}v[e+320|0]=y[e+1283|0];v[e+240|0]=64;N=a,O=y[Wb(e+320|0,e+240|0)|0]<<2,x[N+480200>>2]=O}d=v[e+1285|0];l:{if((d|0)<0){d=d+52|0;break l}H=sr(+(d|0)*3.1/20);m:{if(H<4294967296&H>=0){d=~~H>>>0;break m}d=0}d=d+51|0}x[a+480228>>2]=d;w[e+320>>1]=64;h=z[Zc(E,e+320|0)>>1];f=0;l=(j|0)!=32;r=(j|0)==4;g=0;while(1)if((g|0)==(h|0)){g=0;h=0;while(1){if((f|0)!=16){h=y[(e+f|0)+1414|0]!=0|h;f=f+1|0;continue}break}while(1){if((g|0)!=128){h=y[((g<<1)+e|0)+1431|0]!=0|h;g=g+1|0;continue}break}n:{if(!(h&1)){break n}d=a+901692|0;g=0;while(1){if((g|0)==16){d=a+902204|0;g=0;while(1){if((g|0)!=128){f=(e+1264|0)+(g<<1)|0;o:{if(y[f+167|0]){x[23420]=0;Y(493,e+240|0);h=x[23420];x[23420]=0;p:{q:{r:{s:{t:{if((h|0)!=1){h=y[f+167|0];x[23420]=0;x[e+264>>2]=h-1;R(494,e+1208|0,e+264|0);h=x[23420];x[23420]=0;if((h|0)==1){break t}f=y[f+166|0];x[23420]=0;v[e+208|0]=f;R(495,e+1184|0,e+208|0);f=x[23420];x[23420]=0;if((f|0)==1){break s}x[23420]=0;X(496,e+320|0,e+240|0,e+1208|0,e+1184|0);f=x[23420];x[23420]=0;if((f|0)==1){break r}f=e+320|0;ue(e+1240|0,f);Xe(pe(d,g),x[e+1240>>2],x[e+1244>>2]);xb(f);xb(e+1184|0);xb(e+1208|0);Sb(e+240|0);break o}d=P()|0;break e}d=P()|0;break p}d=P()|0;break q}d=P()|0;xb(e+1184|0)}xb(e+1208|0)}Sb(e+240|0);break e}f=qc(e+1232|0,21473);Xe(pe(d,g),x[f>>2],x[e+1236>>2])}g=g+1|0;continue}break}j=x[a+480180>>2];break n}f=(e+g|0)+1414|0;u:{if(y[f|0]){x[23420]=0;Y(497,e+240|0);h=x[23420];x[23420]=0;v:{w:{x:{if((h|0)!=1){f=y[f|0];x[23420]=0;x[e+1184>>2]=f-1;R(494,e+1208|0,e+1184|0);f=x[23420];x[23420]=0;if((f|0)==1){break x}x[23420]=0;U(275,e+320|0,e+240|0,e+1208|0);f=x[23420];x[23420]=0;if((f|0)==1){break w}f=e+320|0;ue(e+1256|0,f);Xe(pe(d,g),x[e+1256>>2],x[e+1260>>2]);xb(f);xb(e+1208|0);Sb(e+240|0);break u}d=P()|0;break e}d=P()|0;break v}d=P()|0;xb(e+1208|0)}Sb(e+240|0);break e}f=qc(e+1248|0,21473);Xe(pe(d,g),x[f>>2],x[e+1252>>2])}g=g+1|0;continue}}d=y[a+484376|0];f=x[a+484360>>2];x[23420]=0;f=Yb(f,d);d=j&5;ea(326,f|0,m|0,y[e+1265|0]|y[e+1266|0]<<8,(d?65535:255)|0,(d?65535:254)|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;U(178,e+320|0,m|0,D(y[e+1264|0],y[e+1269|0]|y[e+1270|0]<<8)<<1);d=x[23420];x[23420]=0;if((d|0)!=1){d=e+320|0;I=jc(e+1208|0,d);zb(d);x[23420]=0;U(178,d|0,m|0,(y[e+1269|0]|y[e+1270|0]<<8)<<1);d=x[23420];x[23420]=0;y:{if((d|0)!=1){d=e+320|0;J=jc(e+1184|0,d);zb(d);x[23420]=0;r=Q(206,e+1168|0,y[e+1271|0]|y[e+1272|0]<<8)|0;d=x[23420];x[23420]=0;z:{if((d|0)!=1){N=e,O=Db(x[r>>2]),x[N+264>>2]=O;d=Db(x[r+4>>2]);A:{B:{C:{while(1){f=x[e+264>>2];if(!Pb(f,d)){j=a+480180|0;d=x[j>>2];B=c&1;if(!B){break B}x[23420]=0;R(213,a+484344|0,y[e+1269|0]|y[e+1270|0]<<8);f=x[23420];x[23420]=0;if((f|0)!=1){break B}d=P()|0;break A}x[23420]=0;g=T(145,m|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;U(178,e+240|0,m|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break C}h=f;f=e+240|0;g=jc(e+320|0,f);bd(h,g);zb(g);zb(f);th(e+264|0);continue}break}d=P()|0;break A}d=P()|0;break A}s=(d|0)==16?14:(d|0)==32?1:13;K=a+484344|0;q=0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[e+1269|0]|y[e+1270|0]<<8)>>>0<=q>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[23420]=0;d=T(182,J|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break H}x[e+240>>2]=d;if(!B){break D}x[23420]=0;d=W(214,K|0,q&65535,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break H}n=0;if(!d){break D}while(1){g=n&65535;if(g>>>0>=y[e+1264|0]){break D}x[23420]=0;d=T(182,I|0)|0;f=x[23420];x[23420]=0;J:{if((f|0)!=1){f=x[r>>2];if(Ff(f,x[r+4>>2])>>>0<=d>>>0){break J}k=Bg(f,d);zc(k);f=0;d=_b(x[K>>2],q);g=ed(x[d>>2],x[x[d+48>>2]+12>>2],0,g);K:while(1){if(A[e+240>>2]<=f>>>0){break J}x[23420]=0;d=T(194,k|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){if(!d){break J}t=d>>>4|0;u=d&15;Rh(e+320|0);h=0;while(1){L:{M:{N:{if(u>>>0>(h&255)>>>0){x[23420]=0;R(498,k|0,e+264|0);d=x[23420];x[23420]=0;if((d|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{d=y[e+264|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(d-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}d=y[e+265|0];fa:{if(d>>>0<=119){d=d+s|0;break fa}ga:{switch(d-254|0){case 1:d=255;break fa;case 0:d=254;break fa;default:break ga}}d=253}v[e+320|0]=d;l=$A(d)&l;break L}v[e+321|0]=y[e+265|0]+1;break L}ha:{if(y[e+322|0]){break ha}d=x[j>>2];if((d|0)!=32){if((d|0)!=4){break ha}d=y[e+265|0];if(d&15){break ha}v[e+322|0]=11;v[e+324|0]=d>>>4;break L}d=0;i=y[e+265|0];while(1){if((d|0)==10){break ha}if((i|0)==y[d+43744|0]){v[e+324|0]=d;v[e+322|0]=11;break L}else{d=d+1|0;continue}}}v[e+323|0]=4;v[e+325|0]=y[e+265|0];break L}d=y[e+265|0];if(!(y[e+322|0]|d>>>0>9|x[j>>2]!=32)){v[e+324|0]=d;v[e+322|0]=8;break L}v[e+325|0]=d;v[e+323|0]=5;break L}if(y[e+322|0]){d=y[e+265|0];break M}i=x[j>>2];F=(i|0)!=32;d=y[e+265|0];if(!(F|(d|0)!=255)){v[e+324|0]=64;v[e+322|0]=2;break L}ia:{if(!F){if(d&3){break M}break ia}if(d&15|(i|0)!=4){break M}}v[e+322|0]=2;v[e+324|0]=(d&252)>>>2;break L}d=y[e+265|0];if(!(y[e+322|0]|d>>>0>64|x[j>>2]==1)){v[e+324|0]=d;v[e+322|0]=1;break L}v[e+325|0]=d;v[e+323|0]=13;break L}v[e+323|0]=14;d=y[e+265|0];v[e+325|0]=d;if(x[j>>2]==32){break L}v[e+325|0]=D((d&240)>>>4|0,10)+(d&15);break L}d=y[e+265|0];v[e+325|0]=d;if(d>>>0<=31){v[e+323|0]=16;break L}v[e+323|0]=17;break L}i=y[e+265|0];if(i>>>0>=16){v[e+324|0]=i>>>4;v[e+322|0]=(d|0)==20?3:5;break L}v[e+324|0]=i;v[e+322|0]=(d|0)==20?4:6;break L}d=y[e+265|0];if(d>>>0>=16){v[e+322|0]=10;v[e+324|0]=d>>>4;break L}v[e+324|0]=d;v[e+322|0]=9;break L}v[e+323|0]=28;v[e+325|0]=y[e+265|0]|16;break L}v[e+323|0]=28;v[e+325|0]=y[e+265|0]|32;break L}v[e+324|0]=y[e+265|0];v[e+322|0]=y[d+26656|0];break L}v[e+325|0]=y[e+265|0];d=y[e+323|0];v[e+323|0]=(d|0)==4?6:(d|0)==5?7:11;break L}d=y[e+265|0];v[e+324|0]=(d>>>0)%10;if(d>>>0<=9){v[e+322|0]=5;break L}if(d>>>0<=19){v[e+322|0]=6;break L}if(d>>>0<=29){v[e+322|0]=3;break L}if(d>>>0>39){break L}v[e+322|0]=4;break L}v[e+324|0]=y[e+265|0];v[e+322|0]=y[d+26656|0];break L}d=y[e+265|0]+33|0;if((d&255)>>>0>9){break L}v[e+324|0]=d;v[e+322|0]=15;break L}if(d>>>0>57){break L}v[e+325|0]=y[e+265|0];v[e+323|0]=y[d+26656|0];break L}x[e+264>>2]=f+t;d=x[Hb(e+264|0,e+240|0)>>2];d=d>>>0<f>>>0?f:d;while(1){if((d|0)!=(f|0)){h=x[e+320>>2];v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24;h=z[e+324>>1];v[g+4|0]=h;v[g+5|0]=h>>>8;f=f+1|0;g=D(y[e+1264|0],6)+g|0;continue}break}f=d;continue K}d=P()|0;break A}v[e+325|0]=d;v[e+323|0]=9}h=h+1|0;continue}}break}d=P()|0;break A}d=P()|0;break A}n=n+1|0;continue}}g=z[a+480192>>1];d=0;break E}d=P()|0;break A}if((l^1)&1|z[E>>1]!=4){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}g=0;d=!((y[e+1279|0]|y[e+1280|0]<<8|(y[e+1281|0]<<16|y[e+1282|0]<<24))&512)}x[23420]=0;B=Q(499,e+1152|0,g|0)|0;f=x[23420];x[23420]=0;ja:{ka:{la:{ma:{na:{if((f|0)!=1){n=a+480192|0;l=o>>>0<5;q=a+480180|0;h=1;oa:{while(1){j=h&65535;if(j>>>0>z[n>>1]){break oa}pa:{qa:{ra:{sa:{if(!d){x[23420]=0;g=W(239,a|0,j|0,0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break sa}if(g){break ra}}while(1){x[23420]=0;f=T(194,m|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break ka}if(f){continue}break}if(!l){while(1){x[23420]=0;f=T(194,m|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){d=P()|0;break ja}if(f){continue}break}}x[23420]=0;Q(176,m|0,826)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break qa}}d=P()|0;break ja}f=Jb(e+240|0);x[23420]=0;U(336,m|0,f|0,-1);k=x[23420];x[23420]=0;if((k|0)==1){break pa}Dc(g+492|0,f);if(!l){x[23420]=0;U(336,m|0,f|0,-1);k=x[23420];x[23420]=0;if((k|0)==1){break pa}Dc(g+524|0,f)}x[23420]=0;k=Q(500,m|0,e+320|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break la}if(!k){break na}k=x[q>>2];x[23420]=0;U(501,e+320|0,g|0,k|0);g=x[23420];x[23420]=0;if((g|0)==1){break la}if(x[q>>2]==4){g=Cb(x[B>>2],j-1|0);j=z[e+1122>>1]|z[e+1124>>1]<<16;v[g|0]=j;v[g+1|0]=j>>>8;v[g+2|0]=j>>>16;v[g+3|0]=j>>>24}xb(f)}h=h+1|0;continue}break}break la}if(!d){break ma}w[a+480192>>1]=0;break ma}d=P()|0;break A}xb(f)}d=z[a+480190>>1];x[23420]=0;q=Q(502,e+304|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){F=!(v[e+1279|0]&1)|o>>>0>4;s=c&2;M=a+480180|0;h=1;d=0;while(1){c=d;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{n=h&65535;if(n>>>0<=z[a+480190>>1]){j=Jb(e+288|0);x[23420]=0;U(336,m|0,j|0,-1);d=x[23420];x[23420]=0;Ga:{Ha:{if((d|0)!=1){Dc(((n<<5)+a|0)+946304|0,j);d=o>>>0<5;if(d){break Ha}x[23420]=0;U(336,m|0,j|0,-1);f=x[23420];x[23420]=0;if((f|0)!=1){break Ga}}d=P()|0;break wa}Df(j)}x[23420]=0;f=Q(503,m|0,e+320|0)|0;g=x[23420];x[23420]=0;Ia:{Ja:{if((g|0)==1){break Ja}if(!f){break Ia}g=x[M>>2];x[23420]=0;l=D(n,104)+a|0;f=l+484380|0;X(504,e+320|0,f|0,g|0,F|0);g=x[23420];x[23420]=0;if((g|0)==1){break Ja}ze(l+484423|0,j);t=0;Ka:{if((z[e+340>>1]&61440)!=28672|d){break Ka}x[23420]=0;t=T(505,m|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break Ka}d=P()|0;break wa}if(!s){break ua}g=y[e+355|0]|y[e+356|0]<<8|(y[e+357|0]<<16|y[e+358|0]<<24);d=z[e+340>>1];k=d&61440;if(!(g|k)){d=_c(e+240|0,d&1?16:8,d&1024?3:1,0,0);x[23420]=0;W(207,d|0,f|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break ua}d=P()|0;break wa}if((g|0)<0){d=g+n|0;if((d|0)<=0){break ua}ZR(f,(D(d,104)+a|0)+484380|0);break ua}if((g|0)<=0){break ua}if(d&1){i=l+484414|0;w[i>>1]=z[i>>1]|1}if(d&1024){i=l+484414|0;w[i>>1]=z[i>>1]|64}x[23420]=0;U(178,e+240|0,b|0,g|0);g=x[23420];x[23420]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{if((g|0)!=1){i=e+240|0;g=jc(e+264|0,i);zb(i);i=Gd(z[f+34>>1]);L=(k|0)==16384;if(!L&(k|0)!=8192){break Oa}u=x[g>>2];x[23420]=0;u=T(148,u|0)|0;G=x[23420];x[23420]=0;if((G|0)==1){break La}G=4/(i>>>0)|0;Wia(G,0,u,0);xc(f,lb?-1:D(G,u));if((k|0)==8192){break Qa}if(!L){break Oa}if(!Ag(f)){break Na}d=x[l+484400>>2];f=x[f>>2];if(!(v[e+340|0]&1)){break Pa}x[23420]=0;X(506,g|0,d|0,f|0,i|0);f=x[23420];x[23420]=0;d=c;if((f|0)==1){break ya}break Ma}d=P()|0;break wa}if(!Ag(f)){break Na}d=x[l+484400>>2];f=x[f>>2];if(v[e+340|0]&1){x[23420]=0;X(507,g|0,d|0,f|0,i|0);f=x[23420];x[23420]=0;d=c;if((f|0)!=1){break Ma}break ya}x[23420]=0;X(508,g|0,d|0,f|0,i|0);f=x[23420];x[23420]=0;d=c;if((f|0)==1){break ya}break Ma}x[23420]=0;X(509,g|0,d|0,f|0,i|0);f=x[23420];x[23420]=0;d=c;if((f|0)==1){break ya}break Ma}if((d&45056)==12288){d=YR(e+240|0,g,y[e+359|0]|y[e+360|0]<<8,t);N=bd(bl(x[q>>2],n-1|0),d),O=x[d+20>>2],x[N+20>>2]=O;zb(d);break Na}if((k|0)!=32768){d=1;if((k|0)!=4096){break Ma}k=he(e+240|0,g);x[23420]=0;d=Q(510,e+232|0,g|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){Ra:{Sa:{if(!y[e+237|0]){break Sa}t=y[e+359|0]|y[e+360|0]<<8;i=z[e+234>>1]<<1;if(t>>>0<(i&65535)>>>0){break Sa}i=t-i|0;v[e+359|0]=i;v[e+360|0]=i>>>8;d=z[d>>1];x[23420]=0;Q(143,g|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ra}x[23420]=0;d=T(190,g|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break Ra}x[23420]=0;U(178,e+184|0,g|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break Ra}d=e+184|0;i=jc(e+208|0,d);bd(k,i);zb(i);zb(d)}x[23420]=0;n=W(511,a|0,n|0,k|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ra}d=1;if(n){d=y[e+359|0]|y[e+360|0]<<8;Ta:{if(!d){break Ta}n=z[f+34>>1];i=uj(x[f>>2],n);if(i>>>0<=d>>>0){break Ta}n=lk(n);l=x[l+484400>>2];Ji(l,d+l|0,i-d|0);x[f>>2]=x[f>>2]-((d>>>0)/(n>>>0)|0)}xc(f,x[e+328>>2]);d=c}zb(k);break Ma}}d=P()|0;zb(k);break xa}x[23420]=0;d=Q(363,g|0,e+240|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break Fa}if(!d){break Na}x[e+80>>2]=x[e+248>>2];d=x[e+244>>2];x[e+72>>2]=x[e+240>>2];x[e+76>>2]=d;il(f,1,e+72|0)}d=c}zb(g);break ta}d=P()|0;break xa}d=P()|0;break wa}xb(j)}Ua:{Va:{Wa:{if(!s){break Wa}l=1;while(1){g=l&65535;if(g>>>0>z[a+480190>>1]){break Wa}b=bl(x[q>>2],g-1|0);d=x[b>>2];x[23420]=0;d=T(166,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ua}Xa:{Ya:{if(!d){break Ya}f=z[b+22>>1];d=f+l&65535;h=z[b+20>>1];o=(f|0)!=0&(d|0)!=0&d>>>0<=z[a+480190>>1]&(h|0)!=0;Za:{if(o){f=bl(x[q>>2],d-1|0);break Za}d=x[b>>2];x[23420]=0;h=T(148,d|0)|0;d=x[23420];x[23420]=0;f=b;if((d|0)==1){break Va}}zc(f);_a:{if(o){d=x[f+8>>2];j=x[f>>2];n=z[b+20>>1];x[23420]=0;d=W(144,j|0,d|0,n|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break Va}if(!d){break Ya}x[e+240>>2]=0;x[e+264>>2]=0;x[23420]=0;U(191,e+320|0,f|0,h|0);d=x[23420];x[23420]=0;$a:{if((d|0)!=1){j=qA(xe(e+320|0),vi(x[e+320>>2]),e+240|0,e+264|0);x[23420]=0;Q(176,f|0,x[e+240>>2])|0;d=x[23420];x[23420]=0;if((d|0)==1){break $a}Oc(e+320|0);break _a}d=P()|0;break va}d=P()|0;Oc(e+320|0);break va}j=0;x[e+240>>2]=0;x[e+264>>2]=0}x[23420]=0;R(512,e+320|0,b|0);d=x[23420];x[23420]=0;ab:{bb:{if((d|0)!=1){d=xe(e+320|0);h=x[e+320>>2];if(!o){j=qA(d,vi(h),e+240|0,e+264|0);x[23420]=0;f=x[e+240>>2];Q(176,b|0,f|0)|0;o=x[23420];x[23420]=0;if((o|0)==1){break Xa}h=h-f|0;d=d+f|0}if(j){break bb}c=1;break ab}d=P()|0;break va}f=D(g,104)+a|0;n=f+484380|0;Ag(n);t=f+484400|0;f=0;g=x[e+264>>2];while(1){cb:{if(!h|(g|0)!=1?g:0){break cb}g=x[n>>2];if(g>>>0<=f>>>0){break cb}if(!Td(g,x[n+20>>2])){break cb}x[e+208>>2]=0;x[e+184>>2]=0;g=XR(j,d,vi(h),e+208|0,e+288|0,e+184|0);x[23420]=0;x[e+240>>2]=g;Q(176,b|0,g|0)|0;o=x[23420];x[23420]=0;if((o|0)==1){break za}Vh(e+184|0,vi(x[n>>2]-f|0));o=x[e+184>>2];db:{if((o|0)<=0){break db}k=x[e+208>>2];u=z[n+34>>1];if((Gd(u)|0)!=(k|0)){break db}i=D(f,k);s=x[t>>2];if(u&1){k=Vg(e+168|0,s+(i<<1)|0,k,o);i=Vg(e+152|0,x[e+288>>2],x[e+208>>2],o);x[23420]=0;x[e- -64>>2]=x[k+8>>2];s=x[k+4>>2];x[e+56>>2]=x[k>>2];x[e+60>>2]=s;x[e+48>>2]=x[i+8>>2];k=x[i+4>>2];x[e+40>>2]=x[i>>2];x[e+44>>2]=k;R(513,e+56|0,e+40|0);k=x[23420];x[23420]=0;if((k|0)!=1){break db}break za}k=Vg(e+136|0,i+s|0,k,o);i=Vg(e+120|0,x[e+288>>2],x[e+208>>2],o);x[23420]=0;x[e+32>>2]=x[k+8>>2];s=x[k+4>>2];x[e+24>>2]=x[k>>2];x[e+28>>2]=s;x[e+16>>2]=x[i+8>>2];k=x[i+4>>2];x[e+8>>2]=x[i>>2];x[e+12>>2]=k;R(514,e+24|0,e+8|0);k=x[23420];x[23420]=0;if((k|0)==1){break za}}h=h-g|0;d=d+g|0;g=WR(j);x[e+264>>2]=g;f=f+o|0;continue}break}VR(j)}Oc(e+320|0)}l=l+1|0;continue}break}break za}eb:{if(x[a+480180>>2]!=4){break eb}g=0;d=a+480192|0;while(1){if(z[d>>1]<=g>>>0){break eb}b=Cb(x[B>>2],g);f=y[b+3|0];h=y[b+2|0];j=y[b+1|0];b=y[b|0];x[23420]=0;g=g+1|0;ma(515,a|0,g&65535,b|0,j|0,h|0,f|0);b=x[23420];x[23420]=0;if((b|0)!=1){continue}break}d=P()|0;break va}fb:{gb:{hb:{if(!(y[e+1281|0]&16)){break hb}b=x[m+8>>2];d=x[m>>2];x[23420]=0;b=W(144,d|0,b|0,1)|0;d=x[23420];x[23420]=0;ib:{jb:{kb:{if((d|0)!=1){if(!b){break hb}g=0;x[23420]=0;b=T(194,m|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break kb}if(!(b&1)){break ib}while(1){if(z[E>>1]<=g>>>0){break ib}x[23420]=0;b=T(145,m|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break jb}v[((g<<5)+a|0)+480288|0]=b;g=g+1|0;continue}}d=P()|0;break va}d=P()|0;break va}d=P()|0;break va}while(1){b=x[m+8>>2];d=x[m>>2];x[23420]=0;b=W(144,d|0,b|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Aa}if(!b){break hb}x[23420]=0;b=T(194,m|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break fb}if(!b){break hb}x[23420]=0;d=T(145,m|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break gb}x[23420]=0;U(178,e+240|0,m|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break gb}d=e+240|0;f=jc(e+320|0,d);zb(d);lb:{if(b>>>0<=250){x[23420]=0;R(386,f|0,(D(b,160)+a|0)+906140|0);b=x[23420];x[23420]=0;if((b|0)==1){break lb}}zb(f);continue}break}d=P()|0;zb(f);break va}l=a+901404|0;h=Jb(e+208|0);o=a+480180|0;n=a+484348|0;d=0;j=0;while(1){b=x[m+8>>2];f=x[m>>2];x[23420]=0;b=W(144,f|0,b|0,8)|0;f=x[23420];x[23420]=0;mb:{nb:{ob:{pb:{qb:{if((f|0)!=1){if(b){x[23420]=0;f=T(145,m|0)|0;b=x[23420];x[23420]=0;rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{if((b|0)!=1){x[23420]=0;b=T(145,m|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break yb}x[23420]=0;U(178,e+320|0,m|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break xb}g=e+320|0;b=jc(e+240|0,g);zb(g);if((f|0)==1229211981){break ub}if((f|0)==1229476432){break vb}if((f|0)==1397900630){break wb}if((f|0)!=1414548815){break mb}x[23420]=0;f=Q(348,b|0,13698)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ea}if(!f){break nb}x[23420]=0;f=T(145,b|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){x[23420]=0;U(178,e+320|0,b|0,f|0);f=x[23420];x[23420]=0;if((f|0)!=1){break tb}}d=P()|0;break Da}d=P()|0;break Ba}d=P()|0;break Ba}d=P()|0;break Ba}zb:{Ab:{Bb:{f=x[o>>2];switch(f-2|0){case 1:break mb;case 0:break sb;case 2:break Ab;default:break Bb}}if((f|0)==16){break zb}if((f|0)!=32){break mb}x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ea}x[23420]=0;j=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break mb}break Ea}x[e+320>>2]=32;f=x[b>>2];x[23420]=0;f=T(148,f|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){x[e+264>>2]=f;f=x[Hb(e+320|0,e+264|0)>>2];x[23420]=0;U(516,b|0,h|0,f|0);f=x[23420];x[23420]=0;if((f|0)!=1){break mb}}d=P()|0;break Da}x[23420]=0;f=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break rb}x[23420]=0;R(517,e+264|0,4172);g=x[23420];x[23420]=0;Cb:{if((g|0)!=1){x[e+288>>2]=f>>>4;x[23420]=0;x[e+104>>2]=f&15;X(288,e+320|0,e+264|0,e+288|0,e+104|0);f=x[23420];x[23420]=0;if((f|0)==1){break Cb}f=e+320|0;Gb(h,f);yb(f);cc(e+264|0);break mb}d=P()|0;break Da}d=P()|0;cc(e+264|0);break Da}x[23420]=0;f=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ea}x[a+480216>>2]=f;x[23420]=0;f=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ea}x[a+480220>>2]=f;break mb}x[23420]=0;Q(358,b|0,l|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ea}XA(l);break mb}g=e+320|0;f=jc(e+264|0,g);zb(g);g=x[f>>2];x[23420]=0;g=T(148,g|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break ob}w[e+320>>1]=g>>>5;N=e,O=of(x[a+484344>>2],x[n>>2]),w[N+288>>1]=O;k=z[Zc(e+320|0,e+288|0)>>1];g=0;while(1){if((g|0)==(k|0)){zb(f);break nb}x[23420]=0;R(518,f|0,e+320|0);i=x[23420];x[23420]=0;Db:{if((i|0)==1){break Db}i=x[K>>2];x[23420]=0;R(519,_b(i,g)|0,e+320|0);i=x[23420];x[23420]=0;if((i|0)==1){break Db}g=g+1|0;continue}break}break ob}x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ea}break mb}d=P()|0;break Da}b=x[a+480180>>2];Eb:{Fb:{Gb:{if((b|0)!=32){break Gb}f=d&65535;if(f>>>0<256){break Gb}if(f>>>0<532){break Fb}}b=(b|0)!=2;Hb:{if(b){break Hb}f=d&65535;if(f>>>0<12544){break Hb}if(f>>>0<12820){break Fb}}if(b){break Eb}b=d&65535;if(b>>>0<4864|b>>>0>4895){break Eb}}bq(l)}g=1;Ib:{if(!(v[e+1281|0]&1)){break Ib}f=x[a+1074308>>2];if(!f){d=a+480192|0;f=a+480180|0;while(1){b=g&65535;if(b>>>0<=z[d>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){l=x[f>>2];x[23420]=0;R(520,Ci(b,2)|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break qb}v[b+19|0]=y[b+19|0]+3>>>2}g=g+1|0;continue}break}f=x[a+1074308>>2]}if(f>>>0<=18350079){x[23420]=0;b=Q(252,a+1074312|0,27)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ca}x[23420]=0;Q(252,b|0,57)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Ca}f=x[a+1074308>>2]}if(f>>>0<=19070975){x[23420]=0;Q(252,a+1074312|0,73)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Ca}f=x[a+1074308>>2]}if(f>>>0>19267583){break Ib}x[23420]=0;Q(252,a+1074312|0,50)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Ca}}Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{if(eh(x[h+4>>2],y[h+11|0])){x[23420]=0;Y(521,e+240|0);b=x[23420];x[23420]=0;Xb:{if((b|0)!=1){x[23420]=0;U(486,e+320|0,e+240|0,e+1751|0);b=x[23420];x[23420]=0;if((b|0)==1){break Xb}break Wb}d=P()|0;break Ba}d=P()|0;cc(e+240|0);break Ba}x[23420]=0;Y(522,e+240|0);b=x[23420];x[23420]=0;if((b|0)==1){break Vb}x[23420]=0;X(523,e+320|0,e+240|0,e+1751|0,h|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ub}}b=e+320|0;Gb(h,b);yb(b);b=e+240|0;cc(b);x[23420]=0;R(485,b|0,3960);b=x[23420];x[23420]=0;if((b|0)==1){break Sb}x[23420]=0;U(486,e+320|0,e+240|0,e+1751|0);b=x[23420];x[23420]=0;if((b|0)==1){break Rb}b=e+320|0;Gb(a+1298344|0,b);yb(b);cc(e+240|0);x[23420]=0;b=Q(1,b|0,14836)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Qb}Gb(a+1298356|0,b);yb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break pb;case 1:break Mb;case 3:break Nb;case 0:break Ob;default:break Tb}}d=P()|0;break Ba}d=P()|0;cc(e+240|0);break Ba}if((b|0)==16){break Pb}if((b|0)==32){break Lb}if((b|0)!=16777216){break pb}x[23420]=0;b=Q(1,e+240|0,10016)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Kb}Gb(a+1298392|0,b);yb(b);x[23420]=0;b=Q(1,e+264|0,13645)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Jb}Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;cc(e+240|0);break Ba}d=P()|0;break Ba}x[23420]=0;b=Q(1,e+240|0,10021)|0;d=x[23420];x[23420]=0;Yb:{if((d|0)!=1){Gb(a+1298392|0,b);yb(b);x[23420]=0;b=Q(1,e+264|0,8283)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Yb}Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;break Ba}x[23420]=0;b=Q(1,e+240|0,12176)|0;d=x[23420];x[23420]=0;Zb:{if((d|0)!=1){Gb(a+1298392|0,b);yb(b);x[23420]=0;b=Q(1,e+264|0,14108)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Zb}Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;break Ba}x[23420]=0;b=Q(1,e+240|0,9994)|0;d=x[23420];x[23420]=0;_b:{if((d|0)!=1){Gb(a+1298392|0,b);yb(b);x[23420]=0;b=Q(1,e+264|0,15065)|0;d=x[23420];x[23420]=0;if((d|0)==1){break _b}Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;break Ba}x[23420]=0;b=Q(1,e+240|0,10366)|0;d=x[23420];x[23420]=0;$b:{if((d|0)!=1){Gb(a+1298392|0,b);yb(b);x[23420]=0;b=Q(1,e+264|0,14876)|0;d=x[23420];x[23420]=0;if((d|0)==1){break $b}Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;break Ba}x[23420]=0;b=Q(1,e+240|0,6088)|0;d=x[23420];x[23420]=0;ac:{bc:{cc:{dc:{ec:{if((d|0)!=1){Gb(a+1298392|0,b);yb(b);if(!(j&65535)){break ac}x[23420]=0;R(253,e+288|0,4275);b=x[23420];x[23420]=0;if((b|0)==1){break ec}x[e+116>>2]=(j&65280)>>>8;x[23420]=0;x[e+100>>2]=j&255;R(380,e+104|0,e+100|0);b=x[23420];x[23420]=0;if((b|0)==1){break dc}x[23420]=0;X(366,e+264|0,e+288|0,e+116|0,e+104|0);b=x[23420];x[23420]=0;if((b|0)==1){break cc}b=e+264|0;Gb(a+1298380|0,b);yb(b);yb(e+104|0);cc(e+288|0);break pb}d=P()|0;break Ba}d=P()|0;break Ba}d=P()|0;break bc}d=P()|0;yb(e+104|0)}cc(e+288|0);break Ba}x[23420]=0;b=Q(1,e+264|0,8459)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Gb(a+1298380|0,b);yb(b);break pb}d=P()|0;break Ba}d=P()|0;break Ba}d=P()|0;break Ba}d=P()|0;break Ba}d=P()|0;break Ba}Gb(a+1298368|0,h);fc:{if(x[a+1074308>>2]){x[a+1298404>>2]=8;break fc}if(x[a+480180>>2]==1){x[a+1298404>>2]=13;break fc}x[a+1298404>>2]=5}g=1;gc:{hc:{if(c&1){x[23420]=0;b=Q(1,e+288|0,16448)|0;c=x[23420];x[23420]=0;if((c|0)==1){break hc}a=x[a+1298464>>2];x[23420]=0;U(353,a|0,2,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break gc}yb(b)}yb(h);UR(q);tc(B);kd(r);zb(J);zb(I);break c}d=P()|0;break Ba}d=P()|0;yb(b);break Ba}d=P()|0;zb(f);break Da}x[23420]=0;f=Q(348,b|0,13703)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ea}ic:{if(!f){break ic}x[23420]=0;f=T(145,b|0)|0;g=x[23420];x[23420]=0;jc:{if((g|0)!=1){x[23420]=0;U(178,e+264|0,b|0,f|0);f=x[23420];x[23420]=0;if((f|0)!=1){break jc}}d=P()|0;break Da}g=e+264|0;f=jc(e+320|0,g);zb(g);g=x[f>>2];x[23420]=0;g=T(148,g|0)|0;k=x[23420];x[23420]=0;if((k|0)!=1){w[e+264>>1]=(g>>>0)/20;w[e+288>>1]=z[E>>1];k=z[Zc(e+264|0,e+288|0)>>1];g=0;while(1){if((g|0)==(k|0)){zb(f);break ic}x[23420]=0;U(359,f|0,((g<<5)+a|0)+480289|0,20);i=x[23420];x[23420]=0;if((i|0)!=1){g=g+1|0;continue}break}}d=P()|0;zb(f);break Da}x[23420]=0;Q(369,a|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ea}x[23420]=0;X(370,a|0,b|0,1,0);f=x[23420];x[23420]=0;if((f|0)==1){break Ea}if((d-2186&65535)>>>0<=117){x[o>>2]=16777216;x[23420]=0;U(384,a|0,b|0,d&65535);f=x[23420];x[23420]=0;if((f|0)==1){break Ea}}if(!x[a+1074308>>2]){break mb}x[23420]=0;f=Q(1,e+184|0,17433)|0;g=x[23420];x[23420]=0;kc:{lc:{mc:{if((g|0)!=1){g=x[a+1074308>>2];x[23420]=0;R(128,e+264|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break mc}x[23420]=0;U(2,e+320|0,f|0,e+264|0);g=x[23420];x[23420]=0;if((g|0)==1){break lc}g=e+320|0;Gb(h,g);yb(g);yb(e+264|0);yb(f);break mb}d=P()|0;break Da}d=P()|0;break kc}d=P()|0;yb(e+264|0)}yb(f);break Da}zb(b);continue}}d=P()|0;break va}d=P()|0;break va}d=P()|0;break va}d=P()|0;break va}d=P()|0;break xa}d=P()|0}zb(b);break Ba}d=P()|0}yb(h);break va}d=P()|0;break va}d=P()|0;Oc(e+320|0);break va}d=P()|0}zb(g)}xb(j)}UR(q);break ja}d=c}xb(j);h=h+1|0;continue}}d=P()|0;break ja}d=P()|0;xb(f);break ja}d=P()|0}tc(B);break A}q=q+1|0;continue}}kd(r);break z}d=P()|0}zb(J);break y}d=P()|0}zb(I);break e}d=P()|0;break e}d=P()|0;break e}else{nc:{oc:{if(!l){v[e+320|0]=y[(e+g|0)+1286|0];v[e+240|0]=64;N=((g<<5)+a|0)+480286|0,O=y[Wb(e+320|0,e+240|0)|0],w[N>>1]=O;break oc}if(r){break nc}}pc:{d=y[(e+g|0)+1350|0];if((d|0)!=255){if((d|0)!=127){break pc}x[((g<<5)+a|0)+480280>>2]=256;break nc}w[((g<<5)+a|0)+480284>>1]=256;break nc}w[((g<<5)+a|0)+480284>>1]=d}g=g+1|0;continue}}d=P()|0;break d}d=P()|0;break d}d=P()|0}zb(m)}dc(C);S(d|0);p()}zb(m)}dc(C)}hb=e+1760|0;return g|0}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=hb-976|0;hb=e;zc(b);a:{if(!jS(b,e+920|0)){break a}if(!nS(e+920|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(mS(e+920|0),lb))){break a}if(!c){d=1;break a}Dd(a,8);Cg(a);aa=y[e+923|0];L=aa-48|0;v[e+919|0]=L;$c(b,ac(x[e+928>>2]));f=e+608|0;Xd(f,b,504);_=jc(e+896|0,f);zb(f);x[23420]=0;R(458,b|0,f|0);f=x[23420];x[23420]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(y[e+891|0]>63){break b}if(Lb(z[e+608>>1])<<16>>16<0){break b}Tb(e+528|0,0,80);h:{d=ac(x[e+952>>2]);if(!d){break h}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){if(!f){break h}x[23420]=0;R(459,b|0,e+528|0);d=x[23420];x[23420]=0;if((d|0)!=1){break h}}i=P()|0;break e}x[23420]=0;U(460,e+520|0,b|0,L&255);d=x[23420];x[23420]=0;if((d|0)!=1){ba=Ue(e+520|0);d=0;f=z[e+520>>1];if((f-128&65535)>>>0<65409){break b}w[a+480188>>1]=f;M=Qb(e+504|0);f=ac(x[e+944>>2]);i:{if(f){x[23420]=0;Q(143,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;U(461,b|0,M|0,y[e+891|0]);d=x[23420];x[23420]=0;if((d|0)==1){break g}d=y[e+891|0];break i}f=0;if(y[e+891|0]){break c}}j=d&255;w[a+480192>>1]=j;w[a+480190>>1]=j;ca=(L&255)>>>0<2|v[e+872|0]>=0;o=!ca;q=c&2;u=1;G=1;while(1){j:{k:{l:{m:{n:{o:{g=G&65535;if(g>>>0<=(j&65535)>>>0){x[23420]=0;s=u&65535;f=W(239,a|0,g|0,s|0)|0;d=x[23420];x[23420]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;break f}B=x[((g<<2)+a|0)+900380>>2];w[e+84>>1]=0;x[e+80>>2]=0;x[23420]=0;C=T(162,e+480|0)|0;d=x[23420];x[23420]=0;q:{if((d|0)!=1){d=Cb(x[M>>2],g-1|0);d=ac(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break k}if(!f){break r}x[23420]=0;R(462,b|0,e+80|0);d=x[23420];x[23420]=0;if((d|0)==1){break k}f=x[e+80>>2];d=z[e+84>>1];x[23420]=0;f=ac(f);d=Lb(d);U(178,e+120|0,b|0,f<<(d>>>5&1&d<<16>>16>0));d=x[23420];x[23420]=0;if((d|0)==1){break k}f=e+120|0;d=jc(e+192|0,f);bd(C,d);zb(d);zb(f)}d=Lb(z[e+84>>1]);f=d&15;r=d<<16>>16;if((r|0)>=0){break q}Ut(B,0);da=1;break o}i=P()|0;break f}if(f>>>0>6){break o}A=y[f+26534|0];if(!f){break m}w[a+480190>>1]=(z[a+480190>>1]+A|0)-1;l=B+108|0;t=B+236|0;m=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=D(j,12);d=(m<<3)+j|0;h=y[d+26540|0]+u|0;g=y[d+26588|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;ea=bc(t,f),fa=h,w[ea>>1]=fa;f=Kb(l,f);v[f|0]=g+y[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=ac(x[e+532>>2]);if(!d){break D}if(!Lb(z[e+536>>1])){break D}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break C}if(!f){break D}ea=e,fa=Lb(z[e+536>>1]),w[ea+192>>1]=fa;w[e+120>>1]=y[e+891|0];f=e+120|0;q=z[Zc(e+192|0,f)>>1];d=e+128|0;l=f|4;r=Lb(z[e+538>>1]);t=r>>>0<19;m=r>>>0<21;k=r>>>0<15;h=r>>>0<6;j=0;while(1){if((j|0)==(q|0)){break D}x[23420]=0;U(463,b|0,e+192|0,r|0);f=x[23420];x[23420]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;s=x[((j<<2)+a|0)+900380>>2];o=y[e+192|0];if(o){g=jo(e+120|0,0,64);jo(l,o-1&65535,64);f=y[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}jo(d,f+o|0,0);x[23420]=0;o=s+48|0;U(464,o|0,g|0,3);f=x[23420];x[23420]=0;if((f|0)==1){break G}if(y[e+192|0]==1){g=x[gc(e+472|0,Db(x[o>>2]))>>2];f=Db(x[o>>2]);f=x[o>>2]+(Rt(g,f)<<2)|0;Nd(o,Hi(f+4|0,x[o+4>>2],f));Db(f)}f=y[e+193|0];x[s>>2]=f?f<<9:32767;v[s+60|0]=y[s+60|0]|1;H=1}H:{if(t){break H}x[s+4>>2]=y[e+210|0]+1>>>1;if(m){break H}w[s+28>>1]=z[e+212>>1]}g=D(z[bc(s+236|0,61)>>1],104)+a|0;v[g+484417|0]=y[e+195|0]<<4;if(k){break F}f=ac(z[e+202>>1]|z[e+204>>1]<<16);x[g+484384>>2]=f;ea=g+484388|0,fa=ac(z[e+206>>1]|z[e+208>>1]<<16)+f|0,x[ea>>2]=fa;break E}i=P()|0;break f}i=P()|0;break f}if(h){continue}}f=g+484414|0;i=f;n=z[f>>1]&65529;f=y[e+197|0];w[i>>1]=n|f<<1&2|f>>>1&4;if(!(f&4)){continue}w[g+484412>>1]=0;continue}}I:{d=ac(x[e+548>>2]);if(!d){break I}if(!Lb(z[e+552>>1])){break I}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break C}if(!f){break I}ea=e,fa=Lb(z[e+552>>1]),w[ea+192>>1]=fa;w[e+120>>1]=y[e+891|0];m=z[Zc(e+192|0,e+120|0)>>1];k=Lb(z[e+554>>1]);d=0;J:while(1){if((d|0)==(m|0)){break I}x[23420]=0;U(465,b|0,e+192|0,k|0);f=x[23420];x[23420]=0;if((f|0)==1){break t}f=e+80|0;wT(f,e+192|0);x[23420]=0;R(210,e+120|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break u}d=d+1|0;t=((d<<2)+a|0)+900380|0;g=e+120|0;Dc(x[t>>2]+492|0,g);xb(g);f=x[t>>2];x[23420]=0;R(466,g|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break v}ea=e,fa=qj(x[e+120>>2]),x[ea+80>>2]=fa;h=yf(e+120|0);while(1){f=x[e+80>>2];if(Pb(f,h)){l=(z[Vp(f)>>1]<<5)+a|0;g=l+946328|0;q=x[t>>2];f=x[q+520>>2];x[g>>2]=x[q+516>>2];x[g+4>>2]=f;f=x[q+512>>2];g=l+946320|0;x[g>>2]=x[q+508>>2];x[g+4>>2]=f;f=x[q+504>>2];g=l+946312|0;x[g>>2]=x[q+500>>2];x[g+4>>2]=f;f=x[q+496>>2];g=l+946304|0;x[g>>2]=x[q+492>>2];x[g+4>>2]=f;Wg(e+80|0);continue}else{yA(e+120|0);continue J}}}}bq(a+901404|0);d=qc(e+464|0,4901);Xe(pe(a+901692|0,0),x[d>>2],x[d+4>>2]);zc(b);G=c&1;I=a+484344|0;J=a+1298332|0;B=a+1298308|0;$=a+484360|0;c=0;u=0;while(1){K:{f=c&255;if(f>>>0<y[ba|0]){x[23420]=0;X(467,b|0,e+920|0,e+528|0,e+608|0);d=x[23420];x[23420]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}x[23420]=0;f=T(259,$|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=pj(x[$>>2],d&255);E=gg(e+448|0);Gc(n);K=L&255;if(K>>>0>1){break N}i=0;f=Lb(z[e+610>>1]);if(f>>>0>256|z[a+480188>>1]>16){break L}d=e+192|0;gS(d,e+608|0);x[23420]=0;U(468,n|0,d|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break O}ea=e,fa=Db(x[n>>2]),x[ea+192>>2]=fa;d=Db(x[n+4>>2]);while(1){f=x[e+192>>2];if(Pb(f,d)){w[f>>1]=z[f>>1]+u;Re(e+192|0);continue}else{wh(a,1);f=z[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{v[e+192|0]=y[(d+e|0)+874|0];v[e+120|0]=64;ea=((d<<5)+a|0)+480286|0,fa=y[Wb(e+192|0,e+120|0)|0],w[ea>>1]=fa;d=d+1|0;continue}}}}i=P()|0;break f}i=P()|0;break w}gS(e+192|0,e+608|0);R:{S:{T:{U:{d=Lb(z[e+204>>1]);if(!(!d|d>>>0>64|z[a+480188>>1]>64)){o=ac(x[e+212>>2]);d=Lb(z[e+216>>1]);if(d){w[e+120>>1]=d;w[e+80>>1]=800;f=Vc(((z[Zc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=x[e+200>>2];x[23420]=0;g=Q(143,b|0,ac(d)|0)|0;d=x[23420];x[23420]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(z[a+480188>>1]<=d>>>0){break W}x[23420]=0;h=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){v[e+120|0]=h;v[e+80|0]=64;ea=((d<<5)+a|0)+480286|0,fa=y[Wb(e+120|0,e+80|0)|0],w[ea>>1]=fa;d=d+1|0;continue}break}i=P()|0;break w}X:{Y:{d=ac(x[e+208>>2]);if(!d){break Y}x[23420]=0;g=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(z[a+480188>>1]<=d>>>0){break X}x[23420]=0;h=T(469,b|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){ea=((d<<5)+a|0)+480284|0,fa=(Xb(h,-16,16)<<3)+128|0,w[ea>>1]=fa;d=d+1|0;continue}break}i=P()|0;break w}wh(a,1)}r=Qb(e+176|0);d=x[e+196>>2];x[23420]=0;g=Q(143,b|0,ac(d)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=z[e+610>>1];h=x[b+8>>2];g=x[b>>2];x[23420]=0;h=W(144,g|0,h|0,Lb(k)<<1)|0;g=x[23420];x[23420]=0;if((g|0)==1){break U}if(!h){break R}g=z[e+610>>1];x[23420]=0;h=W(470,b|0,r|0,Lb(g)|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break U}if(!h){break R}ea=e,fa=Db(x[r>>2]),x[ea+168>>2]=fa;q=Db(x[e+180>>2]);l=x[e+192>>2];t=z[e+206>>1];while(1){d=x[e+168>>2];if(!Pb(d,q)){i=0;d=1;break R}d=Lb(y[d|0]|y[d+1|0]<<8);Z:{if(Lb(t)>>>0<d>>>0){break Z}x[23420]=0;Q(143,b|0,ac(l)+(d<<2)|0)|0;d=x[23420];x[23420]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}x[23420]=0;g=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ca}x[23420]=0;g=Q(143,b|0,g|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ca}if(!g){break Z}g=x[b+8>>2];d=x[b>>2];x[23420]=0;g=W(144,d|0,g|0,42)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ca}if(!g){break Z}x[23420]=0;R(471,b|0,e+120|0);d=x[23420];x[23420]=0;da:{if((d|0)!=1){if(uc(x[n>>2],x[n+4>>2])){break da}x[23420]=0;R(472,n|0,65534);d=x[23420];x[23420]=0;if((d|0)!=1){break da}}i=P()|0;break S}h=Lb(z[e+160>>1]);x[e+116>>2]=h;g=x[b+8>>2];d=x[b>>2];x[23420]=0;g=W(144,d|0,g|0,h|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ba}if(!g){x[23420]=0;g=T(190,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ba}xc(e+116|0,g)}xc(e+116|0,65534);h=x[n+4>>2];g=x[n>>2];d=0;x[23420]=0;m=x[e+116>>2];k=Mc(g,h);R(473,n|0,m+k|0);g=x[23420];x[23420]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(m|0)){if(y[e+120|0]){break ea}break aa}x[23420]=0;h=T(258,b|0)|0;g=x[23420];x[23420]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}x[23420]=0;R(472,n|0,g+u&65535);g=x[23420];x[23420]=0;if((g|0)!=1){break fa}}i=P()|0;break S}d=d+1|0;continue}break}Fm(e+104|0,e+120|0);x[23420]=0;U(474,e+56|0,x[e+104>>2],x[e+108>>2]);d=x[23420];x[23420]=0;ga:{ha:{ia:{if((d|0)!=1){x[23420]=0;U(11,e+80|0,13,e+56|0);d=x[23420];x[23420]=0;if((d|0)==1){break ia}x[23420]=0;R(260,n|0,e+80|0);d=x[23420];x[23420]=0;if((d|0)==1){break ha}yb(e+80|0);xb(e+56|0);break aa}i=P()|0;break S}i=P()|0;break ga}i=P()|0;yb(e+80|0)}xb(e+56|0);break S}i=P()|0;break S}i=P()|0;break S}d=ac(x[e+152>>2]);if(!d){break Z}x[23420]=0;g=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break _}}i=P()|0;break S}if(!g){break Z}while(1){ja:{x[23420]=0;g=Q(475,b|0,e+104|0)|0;d=x[23420];x[23420]=0;ka:{la:{ma:{na:{if((d|0)!=1){if(!g){break Z}x[23420]=0;U(178,e+56|0,b|0,y[e+107|0]);d=x[23420];x[23420]=0;if((d|0)==1){break na}d=e+56|0;m=jc(e+80|0,d);zb(d);g=Lb(z[e+104>>1]);d=mu(g+k|0);w[e+56>>1]=d;if((g|0)==65535){break ja}i=x[n>>2];if(Mc(i,x[n+4>>2])>>>0<=d>>>0){break ja}g=65535;switch(y[e+106|0]-1|0){case 0:break la;case 1:break ma;default:break ka}}i=P()|0;break S}i=P()|0;break S}x[23420]=0;h=T(258,m|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break T}x[23420]=0;g=Q(476,E|0,e+56|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break T}w[g>>1]=h;i=x[n>>2];g=65534;d=z[e+56>>1]}ea=bc(i,d),fa=g,w[ea>>1]=fa}zb(m);continue}break}zb(m)}Re(e+168|0);continue}}i=P()|0;break w}i=0;break L}i=P()|0;break S}i=P()|0;zb(m)}od(r);break w}od(r);if(d){d=f>>>(o>>>1&1)|0;break M}Qt(E);if(!i){break d}break K}g=Lb(z[e+868>>1]);k=y[e+871|0];s=k&64;f=y[e+872|0];A=f&32;N=(f&31)+1|0;ea=a,fa=dS(g,s>>>6|0,A>>>5|0,N),x[ea+480204>>2]=fa;ea=a,fa=Wd(y[e+873|0],1,32),x[ea+480196>>2]=fa;if(A){x[a+480216>>2]=N;x[a+480220>>2]=N<<2}f=y[e+890|0];if(f){v[e+192|0]=f;v[e+120|0]=64;ea=a,fa=y[Wb(e+192|0,e+120|0)|0]<<2,x[ea+480200>>2]=fa}x[a+480228>>2]=d;x[a+480232>>2]=d;x[a+480208>>2]=x[a+480208>>2]&-3|(k^-1)>>>4&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=ac(x[e+572>>2]);if(!d){break ya}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}if(!f){break ya}d=x[e+576>>2];x[23420]=0;U(255,b|0,B|0,ac(d)|0);d=x[23420];x[23420]=0;if((d|0)==1){break xa}if(y[ba|0]<2){break ya}x[23420]=0;U(11,e+192|0,13,B|0);d=x[23420];x[23420]=0;za:{if((d|0)!=1){x[23420]=0;R(260,n|0,e+192|0);d=x[23420];x[23420]=0;if((d|0)==1){break za}yb(e+192|0);break ya}i=P()|0;break w}i=P()|0;yb(e+192|0);break w}Aa:{if(ac(x[e+544>>2])>>>0<2){break Aa}d=x[e+540>>2];x[23420]=0;f=Q(143,b|0,ac(d)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}if(!f){break Aa}d=x[e+544>>2];x[23420]=0;X(317,J|0,b|0,ac(d)-1|0,4);d=x[23420];x[23420]=0;if((d|0)==1){break xa}}d=ac(x[e+584>>2]);if(!d){break oa}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}if(!f){break oa}f=x[b+8>>2];d=x[b>>2];x[23420]=0;f=W(144,d|0,f|0,12)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}if(!f){break oa}x[23420]=0;Q(176,b|0,6)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}x[23420]=0;f=T(258,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}x[23420]=0;g=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break va}if(!g){break oa}f=x[b+8>>2];d=x[b>>2];x[23420]=0;f=W(144,d|0,f|0,g|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;break w}h=Rc(e+192|0,J);x[23420]=0;X(317,J|0,b|0,g|0,4);d=x[23420];x[23420]=0;if((d|0)==1){break qa}if(!De(h)){x[23420]=0;f=W(477,e+24|0,2,13)|0;d=x[23420];x[23420]=0;if((d|0)==1){break ua}x[23420]=0;U(478,e+120|0,h|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break ta}x[23420]=0;U(479,e+40|0,e+120|0,J|0);d=x[23420];x[23420]=0;if((d|0)==1){break sa}d=e+40|0;Ac(J,d);xb(d);xb(e+120|0);xb(f)}xb(h);break oa}i=P()|0;break w}i=P()|0;break pa}i=P()|0;break ra}i=P()|0;xb(e+120|0)}xb(f);break pa}i=P()|0}xb(h);break w}Ba:{if(K>>>0<2){break Ba}i=0;if(!ac(x[e+596>>2])){break Ba}while(1){if(z[a+480188>>1]<=i>>>0){break Ba}d=x[e+596>>2];x[23420]=0;f=Q(143,b|0,ac(d)+(i<<2)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}x[23420]=0;f=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break x}x[23420]=0;f=Q(143,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Ca}while(1){Da:{h=x[b+8>>2];f=x[b>>2];x[23420]=0;h=W(144,f|0,h|0,8)|0;f=x[23420];x[23420]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!h){break Da}x[23420]=0;R(480,b|0,e+192|0);f=x[23420];x[23420]=0;if((f|0)==1){break Ga}f=ac(x[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;break w}i=P()|0;break w}g=ac(x[e+196>>2]);continue}d=ac(x[e+196>>2]);continue}break}if(!g|!d){break Ca}x[23420]=0;g=Q(143,b|0,g|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break y}if(!g){break Ca}x[23420]=0;U(359,b|0,((i<<5)+a|0)+480289|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=z[e+608>>1];x[23420]=0;F=Lb(d);R(213,I|0,u+F&65535);d=x[23420];x[23420]=0;if((d|0)==1){break z}r=k&16;o=u&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(F|0)){ea=e,fa=qj(x[E>>2]),x[ea+120>>2]=fa;g=yf(E);while(1){d=x[e+120>>2];if(!zg(d,g)){i=1;d=ac(x[e+528>>2]);if(!d){break L}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break z}if(!f){break L}u=u+F|0;Qt(E);break K}k=Vp(d);h=Ue(k);Ja:{Ka:{La:{Ma:{d=z[k>>1];if(!d){j=0;break Ma}x[23420]=0;f=Q(297,n|0,d-1&65535)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ja}j=z[k>>1];if(!f){break Ma}x[23420]=0;j=Q(346,n|0,j-1&65535)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ja}break La}if(z[h>>1]==((j&65535)+1|0)){break Ka}x[23420]=0;j=Q(345,I|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}ea=bc(x[n>>2],z[k>>1]),fa=j,w[ea>>1]=fa}d=_b(x[I>>2],j);ie(d,tm(Fe(ye(e+192|0,12,hu(z[h>>1])),x[d+12>>2]-1|0)));F=(F&65535)>>>0>j>>>0?F:j+1|0}Wg(e+120|0);continue}break}i=P()|0;break w}Na:{Oa:{if(!G){break Oa}d=x[e+936>>2];x[23420]=0;f=Q(143,b|0,ac(d)+(g<<2)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ia}if(!f){break Oa}x[23420]=0;f=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ia}x[23420]=0;f=Q(143,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break Ia}if(!f){break Oa}O=Jb(e+56|0);x[23420]=0;V=T(162,e|0)|0;d=x[23420];x[23420]=0;Pa:{Qa:{if((d|0)!=1){if(K){break Qa}x[23420]=0;R(481,b|0,e+192|0);d=x[23420];x[23420]=0;if((d|0)==1){break Na}w[e+104>>1]=y[e+192|0];Y=y[e+193|0]+1|0;f=48;break Pa}i=P()|0;break A}x[23420]=0;m=v[e+870|0];R(482,b|0,e+176|0);d=x[23420];x[23420]=0;Ra:{Sa:{if((d|0)!=1){k=Lb(z[e+176>>1]);w[e+104>>1]=k;Y=Lb(z[e+178>>1])+1|0;d=ac(x[e+180>>2]);if(!d){break Ra}h=x[b+8>>2];x[23420]=0;Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}x[23420]=0;R(483,b|0,e+192|0);d=x[23420];x[23420]=0;if((d|0)==1){break B}d=x[e+196>>2];x[23420]=0;f=Q(143,b|0,ac(d)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if(!f){break Sa}d=x[e+200>>2];x[23420]=0;U(255,b|0,O|0,ac(d)|0);d=x[23420];x[23420]=0;if((d|0)!=1){break Sa}break B}break B}d=ac(x[e+208>>2]);Ta:{if(!d){break Ta}x[23420]=0;f=Q(143,b|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if(!f){break Ta}x[23420]=0;f=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}x[23420]=0;f=Q(143,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if(!f){break Ta}x[23420]=0;U(178,e+80|0,b|0,D(k,Y)|0);d=x[23420];x[23420]=0;if((d|0)==1){break B}f=e+80|0;d=jc(e+120|0,f);bd(V,d);zb(d);zb(f)}x[23420]=0;Q(143,b|0,h|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}}f=m+(K>>>0<3?48:24)|0}x[23420]=0;k=g+o|0;h=W(214,I|0,k&65535,Y|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=x[I>>2];x[23420]=0;C=_b(d,k);R(268,C|0,O|0);d=x[23420];x[23420]=0;if((d|0)==1){break Ha}tg(e+104|0,z[a+480188>>1]);Z=0;q=z[e+104>>1];Va:while(1){if((Y|0)==(Z|0)){break Ua}i=0;d=ed(x[C>>2],x[x[C+48>>2]+12>>2],Z,0);while(1){if((i&65535)>>>0>=q>>>0){Z=Z+1|0;continue Va}Wa:{if(!K){x[23420]=0;R(484,e+192|0,b|0);h=x[23420];x[23420]=0;if((h|0)!=1){m=y[e+192|0];k=e+192|0;h=jd(k);v[d+1|0]=m>>>3&16|y[h|0]>>>4|m>>>1&32;v[d+3|0]=y[h|0]&15;ea=d,fa=y[Ue(k)|0],v[ea+5|0]=fa;h=m&63;j=h?h+f|0:0;break Wa}break B}x[23420]=0;R(335,e+192|0,b|0);h=x[23420];x[23420]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=jd(h);t=Ue(h);m=Bi(h);x[23420]=0;k=T(194,V|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break B}v[d+4|0]=k;k=y[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}v[d|0]=254}v[d+1|0]=y[l|0]&63;v[d+3|0]=y[t|0];v[d+5|0]=y[m|0]}if(j-1>>>0<=119){v[d|0]=j}H=(j|0)>84&ca|H;t=(s|0)!=0;m=(A|0)!=0;k=(r|0)!=0;l=hb-16|0;hb=l;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{h=y[d+3|0];switch(h-4|0){case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 10:break rb;case 9:break sb;case 8:break tb;case 5:break ub;case 4:break vb;case 0:break wb;default:break _a}}v[d+3|0]=5;k=y[d+5|0];v[l+15|0]=k>>>3;v[l+14|0]=15;h=y[Wb(l+15|0,l+14|0)|0];v[l+13|0]=k<<1&30;v[l+12|0]=15;ea=d,fa=y[Wb(l+13|0,l+12|0)|0]|h<<4,v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}if((y[d+5|0]-1&255)>>>0<=19){v[d+3|0]=16;break Za}v[d+3|0]=0;break Za}v[d+3|0]=13;h=y[d+5|0];xb:{if(!k){if(h>>>0>152){break xb}v[d+5|0]=D((h&240)>>>4|0,10)+(h&15);break Za}v[d+5|0]=(h&127)+1>>>1;break Za}v[d+3|0]=0;break Za}v[d+3|0]=11;break Za}v[d+3|0]=0;break Za}h=y[d+5|0];if(!h){v[d+3|0]=14;break Za}if(h>>>0<=240){v[d+3|0]=17;if(h>>>0<=2){v[d+5|0]=112;break Za}ea=d,fa=ho(+(dS(h,t,m,N)>>>0)/1e4),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}v[d+3|0]=31;v[d+5|0]=y[d+5|0]|128;break Za}v[d+3|0]=19;v[l+11|0]=15;ea=d,fa=y[Wb(d+5|0,l+11|0)|0]|16,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+10|0]=15;ea=d,fa=y[Wb(d+5|0,l+10|0)|0]|32,v[ea+5|0]=fa;break Za}v[d+3|0]=5;h=y[d+5|0];v[l+9|0]=(h>>>4|0)+1;v[l+8|0]=15;ea=d,fa=h&15|y[Wb(l+9|0,l+8|0)|0]<<4,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[d+5|0]=y[d+5|0]&15|80;break Za}v[d+3|0]=19;v[l+7|0]=15;ea=d,fa=y[Wb(d+5|0,l+7|0)|0]|96,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+6|0]=15;ea=d,fa=y[Wb(d+5|0,l+6|0)|0]|192,v[ea+5|0]=fa;break Za}v[d+3|0]=10;break Za}v[d+3|0]=19;v[l+5|0]=15;ea=d,fa=y[Wb(d+5|0,l+5|0)|0]|160,v[ea+5|0]=fa;break Za}v[d+3|0]=19;v[l+4|0]=15;ea=d,fa=y[Wb(d+5|0,l+4|0)|0]|176,v[ea+5|0]=fa;break Za}h=(y[d+5|0]<<24)-16777216>>24;if((h|0)>=0){v[d+5|0]=h;v[d+3|0]=31;break Za}v[d+3|0]=0;break Za}v[d+3|0]=14;break Za}v[d+3|0]=19;v[l+3|0]=15;ea=d,fa=y[Wb(d+5|0,l+3|0)|0]|224,v[ea+5|0]=fa;break Za}h=y[d+5|0];if(h>>>0>=16){v[d+3|0]=19;v[d+5|0]=h>>>4|208;break Za}if(h){v[d+3|0]=19;v[d+5|0]=h|144;break Za}v[d+3|0]=0;break Za}if(!(y[d+5|0]|y[d+4|0])){if(!Uc(y[d|0])){break Za}v[d+5|0]=159;v[d+3|0]=20;break Za}v[d+3|0]=0;break Za}h=y[d+4|0];if(h){v[d+3|0]=44;ea=d,fa=Cm(Vc(((y[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}h=y[d+5|0];if((h+16&255)>>>0<=32){v[d+3|0]=9;ea=d,fa=xi(((h^128)<<3)-896|0),v[ea+5|0]=fa;break Za}v[d+3|0]=0;break Za}if(h>>>0<=15){Of(d);break Za}v[d+3|0]=0}hb=l+16|0;d=d+6|0;i=i+1|0;continue}}}zb(V);xb(O)}g=g+1|0;continue}break}break B}i=P()|0;break w}break B}Qt(E);f=0;if(!i){break c}}zi($,0);d=1;yb:{if(H&1){break yb}while(1){b=d&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break yb}c=((b<<2)+a|0)+900380|0;b=x[c>>2];if(b){Ib(St(b))}x[c>>2]=0;d=d+1|0;continue}}zb:{if(!da){break zb}x[23420]=0;c=Q(1,e+192|0,16189)|0;b=x[23420];x[23420]=0;Ab:{if((b|0)!=1){b=x[a+1298464>>2];x[23420]=0;U(353,b|0,2,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ab}yb(c);break zb}i=P()|0;break f}i=P()|0;yb(c);break f}j=21473;Bb:{Cb:{switch(aa-48|0){case 0:j=z[a+480188>>1]>4?17084:17070;break Bb;case 1:j=17052;break Bb;case 2:j=17034;break Bb;case 3:break Cb;default:break Bb}}j=17007}x[23420]=0;R(485,e+80|0,16622);b=x[23420];x[23420]=0;Db:{Eb:{Fb:{if((b|0)!=1){x[23420]=0;U(486,e+120|0,e+80|0,e+919|0);b=x[23420];x[23420]=0;if((b|0)==1){break Fb}b=e+120|0;Gb(a+1298344|0,b);yb(b);cc(e+80|0);x[23420]=0;c=Q(1,b|0,12496)|0;b=x[23420];x[23420]=0;if((b|0)==1){break Eb}Gb(a+1298356|0,c);yb(c);x[23420]=0;R(124,a+1298368|0,j|0);b=x[23420];x[23420]=0;if((b|0)==1){break Db}x[a+1298404>>2]=13;f=1;break c}i=P()|0;break f}i=P()|0;cc(e+80|0);break f}i=P()|0;break f}i=P()|0;break f}c=c+1|0;continue}}i=P()|0;break f}i=P()|0;zb(V)}xb(O);break w}i=P()|0;break w}i=P()|0;break w}i=P()|0}Qt(E);break f}i=P()|0;break f}i=P()|0;break f}i=P()|0;break f}A=1;if((f|0)!=7){break m}d=B+108|0;f=fA(d);while(1){if((d|0)!=(f|0)){ea=d,fa=sm(y[d|0]-24|0),v[ea|0]=fa;d=d+1|0;continue}break}g=0}H=1;break l}g=0;Gb:{if(o|(r|0)<0){break Gb}m=B+108|0;j=7;Hb:while(1){if((j|0)==10){break Gb}k=D(j,12);h=D(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Hb}else{f=Kb(m,d+k|0);v[f|0]=h+y[f|0];d=d+1|0;continue}}}}x[23420]=0;R(487,_|0,e+192|0);d=x[23420];x[23420]=0;if((d|0)!=1){Ib:{d=y[e+196|0];if((d-1&255)>>>0<=15){v[B+31|0]=d;H=1}d=y[e+197|0];if((d<<24)-16777216>>24>=0){v[B+30|0]=d}d=0;Jb:{while(1){if((d|0)==(A|0)){if(!q){break j}if((r|0)>=0){break Jb}break j}x[23420]=0;h=D(d+s|0,104)+a|0;R(264,h+484380|0,8);f=x[23420];x[23420]=0;if((f|0)!=1){v[e+120|0]=y[e+198|0];v[e+56|0]=64;ea=h+484410|0,fa=y[Wb(e+120|0,e+56|0)|0]<<2,w[ea>>1]=fa;v[h+484416|0]=y[e+199|0];d=d+1|0;continue}break}break k}m=_c(e+120|0,8,1,1,0);h=Lb(z[e+194>>1]);i=Lb(z[e+192>>1]);d=x[C>>2];x[23420]=0;j=T(148,d|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){d=Lb(z[e+84>>1]);if(d&16){Dh(m,16);j=j>>>1|0}if(d&32){yo(m,3);j=j>>>1|0}if(d&64){Rf(m,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;g=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}k=D(d+s|0,104)+a|0;f=k+484380|0;x[f>>2]=j;x[23420]=0;W(207,m|0,f|0,C|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ib}i=i<<1;g=g<<1;if(h>>>0>=2){x[k+484388>>2]=g;x[k+484384>>2]=i;f=k+484414|0;w[f>>1]=z[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;zb(C);break f}zb(C);G=G+1|0;u=u+A|0;j=z[a+480192>>1];continue}}i=P()|0;break e}i=P()|0;break e}i=P()|0}tc(M)}zb(_);S(i|0);p()}f=0}d=f;tc(M)}zb(_)}hb=e+976|0;return d|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=E(0),ea=0,ga=0,ha=0,ia=0,ka=0,la=0;e=hb-688|0;hb=e;zc(b);a:{b:{c:{if(!Yh(b,e+680|0)){break c}if(!_P(e+680|0)){break c}if((to(b)|0)>=0){break c}if(!c){d=1;break c}Dd(a,16777216);d=a+480208|0;x[d>>2]=x[d>>2]|1681e4;Pz(e+288|0,32);g=x[e+300>>2];d=a+1074320|0;x[d>>2]=x[e+296>>2];x[d+4>>2]=g;d=x[e+292>>2];x[a+1074312>>2]=x[e+288>>2];x[a+1074316>>2]=d;Cf(a+1074312|0,38);q=Qb(e+664|0);r=Qb(e+648|0);u=Qb(e+632|0);l=Qb(e+616|0);mg(b,4);m=a+480190|0;K=c&1;J=a+1298332|0;s=2500;I=!(c&2);G=a+1298464|0;d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[23420]=0;c=W(144,d|0,c|0,4)|0;d=x[23420];x[23420]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[23420]=0;c=T(635,b|0)|0;d=x[23420];x[23420]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[23420]=0;c=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ka=a,la=Xb(512/(d>>>0)|0,16,128),x[ka+480228>>2]=la;continue}c=P()|0;break a;case 19:x[23420]=0;L=T(266,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break o}if(L>>>0<=1024){continue}break m;case 16:x[23420]=0;c=T(266,b|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;break a;case 15:x[23420]=0;c=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[e+288>>2]=c;x[e+184>>2]=800;ka=a,la=Ie(+A[Hb(e+288|0,e+184|0)>>2]*1.24*1e4),x[ka+480204>>2]=la;continue}c=P()|0;break a;case 31:x[23420]=0;c=T(266,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break o}V=1;s=Wd(c,0,1e4);continue;case 32:case 33:x[23420]=0;c=T(266,b|0)|0;d=x[23420];x[23420]=0;s:{t:{if((d|0)!=1){V=1;if(!c){continue}x[23420]=0;d=Q(1,e+600|0,12405)|0;c=x[23420];x[23420]=0;if((c|0)==1){break t}c=x[G>>2];x[23420]=0;U(353,c|0,2,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break s}yb(d);continue}c=P()|0;break a}c=P()|0;break a}c=P()|0;yb(d);break a;case 14:x[23420]=0;Q(176,b|0,4)|0;c=x[23420];x[23420]=0;if((c|0)==1){break o}i=!z[m>>1]|i;continue;case 11:if(!K){break q}if(!uc(x[q>>2],x[q+4>>2])){break q}x[23420]=0;R(636,e+288|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){if(x[q>>2]){Gc(q);c=x[q>>2];go(q);Ib(c);ka=Fb(q),la=0,x[ka>>2]=la;x[q>>2]=0;x[q+4>>2]=0}c=e+288|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=Fb(c);ka=Fb(q),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ui(c);continue}c=P()|0;break a;case 3:case 4:case 10:g=ph(x[l>>2],x[l+4>>2]);d=z[m>>1];if(g>>>0<=d>>>0){continue}if((i|I)&1){break q}if(!Qh(d)){break q}d=d+1|0;w[m>>1]=d;t=Qb(e+584|0);x[23420]=0;i=T(162,e+560|0)|0;g=x[23420];x[23420]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[23420]=0;c=T(266,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break u}x[23420]=0;U(178,e+184|0,b|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break u}c=e+184|0;g=jc(e+288|0,c);bd(i,g);zb(g);break g}c=P()|0;break d}x[23420]=0;R(637,e+288|0,b|0);c=x[23420];x[23420]=0;x:{if((c|0)!=1){c=e+288|0;g=rm(t,c);dc(c);ke(e+528|0,x[g>>2],x[e+588>>2]);c=$d(e+520|0);x[23420]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=wg(314,e+536|0,x[e+528>>2],x[e+532>>2],e+16|0);g=x[23420];x[23420]=0;if((g|0)==1){break x}bd(i,c);break g}c=P()|0;break e}c=P()|0;break e}x[23420]=0;R(638,e+288|0,b|0);c=x[23420];x[23420]=0;y:{if((c|0)!=1){c=e+288|0;g=rm(t,c);dc(c);ke(e+488|0,x[g>>2],x[e+588>>2]);c=$d(e+480|0);x[23420]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=wg(314,e+496|0,x[e+488>>2],x[e+492>>2],e+8|0);g=x[23420];x[23420]=0;if((g|0)==1){break y}bd(i,c);break g}c=P()|0;break e}c=P()|0;break e}c=P()|0;break e;case 9:c=z[m>>1];if(!Qh(c)){continue}w[m>>1]=c+1;continue;case 8:if(!K){break q}if(!uc(x[u>>2],x[u+4>>2])){break q}x[23420]=0;R(639,e+288|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){c=e+288|0;ZP(u,c);tc(c);continue}c=P()|0;break a;case 7:if(!uc(x[l>>2],x[l+4>>2])){break q}x[23420]=0;R(640,e+288|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){if(x[l>>2]){Gc(l);c=x[l>>2];Oz(l);Ib(c);ka=Fb(l),la=0,x[ka>>2]=la;x[l>>2]=0;x[l+4>>2]=0}c=e+288|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=Fb(c);ka=Fb(l),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;yt(c);continue}c=P()|0;break a;case 6:if(!K){break q}if(!uc(x[r>>2],x[r+4>>2])){break q}x[23420]=0;R(641,e+288|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){if(x[r>>2]){Gc(r);c=x[r>>2];mr(r);Ib(c);ka=Fb(r),la=0,x[ka>>2]=la;x[r>>2]=0;x[r+4>>2]=0}c=e+288|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Fb(c);ka=Fb(r),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;dl(c);continue}c=P()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[23420]=0;R(642,e+288|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break n}z:{c=x[e+288>>2];d=x[e+292>>2];if(uc(c,d)){break z}x[23420]=0;X(323,J|0,c|0,Wc(c,d)|0,1);c=x[23420];x[23420]=0;if((c|0)!=1){break z}c=P()|0;dc(e+288|0);break a}dc(e+288|0);continue}x[23420]=0;n=T(266,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break o}}x[23420]=0;Q(176,b|0,n|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){continue}}c=P()|0;break a}d=0;if(!z[a+480188>>1]|!L){break m}b=x[l>>2];c=x[l+4>>2];if(uc(b,c)){break m}if(K){if(uc(x[q>>2],x[q+4>>2])){break m}if(uc(x[u>>2],x[u+4>>2])){break m}if(uc(x[r>>2],x[r+4>>2])){break m}}b=ph(b,c);if(b>>>0>=256){x[23420]=0;R(643,l|0,255);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=ph(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;h=a+480190|0;n=a+480192|0;ka=h,la=z[Ve(m,n)>>1],w[ka>>1]=la;if(i&1){x[23420]=0;b=Q(1,e+584|0,16278)|0;c=x[23420];x[23420]=0;if((c|0)==1){break h}c=x[a+1298464>>2];x[23420]=0;U(353,c|0,2,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break i}yb(b)}i=0;A:while(1){if((i|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>z[n>>1]){i=i+1|0;continue A}B:{c=im(x[l>>2],f-1|0);if(!y[c|0]|v[c+128|0]<0){break B}if((vt(c)|0)==((i|0)!=1|0)){break B}C:{D:{E:{g=0;F:{if(!vt(c)){break F}if(Lb(y[c+6|0]|y[c+7|0]<<8)){break F}if(Lb(y[c+14|0]|y[c+15|0]<<8)>>>0>20){break F}g=(Lb(y[c+18|0]|y[c+19|0]<<8)|0)==4}G:{H:{if(g){g=y[c+23|0];b=y[c+140|0];x[23420]=0;b=ja(644,c|0,a|0,(b&2)>>>1|0,(D(f,104)+a|0)+484380|0,s&65535)|0;k=x[23420];x[23420]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[23420]=0;b=Q(54,e+416|0,10618)|0;k=x[23420];x[23420]=0;if((k|0)==1){break J}Dc(((f<<5)+a|0)+946304|0,b);xb(b);k=x[l>>2];b=d;if(ph(k,x[l+4>>2])>>>0<=g>>>0){break G}ka=c,la=y[c+143|0]+y[im(k,g)+143|0]|0,v[ka+143|0]=la;break H}c=P()|0;break a}c=P()|0;break a}b=g+1|0;break G}g=0;K:{if(!vt(c)){break K}if((Lb(y[c+6|0]|y[c+7|0]<<8)|0)!=1){break K}if((Lb(y[c+14|0]|y[c+15|0]<<8)|0)!=2){break K}g=(Lb(y[c+18|0]|y[c+19|0]<<8)|0)==10}b=d;if(!g){break G}pc(e+288|0,c,128);b=Lb(z[e+308>>1]);if(b>>>0>=z[m>>1]){break H}x[23420]=0;g=T(634,e+184|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break E}k=z[e+324>>1];o=z[h>>1];x[23420]=0;t=D(b,104);b=a+484380|0;k=Lb(k);b=fa(645,e+288|0,(t+b|0)+104|0,(k>>>0<o>>>0?(b+D(k,104)|0)+104|0:g)|0,b+D(f,104)|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break D}if(!b){break H}x[23420]=0;b=Q(54,e+168|0,11111)|0;g=x[23420];x[23420]=0;if((g|0)==1){break C}Dc(((f<<5)+a|0)+946304|0,b);xb(b);v[c+139|0]=y[c+139|0]+12}b=d}x[23420]=0;b=b&65535;g=W(239,a|0,f|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){if(!g|b>>>0>z[m>>1]){break B}x[23420]=0;X(646,c|0,g|0,(D(b,104)+a|0)+484380|0,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){break B}}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}c=P()|0;break a}d=d+1|0;continue}}break}J=gg(e+152|0);t=gg(e+136|0);b=vc(x[u>>2],x[u+4>>2]);Z=D(z[a+480188>>1],L);_=mu((b>>>0)/(Z>>>0)|0);x[23420]=0;N=a+484344|0;R(213,N|0,_|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}$=a+484376|0;Gc(Yb(x[a+484360>>2],y[$|0]));b=z[a+480188>>1];x[23420]=0;G=Q(647,e+120|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break l}ka=e,la=Db(x[r>>2]),x[ka+64>>2]=la;ea=a+902204|0;ga=Db(x[r+4>>2]);ha=a+480208|0;while(1){L:{M:{N:{k=x[e+64>>2];if(!Pb(k,ga)){break N}b=Lb(y[k+6|0]|y[k+7|0]<<8);if((b|0)==1){break L}if((b|0)==65535){break N}g=Lb(y[k|0]|y[k+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=fg(b,f);if(g>>>0>=c>>>0){break L}d=Lb(y[k+2|0]|y[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(fg(b,f)<<5)|0;x[e+288>>2]=b;x[e+292>>2]=c-b>>5;b=x[e+288>>2];fc(e+96|0,b+(Lb(y[k|0]|y[k+1|0]<<8)<<5)|0,Lb(y[k+2|0]|y[k+3|0]<<8));O:{I=Yb(x[a+484360>>2],y[$|0]);if(uc(x[I>>2],x[I+4>>2])){break O}x[23420]=0;R(472,I|0,65534);b=x[23420];x[23420]=0;if((b|0)!=1){break O}break M}c=x[e+96>>2];ia=pe(c,x[e+100>>2]);while(1){if((c|0)==(ia|0)){break L}b=Lb(Lb(y[k+8|0]|y[k+9|0]<<8)+Lb(y[c+16|0]|y[c+17|0]<<8)&65535);v[c+16|0]=b;v[c+17|0]=b>>>8;g=c;b=Vd(J);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!st(g,d)){c=1;if(!st(d,g)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[23420]=0;b=Q(648,J|0,g|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}F=z[b>>1];break S}F=0;if(!K){break S}b=y[g+12|0]|y[g+13|0]<<8;x[23420]=0;F=Q(345,N|0,Lb(b)|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break M}if((F|0)==65535){break L}x[23420]=0;b=Q(648,J|0,g|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}w[b>>1]=F;if(Lb(y[g+8|0]|y[g+9|0]<<8)>>>0>=_>>>0){break R}if(Lb(y[g+10|0]|y[g+11|0]<<8)>>>0>=L>>>0){break R}m=Lb(y[g+14|0]|y[g+15|0]<<8);c=hm(Db(x[u>>2]),D(Lb(y[g+8|0]|y[g+9|0]<<8),Z));b=z[a+480188>>1];ka=e,la=hm(c,D(b,Lb(y[g+10|0]|y[g+11|0]<<8))),x[ka+48>>2]=la;M=0;x[e+32>>2]=0;o=Sh(e+80|0);T:while(1){U:{d=Lb(y[g+12|0]|y[g+13|0]<<8);c=_b(x[N>>2],F);if(d>>>0<=M>>>0){break U}n=0;O=ed(x[c>>2],x[x[c+48>>2]+12>>2],M,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){M=M+1|0;continue T}b=Db(x[u+4>>2]);d=x[e+48>>2];h=Pb(d,b)?d:e+32|0;b=Db(x[u+4>>2]);if(Pb(x[e+48>>2],b)){XP(e+48|0)}d=D(n,6)+O|0;f=y[h+1|0];b=(f>>>0>=85?-1:f+25|0)<<24>>24;s=0;i=x[l>>2];aa=ph(i,x[l+4>>2]);H=y[h+3|0];V:{if(aa>>>0<=H>>>0){break V}s=H+1|0;if(v[im(i,H)+142|0]&1|(b|0)<0){break V}b=sm(Lb(y[g+16|0]|y[g+17|0]<<8)+b<<24>>24)}W:{if(!y[d|0]|!(H|(y[h|0]|(f|0)!=255)|y[h+2|0])){break W}f=y[d+1|0];if(!f|f>>>0>aa>>>0){break W}if(y[im(i,f-1|0)+132|0]!=2){break W}eo(d)}f=xt(x[G>>2],n);X:{Y:{if(c&1){c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}i=y[f+21|0];c=y[xt(x[G>>2],n-1|0)+21|0];if((i|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;i=y[h|0];if(i-24>>>0<2|(i|0)==9|!i&(y[h+2|0]+7&255)>>>0<2){break Y}break X}i=y[h|0]}_:{$:{aa:{ba:{ca:{da:{switch(i|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){i=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}ga:{if(v[h+1|0]<0){i=0;if(c>>>0<100){break ga}break $}v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){i=0;break $}ka=f,la=ho(+(b>>>0)*.64),v[ka+19|0]=la;j=B[f>>2];x[f>>2]=0;i=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+288|0]=15;v[e+116|0]=y[h+3|0]>>>3;b=y[Wb(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[h+2|0]>>>3;ka=f,la=y[Wb(e+288|0,e+116|0)|0]|b<<4,v[ka+24|0]=la;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}i=b-y[f+17|0]<<5;c=i>>31;c=(c^i)-c|0;x[e+288>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=xi((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+116>>2]=D(b,(m&255)-1|0);ka=f,la=c-x[td(e+288|0,e+116|0)>>2]|0,w[ka+32>>1]=la;break _;case 10:case 11:v[d+3|0]=0;v[d+5|0]=0;break _;case 13:v[e+288|0]=15;v[e+116|0]=y[h+3|0]>>>3;b=y[Wb(e+288|0,e+116|0)|0];v[e+288|0]=15;v[e+116|0]=y[h+2|0];ka=f,la=y[Wb(e+288|0,e+116|0)|0]|b<<4,v[ka+23|0]=la;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=Vd(t);while(1){ha:{c=0;if(!b){break ha}i=b+13|0;if(!tt(h,i)){c=1;if(!tt(i,h)){break ha}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[23420]=0;b=Q(649,t|0,h|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[Fb(t)>>2];if(b>>>0>127){break _}x[e+112>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=x[ha>>2];x[23420]=0;x[e+28>>2]=x[e+112>>2];c=W(650,e+28|0,pe(ea,b&255)|0,c|0)|0;i=x[23420];x[23420]=0;ia:{if((i|0)==1){break ia}if(!c){break _}v[d+3|0]=31;x[23420]=0;c=Q(649,t|0,h|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break ia}b=b|-128;v[c|0]=b;v[d+5|0]=b;ba=(y[h|0]&254)==24|ba;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+288>>2]=15;x[e+116>>2]=y[h+3|0]+1;ka=d,la=x[td(e+288|0,e+116|0)>>2],v[ka+5|0]=la;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];m=b?b:4;v[d+5|0]=m;break _;case 19:ja:{ka:{switch(y[h+1|0]){case 0:b=128;break ja;case 4:break ka;default:break _}}b=y[h+3|0]}v[e+111|0]=b;v[e+288|0]=y[h+2|0];v[e+116|0]=100;c=e+288|0;s=e+116|0;i=y[Wb(c,s)|0];x[e+288>>2]=128;x[e+116>>2]=256-(b&255);b=x[td(c,s)>>2];v[e+288|0]=128;c=y[Wb(c,e+111|0)|0];b=(D(b,i)|0)/128|0;s=b&255;if((s|0)!=y[f+20|0]){v[f+20|0]=b;v[d+3|0]=21;b=Vc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=b;v[d+5|0]=b}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=n+1|0;h=xt(x[G>>2],b);c=D(c,i)>>>7|0;if(y[h+20|0]==(c&255)){break _}v[h+20|0]=c;b=D(b,6)+O|0;v[b+3|0]=21;c=Vc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){ca=(si(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{ca=0}v[d+3|0]=44;ka=d,la=ho(ca+ +(c+y[h+2|0]|0)),v[ka+5|0]=la}w[f+32>>1]=0;break _}v[d+5|0]=m;v[d+3|0]=16}b=Vc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!i&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(n&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(n|0)){break _}b=x[l>>2];if(ph(b,x[l+4>>2])>>>0<=H>>>0){break _}if(y[im(b,H)+132|0]!=1){break _}h=n+1|0;b=D(h,6)+O|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=xt(x[G>>2],h);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}la:{if(y[d|0]){v[f+16|0]=0;break la}c=0;if(y[f+16|0]){break X}}ma:{if(!z[f+30>>1]){break ma}b=m&255;w[e+288>>1]=b;c=f+30|0;ka=c,la=z[Ve(c,e+288|0)>>1]-b|0,w[ka>>1]=la;if(y[d+3|0]){break ma}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];na:{if(j==E(0)){break na}b=m&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break na}oa:{pa:{qa:{ra:{if(b>>>0>=2){h=b-1|0;C=E(h|0);if(!(C<=j)){break ra}v[e+288|0]=15;ka=e,la=Ug(E(j/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(D(b,h)|0);v[d+3|0]=22;c=b<<4;break oa}if(!(j>=E(1))){break qa}break pa}if(j>=E(1)){break pa}if(!(j<=E(1-b|0))){break qa}v[e+288|0]=15;ka=e,la=Ug(E(E(-j)/C)),v[ka+116|0]=la;c=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(D(h,c)|0);v[d+3|0]=22;break oa}if(!(j<=E(-1))){break na}v[e+288|0]=14;ka=e,la=Ug(E(-j)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break oa}v[e+288|0]=15;ka=e,la=Ug(j),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];sa:{if(j==E(0)){break sa}b=m&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ta:{if(!y[d+3|0]){ua:{va:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break va}v[e+288|0]=223;ka=e,la=Ug(E(j/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break sa}if(!(j>=E(1))){break ua}break ta}if(j>=E(1)){break ta}if(!(j<=E(1-b|0))){break ua}v[e+288|0]=223;ka=e,la=Ug(E(E(-j)/C)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break sa}if(!(j<=E(-1))){break sa}v[e+288|0]=14;ka=e,la=Ug(E(-j)),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break sa}if(y[d+2|0]|b>>>0<2){break sa}da=E(j*E(.25));c=b-1|0;C=E(c|0);if(da>=C){v[e+288|0]=9;ka=e,la=Ug(E(j/C))>>>2|0,v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break sa}if(!(E(1-b|0)>=da)){break sa}v[e+288|0]=9;ka=e,la=Ug(E(E(-j)/C))>>>2|0,v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break sa}v[e+288|0]=15;ka=e,la=Ug(j),v[ka+116|0]=la;b=y[Wb(e+288|0,e+116|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{b=y[d+3|0];switch(b|0){case 4:break wa;case 0:break Ca;default:break Ba}}Da:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Da}if(!z[f+32>>1]){break wa}c=f+32|0;break Aa}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break wa}break za}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break za}break wa}if(!z[f+32>>1]){break wa}c=f+32|0;if(b){break ya}}v[d+3|0]=4;break xa}c=f+32|0}v[d+2|0]=11}w[e+288>>1]=D(y[f+27|0],(m&255)-1|0);ka=f,la=z[f+32>>1]-z[Zc(c,e+288|0)>>1]|0,w[ka+32>>1]=la}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=y[f+18|0];if(!b){break X}f=x[l>>2];if(ph(f,x[l+4>>2])>>>0<b>>>0){break X}f=im(f,b-1|0);if(!(y[f+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+81|0];if(!b|y[f+132|0]!=1){break X}v[e+81|0]=b+1}n=n+1|0;b=z[a+480188>>1];continue}}break}ie(c,xh(Fe(ye(e+288|0,16,Lb(y[g+14|0]|y[g+15|0]<<8)&255),0)))}b=fl(x[I>>2],x[I+4>>2]);ka=e,la=Lb(y[g+4|0]|y[g+5|0]<<8),w[ka+288>>1]=la;w[e+80>>1]=1;c=z[Ve(e+288|0,e+80|0)>>1];x[23420]=0;X(651,I|0,b|0,c|0,F&65535);b=x[23420];x[23420]=0;if((b|0)==1){break Q}b=Lb(y[k+8|0]|y[k+9|0]<<8);b=Lb(Lb(y[g+16|0]|y[g+17|0]<<8)-b&65535);v[g+16|0]=b;v[g+17|0]=b>>>8}c=g+32|0;continue}break}break M}c=ba&1;if(c){x[23420]=0;Y(271,a+906300|0);b=x[23420];x[23420]=0;if((b|0)==1){break M}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=1299020115;x[b+4>>2]=1869112133;x[e+288>>2]=0;d=a+906348|0;b=e+288|0;DU(a+906332|0,d,b);x[23420]=0;b=Q(54,b|0,9458)|0;g=x[23420];x[23420]=0;if((g|0)==1){break M}BB(d,b);xb(b);x[23420]=0;b=Q(54,e+96|0,9451)|0;d=x[23420];x[23420]=0;if((d|0)==1){break M}su(a+906380|0,b);xb(b);x[23420]=0;b=Q(54,e+80|0,9443)|0;d=x[23420];x[23420]=0;if((d|0)==1){break M}BB(a+906508|0,b);xb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){lB(a,b&65535);d=(b<<5)+a|0;v[d+480288|0]=c;w[d+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[23420]=0;b=Q(1,e- -64|0,11955)|0;c=x[23420];x[23420]=0;Ea:{Fa:{Ga:{if((c|0)!=1){Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,e+48|0,12173)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}Gb(a+1298356|0,b);yb(b);if(V){break Ga}x[23420]=0;b=Q(1,e+32|0,11955)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}break Fa}break M}if(ph(x[l>>2],x[l+4>>2])>>>0<=128){x[23420]=0;b=Q(1,e+32|0,9200)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break Fa}break M}x[23420]=0;b=Q(1,e+32|0,14640)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Ea}}Gb(a+1298368|0,b);yb(b);x[a+1298404>>2]=13;WP(G);NP(t);MP(J);d=1;break m}}c=P()|0;WP(G);break j}co(e- -64|0);continue}}c=P()|0;break a}c=P()|0;break a}yt(l);tc(u);dl(r);ui(q);break c}c=P()|0;break j}c=P()|0}NP(t);MP(J);break a}c=P()|0;yb(b);break a}c=P()|0;break a}zb(c);x[23420]=0;c=d&65535;d=W(652,a|0,c|0,i|0)|0;g=x[23420];x[23420]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)==1){break Ka}if(d){break Ha}x[23420]=0;d=W(653,a|0,c|0,i|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23420]=0;d=W(654,a|0,c|0,i|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23420]=0;d=Q(655,(D(c,104)+a|0)+484380|0,i|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ka}if(d){break Ha}x[23420]=0;d=Q(1,e+464|0,15984)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Ja}g=x[G>>2];x[23420]=0;U(353,g|0,2,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break Ia}yb(d);break Ha}c=P()|0;break e}c=P()|0;break e}c=P()|0;yb(d);break e}La:{Ma:{Na:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[m>>1];if(Qh(d)){break Na}}d=x[l>>2];if(ph(d,x[l+4>>2])>>>0<=c>>>0){break Ma}if(y[im(d,c)+132|0]!=2){break Ma}c=z[m>>1];if(!Qh(c)){break Ma}w[m>>1]=c+1;break Ma}c=d+1|0;w[m>>1]=c;H=D(c&65535,104)+a|0;o=H+484380|0;h=F+484380|0;g=x[h>>2];c=x[h+20>>2];Oa:{if(!Td(g,c)){break Oa}f=z[h+34>>1];if((h|0)==(o|0)|(Gd(f)|0)!=2){break Oa}d=(h|0)==(o|0);if(!(Td(x[o>>2],x[o+20>>2])?d:1)){break Oa}Td(x[h>>2],x[h+20>>2]);if(!d){c=ut(g,Im(f))}f=x[h+20>>2];if(!(f?c:0)){if(!d){xz(c)}break Oa}Pa:{Qa:{switch(Im(z[h+34>>1])-1|0){case 1:g=c;d=f;n=x[h+20>>2];k=x[h>>2];while(1){if(k){w[g>>1]=z[n>>1];w[d>>1]=z[n+2>>1];n=n+4|0;d=d+2|0;g=g+2|0;k=k-1|0;continue}break};break Pa;case 0:break Qa;default:break Pa}}g=c;d=f;n=x[h+20>>2];k=x[h>>2];while(1){if(k){v[g|0]=y[n|0];v[d|0]=y[n+1|0];n=n+2|0;d=d+1|0;g=g+1|0;k=k-1|0;continue}break}}d=fo(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=c;g=fo(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}lj(d,a);lj(g,a)}x[23420]=0;c=Q(54,e+448|0,6281)|0;d=x[23420];x[23420]=0;if((d|0)==1){break La}ze(H+484423|0,c);xb(c);x[23420]=0;c=Q(54,e+432|0,6184)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}ze(F+484423|0,c);xb(c)}zb(i);dc(t);i=0;continue}break}c=P()|0;break e}c=P()|0}zb(i)}dc(t);break a}hb=e+688|0;return d|0}c=P()|0}yt(l);tc(u);dl(r);ui(q);S(c|0);p()}function Jt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,T=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,za=0,Aa=0,Ba=0,Ca=0,Da=E(0),Ea=0,Fa=0,Ga=0,Ha=E(0);h=hb-208|0;hb=h;_=Qb(a);t=h+176|0;v[t+26|0]=0;w[t+24>>1]=0;x[t+16>>2]=0;x[t+20>>2]=-1;x[t+8>>2]=-1;x[t+12>>2]=-1;x[t>>2]=0;x[t+4>>2]=0;L=x[d+16>>2];a=y[d+6|0];ka=b+484360|0;i=x[ka>>2];la=(Ea=a,Fa=y[b+484376|0],Ga=jj(i,x[b+484364>>2])>>>0>a>>>0,Ga?Ea:Fa);a=la&255;H=pj(i,a);x[23420]=0;u=Q(533,h+144|0,b|0)|0;i=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((i|0)!=1){l=x[u+4>>2];x[23420]=0;I=W(534,h+104|0,b|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break i}ba=c&7;e=x[d>>2];a=z[d+4>>1];while(1){i=a&65535;if(Mc(x[H>>2],x[H+4>>2])>>>0<=i>>>0){break g}x[23420]=0;i=Q(297,H|0,i|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}if(i){break g}a=a+1|0;e=0;continue}}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}x[d>>2]=e;w[d+4>>1]=a;x[l+52>>2]=e;K=l+48|0;x[K>>2]=e;x[t+16>>2]=e;w[l+74>>1]=a;w[l+72>>1]=a;w[t+24>>1]=a;na=$d(h+96|0);oa=Bc(h+88|0);j:{if((ba|0)!=7){break j}Sk(Sk(Sk(Sk(Sk(Sk(Sk(Sk(na,1),2),3),28),38),40),39),41);HN(HN(oa,12),13);if((L|0)!=2){break j}a=x[H>>2];e=Mc(a,x[H+4>>2]);i=z[d+12>>1];if(e>>>0<=i>>>0){break j}e=x[b+484344>>2];f=x[b+484348>>2];a=z[bc(a,i)>>1];if(!oe(e,f,a)){break j}i=_b(e,a);e=x[d+8>>2];if(A[i+12>>2]<=e>>>0){break j}a=0;m=ed(x[i>>2],x[x[i+48>>2]+12>>2],e,0);i=z[b+480188>>1];e=x[u+8>>2];f=z[b+480192>>1];while(1){if((a|0)==(i|0)){break j}k:{l:{m:{n:{k=y[m|0];switch(k-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!Uc(k)){break k}if(at(y[m+2|0],y[m+3|0])){break k}}Ea=Pe(e,a),Fa=-1,x[Ea>>2]=Fa}m=m+6|0;a=a+1|0;continue}}$=c&1;if($){GN(l+223860|0)}N=l+74|0;va=l+223872|0;wa=(L|0)!=3;O=l+80|0;xa=b+901692|0;za=b+902204|0;fa=l+44|0;aa=l+20|0;G=b+1074312|0;pa=l+616|0;ca=32768;qa=C[d+8>>3];o(+qa);a=j(1)|0;Aa=j(0)|0;ga=a;Z=b+480188|0;F=b+480180|0;ha=b+484348|0;ra=(L|0)!=2;Ba=l+223884|0;sa=b+480192|0;Ca=(ba|0)!=7;d=0;o:{p:{q:{r:{s:while(1){i=ga;while(1){FN(h+24|0,x[F>>2],z[Z>>1],l,r&1);t:{u:{v:{w:{if(!(!(C[u+24>>3]>=qa)|wa)){break w}k=y[h+24|0];a=65535;e=x[H>>2];g=Mc(e,x[H+4>>2]);f=z[l+72>>1];if(g>>>0>f>>>0){a=z[bc(e,f)>>1]}w[l+70>>1]=a;g=x[b+484344>>2];e=x[ha>>2];q=a&65535;if(!(oe(g,e,q)|(q|0)==65535|ra)&(f|0)==(i&65535)){break w}x:{y:{while(1){a=a&65535;if(of(g,e)>>>0>a>>>0){break x}q=z[l+72>>1];z:{A:{if((a|0)!=65535){n=x[H>>2];f=Mc(n,x[H+4>>2]);if(q>>>0<f>>>0){break A}}a=z[H+28>>1];if((q|0)==(a|0)){break x}n=x[H>>2];f=Mc(n,x[H+4>>2]);break z}a=q+1|0}w[l+72>>1]=a;m=65535;q=f;f=a&65535;if(q>>>0>f>>>0){m=z[bc(n,f)>>1]}w[l+74>>1]=a;w[l+70>>1]=m;B:{if(!oe(g,e,m&65535)){e=Bp(h+24|0,pa);x[23420]=0;a=ja(535,I|0,a&65535,0,e|0,(k|0)!=0|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break B}if(a){break y}g=x[b+484344>>2];e=x[ha>>2]}a=z[l+70>>1];continue}break}a=P()|0;break f}if(L>>>0<=1){a=z[l+72>>1];x[t+8>>2]=0;w[t+20>>1]=a;if(!L){break x}}x[23420]=0;a=W(536,I|0,N|0,K|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break p}if(!a){break x}C[t>>3]=C[u+24>>3];x[23420]=0;R(537,_|0,t|0);a=x[23420];x[23420]=0;if((a|0)==1){break p}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23420]=0;Y(538,u|0);a=x[23420];x[23420]=0;if((a|0)==1){break p}a=z[l+74>>1];w[l+72>>1]=a;Ea=l,Fa=z[bc(x[H>>2],a)>>1],w[Ea+70>>1]=Fa;x[l+52>>2]=x[l+48>>2]}if(z[N>>1]==65535){break o}a=x[b+484344>>2];e=z[l+70>>1];if(!oe(a,x[ha>>2],e)){a=z[l+72>>1];if((a|0)==z[H+28>>1]){if(!L){break o}x[23420]=0;a=W(536,I|0,N|0,K|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break p}if(!a){break o}C[t>>3]=C[u+24>>3];x[23420]=0;R(537,_|0,t|0);a=x[23420];x[23420]=0;if((a|0)==1){break p}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23420]=0;Y(538,u|0);a=x[23420];x[23420]=0;if((a|0)==1){break p}x[l+52>>2]=x[l+48>>2];continue}w[N>>1]=a+1;continue}g=x[K>>2];if(g>>>0>=A[_b(a,e)+12>>2]){x[K>>2]=0;g=0}if(ra){break v}if(z[l+72>>1]!=(i&65535)|(g|0)!=(Aa|0)){break u}}v[t+26|0]=1;break o}a=0;if((L|0)==3){break t}}a=0;if(A[I+28>>2]<ca>>>0){break t}x[u+24>>2]=0;x[u+28>>2]=2146435072;x[I+28>>2]=0;ca=ca>>>(ca>>>0>256)|0;g=x[K>>2];a=1}e=z[l+72>>1];f=Bp(h+24|0,pa);x[23420]=0;e=ja(535,I|0,e|0,g|0,f|0,(k|0)!=0|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break r}if((a|e)==1){if(L>>>0<=1){w[t+20>>1]=z[l+72>>1];x[t+8>>2]=x[l+48>>2];if(!L){break o}}x[23420]=0;a=W(536,I|0,N|0,K|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break q}if(!a){break o}C[t>>3]=C[u+24>>3];x[23420]=0;R(537,_|0,t|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}x[t+16>>2]=x[K>>2];w[t+24>>1]=z[N>>1];x[23420]=0;Y(538,u|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}x[l+52>>2]=x[l+48>>2];continue}w[t+22>>1]=z[l+72>>1];x[t+12>>2]=x[l+48>>2];EN(b,l,0);m=x[l+48>>2];e=_b(x[b+484344>>2],z[l+70>>1]);if(m>>>0>=A[e+12>>2]){x[K>>2]=0;m=0}if(k){continue}break}a=0;m=ed(x[e>>2],x[x[e+48>>2]+12>>2],m,0);Ab(h+24|0,G,77);k=Bb(x[x[h+24>>2]>>2],x[h+28>>2]);C:{while(1){if(z[Z>>1]>a>>>0){D:{if(!(!Vy(m)&(!k|!(y[((a<<5)+b|0)+480281|0]&4)))){eo((l+D(a,872)|0)+1404|0);break D}if(Rg(y[m|0])){E:{if(!Rd(y[Ba|0])){break E}i=y[m+1|0];if(i-251>>>0<5|!i){break E}f=y[m+5|0];r=y[m+3|0];q=Sj(y[m+2|0],y[m+4|0]);e=h+24|0;v[e|0]=i-1;x[e+4>>2]=q&65535;x[23420]=0;i=Q(539,va|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break C}Ea=i,Ha=E(E(Sj(r,f)>>>0)/E(999)),B[Ea>>2]=Ha}eo((l+D(a,872)|0)+1404|0);break D}i=l+D(a,872)|0;e=i+1408|0;f=y[m+4|0]|y[m+5|0]<<8;v[e|0]=f;v[e+1|0]=f>>>8;e=i+1404|0;f=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;F:{G:{H:{I:{switch(y[m+3|0]-16|0){case 0:e=y[m+5|0];break H;case 3:break F;case 4:break G;case 1:break I;default:break D}}Ab(h+24|0,G,5);if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break D}e=y[m+5|0];if(!e){break D}}CN(b,l,e&255);break D}e=i+1409|0;f=y[e|0];J:{if(!(f|!(x[F>>2]&16777250))){v[e|0]=y[i+1449|0];break J}v[i+1449|0]=f}i=y[m+5|0];e=i&240;if((e|0)!=224){if((e|0)!=96){break D}x[l+24>>2]=x[l+24>>2]+(i&15);break D}if(x[aa>>2]){break D}i=i&15;if(i?0:y[F|0]&2){break D}x[aa>>2]=i+1;break D}i=y[m+5|0];if((i&240)!=224){break D}x[aa>>2]=(i&15)+1}m=m+6|0;a=a+1|0;continue}break}i=Rk(l);x[h+24>>2]=1;a=x[Yc(aa,h+24|0)>>2];w[l+68>>1]=65535;x[l+60>>2]=-1;x[l+64>>2]=-1;T=i-1|0;a=i-a|0;M=D(a,1e4);m=0;while(1){if(z[Z>>1]<=m>>>0){if(x[F>>2]==4&x[l+40>>2]==65535){break o}x[l+32>>2]=x[b+480216>>2];a=_b(x[b+484344>>2],z[l+70>>1]);e=x[a+16>>2];if(AN(e,x[a+20>>2])){x[l+32>>2]=e}e=zN(b,l);a=D(e,i);C[u+24>>3]=C[u+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[l>>2]=a+x[l>>2];K:{L:{if(Ca){break L}m=0;da=(d|0)!=0&(d|0)!=(e|0);while(1){if(z[Z>>1]<=m>>>0){break L}s=Pe(x[u+8>>2],m);M:{if(x[s>>2]==-1){break M}n=l+D(m,872)|0;T=n+1404|0;J=x[n+1316>>2];if(!J){if(Vy(T)){break M}}q=n+1409|0;f=1;N:{O:{M=n+1407|0;switch(y[M|0]-4|0){case 0:case 2:break N;default:break O}}f=y[n+1406|0]==11}a=y[q|0];if(y[n+1405|0]){x[n+1276>>2]=0}k=n+616|0;g=a&15;r=0;P:{Q:{R:{if(!Uc(y[T|0])){break R}if(!(!f|!y[s+4|0])){Uy(h+24|0,b,k,J,0);r=x[h+28>>2];x[n+624>>2]=x[h+24>>2];x[n+628>>2]=r}v[n+1418|0]=y[n+1415|0];J=n+1308|0;V=x[J>>2];r=y[n+1419|0];if(r){Ap(b,k,r,f,1,1)}r=y[T|0];x[23420]=0;ia(540,b|0,k|0,r|0,f|0,1,0,65535);r=x[23420];x[23420]=0;if((r|0)==1){break Q}a=a>>>4|0;yN(x[F>>2],z[Z>>1],l,m&65535);ta=Pe(x[u+8>>2],m);v[ta+4|0]=1;s=y[M|0];S:{if(!((y[q|0]&240)!=208|(s-19&255)>>>0>1)){r=g;if(g>>>0<i>>>0){break S}}r=(s|0)==33?a>>>0<i>>>0?a:0:0}ua=x[aa>>2];if(!(!(x[F>>2]&16777250)|(!r|ua>>>0<2))){r=D(ua-1|0,x[l+24>>2]+x[l+40>>2]|0)+r|0}if(!f){x[ta>>2]=0}T:{if((s|0)==9){break T}U:{if((s|0)!=19){if((s|0)!=20|(a|0)!=8){break U}break T}if((a|0)==8){break T}}if(y[n+1406|0]!=2){break R}}x[J>>2]=V}V:{if(!Uc(y[T|0])){Ab(h+24|0,G,114);if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break V}}W:{X:{Y:{Z:{a=y[M|0];switch(a-42|0){case 1:break W;case 0:break X;case 2:break Y;default:break Z}}if((a|0)!=10){break W}a=z[l+70>>1];s=x[l+48>>2];x[23420]=0;ea(541,b|0,k|0,m&65535,s|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){break V}break K}J=Wia(y[q|0],0,x[n+692>>2],0);s=lb;a=s>>>8|0;Un(b,k,Vc((s&255)<<24|J>>>8,a));break V}if(!x[n+720>>2]){break W}x[23420]=0;X(542,u|0,m&65535,d|0,-1);a=x[23420];x[23420]=0;if((a|0)==1){break K}wN(k,y[q|0]);r=x[l+40>>2]-1|0;break V}if(y[n+1406|0]!=15){break V}s=x[n+720>>2];if(!s){break V}a=y[n+1408|0];if(a>>>0>9){break V}_:{if(!a){s=x[n+1280>>2];break _}s=x[Cb(s+68|0,a-1|0)>>2];x[n+1280>>2]=s}Un(b,k,s)}$:{aa:{ba:{switch(y[T|0]-253|0){case 0:if(z[sa>>1]){break aa}break;case 1:case 2:break aa;default:break ba}}a=y[M|0];if(!((y[q|0]&240)!=192|(a-19&255)>>>0>1)&g>>>0<i>>>0){break aa}s=0;if((a|0)==33&(g|0)!=0&i>>>0>g+r>>>0){break aa}if((a|0)!=25){break $}}a=y[M|0];s=1}J=n+1304|0;ca:{if((a|0)!=13){if(y[n+1406|0]!=1){break ca}g=n+1408|0}else{g=q}x[J>>2]=y[g|0]<<2}da:{if(!(!x[n+720>>2]|s)){s=0;ea:{fa:{ga:{if(a>>>0>45){break ga}Ab(h+24|0,na,a);if(Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break fa}if(y[M|0]!=19){break ga}s=(y[q|0]-16&255)>>>0<32}a=y[n+1406|0];if(a>>>0<16){break ea}if(s){break da}break P}s=1;a=y[n+1406|0];if(a>>>0>=16){break da}}sk(h+24|0,oa,a);a=Bb(x[x[h+24>>2]>>2],x[h+28>>2]);if(s){break da}if(!a){break P}break da}if(!s){break P}}kP(k);Ea=Pe(x[u+8>>2],m),Fa=0,x[Ea>>2]=Fa;break M}a=P()|0;break f}if(da){x[23420]=0;X(542,u|0,m&65535,d|0,-1);a=x[23420];x[23420]=0;if((a|0)==1){break K}}ha:{ia:{ja:{ka:{la:{a=y[M|0];if(a-6>>>0>=2){ma:{switch(a-19|0){case 1:break ka;case 0:break la;default:break ma}}if(a-35>>>0<2){break ia}if((a|0)==45){break ja}if((a|0)!=11){break ha}}if(!y[q|0]&x[F>>2]==1){break ha}a=n+1467|0;g=0;while(1){if((g|0)==(i|0)){break ha}v[a|0]=!g|y[a|0]&254;Tn(b,k,y[q|0]);g=g+1|0;continue}}q=y[q|0];a=q&15;if(!(a|x[F>>2]&1048580)){break ha}g=n+1467|0;v[g|0]=y[g|0]|1;q=q&240;if((q|0)!=176){if((q|0)!=160){break ha}Sn(b,k,a,0);break ha}Rn(b,k,a,0);break ha}na:{oa:{pa:{a=y[q|0];switch(a-158|0){case 1:break oa;case 0:break pa;default:break na}}x[23420]=0;X(542,u|0,m&65535,d|0,-1);a=x[23420];x[23420]=0;if((a|0)==1){break K}x[n+704>>2]=x[n+704>>2]&-129;break ha}x[23420]=0;X(542,u|0,m&65535,d|0,-1);a=x[23420];x[23420]=0;if((a|0)==1){break K}a=x[n+704>>2];x[n+704>>2]=a|128;if(x[k+4>>2]){break ha}q=x[n+692>>2];if(!q){break ha}if(!(Ea=Uc(y[T|0]),Fa=1,Ga=a&2,Ga?Ea:Fa)){break ha}x[k>>2]=-1;x[k+4>>2]=q-1;break ha}if((a&240)!=112|a>>>0<115){break ha}gP(k,a,x[F>>2]);break ha}vN(k,y[q|0]);break ha}x[23420]=0;a=m&65535;X(542,u|0,a|0,d|0,-1);q=x[23420];x[23420]=0;if((q|0)==1){break K}uN(b,a,l,0)}q=n+1467|0;a=y[q|0]|1;v[q|0]=a;qa:{ra:{sa:{ta:{ua:{g=n+1406|0;switch(y[g|0]-3|0){case 11:break ra;case 0:case 1:break sa;case 3:break ta;case 2:break ua;default:break qa}}a=y[n+1408|0];Ab(h+24|0,G,41);Sn(b,k,a,Bb(x[x[h+24>>2]>>2],x[h+28>>2]));break qa}a=y[n+1408|0];Ab(h+24|0,G,41);Rn(b,k,a,Bb(x[x[h+24>>2]>>2],x[h+28>>2]));break qa}a=y[n+1408|0];va:{if(a){break va}Ab(h+24|0,G,41);a=0;if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break va}a=y[n+1450|0];if(!a){break qa}}g=y[g|0]==3?a<<4:a;a=0;while(1){if((a|0)==(i|0)){break qa}v[q|0]=!a|y[q|0]&254;Tn(b,k,g&255);a=a+1|0;continue}}k=y[n+1408|0];if(k>>>0>1){break qa}v[q|0]=a&247|!k<<3}if(y[q|0]&8){break M}if(f){f=Pe(x[u+8>>2],m);a=x[f>>2];x[f>>2]=a+i;x[23420]=0;X(542,u|0,m&65535,e|0,(a+r|0)+1|0);a=x[23420];x[23420]=0;if((a|0)!=1){break M}a=P()|0;break f}a=Pe(x[u+8>>2],m);x[a>>2]=x[a>>2]+(i-r|0)}m=m+1|0;continue}}r=tN(b,l,H,0);d=e;continue s}a=P()|0;break f}k=l+D(m,872)|0;e=k+1404|0;wa:{if(Vy(e)){break wa}r=k+616|0;da=k+1409|0;g=y[da|0];J=k+1407|0;q=y[J|0];xa:{ya:{if(!$){break ya}n=y[e|0];f=n;s=k+1405|0;V=y[s|0];if(V){v[k+1415|0]=0;v[k+1419|0]=V;Ea=Pe(x[u+8>>2],m),Fa=255,v[Ea+5|0]=Fa;f=y[e|0]}if(Uc(f)){v[k+1415|0]=n;iP(r);f=y[e|0]}za:{if(!(Uc(f)|y[s|0])){break za}V=k+1419|0;f=y[V|0];Aa:{if(!f){f=0;break Aa}if(z[sa>>1]<f>>>0){break Aa}s=x[((f<<2)+b|0)+900380>>2];if(!s|!(v[s+15|0]&1)){break Aa}Ip(r,x[s+8>>2],b);f=y[V|0]}f=Ty(b,n,f);if(!f){break za}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break za}Ip(r,z[f+484408>>1],b)}Ba:{Ca:{Da:{f=y[k+1406|0];switch(f-1|0){case 1:break ya;case 2:case 3:break Ca;case 0:break Da;default:break Ba}}Ea=Pe(x[u+8>>2],m),Fa=y[k+1408|0],v[Ea+5|0]=Fa;break ya}e=y[k+1408|0];if(!e){break ya}v[k+1450|0]=e;break ya}if((f|0)!=11){break ya}f=y[k+1408|0];if(!f){break ya}n=h+24|0;Sy(n,b,y[e+3|0],f,0);w[k+1384>>1]=z[h+24>>1];if(y[Ue(n)|0]){break xa}}Ea:{Fa:{Ga:{Ha:{Ia:{switch(q-12|0){case 0:sN(b,l,m&65535);break Ea;case 2:e=qN(b,l,m&65535,g);if((e|0)==-1){break Ea}x[l+60>>2]=e;break Ea;case 5:Ab(h+24|0,G,5);if(Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ea}e=D(Qn(b,z[l+70>>1],x[l+48>>2],m&65535,0),1e4);Ja:{if(!$|!(x[F>>2]&16777250)){break Ja}if(e>>>0>=1e4){v[k+1451|0]=(e>>>0)/1e4;break Ja}e=D(y[k+1451|0],1e4)}Ka:{if(e>>>0>319999){break Ka}n=(e>>>0)/1e4|0;f=D(M,n&15);e=x[fa>>2];if((n&240)==16){e=e+f|0;break Ka}f=e-f|0;e=e>>>0>=f>>>0?f:0}x[fa>>2]=e;e=x[b+8>>2];f=x[e+20>>2];e=x[e+24>>2];Ab(h+24|0,G,8);Eo(fa,D(f,1e4),Bb(x[x[h+24>>2]>>2],x[h+28>>2])?255e4:D(e,1e4));break Ea;case 8:La:{switch((g&240)-144>>>4|0){case 0:if(g>>>0>145){break Ea}x[k+704>>2]=x[k+704>>2]&-257|((g|0)==145)<<8;break Ea;case 1:v[k+1452|0]=g&15;break Ea;case 2:break Ha;case 6:break La;default:break Ea}}v[k+1460|0]=g&15;break Ea;case 1:case 3:case 4:case 6:break Ea;case 7:break Ia;default:break Fa}}e=g&240;if((e|0)==240){break Ga}if((e|0)!=96){break Ea}}Ry(b,l,r,g&15);break Ea}v[k+1460|0]=g&15;break Ea}if((q|0)!=28|(g&240)!=160){break Ea}Ab(h+24|0,G,58);if(Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ea}v[k+1452|0]=g&15}if(!$){break wa}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{switch(q-2|0){case 0:if(!g){break Ma}Ab(h+24|0,G,90);if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1428|0]=g}v[k+1427|0]=g;break xa;case 1:if(!g){break Ma}Ab(h+24|0,G,90);if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1427|0]=g}v[k+1428|0]=g;break xa;case 2:if(!g){break Ma}w[k+1384>>1]=g;break xa;case 8:if(!g){break Ma}x[k+1280>>2]=g<<8;break xa;case 4:case 9:if(!g){break Ma}v[k+1425|0]=g;break xa;case 11:Ea=Pe(x[u+8>>2],m),Fa=g,v[Ea+5|0]=Fa;break xa;case 21:e=x[F>>2];g=g<<(!(e&59593760)&g<<24>>24>=0);f=g&255;if(f>>>0<=128){x[O>>2]=f<<1;break xa}if(e&16777250){break xa}x[O>>2]=256;break xa;case 22:Ab(h+24|0,G,9);Va:{if(Bb(x[x[h+24>>2]>>2],x[h+28>>2])){e=k+1433|0;if(g){v[e|0]=g;break Va}g=y[e|0];break Va}if(g){v[l+1433|0]=g;break Va}g=y[l+1433|0]}e=g&15;f=g&255;Wa:{if(!((e|0)!=15|f>>>0<16)){g=(g&240)>>>4<<!(x[F>>2]&59593760);e=x[O>>2]+(g<<1)|0;break Wa}f=f&240;if(!(!e|(f|0)!=240)){g=e<<(x[F>>2]&59593760?1:2);e=x[O>>2]-g|0;break Wa}if(f){g=(g>>>3&30)<<!(x[F>>2]&59593760);e=x[O>>2]+D(a,g)|0;break Wa}g=e<<(x[F>>2]&59593760?1:2);e=x[O>>2]-D(a,g)|0}x[O>>2]=e;ge(O,0,256);break xa;case 19:if(g>>>0>64){break xa}x[k+1364>>2]=g;break xa;case 20:e=k+1432|0;Xa:{if(g){v[e|0]=g;break Xa}g=y[e|0]}n=k+1364|0;e=x[n>>2];f=g&15;q=g&255;Ya:{if(!((f|0)!=15|q>>>0<16)){x[h+24>>2]=e+(q>>>4|0);break Ya}if(!(!f|(q&240)!=240)){x[h+24>>2]=e-f;break Ya}if(f){x[h+24>>2]=e-D(a,f);break Ya}x[h+24>>2]=e+D(a,q>>>4|0)}ge(h+24|0,0,64);x[n>>2]=x[h+24>>2];break xa;case 7:$l(b,r,g,8);break xa;case 29:case 30:break Na;case 25:break Oa;case 6:break Pa;case 24:break Qa;case 3:break Ra;case 5:break Sa;case 18:break Ta;case 17:break Ua;default:break xa}}if(g>>>0>15){break Ta}f=(g&1)<<14;q=z[Z>>1];e=0;while(1){if((e|0)==(q|0)){break Ta}n=l+D(e,872)|0;x[n+704>>2]=(f|x[n+704>>2]&-16385)^16384;e=e+1|0;continue}}if((g&240)!=128){break xa}$l(b,r,g&15,4);break xa}if(g){v[k+1425|0]=g}g=0}Qk(r,g);break xa}pN(b,r,g);break xa}oN(r,g);break xa}nN(r,g);break xa}Za:{if(g<<24>>24>=0){e=pe(xa,y[k+1460|0]);break Za}e=pe(za,g&127)}f=y[da|0];x[23420]=0;ma(543,b|0,l|0,m&65535,0,e|0,f|0);e=x[23420];x[23420]=0;if((e|0)!=1){break xa}a=P()|0;break f}g=0}_a:{$a:{switch(y[k+1406|0]-2|0){case 0:$l(b,r,y[k+1408|0],6);break _a;case 5:Ab(h+24|0,G,53);e=y[k+1408|0];if(Bb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1439|0]=e&15;break _a}Qk(r,e<<4);break _a;case 6:break $a;default:break _a}}Qk(r,y[k+1408|0])}ab:{bb:{cb:{db:{eb:{e=y[J|0];switch(e-5|0){case 1:break ab;case 3:break cb;case 0:case 2:break db;default:break eb}}switch(e-26|0){case 1:break bb;case 0:break db;default:break ab}}fb:{if(x[F>>2]&16777248){e=i;if(!(y[b+480208|0]&4)){break fb}}e=a}f=y[k+1439|0];Ab(h+24|0,G,21);k=k+1435|0;q=y[k|0];e=D(e,f);Ea=k,Fa=(Bb(x[x[h+24>>2]>>2],x[h+28>>2])?e<<2:e)+q|0,v[Ea|0]=Fa;break ab}gb:{if(x[F>>2]&16777248){e=i;if(!(y[b+480208|0]&4)){break gb}}e=a}f=y[k+1442|0];Ab(h+24|0,G,21);k=k+1436|0;q=y[k|0];e=D(e,f);Ea=k,Fa=(Bb(x[x[h+24>>2]>>2],x[h+28>>2])?e<<2:e)+q|0,v[Ea|0]=Fa;break ab}e=k+1437|0;v[e|0]=y[e|0]+D(T,y[k+1445|0]);lN(b,r)}Ab(h+24|0,G,78);if(!Bb(x[x[h+24>>2]>>2],x[h+28>>2])){break wa}e=g&255;if(!e){break wa}kN(r,e)}m=m+1|0;continue}}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}hb:{if((ba|0)!=7){break hb}a=0;i=b+480188|0;while(1){if(z[i>>1]<=a>>>0){break hb}ib:{if(x[Pe(x[u+8>>2],a)>>2]==-1){break ib}x[23420]=0;X(542,u|0,a&65535,d|0,-1);e=x[23420];x[23420]=0;if((e|0)!=1){break ib}a=P()|0;break f}a=a+1|0;continue}}if(y[t+26|0]){w[t+20>>1]=z[l+72>>1];x[t+8>>2]=x[l+48>>2]}a=l+223860|0;C[t>>3]=C[u+24>>3];x[23420]=0;R(537,_|0,t|0);d=x[23420];x[23420]=0;if((d|0)!=1){if(!$){break a}if(!(L?y[t+26|0]:1)){break c}f=Ky(h+56|0);if(Rd(y[a+24|0])){_M(f,a)}Qy(a);a=pc(b+1074376|0,l,614);e=0;while(1){if((e|0)==256){rm(a+223848|0,l+223848|0);d=a+223860|0;e=y[d+24|0];i=l+223860|0;jb:{if((Rd(y[i+24|0])|0)==(e|0)){if(!e){break jb}e=ic(d);Xs(d,x[e>>2]);x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];kb:{if(!x[Fb(d)>>2]){x[d>>2]=e;break kb}x[x[e>>2]+8>>2]=e;e=ic(i);x[i>>2]=e;x[e>>2]=0;Ea=Fb(i),Fa=0,x[Ea>>2]=Fa}d=d+12|0;e=ic(d);Vs(d,x[e>>2]);i=i+12|0;x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];lb:{if(!x[Fb(d)>>2]){x[d>>2]=e;break lb}x[x[e>>2]+8>>2]=e;d=ic(i);x[i>>2]=d;x[d>>2]=0;Ea=Fb(i),Fa=0,x[Ea>>2]=Fa}break jb}if(e){Qy(d);break jb}_M(d,i)}}else{d=D(e,872);yp((d+a|0)+616|0,(d+l|0)+616|0);e=e+1|0;continue}break}Py(a);a=0;x[b+1074400>>2]=0;v[b+1074476|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];mb:{nb:{d=x[b+1298300>>2];if(!wd(d)){break nb}x[23420]=0;Y(544,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){break nb}break mb}while(1){if(z[b+480188>>1]<=a>>>0){a=aA(h+24|0);Ea=h,Fa=qj(x[f+12>>2]),x[Ea+16>>2]=Fa;k=yf(f+12|0);while(1){d=x[h+16>>2];if(!zg(d,k)){ob:{e=250;d=a;pb:{while(1){if(e>>>0>=32){if(x[a>>2]){a=1;break pb}else{e=e-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break ob}a=0;while(1){if((a|0)==250){break ob}Ab(h+8|0,d,a);qb:{if(!Bb(x[x[h+8>>2]>>2],x[h+12>>2])){break qb}i=x[(D(a,160)+b|0)+906300>>2];e=x[x[i>>2]+176>>2];x[23420]=0;Y(e|0,i|0);i=x[23420];x[23420]=0;if((i|0)!=1){break qb}break mb}a=a+1|0;continue}}Ea=h,Fa=qj(x[f>>2]),x[Ea+8>>2]=Fa;a=yf(f);while(1){d=x[h+8>>2];if(zg(d,a)){d=ud(d);Ea=(D(y[d|0],160)+b|0)+906444|0,Ha=B[ic(d)>>2],B[Ea>>2]=Ha;Wg(h+8|0);continue}else{zp(f);break b}}}i=ud(d);r=Fb(i);rb:{e=y[i|0];d=x[(D(e,160)+b|0)+906300>>2];if(d){Ab(h+8|0,a,e);if(!Bb(x[x[h+8>>2]>>2],x[h+12>>2])){x[23420]=0;Q(545,a|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break rb}e=x[x[d>>2]+172>>2];x[23420]=0;R(e|0,d|0,-1);e=x[23420];x[23420]=0;if((e|0)==1){break rb}}Da=B[r>>2];i=x[i+4>>2];e=x[x[d>>2]+44>>2];x[23420]=0;ya(e|0,d|0,i|0,E(Da));d=x[23420];x[23420]=0;if((d|0)==1){break rb}}Wg(h+16|0);continue}break}break mb}d=D(a,872)+b|0;i=y[d+1075791|0];if(i){v[d+1075794|0]=i}d=Pe(x[u+8>>2],a);if(!((ba|0)==7|y[d+5|0]==255)){v[h+24|0]=64;Ea=(D(a,872)+b|0)+1075680|0,Fa=y[Wb(d+5|0,h+24|0)|0]<<2,x[Ea>>2]=Fa}sb:{i=D(a,872)+b|0;d=x[i+1075096>>2];tb:{if(!d|!(y[d+35|0]&2)){break tb}e=x[b+1298300>>2];if(!wd(e)){break tb}x[23420]=0;ga=e;e=a&65535;U(546,ga|0,e|0,d+68|0);d=x[23420];x[23420]=0;if((d|0)==1){break sb}d=x[b+1298300>>2];x[23420]=0;U(547,d|0,e|0,1);d=x[23420];x[23420]=0;if((d|0)==1){break sb}}x[i+1075008>>2]=0;a=a+1|0;continue}break}}a=P()|0;zp(f);break f}a=P()|0}_s(I)}jN(u)}ui(_);S(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=la&255;if((a|0)==y[b+484376|0]){break a}zi(ka,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){fO(a);b=x[a>>2];Fj(a);Ib(b);Ea=Fb(a),Fa=0,x[Ea>>2]=Fa;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[I>>2];x[a+4>>2]=x[I+4>>2];b=Fb(I);Ea=Fb(a),Fa=x[b>>2],x[Ea>>2]=Fa;x[b>>2]=0;x[I>>2]=0;x[I+4>>2]=0;a=a+12|0;c=ic(a);Dp(a,x[c>>2]);b=I+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];ub:{if(!x[Fb(a)>>2]){x[a>>2]=c;break ub}x[x[c>>2]+8>>2]=c;a=ic(b);x[b>>2]=a;x[a>>2]=0;Ea=Fb(b),Fa=0,x[Ea>>2]=Fa}}_s(I);jN(u);hb=h+208|0}function XR(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0,r=E(0),s=E(0),t=0,u=0,C=0,F=0,G=0,H=0,I=E(0),J=E(0),K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=E(0),_=E(0),$=0,ba=0,ca=E(0),da=E(0),ea=E(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;ba=hb-16|0;hb=ba;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;P=x[a+1420>>2];d=(P|0)>0?P:0;while(1){if((d|0)!=(h|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((P|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{k=b+d|0;if(y[k|0]!=79){break f}if(Ob(k,92708,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}l=d+27|0;i=b+g|0;f=y[i|0];if((l+f|0)>=(c|0)){break e}j=f+27|0;h=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((h|0)!=22){e=_w(e,y[(d+h|0)+b|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=_w(e,0);continue}break}x[a+1420>>2]=P+1;f=D(P,20)+a|0;x[f+1432>>2]=e;x[f+1428>>2]=j-26;x[f+1424>>2]=y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24);e=y[(g+y[i|0]|0)+b|0]==255?-1:y[k+6|0]|y[k+7|0]<<8|(y[k+8|0]<<16|y[k+9|0]<<24);x[f+1436>>2]=g;x[f+1440>>2]=e;P=x[a+1420>>2];if((P|0)!=4){break f}P=4;break d}else{j=y[(e+l|0)+b|0]+j|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(P|0)?d:P;while(1){if((d|0)==(i|0)){break b}h=0;f=D(d,20)+a|0;n=f+1428|0;k=x[n>>2];l=x[f+1436>>2];j=c-l|0;g=(j|0)>(k|0)?k:j;S=(g|0)>0?g:0;o=f+1432|0;e=x[o>>2];while(1){if((h|0)!=(S|0)){e=_w(e,y[(h+l|0)+b|0]);h=h+1|0;continue}break}x[n>>2]=k-g;x[o>>2]=e;if((j|0)>=(k|0)){h=e;e=f+1424|0;if((h|0)==x[e>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=g+l|0;break c}f=P-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];h=f+1432|0;k=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=k;f=f+1424|0;h=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=h;P=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!VH(a)){x[f>>2]=0;c=0;break a}ha=hb-16|0;hb=ha;ja=ba+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=Ne(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((Ne(a)|0)!=103){break j}if((Ne(a)|0)!=103){break j}if((Ne(a)|0)!=83){break j}if(!UH(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;ec(a,32);break i}k=Xw(a);break i}ec(a,30)}if(!k){break h}if(oc(a,1)){ec(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=oc(a,Ml(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[ha+12>>2]=c;j=D(c,6)+a|0;if(!y[j+412|0]){h=x[a+112>>2];k=h>>1;break m}h=x[a+116>>2];k=h>>1;c=oc(a,1);l=oc(a,1);if(c|!y[j+412|0]){break m}x[ja>>2]=h-x[a+112>>2]>>2;c=x[a+112>>2]+h>>2;break l}aa(6286,13048,3152,10626);p()}x[ja>>2]=0;c=k}x[ha+8>>2]=c;n:{if(!(!y[j+412|0]|l)){c=D(h,3);x[ba+8>>2]=c-x[a+112>>2]>>2;h=c+x[a+112>>2]>>2;break n}x[ba+8>>2]=k}x[ha+4>>2]=h;h=1}if(h){S=x[ja>>2];la=x[ba+8>>2];ka=x[ha+4>>2];N=hb-2368|0;hb=N;G=x[a+404>>2];oa=D(x[ha+12>>2],6)+a|0;C=y[oa+413|0];Q=G+D(C,40)|0;V=x[((y[oa+412|0]<<2)+a|0)+104>>2];fa=V>>1;ra=0-fa|0;o:{while(1){c=x[a+4>>2];if((c|0)>(g|0)){c=y[(x[Q+4>>2]+D(g,3)|0)+2|0];O=(N+1344|0)+(g<<2)|0;x[O>>2]=0;h=y[(c+Q|0)+9|0];if(z[((h<<1)+a|0)+132>>1]){k=x[a+260>>2];p:{q:{if(!oc(a,1)){break q}c=2;j=x[((g<<2)+a|0)+996>>2];k=k+D(h,1596)|0;F=x[(y[k+1588|0]<<2)+71532>>2];h=Ml(F)-1|0;ta=j,ua=oc(a,h),w[ta>>1]=ua;ta=j,ua=oc(a,h),w[ta+2>>1]=ua;H=k+82|0;W=k+65|0;T=k+49|0;R=k+33|0;K=k+1|0;t=0;while(1){if(y[k|0]>t>>>0){o=y[t+K|0];u=y[o+T|0];i=-1<<u;n=y[o+R|0];r:{if(!u){l=0;break r}h=x[a+124>>2]+D(y[o+W|0],2096)|0;if(x[a+1396>>2]<=9){Hk(a)}l=x[a+1392>>2];X=w[(h+((l&1023)<<1)|0)+36>>1];s:{if((X|0)>=0){q=l;X=X&65535;l=y[X+x[h+8>>2]|0];x[a+1392>>2]=q>>>l;l=x[a+1396>>2]-l|0;x[a+1396>>2]=(l|0)>0?l:0;l=(l|0)<0?-1:X;break s}l=Ll(a,h)}if(!y[h+23|0]){break r}l=x[x[h+2088>>2]+(l<<2)>>2]}X=i^-1;h=c+n|0;while(1){if((c|0)!=(h|0)){n=0;i=w[(H+(o<<4)|0)+((l&X)<<1)>>1];t:{if((i|0)<0){break t}i=x[a+124>>2]+D(i&65535,2096)|0;if(x[a+1396>>2]<=9){Hk(a)}n=x[a+1392>>2];Y=w[(i+((n&1023)<<1)|0)+36>>1];u:{if((Y|0)>=0){q=n;Y=Y&65535;n=y[Y+x[i+8>>2]|0];x[a+1392>>2]=q>>>n;n=x[a+1396>>2]-n|0;x[a+1396>>2]=(n|0)>0?n:0;n=(n|0)<0?-1:Y;break u}n=Ll(a,i)}if(!y[i+23|0]){break t}n=x[x[i+2088>>2]+(n<<2)>>2]}l=l>>u;w[j+(c<<1)>>1]=n;c=c+1|0;continue}break}t=t+1|0;c=h;continue}break}if(x[a+1396>>2]==-1){break q}w[N+320>>1]=257;h=k+338|0;t=k+1088|0;c=2;while(1){n=x[k+1592>>2];if((n|0)<=(c|0)){c=0;while(1){if((c|0)>=(n|0)){break p}if(!y[(N+320|0)+c|0]){w[j+(c<<1)>>1]=65535;n=x[k+1592>>2]}c=c+1|0;continue}}else{l=c<<1;n=l+t|0;u=y[n|0];o=u<<1;i=z[o+h>>1];O=y[n+1|0];H=O<<1;W=w[j+o>>1];n=w[H+j>>1]-W|0;o=n>>31;i=(D((n^o)-o|0,z[h+l>>1]-i|0)|0)/(z[h+H>>1]-i|0)|0;n=W+((n|0)<0?0-i|0:i)|0;H=j+l|0;i=z[H>>1];v:{w:{if(i){l=N+320|0;v[l+O|0]=1;v[l+u|0]=1;v[c+l|0]=1;l=i<<16>>16;o=F-n|0;if((l|0)>=((n|0)>(o|0)?o:n)<<1){if((n|0)<(o|0)){break v}n=F+(i^-1)|0;break w}if(l&1){n=n-(l+1>>>1|0)|0;break w}n=(l>>1)+n|0;break w}v[(N+320|0)+c|0]=0}w[H>>1]=n}c=c+1|0;continue}}}x[O>>2]=1}g=g+1|0;continue}else{ec(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){pc(N+320|0,N+1344|0,c<<2);k=z[Q>>1];c=0;while(1){if((c|0)==(k|0)){X=G+D(C,40)|0}else{g=x[Q+4>>2]+D(c,3)|0;h=y[g+1|0];n=N+1344|0;g=n+(y[g|0]<<2)|0;if(!(x[(h<<2)+n>>2]?x[g>>2]:0)){x[(N+1344|0)+(h<<2)>>2]=0;x[g>>2]=0}c=c+1|0;continue}break}l=0;while(1){x:{if(y[X+8|0]>l>>>0){n=0;c=x[a+4>>2];g=(c|0)>0?c:0;c=0;while(1){if((c|0)==(g|0)){break x}if(y[(x[Q+4>>2]+D(c,3)|0)+2|0]==(l|0)){j=n+N|0;k=c<<2;y:{if(x[k+(N+1344|0)>>2]){k=0;h=1;break y}k=x[(a+k|0)+800>>2];h=0}v[j|0]=h;x[(N+256|0)+(n<<2)>>2]=k;n=n+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){g=(fa|0)>0?fa:0;h=z[Q>>1];k=a+800|0;z:while(1){if((h|0)<=0){O=fa<<2;n=0;c=0;while(1){l=x[a+4>>2];if((l|0)<=(c|0)){while(1){if((n|0)<(l|0)){O=y[oa+412|0];Q=V>>1;h=Q<<2;X=x[a+92>>2];F=V>>3;W=V>>2;k=x[((n<<2)+a|0)+800>>2];c=Q<<2;u=k+c|0;A:{if(x[a+80>>2]){l=vn(a,h);break A}l=Ld(h)}h=(l+c|0)-8|0;j=x[((O<<2)+a|0)+1068>>2];i=j;c=k;while(1){if((c|0)!=(u|0)){B[h+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[h>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((Q<<2)+k|0)-12|0;while(1){if(h>>>0>=l>>>0){B[h+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[h>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;t=c+k|0;h=c+l|0;i=(j+(Q<<2)|0)-32|0;c=l;g=k;while(1){if(i>>>0>=j>>>0){m=B[c>>2];r=B[h>>2];s=B[h+4>>2];I=B[c+4>>2];B[t+4>>2]=s+I;B[t>>2]=B[h>>2]+B[c>>2];s=E(s-I);m=E(r-m);B[g+4>>2]=E(s*B[i+16>>2])-E(B[i+20>>2]*m);B[g>>2]=E(m*B[i+16>>2])+E(s*B[i+20>>2]);m=B[c+8>>2];r=B[h+8>>2];s=B[h+12>>2];I=B[c+12>>2];B[t+12>>2]=s+I;B[t+8>>2]=B[h+8>>2]+B[c+8>>2];s=E(s-I);m=E(r-m);B[g+12>>2]=E(s*B[i>>2])-E(B[i+4>>2]*m);B[g+8>>2]=E(m*B[i>>2])+E(s*B[i+4>>2]);c=c+16|0;h=h+16|0;g=g+16|0;t=t+16|0;i=i-32|0;continue}break}h=Ml(V);c=V>>4;o=Q-1|0;g=0-F|0;RH(c,k,o,g,j);RH(c,k,o-W|0,g,j);H=V>>5;c=0-c|0;ep(H,k,o,c,j,16);ep(H,k,o-F|0,c,j,16);ep(H,k,o-(F<<1)|0,c,j,16);ep(H,k,o+D(F,-3)|0,c,j,16);c=h-4>>1;t=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(t|0)){Y=h-7|0;break D}i=0;g=2<<c;g=(g|0)>0?g:0;F=8<<c;C=V>>c+4;G=V>>c+2;T=0-(G>>1)|0;while(1){if((g|0)==(i|0)){break C}ep(C,k,o-D(i,G)|0,T,j,F);i=i+1|0;continue}}while(1){E:{if((t|0)<(Y|0)){ma=32<<t;F=2<<t;T=8<<t;i=V>>t+6;$=V>>t+2;ga=0-($>>1)|0;h=o;c=j;while(1){if((i|0)<=0){break E}g=F;C=(h<<2)+k|0;G=C+(ga<<2)|0;R=D(T,12)+c|0;m=B[R>>2];K=(T<<3)+c|0;r=B[K>>2];q=(T<<2)+c|0;s=B[q>>2];I=B[R+4>>2];L=B[K+4>>2];Z=B[q+4>>2];_=B[c+4>>2];ea=B[c>>2];R=0-$<<2;while(1){if((g|0)>0){K=G-4|0;M=B[K>>2];ca=B[C>>2];da=B[G>>2];B[C>>2]=ca+da;q=C-4|0;J=B[q>>2];B[q>>2]=J+B[K>>2];J=E(J-M);M=E(ca-da);B[K>>2]=E(J*ea)+E(_*M);B[G>>2]=E(M*ea)-E(_*J);K=G-12|0;ca=B[K>>2];q=C-8|0;J=B[q>>2];U=q;q=G-8|0;da=B[q>>2];B[U>>2]=J+da;U=C-12|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*s)+E(Z*J);B[q>>2]=E(J*s)-E(Z*M);K=G-20|0;ca=B[K>>2];q=C-16|0;J=B[q>>2];U=q;q=G-16|0;da=B[q>>2];B[U>>2]=J+da;U=C-20|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*r)+E(L*J);B[q>>2]=E(J*r)-E(L*M);K=G-28|0;ca=B[K>>2];q=C-24|0;J=B[q>>2];U=q;q=G-24|0;da=B[q>>2];B[U>>2]=J+da;U=C-28|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*m)+E(I*J);B[q>>2]=E(J*m)-E(I*M);g=g-1|0;G=G+R|0;C=C+R|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(o<<2)+k|0;g=c-(H<<6)|0;m=B[j+(V>>3<<2)>>2];ea=E(-m);while(1){if(c>>>0>g>>>0){L=B[c>>2];h=c-32|0;Z=B[h>>2];B[c>>2]=L+Z;j=c-4|0;r=B[j>>2];q=j;j=c-36|0;_=B[j>>2];B[q>>2]=r+_;i=c-8|0;s=B[i>>2];q=i;i=c-40|0;J=B[i>>2];B[q>>2]=s+J;o=c-12|0;I=B[o>>2];q=o;o=c-44|0;M=B[o>>2];B[q>>2]=I+M;B[h>>2]=L-Z;B[j>>2]=r-_;j=c-16|0;r=B[j>>2];q=j;j=c-48|0;ca=B[j>>2];B[q>>2]=r+ca;s=E(s-J);I=E(I-M);B[i>>2]=m*E(s+I);B[o>>2]=m*E(I-s);i=c-28|0;s=B[i>>2];o=c-60|0;I=B[o>>2];F=c-24|0;L=B[F>>2];t=c-56|0;Z=B[t>>2];C=c-20|0;_=B[C>>2];q=C;C=c-52|0;J=B[C>>2];B[q>>2]=_+J;B[F>>2]=L+Z;B[i>>2]=s+I;B[j>>2]=_-J;B[C>>2]=-E(r-ca);r=E(s-I);s=E(L-Z);B[t>>2]=m*E(r-s);B[o>>2]=E(s+r)*ea;QH(c);QH(h);c=c+-64|0;continue}break}o=Q-4|0;h=l+(o<<2)|0;i=(l+(W<<2)|0)-16|0;c=x[((O<<2)+a|0)+1100>>2];while(1){if(i>>>0>=l>>>0){g=(z[c>>1]<<2)+k|0;B[h+12>>2]=B[g>>2];B[h+8>>2]=B[g+4>>2];B[i+12>>2]=B[g+8>>2];B[i+8>>2]=B[g+12>>2];g=(z[c+2>>1]<<2)+k|0;B[h+4>>2]=B[g>>2];B[h>>2]=B[g+4>>2];B[i+4>>2]=B[g+8>>2];B[i>>2]=B[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=x[((O<<2)+a|0)+1084>>2];i=l;h=i+(Q<<2)|0;j=h;while(1){g=j-16|0;if(g>>>0>i>>>0){m=B[i+4>>2];F=j-4|0;r=B[F>>2];s=E(m-r);I=B[c+4>>2];m=E(m+r);r=B[i>>2];t=j-8|0;L=B[t>>2];Z=E(r-L);_=B[c>>2];ea=E(E(I*m)-E(Z*_));B[i+4>>2]=s+ea;r=E(r+L);m=E(E(I*Z)+E(m*_));B[i>>2]=r+m;B[F>>2]=ea-s;B[t>>2]=r-m;m=B[i+8>>2];r=B[g>>2];s=E(m+r);I=B[c+12>>2];m=E(m-r);r=B[i+12>>2];j=j-12|0;L=B[j>>2];Z=E(r+L);_=B[c+8>>2];ea=E(E(I*m)+E(Z*_));B[i+8>>2]=s+ea;r=E(r-L);m=E(E(I*Z)-E(m*_));B[i+12>>2]=r+m;B[g>>2]=s-ea;B[j>>2]=m-r;i=i+16|0;c=c+16|0;j=g;continue}break}i=x[((O<<2)+a|0)+1076>>2]+(Q<<2)|0;c=(o<<2)+k|0;j=((V<<2)+k|0)-16|0;while(1){g=h-32|0;if(g>>>0>=l>>>0){m=B[h-8>>2];r=B[i-4>>2];s=B[i-8>>2];I=B[h-4>>2];L=E(E(m*r)-E(s*I));B[k>>2]=L;B[c+12>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u>>2]=m;B[j+12>>2]=m;m=B[h-16>>2];r=B[i-12>>2];s=B[i-16>>2];I=B[h-12>>2];L=E(E(m*r)-E(s*I));B[k+4>>2]=L;B[c+8>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+4>>2]=m;B[j+8>>2]=m;m=B[h-24>>2];r=B[i-20>>2];s=B[i-24>>2];I=B[h-20>>2];L=E(E(m*r)-E(s*I));B[k+8>>2]=L;B[c+4>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+8>>2]=m;B[j+4>>2]=m;m=B[g>>2];r=B[i-28>>2];i=i-32|0;s=B[i>>2];I=B[h-28>>2];L=E(E(m*r)-E(s*I));B[k+12>>2]=L;B[c>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+12>>2]=m;B[j>>2]=m;j=j-16|0;c=c-16|0;u=u+16|0;k=k+16|0;h=g;continue}break}if(!x[a+80>>2]){Ib(l)}x[a+92>>2]=X;break B}t=t+1|0;continue}}c=c+1|0;continue}break}n=n+1|0;l=x[a+4>>2];continue}break}}else{h=c<<2;k=h+a|0;i=x[k+800>>2];F:{if(x[h+(N+320|0)>>2]){Tb(i,0,O);break F}G=x[k+996>>2];G:{h=y[(y[(x[Q+4>>2]+D(c,3)|0)+2|0]+Q|0)+9|0];if(!z[((h<<1)+a|0)+132>>1]){ec(a,21);break G}o=V>>1;F=x[a+260>>2]+D(h,1596)|0;H=F+338|0;W=F+838|0;k=D(y[F+1588|0],w[G>>1]);t=1;h=0;while(1){if(x[F+1592>>2]>(t|0)){g=y[t+W|0]<<1;l=w[g+G>>1];if((l|0)>=0){j=D(y[F+1588|0],l&65535);l=z[g+H>>1];if((l|0)!=(h|0)){g=j-k|0;u=l-h|0;C=(g|0)/(u|0)|0;H:{T=(l|0)<(o|0)?l:o;if((T|0)<=(h|0)){break H}q=g;g=g>>31;R=C>>31;R=((q^g)-g|0)-D(u,(R^C)-R|0)|0;K=g|1;g=i+(h<<2)|0;B[g>>2]=B[((k&255)<<2)+71552>>2]*B[g>>2];T=T-1|0;g=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;g=g+R|0;Y=(g|0)<(u|0);k=(k+C|0)+(Y?0:K)|0;B[X>>2]=B[((k&255)<<2)+71552>>2]*B[X>>2];g=g-(Y?0:u)|0;continue}}h=l}k=j}t=t+1|0;continue}break}if((h|0)>=(o|0)){break G}k=(k<<2)+71552|0;while(1){if((h|0)==(o|0)){break G}g=i+(h<<2)|0;B[g>>2]=B[k>>2]*B[g>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}TH(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=V-ka;break I}c=x[a+1412>>2];if(!c){break I}h=la-S|0;if((h|0)<=(c|0)){x[a+1412>>2]=c-h;x[ja>>2]=la;S=la;break I}S=c+S|0;x[ja>>2]=S;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];h=x[a+1060>>2];if(c>>>0>=h+(ka-S|0)>>>0){break N}h=c-h|0;c=(c>>>0>=h>>>0?h:0)+S|0;c=(c|0)<(ka|0)?c:ka;x[ba+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(S-fa|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(la-S|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[ba+12>>2]=ka}c=1;break o}aa(6286,13048,3451,5595);p()}h=h-1|0;c=x[Q+4>>2]+D(h,3)|0;l=x[k+(y[c+1|0]<<2)>>2];j=x[k+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(g|0)){continue z}i=c<<2;n=i+l|0;s=B[n>>2];i=i+j|0;m=B[i>>2];O:{if(m>E(0)){if(s>E(0)){r=E(m-s);break O}r=m;m=E(m+s);break O}if(s>E(0)){r=E(m+s);break O}r=m;m=E(m-s)}B[i>>2]=m;B[n>>2]=r;c=c+1|0;continue}}}aa(6286,13048,3335,5595);p()}W=N+256|0;i=0;t=hb-16|0;hb=t;u=x[a+4>>2];G=x[a+396>>2];C=y[(l+X|0)+24|0];F=G+D(C,24)|0;h=x[F+4>>2];Y=z[((C<<1)+a|0)+268>>1];c=fa<<((Y|0)==2);g=c>>>0>h>>>0?h:c;h=x[F>>2];O=(g-(c>>>0>h>>>0?h:c)>>>0)/A[F+8>>2]|0;k=O<<2;c=D(u,k+4|0);K=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];U=x[a+92>>2];P:{if(x[a+80>>2]){h=vn(a,c);u=x[a+4>>2];break P}h=Ld(c)}o=(n|0)>0?n:0;H=fa<<2;g=0;c=(u|0)>0?u:0;j=(u<<2)+h|0;while(1){if((c|0)!=(g|0)){x[(g<<2)+h>>2]=j;g=g+1|0;j=j+k|0;continue}break}k=h;c=0;while(1){if((c|0)!=(o|0)){if(!y[c+N|0]){Tb(x[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((n|0)==1|(Y|0)!=2)){c=0;while(1){R:{if((c|0)!=(o|0)){if(y[c+N|0]){break R}}else{c=o}if((c|0)==(n|0)){break Q}u=G+D(C,24)|0;C=(n|0)!=2;G=(n|0)<3;while(1){if((i|0)==8){break Q}S:{if(!C){h=0;j=0;while(1){if((j|0)>=(O|0)){break S}c=x[F>>2]+D(x[F+8>>2],j)|0;x[t+12>>2]=c&1;x[t+8>>2]=c>>1;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Hk(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break T}g=Ll(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!SH(a,x[a+124>>2]+D(o&65535,2096)|0,W,2,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break U}j=j+1|0;g=x[F>>2]+D(g,j)|0;x[t+8>>2]=g>>1;x[t+12>>2]=g&1}c=c+1|0;continue}break}h=h+1|0;continue}}if(G){break S}h=0;j=0;while(1){if((j|0)>=(O|0)){break S}g=x[F>>2]+D(x[F+8>>2],j)|0;c=(g|0)/(n|0)|0;x[t+12>>2]=g-D(c,n);x[t+8>>2]=c;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Hk(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break V}g=Ll(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!SH(a,x[a+124>>2]+D(o&65535,2096)|0,W,n,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break W}j=j+1|0;g=x[F>>2]+D(g,j)|0;o=(g|0)/(n|0)|0;x[t+8>>2]=o;x[t+12>>2]=g-D(n,o)}c=c+1|0;continue}break}h=h+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=G+D(C,24)|0;n=0;while(1){if((n|0)==8){break Q}i=0;T=0;X:while(1){if((i|0)<(O|0)){h=0;c=0;Y:{if(n){break Y}while(1){if((c|0)==(o|0)){break Y}if(!y[c+N|0]){j=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){Hk(a)}g=x[a+1392>>2];u=w[(j+((g&1023)<<1)|0)+36>>1];Z:{if((u|0)>=0){q=g;u=u&65535;g=y[u+x[j+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:u;break Z}g=Ll(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k+(c<<2)>>2]+(T<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((i|0)>=(O|0)){break $}while(1){if((c|0)==(o|0)){break _}aa:{if(y[c+N|0]){break aa}g=c<<2;j=w[(x[ma+20>>2]+(y[x[x[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(n<<1)>>1];if((j|0)<0){break aa}G=x[a+124>>2]+D(j&65535,2096)|0;$=x[g+W>>2];R=x[F+8>>2];H=x[F>>2]+D(R,i)|0;ba:{ca:{if(Y){u=0;while(1){g=1;if((u|0)>=(R|0)){break ba}ga=$+(H<<2)|0;g=R-u|0;C=0;m=E(0);da:{q=PH(a,G);if((q|0)<0){break da}j=x[G>>2];g=(g|0)>(j|0)?j:g;q=D(j,q);if(y[G+22|0]){j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;m=E(m+B[x[G+28>>2]+(j+q<<2)>>2]);B[ia>>2]=B[ia>>2]+m;j=j+1|0;m=E(m+B[G+12>>2]);continue}}j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;B[ia>>2]=B[ia>>2]+E(B[x[G+28>>2]+(j+q<<2)>>2]+E(0));j=j+1|0;continue}}if(!C){break ca}g=x[G>>2];H=g+H|0;u=g+u|0;continue}}u=0;ga=(R|0)/x[G>>2]|0;q=(ga|0)>0?ga:0;ia=$+(H<<2)|0;g=1;while(1){if((u|0)==(q|0)){break ba}j=u+H|0;C=u<<2;u=u+1|0;sa=C+ia|0;$=R-j|0;j=0;m=E(0);ea:{na=PH(a,G);if((na|0)<0){break ea}C=0;j=x[G>>2];$=(j|0)<($|0)?j:$;$=($|0)>0?$:0;na=D(j,na);j=1;while(1){if((C|0)==($|0)){break ea}qa=sa+(D(C,ga)<<2)|0;r=E(m+B[x[G+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+r;m=y[G+22|0]?r:m;C=C+1|0;continue}}if(j){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}i=i+1|0;h=h+1|0;continue}}break}n=n+1|0;continue}}if(!x[a+80>>2]){Ib(k)}x[a+92>>2]=U;hb=t+16|0;l=l+1|0;continue}}aa(6286,13048,3302,5595);p()}hb=N+2368|0}else{c=0}hb=ha+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((kh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((kh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}g=x[ba+12>>2];j=x[ba+4>>2];k=x[ba+8>>2];ia:{ja:{l=x[a+992>>2];if(l){h=l<<1;ka:{if((h|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((h|0)!=x[a+116>>2]){break ka}c=a+1096|0}c=x[c>>2]}if(!c){break ja}n=(l|0)>0?l:0;while(1){if(x[a+4>>2]>(P|0)){i=(P<<2)+a|0;h=0;while(1){if((h|0)!=(n|0)){S=x[i+800>>2]+(h+j<<2)|0;q=S;m=B[S>>2];S=h<<2;B[q>>2]=E(m*B[S+c>>2])+E(B[S+x[i+928>>2]>>2]*B[c+(l+(h^-1)<<2)>>2]);h=h+1|0;continue}break}P=P+1|0;continue}break}P=x[a+992>>2]}x[a+992>>2]=g-k;l=(g|0)<(k|0);i=(l?k:g)-k|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;h=0;while(1){if((h|0)!=(i|0)){B[x[c+928>>2]+(h<<2)>>2]=B[x[c+800>>2]+(h+k<<2)>>2];h=h+1|0;continue}break}pa=pa+1|0;continue}break}if(!P){break ja}c=(l?g:k)-j|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}h=c;c=0;k=x[a+4>>2];g=(k|0)>0?k:0;while(1){if((c|0)!=(g|0)){l=(c<<2)+a|0;x[l+864>>2]=x[l+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){x[d>>2]=k}x[f>>2]=h;x[e>>2]=a+864;c=x[a+32>>2]-b|0}hb=ba+16|0;return c}function lfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-1760|0;hb=d;zc(b);f=hb-16|0;hb=f;h=d+1632|0;rR(f+8|0,h);g=x[f+12>>2];l=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){$b(l,x[f+12>>2])}hb=f+16|0;b=(b|0)==(g|0);if(!b){qR(h)}a:{if(!b){break a}if(!sR(d+1632|0)){break a}if(!Nb(x[l>>2],x[l+8>>2],Vc(256,0))){break a}b:{if(!c){break b}Dd(a,1048576);Cg(a);b=hb-16|0;hb=b;e=Vb(b,4191);Rc(d+1376|0,e);yb(e);hb=b+16|0;b=z[d+1640>>1];x[d+160>>2]=b>>>8;x[23420]=0;x[d+16>>2]=b&255;R(380,d+88|0,d+16|0);b=x[23420];x[23420]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){x[23420]=0;X(366,d+272|0,d+1376|0,d+160|0,d+88|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}b=d+272|0;Gb(a+1298344|0,b);yb(b);e=d+88|0;yb(e);f=d+1376|0;cc(f);g=Vb(b,14965);Gb(a+1298356|0,g);yb(g);Ye(e,2,d+1642|0);Fc(f,e);x[23420]=0;U(11,b|0,8,f|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}b=d+272|0;Gb(a+1298368|0,b);yb(b);e=d+1376|0;xb(e);x[a+1298404>>2]=8;cA(e,2,d+1674|0);Fc(b,e);Ac(a+1298308|0,b);xb(b);w[a+480188>>1]=z[d+1744>>1];f=y[d+1748|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Wd(f,1,31),x[H+480196>>2]=I;w[a+480192>>1]=z[d+1754>>1];w[a+480190>>1]=z[d+1756>>1];f=Wd(y[d+1749|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;Ru(l,e);f=a+484360|0;g=a+484376|0;Kq(Yb(x[f>>2],y[g|0]),e,z[d+1738>>1],65535,65535);Ze(Yb(x[f>>2],y[g|0]),z[d+1740>>1]);r=Eg(l);Xd(b,l,r?274:0);B=jc(d+1352|0,b);zb(b);x[23420]=0;b=T(145,l|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break k}x[23420]=0;U(178,d+272|0,l|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}b=d+272|0;t=jc(d+1328|0,b);zb(b);b=a+480188|0;q=z[b>>1];if(r){w[b>>1]=q+8}u=c&1;if(!u){break j}x[23420]=0;R(213,a+484344|0,z[d+1742>>1]);b=x[23420];x[23420]=0;if((b|0)!=1){break j}g=P()|0;break e}g=P()|0;break l}g=P()|0;yb(d+88|0)}cc(d+1376|0);break c}g=P()|0;break d}o=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(z[d+1742>>1]<=s>>>0){b=z[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}h=0;b=Hc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}x[23420]=0;b=T(182,l|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break f}x[d+160>>2]=b;x[23420]=0;b=T(145,l|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break g}x[23420]=0;U(178,d+88|0,l|0,b+1&-2);b=x[23420];x[23420]=0;if((b|0)==1){break g}b=d+88|0;j=jc(d+272|0,b);zb(b);xc(d+160|0,1024);if(!u){break o}n=x[d+160>>2];if(!n){break o}x[23420]=0;b=W(214,o|0,s&65535,n|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(v[d+1750|0]&1){break p}t:while(1){if((k|0)==(n|0)){break o}e=0;b=_b(x[o>>2],s);b=pf(x[b>>2],x[x[b+48>>2]+12>>2],k);while(1){if((e|0)==(q|0)){k=k+1|0;continue t}x[23420]=0;R(554,j|0,d+88|0);f=x[23420];x[23420]=0;if((f|0)!=1){g=pR(b+D(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}h=2;b=Ie(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}h=a+480188|0;b=z[h>>1];x[23420]=0;v[d+272|0]=0;s=W(555,d+1312|0,b|0,d+272|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){j=a+1298320|0;n=a+1298332|0;m=a+484348|0;k=0;u:{v:{w:{x:{y:{z:{while(1){b=x[t+8>>2];e=x[t>>2];x[23420]=0;b=W(144,e|0,b|0,8)|0;e=x[23420];x[23420]=0;A:{if((e|0)!=1){if(b){break A}f=x[s>>2];h=0;g=a+480188|0;while(1){e=z[g>>1];if(e>>>0<=h>>>0){x[d+264>>2]=0;x[d+268>>2]=0;x[d+256>>2]=0;x[d+260>>2]=0;x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;B:{C:{if(!r){break C}e=0;x[23420]=0;R(556,B|0,d+272|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;x[23420]=0;j=Q(206,d+224|0,z[d+272>>1])|0;b=x[23420];x[23420]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(z[d+272>>1]<=e>>>0){x[23420]=0;n=W(557,d+208|0,z[d+1742>>1],26764)|0;b=x[23420];x[23420]=0;if((b|0)==1){break E}i=a+484376|0;u=a+484348|0;C=a+480188|0;f=0;break F}x[23420]=0;b=T(182,l|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){x[23420]=0;U(178,d+160|0,l|0,b<<5);b=x[23420];x[23420]=0;if((b|0)==1){break G}f=d+160|0;b=jc(d+88|0,f);bd(Bg(x[j>>2],e),b);zb(b);e=e+1|0;zb(f);continue}break}g=P()|0;break D}g=P()|0;break D}while(1){if(z[d+1738>>1]<=f>>>0){od(n);kd(j);break C}H:{g=d+f|0;e=y[g+290|0];if(e>>>0>=z[d+272>>1]){break H}b=z[bc(x[Yb(x[a+484360>>2],y[i|0])>>2],f)>>1];if(b>>>0>=z[d+1742>>1]){break H}I:{h=bc(x[n>>2],b);m=z[h>>1];J:{if((m|0)==65535){w[h>>1]=e;break J}if((e|0)==(m|0)){break J}x[23420]=0;e=Q(558,o|0,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break I}if((e|0)==65535){break J}H=bc(x[Yb(x[a+484360>>2],y[i|0])>>2],f),I=e,w[H>>1]=I;b=e}if(!oe(x[a+484344>>2],x[u>>2],b)){break H}r=Bg(x[j>>2],y[g+290|0]);zc(r);e=x[r>>2];x[23420]=0;e=T(148,e|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break I}E=e>>>5|0;h=0;K:while(1){e=_b(x[o>>2],b);if(A[e+12>>2]<=h>>>0){break H}g=0;e=ed(x[e>>2],x[x[e+48>>2]+12>>2],h,z[C>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue K}Rh(d+88|0);m=z[d+92>>1];v[e+4|0]=m;v[e+5|0]=m>>>8;m=x[d+88>>2];v[e|0]=m;v[e+1|0]=m>>>8;v[e+2|0]=m>>>16;v[e+3|0]=m>>>24;L:{if(h>>>0>=E>>>0){break L}x[23420]=0;Q(559,r|0,d+88|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break I}if(v[d+88|0]>=0){break L}v[e|0]=61;v[e+1|0]=y[(d+256|0)+(g<<1)|0];m=y[d+88|0]&31;v[d+160|0]=m;if(m){nf(d+160|0,15);v[e+3|0]=20;v[e+5|0]=y[d+160|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;od(n);break D}f=f+1|0;continue}}g=P()|0}kd(j);break u}g=P()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){M:{N:{j=b&65535;if(j>>>0<=h>>>0){if(x[((j<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}w[g>>1]=b;h=f+(d+240|0)|0;f=z[(d+f|0)+274>>1];w[h>>1]=f;O:{if((b|0)!=65535){x[23420]=0;b=W(239,a|0,b|0,f+1&65535)|0;f=x[23420];x[23420]=0;P:{Q:{if((f|0)!=1){if(!b){break O}x[23420]=0;R(273,d+160|0,4436);f=x[23420];x[23420]=0;if((f|0)==1){break Q}x[23420]=0;x[d+16>>2]=e+1;U(560,d+88|0,d+160|0,d+16|0);f=x[23420];x[23420]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Dc(f,b);xb(b);Sb(d+160|0);break O}g=P()|0;break u}g=P()|0;break u}g=P()|0;Sb(d+160|0);break u}w[g>>1]=0}e=e+1|0;continue}}R:{S:{b=z[d+1750>>1]|z[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?z[a+480188>>1]:q)&65535)+(z[d+1640>>1]>591?k:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(z[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=x[l+8>>2];h=x[l>>2];x[23420]=0;g=W(144,h|0,g|0,4)|0;h=x[23420];x[23420]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}x[23420]=0;R(561,z[d+1640>>1],l|0);g=x[23420];x[23420]=0;if((g|0)==1){break R}e=e+1|0;continue}}}x[23420]=0;j=Q(206,d+192|0,255)|0;b=x[23420];x[23420]=0;if((b|0)!=1){m=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){o=aA(d+88|0);n=aA(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){k=0;break Z}x[23420]=0;R(562,l|0,d+272|0);b=x[23420];x[23420]=0;if((b|0)==1){break Y}x[23420]=0;b=T(145,l|0)|0;e=x[23420];x[23420]=0;_:{$:{aa:{if((e|0)!=1){x[23420]=0;U(178,d+16|0,l|0,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break aa}e=d+16|0;k=jc(d- -64|0,e);zb(e);if(z[d+1756>>1]>g>>>0){e=d+48|0;Ye(e,2,d+272|0);x[23420]=0;R(210,d+16|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break _}e=d+16|0;Dc(((g<<5)+a|0)+946336|0,e);xb(e)}if(!b){break X}if(z[d+1756>>1]>g>>>0){break $}break X}g=P()|0;break W}g=P()|0;break W}x[23420]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;R(264,e|0,32);f=x[23420];x[23420]=0;ba:{ca:{da:{if((f|0)!=1){zo(e);x[23420]=0;R(563,k|0,d+16|0);f=x[23420];x[23420]=0;if((f|0)==1){break _}f=x[d+16>>2];x[e>>2]=f;x[b+484404>>2]=x[d+20>>2];if(y[d+24|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+25|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|64;x[e>>2]=f>>>1}h=2;switch(y[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+28>>2];x[b+484388>>2]=x[d+32>>2];w[b+484410>>1]=z[d+36>>1]>>>7;e=y[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ea}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+39|0];e=y[d+26|0];if(e&2){b=d+48|0;Ab(b,n,g);pm(b);e=y[d+26|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break X}b=d+48|0;Ab(b,o,g);pm(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(z[b+(d+240|0)>>1]!=(g|0)){break fa}b=x[((z[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}v[b+14|0]=0}e=e+1|0;continue}}g=P()|0;zb(k);break W}while(1){ga:{ha:{if(z[d+1754>>1]<=k>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(z[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=D(g,104)+a|0;h=c+484380|0;b=c+484416|0;gq(h,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=_c(d+272|0,b&1?16:8,b&64?3:1,0,11);x[23420]=0;W(207,b|0,h|0,l|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}g=P()|0;break W}x[23420]=0;h=T(145,l|0)|0;b=x[23420];x[23420]=0;qa:{if((b|0)==1){break qa}x[23420]=0;Q(176,l|0,12)|0;b=x[23420];x[23420]=0;if((b|0)==1){break qa}b=Jb(d+272|0);x[23420]=0;U(255,l|0,b|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break pa}ze(c+484423|0,b);x[23420]=0;R(365,d- -64|0,16236);c=x[23420];x[23420]=0;if((c|0)==1){break oa}x[d+12>>2]=g;c=x[e>>2];x[23420]=0;U(11,d+48|0,c|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break na}x[23420]=0;X(366,d+16|0,d- -64|0,d+12|0,d+48|0);c=x[23420];x[23420]=0;if((c|0)==1){break ma}c=x[f>>2];x[23420]=0;U(353,c|0,2,d+16|0);c=x[23420];x[23420]=0;if((c|0)==1){break la}yb(d+16|0);yb(d+48|0);cc(d- -64|0);xb(b);continue}break}g=P()|0;break W}g=P()|0;break ia}g=P()|0;break ia}g=P()|0;break ja}g=P()|0;break ka}g=P()|0;yb(d+16|0)}yb(d+48|0)}cc(d- -64|0)}xb(b);break W}b=x[Bg(x[j>>2],k)>>2];x[23420]=0;b=T(148,b|0)|0;e=x[23420];x[23420]=0;ra:{sa:{if((e|0)!=1){if(!b){k=k+1|0;continue}b=Bg(x[j>>2],k);zc(b);x[23420]=0;R(564,b|0,d+272|0);b=x[23420];x[23420]=0;if((b|0)==1){break sa}h=Qb(d+16|0);x[23420]=0;U(565,l|0,h|0,z[d+272>>1]);b=x[23420];x[23420]=0;if((b|0)==1){break ra}k=k+1|0;b=x[((k<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ga}x[b+4>>2]=32;e=0;Ut(b,0);m=b+108|0;i=b+236|0;while(1){if((e|0)==96){break ga}f=y[(d+e|0)+274|0];ta:{if(f>>>0>=z[d+272>>1]){break ta}g=Pe(x[h>>2],f);r=e+12|0;u=bc(i,r);f=y[g|0];q=f+1|0;w[u>>1]=q;if(f>>>0>=z[a+480190>>1]){break ta}f=D(q,104)+a|0;v[f+484418|0]=y[d+370|0]&3;v[f+484419|0]=y[d+371|0];v[f+484420|0]=y[d+372|0];v[f+484421|0]=y[d+373|0];w[f+484412>>1]=y[g+1|0]<<1;v[f+484417|0]=y[g+2|0];f=q-1|0;Ab(d- -64|0,o,f);if(Bb(x[x[d+64>>2]>>2],x[d+68>>2])){v[b+14|0]=0}Ab(d- -64|0,n,f);if(!Bb(x[x[d+64>>2]>>2],x[d+68>>2])){break ta}H=Kb(m,r),I=61,v[H|0]=I}e=e+1|0;continue}}g=P()|0;break W}g=P()|0;break W}g=P()|0;je(h);break W}kd(j);dc(s);zb(t);zb(B);break b}je(h);continue}}g=P()|0;break W}zb(k);g=g+1|0;continue}}x[23420]=0;R(562,l|0,d+160|0);e=x[23420];x[23420]=0;ua:{va:{wa:{xa:{if((e|0)!=1){x[23420]=0;e=T(145,l|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break xa}x[23420]=0;e=(e|0)==32?428:e;k=e?z[d+1640>>1]>513?e+4|0:e:e;U(178,d+88|0,l|0,k|0);e=x[23420];x[23420]=0;if((e|0)==1){break wa}g=d+88|0;e=jc(d+272|0,g);h=he(d+16|0,bd(Bg(x[j>>2],b),e));zb(e);f=b+1|0;zb(g);if(b>>>0>=z[d+1754>>1]){break V}x[23420]=0;b=f&65535;g=W(239,a|0,b|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break va}break ua}g=P()|0;break W}g=P()|0;break W}g=P()|0;break W}if(!g){break V}b=d+88|0;Ye(b,2,d+160|0);x[23420]=0;R(210,d+272|0,b|0);b=x[23420];x[23420]=0;ya:{if((b|0)!=1){b=d+272|0;Dc(g+492|0,b);xb(b);if(!k){break V}x[23420]=0;R(564,h|0,d+272|0);b=x[23420];x[23420]=0;if((b|0)!=1){k=3;o=0;if(z[d+1640>>1]<513){n=0;break ya}x[23420]=0;n=T(182,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ua}if(z[d+1640>>1]<514){break ya}x[23420]=0;k=T(145,h|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}x[g>>2]=z[d+374>>1];v[g+16|0]=y[(z[d+376>>1]&3)+26766|0];v[g+17|0]=y[(y[d+377|0]&3)+26766|0];v[g+18|0]=y[(z[d+376>>1]>>>12&3)+26770|0];while(1){za:{Aa:{if((o|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}Em(g,127,1);Dm(g,0,1);if(!n){break V}x[23420]=0;R(566,h|0,d+88|0);b=x[23420];x[23420]=0;if((b|0)==1){break ua}if(n&2){Em(g,lR(x[m>>2],+z[d+90>>1]),1);Dm(g,y[d+92|0],1)}v[g+25|0]=y[d+89|0]==1;if(!(n&4)){break V}v[g+31|0]=y[d+95|0]+1;b=v[d+96|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+103|0]+1}if(!y[d+100|0]){break Aa}k=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;x[d+64>>2]=b+v[d+100|0];kR(d- -64|0);H=Kb(k,e),I=x[d+64>>2],v[H|0]=I;e=b;continue}}if(!(k&1)){break za}x[23420]=0;R(567,h|0,d+88|0);b=x[23420];x[23420]=0;Ba:{if((b|0)!=1){b=Ci(g,y[o+26774|0]);Ca:{if((o|0)!=3){e=y[d+88|0];q=y[b+12|0]&-17;break Ca}e=y[d+88|0];q=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(q&248|e&1));v[d+64|0]=y[d+89|0];v[d+48|0]=16;e=y[Wb(d- -64|0,d+48|0)|0];x[23420]=0;R(278,b|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break Ba}e=y[d+90|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+91|0];v[b+14|0]=y[d+92|0];e=0;q=x[b>>2];i=qe(q,x[b+4>>2]);while(1){if((e|0)==(i|0)){break za}r=Cb(q,e);b=(d+88|0)+(e<<2)|0;w[r>>1]=y[b+8|0]|y[b+9|0]<<8;H=r,I=Wd(y[b+10|0]|y[b+11|0]<<8,0,64),v[H+2|0]=I;e=e+1|0;continue}}break ua}break ua}Ut(g,0);break V}o=o+1|0;k=k>>>1|0;continue}}g=P()|0;zb(h)}kd(j);break u}zb(h);continue}}g=P()|0;break u}g=P()|0;break u}g=P()|0;break u}else{b=v[Kb(f,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=y[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;j=y[e|0];if(!j){v[e|0]=b;break Da}e=j-1|0;while(1){j=D(e&255,160)+a|0;e=Hm(x[j+906328>>2]);if((e|0)!=255){continue}break}b=b-1&255;x[(j+906300|0)+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;break u}x[23420]=0;f=T(145,t|0)|0;b=x[23420];x[23420]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){x[23420]=0;b=T(145,t|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Ma}x[23420]=0;U(178,d+272|0,t|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break Ma}e=d+272|0;b=jc(d+88|0,e);zb(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}x[23420]=0;e=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[h>>1]<=e>>>0){break Fa}x[23420]=0;f=Q(568,b|0,d+272|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break z}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+272>>1]>>>10;H=Kb(x[s>>2],e),I=y[d+275|0],v[H|0]=I}e=e+1|0;continue}}g=P()|0;break u}g=P()|0;break u}if(g&1){break Fa}v[a+480224|0]=2;x[23420]=0;F=+na(569,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break Ea}if(!(F>1e-8)){break Fa}H=a,I=Ie(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break Fa}while(1){Na:{if(z[h>>1]<=e>>>0){break Fa}f=x[b>>2];x[23420]=0;f=W(144,f|0,x[d+96>>2],1)|0;i=x[23420];x[23420]=0;if((i|0)==1){break y}if(!f){break Fa}f=Jb(d+272|0);x[23420]=0;U(336,b|0,f|0,-1);i=x[23420];x[23420]=0;if((i|0)!=1){i=d+16|0;Qf(i,3,Ic(f),Eb(f));x[23420]=0;R(210,d+160|0,i|0);i=x[23420];x[23420]=0;if((i|0)==1){break Na}i=d+160|0;ym(((e<<5)+a|0)+480289|0,i);xb(i);xb(f);e=e+1|0;continue}}break}g=P()|0;xb(f);break v}while(1){if(z[d+1742>>1]<=e>>>0){break Fa}f=x[b>>2];x[23420]=0;f=W(144,f|0,x[d+96>>2],1)|0;i=x[23420];x[23420]=0;if((i|0)==1){break x}if(!f){break Fa}if(!zm(x[a+484344>>2],x[m>>2],e&65535)){break Fa}f=Jb(d+272|0);x[23420]=0;U(336,b|0,f|0,-1);i=x[23420];x[23420]=0;Oa:{if((i|0)==1){break Oa}i=x[o>>2];x[23420]=0;R(268,_b(i,e)|0,f|0);i=x[23420];x[23420]=0;if((i|0)==1){break Oa}xb(f);e=e+1|0;continue}break}g=P()|0;xb(f);break v}x[23420]=0;Q(176,b|0,1)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}x[23420]=0;e=T(190,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break w}x[23420]=0;X(317,n|0,b|0,e|0,2);e=x[23420];x[23420]=0;if((e|0)!=1){break Fa}break w}x[23420]=0;Q(570,b|0,d+16|0)|0;e=x[23420];x[23420]=0;Pa:{if((e|0)!=1){e=Jb(d+272|0);x[23420]=0;U(336,b|0,e|0,-1);f=x[23420];x[23420]=0;if((f|0)==1){break Pa}if(dq(e,12472)){x[23420]=0;U(11,d+160|0,8,e|0);f=x[23420];x[23420]=0;if((f|0)==1){break Pa}f=d+160|0;Gb(j,f);yb(f)}xb(e);break Fa}g=P()|0;break v}g=P()|0;xb(e);break v}x[23420]=0;k=T(145,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}}zb(b);continue}break}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0;break v}g=P()|0}zb(b)}dc(s);break e}g=P()|0;break e}while(1){b=x[j>>2];x[23420]=0;b=W(144,b|0,x[d+280>>2],1)|0;f=x[23420];x[23420]=0;Qa:{if((f|0)!=1){if(!b){break o}x[23420]=0;h=T(194,j|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break h}m=0;if((h|0)!=255){break Qa}x[23420]=0;m=T(194,j|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;h=T(194,j|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break Qa}}break h}break h}if(h&127){b=_b(x[o>>2],s);f=ed(x[b>>2],x[x[b+48>>2]+12>>2],e,k&65535);Cu(d+88|0);if(h&1){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+88|0]=b}if(h&2){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+89|0]=b}if(h&4){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+90|0]=b}if(h&8){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+91|0]=b}if(h&16){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+92|0]=b}if(h&32){x[23420]=0;b=T(194,j|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}v[d+93|0]=b}if(h&64){x[23420]=0;b=T(194,j|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break n}v[d+94|0]=b}E=pR(f,d+88|0);x[d+16>>2]=m;x[d+64>>2]=n+(e^-1);G=x[Hb(d+16|0,d- -64|0)>>2];h=0;b=f;while(1){if((h|0)!=(G|0)){b=D(z[C>>1],6)+b|0;i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=i;v[b+1|0]=i>>>8;v[b+2|0]=i>>>16;v[b+3|0]=i>>>24;i=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=i;v[b+5|0]=i>>>8;h=h+1|0;continue}break}g=g|E}e=(e+m|0)+1|0;while(1){if(e>>>0>=n>>>0){k=k+1|0;e=e-n|0;continue}break}if(q>>>0>(k&65535)>>>0){continue}break}}zb(j);s=s+1|0;continue}break}break h}g=P()|0;xb(d+1376|0);break c}g=P()|0;zb(j);break e}g=P()|0;break e}g=P()|0}zb(t)}zb(B)}S(g|0);p()}e=1}hb=d+1760|0;return e|0}function $8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,R=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,ba=0;m=hb-1168|0;hb=m;zc(b);a:{if(!gr(b,m+1144|0)){break a}if(!CL(m+1144|0)){break a}if(x[m+1152>>2]!=(Hg(x[b>>2])|0)){break a}if(x[m+1160>>2]!=(df(b)|0)){break a}if(!c){h=1;break a}d=m+1088|0;Tb(d,0,56);o=-2;b:{if(!d){break b}x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+8>>2]=0;o=x[d+32>>2];if(!o){x[d+32>>2]=1038;o=1038}if(!x[d+36>>2]){x[d+36>>2]=1039}e=mb[o|0](x[d+40>>2],1,43784)|0;o=-4;if(!e){break b}x[d+28>>2]=e;x[e+43780>>2]=1;x[e+10992>>2]=0;x[e+10996>>2]=0;x[e>>2]=0;x[e+11008>>2]=15;x[e+11e3>>2]=1;x[e+11004>>2]=0;o=0}if(o){break a}h=x[m+1160>>2];x[m+1084>>2]=h;J=x[m+1164>>2];Q=kB(m+1072|0,J);c:{d:{while(1){if(!(!h|!J|(g|0)==1)){x[m+32>>2]=1024;g=m+32|0;R=x[Hb(g,m+1084|0)>>2];d=fc(m+40|0,m+48|0,R);h=x[d+4>>2];d=x[d>>2];x[23420]=0;bn(153,g,b,d,h);g=x[23420];x[23420]=0;if((g|0)==1){break d}d=m+48|0;g=d;h=R;e=Z^-1;while(1){if(h>>>0<4){while(1){if(h){e=x[(((y[g|0]^e)&255)<<2)+61968>>2]^e>>>8;h=h-1|0;g=g+1|0;continue}break}Z=e^-1}else{e=x[(((y[g|0]^e)&255)<<2)+61968>>2]^e>>>8;e=e>>>8^x[(((e^y[g+1|0])&255)<<2)+61968>>2];e=e>>>8^x[(((e^y[g+2|0])&255)<<2)+61968>>2];e=e>>>8^x[(((e^y[g+3|0])&255)<<2)+61968>>2];h=h-4|0;g=g+4|0;continue}break}x[m+1092>>2]=R;x[m+1088>>2]=d;x[m+1104>>2]=J;x[m+1100>>2]=x[Q>>2]+_;E=hb-16|0;hb=E;g=-2;q=m+1088|0;e:{if(!q){break e}i=x[q+28>>2];if(!i){break e}ba=x[q+4>>2];x[i+11e3>>2]=0;f:{if(x[i+43780>>2]<0){break f}if(x[i+11004>>2]){break e}h=x[i+11008>>2];g=0;x[i+11004>>2]=0;d=x[i+10996>>2];if(!d){U=(h|0)>0?11:10;H=i+11012|0;e=x[q+4>>2];k=x[i+10992>>2];while(1){x[E+12>>2]=e;x[E+8>>2]=32768-k;C=x[q>>2];d=0;e=0;o=0;I=0;K=0;T=0;V=0;X=hb-144|0;hb=X;g:{h:{L=k+H|0;if(L>>>0>=H>>>0){F=x[E+8>>2]+L|0;s=F-H|0;Y=(H^-1)+F|0;if(!(s&Y)){break h}}x[E+8>>2]=0;x[E+12>>2]=0;n=-3;break g}r=x[E+12>>2];B=r+C|0;M=x[i+60>>2];t=x[i+40>>2];g=x[i+36>>2];u=x[i+32>>2];h=x[i+56>>2];f=x[i+4>>2];n=-1;j=C;l=L;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{k=x[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break S;case 1:break T;case 0:break U;default:break j}}x[i+28>>2]=1;h=0;x[i+8>>2]=0;x[i+12>>2]=0;x[i+16>>2]=1;t=0;g=0;u=0;f=0;if(U&1){break T}break v}if((r|0)<=0){x[i>>2]=1;break m}x[i+8>>2]=y[C|0];j=C+1|0}if(j>>>0>=B>>>0){x[i>>2]=2;n=1;break i}g=y[j|0];x[i+12>>2]=g;r=1;e=x[i+8>>2];if(!(((g|e<<8)>>>0)%31|g&32)){r=(e&15)!=8}j=j+1|0;k=36;g=256<<(e>>>4);if(g>>>0>32768|g>>>0>s>>>0){break l}g=0;if(r){break l}break v}if((r|0)<=0){x[i>>2]=5;break m}T=f+8|0;j=C+1|0;h=y[C|0]<<f|h;d=2;break v}if((r|0)<=0){x[i>>2]=32;break m}f=f+8|0;j=C+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}V:while(1){W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(f>>>0>2){break Ba}d=1;continue;case 3:break za;case 2:break Aa;case 1:break Ca;case 9:break fa;case 10:break ga;case 11:break ha;case 12:break ia;case 13:break ja;case 14:break ka;case 15:break la;case 16:break ma;case 17:break na;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;default:break oa}}while(1){if(j>>>0>=B>>>0){x[i>>2]=3;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}}d=h&7;x[i+20>>2]=d;k=d>>>1|0;x[i+24>>2]=k;f=f-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}T=f;break pa}f=T&-8;h=h>>>(T&7)|0;g=0;d=0;break ra}if(j>>>0<B>>>0){break xa}x[i>>2]=7;n=1;break i}while(1){if(j>>>0>=B>>>0){x[i>>2]=6;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}d=1;break ra}v[(g+i|0)+10528|0]=y[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=B>>>0){x[i>>2]=51;n=1;break i}h=y[j|0]<<f|h;d=f>>>0>4294967287;j=j+1|0;f=f+8|0;if(d){continue}break}break Z}if(l>>>0<F>>>0){v[l|0]=u;g=g-1|0;l=l+1|0;break _}n=2;k=52;break k}if(l>>>0<F>>>0){break qa}n=2;k=9;break k}if(j>>>0<B>>>0){d=F-l|0;e=B-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<g>>>0?d:g;g=g-d|0;l=pc(l,j,d)+d|0;j=d+j|0;break Y}x[i>>2]=38;n=1;break i}e=0;Da:{switch(k-1|0){case 0:x[i+44>>2]=288;x[i+48>>2]=32;d=i+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break ca}v[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{v[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{v[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{v[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break ea}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(g>>>0>3){break Ha}if(!f){f=0;d=3;continue V}if(f>>>0>7){break Fa}d=4;continue V;case 1:v[(g+i|0)+10528|0]=h;f=f-8|0;h=h>>>8|0;break Ea;default:break Ia}}g=g+1|0;break Ga}g=z[i+10528>>1];if((g|0)==(z[i+10530>>1]^65535)){break _}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=F>>>0){n=2;k=53;break k}v[l|0]=y[(M-u&Y)+H|0];l=l+1|0;M=M+1|0;d=7;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=27;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}d=6;break $}if(j>>>0>=B>>>0){x[i>>2]=26;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=4;if(f>>>0<15){break $}d=5;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=25;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}d=3;break $}if(l>>>0>=F>>>0){n=2;k=24;break k}v[l|0]=g;l=l+1|0;break aa}if(j>>>0>=B>>>0){x[i>>2]=23;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=0;if(f>>>0<15){break $}d=1;break $}while(1){if(j>>>0>=B>>>0){x[i>>2]=18;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(t>>>0>f>>>0){continue}break}V=u-16|0;d=3;break ba}if(j>>>0>=B>>>0){x[i>>2]=16;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;d=1;if(f>>>0<15){break ba}d=2;break ba}while(1){if(j>>>0>=B>>>0){x[i>>2]=14;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;if(f>>>0<3){continue}break}d=1;break da}d=g+21454|0;while(1){if(j>>>0>=B>>>0){x[i>>2]=11;n=1;break i}h=y[j|0]<<f|h;j=j+1|0;f=f+8|0;K=v[d|0];if(f>>>0<K>>>0){continue}break}e=g;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}g=e;K=v[e+21454|0];if(K>>>0<=f>>>0){break Ja}d=9;continue V}g=e<<2;x[(g+i|0)+44>>2]=x[g+63504>>2]+((-1<<K^-1)&h);e=e+1|0;f=f-K|0;h=h>>>K|0;break Ka}g=0;Tb(i+7040|0,0,288);d=0;break da}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(A[i+52>>2]<=g>>>0){break Oa}if(f>>>0>2){break Ma}d=10;continue V}v[(y[g+63520|0]+i|0)+7040|0]=h&7;g=g+1|0;f=f-3|0;h=h>>>3|0;break Na}x[i+52>>2]=19;break ca}d=0;continue}d=1;continue}}I=x[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((I|0)<0){break aa}N=Tb(X,0,64);e=D(I,3488)+i|0;Tb(e+352|0,0,3200);$=e- -64|0;G=x[i+24>>2];e=x[((G<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(y[d+$|0]<<2)+N|0;x[k>>2]=x[k>>2]+1;d=d+1|0;continue}break};x[N+64>>2]=0;x[N+68>>2]=0;s=0;d=1;k=0;while(1){if((d|0)!=16){r=d<<2;d=d+1|0;r=x[r+N>>2];k=r+k<<1;x[(N- -64|0)+(d<<2)>>2]=k;s=r+s|0;continue}break};O=0;r=-1;if((k|0)!=65536&s>>>0>=2){break p}while(1){if(e>>>0>O>>>0){s=y[O+$|0];Ya:{if(!s){break Ya}d=(N- -64|0)+(s<<2)|0;k=x[d>>2];x[d>>2]=k+1;d=0;e=s;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(s>>>0<=10){e=1<<s;k=s<<9|O;s=D(I,3488)+i|0;while(1){if(d>>>0>1023){break Ya}w[(s+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}G=D(I,3488)+i|0;k=G+((d&1023)<<1)|0;e=w[k+352>>1];Za:{if(e){k=r;r=e;break Za}w[k+352>>1]=r;k=r-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(s>>>0>=12){e=(G+(e+(r^-1)<<1)|0)+2400|0;r=w[e>>1];if(!r){w[e>>1]=k;r=k;k=k-2|0}s=s-1|0;continue}break}w[((D(I,3488)+i|0)+(e+(r^-1)<<1)|0)+2400>>1]=O;r=k}O=O+1|0;G=x[i+24>>2];e=x[((G<<2)+i|0)+44>>2];continue}break};d=0;if((G|0)!=2){break Qa}break Ua;case 1:d=w[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break _a}break Ta}if(f>>>0<11){break _a}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue V;case 2:e=w[(((h&1023)<<1)+i|0)+7328>>1];if((e|0)>=0){break Wa}d=10;while(1){k=h>>>d|0;d=d+1|0;e=w[(((k&1)+(e^-1)<<1)+i|0)+9376>>1];if((e|0)<0){continue}break};u=e&65535;break Va;default:break Xa}}d=v[V+17663|0]+((-1<<t^-1)&h)|0;f=f-t|0;h=h>>>t|0;e=g+i|0;Tb(e+10532|0,(u|0)==16?y[e+10531|0]:0,d);d=d+g|0;break Ua}d=e>>>9|0;u=e&511}f=f-d|0;h=h>>>d|0;if(u>>>0>15){break Sa}v[(g+i|0)+10532|0]=u;d=g+1|0}e=x[i+48>>2];g=x[i+44>>2];k=e+g|0;if(k>>>0<=d>>>0){break Ra}if(f>>>0<=14){if((B-j|0)<=1){g=d;d=1;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;j=j+2|0;f=f+16|0}g=d}d=2;continue}if(!((u|0)!=16|g)){g=0;u=16;break q}V=u-16|0;t=v[u+21429|0];if(t>>>0<=f>>>0){break Pa}d=12;continue V}if((d|0)!=(k|0)){g=d;break r}k=i+10532|0;pc(i- -64|0,k,g);pc(i+3552|0,g+k|0,e);G=x[i+24>>2];g=d}I=G-1|0;x[i+24>>2]=I;d=0;continue}d=3;continue}}o=h;d=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(d|0){case 0:d=w[(((h&1023)<<1)+i|0)+352>>1];pb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break pb}break ab}if(f>>>0<11){break pb}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break ab}}d=13;continue V;case 1:e=w[(((h&1023)<<1)+i|0)+352>>1];if((e|0)>=0){break nb}d=10;while(1){g=h>>>d|0;d=d+1|0;e=w[(((g&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break};g=e&65535;break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){d=B-j|0;if(!((F-l|0)>1&(d|0)>=4)){if(f>>>0>14){h=o;break ab}if((d|0)<=1){h=o;d=0;continue $a}h=y[j|0]<<f|y[j+1|0]<<f+8|o;f=f+16|0;j=j+2|0;break ab}if(f>>>0>14){k=j}else{o=(y[j|0]|y[j+1|0]<<8)<<f|o;f=f+16|0;k=j+2|0}g=w[(((o&1023)<<1)+i|0)+352>>1];qb:{if((g|0)<0){d=10;while(1){h=o>>>d|0;d=d+1|0;g=w[(((h&1)+(g^-1)<<1)+i|0)+2400>>1];if((g|0)<0){continue}break}g=g&65535;break qb}d=g>>>9|0}f=f-d|0;h=o>>>d|0;if(g&256){j=k;break lb}if(!(f>>>0>14)){h=(y[k|0]|y[k+1|0]<<8)<<f|h;k=k+2|0;f=f+16|0}s=f;j=k;e=w[(((h&1023)<<1)+i|0)+352>>1];rb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=w[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}e=e&65535;break rb}d=e>>>9|0}v[l|0]=g;f=s-d|0;o=h>>>d|0;if(!(e&256)){v[l+1|0]=e;l=l+2|0;continue}break}l=l+1|0;h=o;g=e;break lb}d=e>>>9|0;g=e&511}f=f-d|0;h=h>>>d|0;if(g>>>0>255){break lb}d=14;continue V}e=g&511;g=256;if((e|0)==256){break X}d=e-257<<2;g=x[d+62992>>2];t=0;if(e-285>>>0<4294967276){break cb}t=x[d+63120>>2];if(t>>>0>f>>>0){d=15;continue V}d=3;continue}if(!g){o=h;g=-1;break gb}g=g-1|0;d=18;continue V}f=f-t|0;o=h>>>t|0;u=((-1<<t^-1)&h)+u|0;break hb}e=w[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((e|0)<0){d=10;while(1){k=h>>>d|0;d=d+1|0;e=w[(((k&1)+(e^-1)<<1)+i|0)+5888>>1];if((e|0)<0){continue}break}e=e&65535;break sb}d=e>>>9|0;e=e&511}f=f-d|0;h=h>>>d|0;d=e<<2;u=x[d+63248>>2];t=0;if(e-30>>>0<4294967270){o=h;break hb}t=x[d+63376>>2];if(t>>>0<=f>>>0){break fb}d=17;continue V}M=l-H|0;d=(M-u&Y)+H|0;if((d>>>0<l>>>0?l:d)+g>>>0>F>>>0){h=o;d=7;continue}while(1){if(g>>>0>=3){v[l|0]=y[d|0];v[l+1|0]=y[d+1|0];v[l+2|0]=y[d+2|0];g=g-3|0;d=d+3|0;l=l+3|0;continue}break}if(!g){g=0;break gb}v[l|0]=y[d|0];if((g|0)!=1){v[l+1|0]=y[d+1|0]}l=g+l|0}d=2;continue}d=6;continue}d=w[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>f>>>0){break tb}break bb}if(f>>>0<11){break tb}e=10;while(1){d=w[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(f>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=16;continue V}f=f-t|0;g=((-1<<t^-1)&h)+g|0;h=h>>>t|0}if(f>>>0>14){break bb}if((B-j|0)<=1){d=4;continue}h=y[j|0]<<f|y[j+1|0]<<f+8|h;f=f+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!g|!f){break Y}if(f>>>0>7){break Z}d=5;continue}f=f-8|0;u=h&255;h=h>>>8|0;d=6;continue}if(g){break W}g=0}if(v[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;if((f&-8)==d<<3){j=j-d|0;e=0;d=0;f=0;if(!(U&1)){break s}k=0;break t}aa(6800,13026,2797,6810);p()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(k|0){case 0:if(e>>>0>3){g=e;f=d;break s}f=0;if(d){break yb}g=e;k=1;continue;case 1:break zb;default:break xb}}if(j>>>0<B>>>0){break vb}x[i>>2]=42;n=1;break i}g=e;f=d;if(d>>>0>7){break wb}k=2;continue}while(1){if(j>>>0>=B>>>0){x[i>>2]=41;n=1;break i}h=y[j|0]<<f|h;e=f>>>0>4294967287;j=j+1|0;d=f+8|0;f=d;if(e){continue}break}e=g}k=h&255;h=h>>>8|0;d=d-8|0;break ub}k=y[j|0];j=j+1|0;e=g;d=f}x[i+16>>2]=x[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}g=1}x[i>>2]=k}d=f>>>3|0;e=j-C|0;e=e>>>0<=j>>>0?e:0;d=d>>>0<e>>>0?d:e;j=j-d|0;f=f-(d<<3)|0}x[i+4>>2]=f;x[i+60>>2]=M;x[i+40>>2]=t;x[i+36>>2]=g;x[i+32>>2]=u;x[i+56>>2]=(((f&63)>>>0<32?-1<<f:0)^-1)&h;x[E+12>>2]=j-C;h=l-L|0;x[E+8>>2]=h;if((n|0)<0){break g}f=(h>>>0)%5552|0;g=x[i+28>>2];e=g>>>16|0;k=g&65535;while(1){j=0;if(h){d=L;while(1){if((j|7)>>>0<f>>>0){g=y[d|0]+k|0;o=g+y[d+1|0]|0;r=o+y[d+2|0]|0;s=r+y[d+3|0]|0;l=s+y[d+4|0]|0;u=l+y[d+5|0]|0;C=u+y[d+6|0]|0;k=C+y[d+7|0]|0;e=k+(C+(u+(l+(s+(r+(o+(e+g|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;j=j+8|0;continue}break}j=f&8184;while(1){if((f|0)!=(j|0)){j=j+1|0;k=y[d|0]+k|0;e=k+e|0;d=d+1|0;continue}break}h=h-f|0;e=(e>>>0)%65521|0;k=(k>>>0)%65521|0;L=f+L|0;f=5552;continue}break}g=e<<16|k;x[i+28>>2]=g;if(n){break g}n=0;if(!(U&1)){break g}n=(g|0)!=x[i+16>>2]?-2:0}hb=X+144|0;x[i+43780>>2]=n;g=x[E+12>>2];x[q>>2]=g+x[q>>2];x[q+4>>2]=x[q+4>>2]-g;x[q+8>>2]=g+x[q+8>>2];x[q+48>>2]=x[i+28>>2];g=x[E+8>>2];x[i+10996>>2]=g;d=x[q+16>>2];d=d>>>0>g>>>0?g:d;pc(x[q+12>>2],x[i+10992>>2]+H|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;k=d+x[i+10992>>2]&32767;x[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|ba)){g=-5;break e}if(n){g=0;e=x[q+4>>2];if(!e|!x[q+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}g=(d|0)==(h|0);break e}h=x[q+16>>2];d=d>>>0<h>>>0?d:h;pc(x[q+12>>2],(x[i+10992>>2]+i|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];h=x[i+10996>>2];x[i+10996>>2]=h-d;x[i+10992>>2]=d+x[i+10992>>2]&32767;if(x[i+43780>>2]){break e}g=(d|0)==(h|0);break e}g=-3}hb=E+16|0;h=x[m+1084>>2]-R|0;x[m+1084>>2]=h;d=J+_|0;J=x[m+1104>>2];_=d-J|0;continue}break}b=m+1088|0;Ab:{if(!b){break Ab}d=x[b+28>>2];if(!d){break Ab}mb[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}h=0;Bb:{Cb:{if(!(x[m+1156>>2]!=(Z|0)|J|(g|0)!=1)){ke(m+24|0,x[Q>>2],x[Q+4>>2]);b=$d(m+16|0);x[23420]=0;g=x[b+4>>2];x[m+8>>2]=x[b>>2];x[m+12>>2]=g;b=wg(491,m+48|0,x[m+24>>2],x[m+28>>2],m+8|0);g=x[23420];x[23420]=0;if((g|0)==1){break Cb}x[23420]=0;h=W(825,a|0,b|0,c|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break Bb}zb(b)}dc(Q);break a}a=P()|0;break c}a=P()|0;zb(b);break c}a=P()|0}dc(Q);S(a|0);p()}hb=m+1168|0;return h|0}function Ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=E(0),C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=0,N=0,O=E(0),Q=0,R=E(0),U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=hb-96|0;hb=n;zc(c);a:{while(1){b:{if(!Nb(x[c>>2],x[c+8>>2],4)){break b}d=n+72|0;g=hb-16|0;hb=g;c:{if(!Nb(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){ug(d+F|0);F=F+1|0;continue}break}break c}kv(g+8|0,d);qd(g,c,x[g+8>>2],x[g+12>>2])}hb=g+16|0;d:{e:{if(!Ob(d,14868,3)){d=n+24|0;g=hb-16|0;hb=g;f:{if(!Nb(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){ug(d+F|0);F=F+1|0;continue}break}break f}uo(g+8|0,d);qd(g,c,x[g+8>>2],x[g+12>>2])}hb=g+16|0;F=0;g=3;while(1){if((g|0)==7){break d}d=v[(n+24|0)+g|0];if((d|0)<0){break e}g=g+1|0;F=d&255|F<<7;continue}}g:{if(Ob(n+72|0,14041,3)){break g}if(!ER(c,13412)){break g}$b(c,pg(c)+16|0);continue}if(!Ob(n+72|0,30062,3)){continue}if(!Ob(n+72|0,30066,3)){continue}if(!y[n+72|0]){mg(c,2);continue}if(mP(n+72|0)){break b}}g=0;break a}$b(c,F);continue}break}zc(c);g=n+72|0;PA(g,c);Y=x[n+72>>2];fa=xe(g);M=Qb(n+56|0);x[23420]=0;aa=T(525,n+48|0)|0;c=x[23420];x[23420]=0;h:{i:{j:{if((c|0)!=1){cz(Tb(x[aa>>2],0,6668));x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[n+24>>2]=0;x[n+28>>2]=0;x[23420]=0;ba=T(526,n+8|0)|0;c=x[23420];x[23420]=0;k:{if((c|0)!=1){F=0;c=0;while(1){G=x[aa>>2];j=fa;e=Hc(Y,$);U=x[ba>>2];d=0;m=0;r=hb-17168|0;hb=r;x[r+17164>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(e|0)<5){break n}if(!gp(G+6152|0,j)){break n}g=dx(y[j+1|0],y[j+2|0],x[G+6148>>2])+fp(j)|0;x[r+17164>>2]=g;if((e|0)==(g|0)){g=e;break m}o:{if((e|0)>=(g+4|0)){if(gp(j,g+j|0)){break o}}x[r+17164>>2]=0;break n}if(g){break m}}h=j;C=Tb(G,0,6668)+6148|0;I=r+17164|0;s=e-4|0;k=(s|0)>0?s:0;while(1){p:{q:{r:{s:{if((k|0)==(m|0)){m=e;break s}if(!$H(h)){break q}i=dx(y[h+1|0],y[h+2|0],x[C>>2]);g=i+fp(h)|0;f=4;o=m+4|0;t:{while(1){if(!(f>>>0>2303|i)){if((s|0)<=((f<<1)+m|0)){break t}i=0;q=f+h|0;u:{if(!gp(h,q)){break u}l=f-fp(h)|0;u=fp(q)+l|0;if((e|0)<(u+(f+o|0)|0)){break u}if(!gp(h,q+u|0)){break u}x[C>>2]=l;i=l;g=f}f=f+1|0;continue}break}if(!i|(e|0)<(g+m|0)){break t}q=e-m|0;f=0;o=0;while(1){v:{w:{if((o|0)!=10){l=(o|0)!=0;J=f;f=f+h|0;f=(J+dx(y[f+1|0],y[f+2|0],i)|0)+fp(f)|0;if((q|0)<(f+4|0)){break v}if(gp(h,f+h|0)){break w}l=0}else{l=1}break v}o=o+1|0;continue}break}if(!l){break t}d=g;break s}if((e|0)!=(g|0)|m){break r}m=0;d=e}x[I>>2]=d;d=m;break p}x[C>>2]=0}h=h+1|0;m=m+1|0;continue}break}g=x[r+17164>>2];if((e|0)>=(d+g|0)?g:0){break m}x[n+24>>2]=d;o=0;break l}u=d+j|0;x[G+6152>>2]=y[u|0]|y[u+1|0]<<8|(y[u+2|0]<<16|y[u+3|0]<<24);x[n+28>>2]=d;x[n+24>>2]=d+g;x[n+32>>2]=y[u+3|0]>191?1:2;ra=n,sa=dI(y[u+1|0],y[u+2|0]),x[ra+36>>2]=sa;x[n+40>>2]=4-(y[u+1|0]>>>1&3);ra=n,sa=cx(y[u+1|0],y[u+2|0]),x[ra+44>>2]=sa;if(!U){o=bx(y[u+1|0]);break l}bI(r+17152|0,u+4|0,g-4|0);if(!(v[u+1|0]&1)){ce(r+17152|0,16)}x:{if(x[n+40>>2]==3){o=0;d=r+17152|0;ja=r+3740|0;g=ja;h=0;e=y[u+1|0];f=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[u+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;m=y[u+3|0]>191?1:2;y:{if(e&8){i=ce(d,9);m=m<<1;h=ce(d,m+7|0);break y}i=ce(d,m|8)>>>m|0}e=D(f,40);C=e+63840|0;s=e+64160|0;q=D(f,23)+63648|0;j=-1;l=0;z:{while(1){e=y[u+3|0];I=ce(d,12);w[g+4>>1]=I;f=ce(d,9);w[g+6>>1]=f;if((f&65535)>>>0>288){break z}f=e>>>0>191?h<<4:h;ra=g,sa=ce(d,8),v[ra+10|0]=sa;e=ce(d,y[u+1|0]&8?4:9);v[g+13|0]=22;v[g+14|0]=0;x[g>>2]=q;w[g+8>>1]=e;A:{if(ce(d,1)){e=ce(d,2);v[g+11|0]=e;if(!(e&255)){break z}e=ce(d,1);w[g+18>>1]=65287;v[g+12|0]=e;if(y[g+11|0]==2){B:{if(!(e&255)){x[g>>2]=C;v[g+18|0]=8;h=0;e=39;break B}x[g>>2]=s;h=y[u+1|0]&8?8:6;e=30}v[g+14|0]=e;v[g+13|0]=h;f=f&3855}e=ce(d,10);ra=g,sa=ce(d,3),v[ra+21|0]=sa;ra=g,sa=ce(d,3),v[ra+22|0]=sa;ra=g,sa=ce(d,3),v[ra+23|0]=sa;h=e<<5;break A}v[g+11|0]=0;v[g+12|0]=0;h=ce(d,15);ra=g,sa=ce(d,4),v[ra+18|0]=sa;e=ce(d,3);v[g+20|0]=255;v[g+19|0]=e}v[g+17|0]=h&31;v[g+15|0]=h>>>10;v[g+16|0]=h>>>5&31;l=(I&65535)+l|0;C:{if(y[u+1|0]&8){e=ce(d,1);break C}e=z[g+8>>1]>499}v[g+24|0]=e;ra=g,sa=ce(d,1),v[ra+25|0]=sa;e=ce(d,1);v[g+27|0]=f>>>12&15;v[g+26|0]=e;g=g+28|0;h=f<<4;m=m-1|0;if(m){continue}break}j=(x[d+4>>2]+l|0)>(x[d+8>>2]+(i<<3)|0)?-1:i}if(!((j|0)<0|x[r+17156>>2]>x[r+17160>>2])){g=r+17152|0;f=x[g+4>>2];m=x[g+8>>2];h=r+912|0;d=x[G+6144>>2];e=d-j|0;d=(d|0)<(j|0)?d:j;e=pc(h+12|0,(((e|0)>0?e:0)+G|0)+6156|0,d);i=x[g>>2]+(x[g+4>>2]/8|0)|0;g=(m-f|0)/8|0;pc(d+e|0,i,g);bI(h,e,d+g|0);D:{g=x[G+6144>>2]>=(j|0);if(!g){break D}ma=G+2304|0;na=r+8620|0;oa=r+3852|0;while(1){if((y[u+1|0]&8?2:1)>>>0<=o>>>0){break D}pa=Tb(oa,0,4608);e=x[n+32>>2];m=D(D(e,o),28)+ja|0;d=0;ka=(e|0)>0?e:0;C=r+912|0;I=C+7548|0;X=G+6152|0;while(1){if((d|0)!=(ka|0)){j=D(d,28)+m|0;J=z[j+4>>1];Q=x[C+4>>2];t=(C+D(d,39)|0)+16156|0;e=I;s=d;f=hb-48|0;hb=f;d=j;K=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+64480|0;E:{if(y[X+1|0]&8){i=y[d+27|0];j=y[z[d+8>>1]+64576|0];h=j&3;v[f+47|0]=h;v[f+46|0]=h;j=j>>>2|0;v[f+45|0]=j;v[f+44|0]=j;break E}j=(y[X+3|0]&16)>>>4&(s|0)!=0;k=j?12:0;h=z[d+8>>1]>>>j|0;while(1){if((h|0)>=0){i=3;j=1;while(1){if((i|0)>=0){l=y[(i+k|0)+64592|0];v[(f+44|0)+i|0]=((h|0)/(j|0)|0)%(l|0);i=i-1|0;j=D(j,l);continue}break}k=k+4|0;h=h-j|0;continue}break}H=k+H|0;i=-16}j=f;ca=f+44|0;h=0;while(1){F:{G:{H:{if((h|0)==4){break H}q=y[h+H|0];if(!q){break H}if(i&8){pc(j,t,q);break G}k=y[h+ca|0];if(!k){Tb(j,0,q);Tb(t,0,q);break G}ea=(i|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(q|0)){break G}N=ce(C,k);v[l+t|0]=(N|0)==(ea|0)?-1:N;v[j+l|0]=N;l=l+1|0;continue}}v[j+2|0]=0;v[j|0]=0;v[j+1|0]=0;break F}i=i<<1;h=h+1|0;j=j+q|0;t=q+t|0;continue}break}I:{j=y[d+14|0];if(j){h=2-K|0;l=y[d+23|0]<<h;q=y[d+22|0]<<h;k=y[d+21|0]<<h;t=y[d+13|0];i=0;while(1){if(i>>>0>=j>>>0){break I}h=f+(i+t|0)|0;v[h|0]=k+y[h|0];v[h+1|0]=q+y[h+1|0];v[h+2|0]=l+y[h+2|0];i=i+3|0;continue}}if(!y[d+24|0]){break I}i=0;while(1){if((i|0)==10){break I}h=f+i|0;v[h+11|0]=y[h+11|0]+y[i+64616|0];i=i+1|0;continue}}h=K+1|0;i=0;A=ax(E(2048),((((y[X+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(j&255)>>>0>i>>>0){ra=e+(i<<2)|0,ta=ax(A,y[f+i|0]<<h),B[ra>>2]=ta;i=i+1|0;j=y[d+14|0];continue}break}hb=f+48|0;l=(C+D(s,2304)|0)+2940|0;i=e;ca=J+Q|0;A=E(0);j=x[C+4>>2];e=x[C>>2]+((j|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))<<(j&7);k=j|-8;t=e+4|0;q=d;H=x[d>>2];K=z[d+6>>1];e=0;while(1){J:{K:{if((K|0)>0){j=e+1|0;e=e+q|0;d=y[e+15|0];ea=(w[(d<<1)+69040>>1]<<1)+64656|0;N=y[e+18|0];if(d>>>0>=16){ga=y[d+69104|0];qa=32-ga|0;while(1){ha=y[H|0]>>>1|0;ia=(K|0)<(ha|0)?K:ha;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}h=e&65535;d=h>>>8|0;k=d+k|0;f=f<<d;d=0;while(1){if((d|0)!=2){J=h&15;L:{if((J|0)==15){k=k+ga|0;e=f<<ga;while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}L=A;J=(f>>>qa|0)+15|0;f=J;M:{if((f|0)<=128){R=B[(f<<2)+69200>>2];break M}la=f>>>0<1024;f=la?f<<3:f;Q=f<<1&64;O=E(E((f&63)-Q|0)/E(Q+(f&-64)|0));R=E((la?E(16):E(256))*E(E(E(O*E(E(O*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+Q>>6<<2)+69200>>2]))}L=E(E(L*R)*E(e>>31|1));break L}e=f;L=E(A*B[(((e>>>27&16|J)^16)<<2)+69136>>2])}B[l>>2]=L;h=h>>>4|0;l=l+4|0;d=d+1|0;f=(J|0)!=0;k=f+k|0;f=e<<f;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}ia=ia-1|0;if(ia){continue}break}i=i+4|0;H=H+1|0;K=K-ha|0;if((K|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}while(1){Q=y[H|0]>>>1|0;J=(K|0)<(Q|0)?K:Q;A=B[i>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}d=e&65535;e=d>>>8|0;k=e+k|0;f=f<<e;e=0;while(1){if((e|0)!=2){h=d&15;B[l>>2]=A*B[(((h|f>>>27&16)^16)<<2)+69136>>2];d=d>>>4|0;l=l+4|0;e=e+1|0;h=(h|0)!=0;k=h+k|0;f=f<<h;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}J=J-1|0;if(J){continue}break}i=i+4|0;H=H+1|0;K=K-Q|0;if((K|0)<=0){break K}d=(N|0)>0;N=N-1|0;if(d){continue}break}break K}d=1-K|0;while(1){N:{j=y[q+26|0]?69024:68992;e=y[j+(f>>>28|0)|0];if(!(e&8)){e=y[j+((f<<4>>>32-(e&3))+(e>>>3)|0)|0]}j=e&7;k=j+k|0;if((ca|0)<((k+(t-x[C>>2]<<3)|0)-24|0)){break N}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}f=f<<j;if(e>>>0>=128){B[l>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&64){B[l+4>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;A=B[i>>2];i=i+4|0;d=d>>>1|0}if(e&32){B[l+8>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}if(e&16){B[l+12>>2]=(f|0)<0?E(-A):A;k=k+1|0;f=f<<1}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[C+4>>2]=ca;break J}e=j;continue}break}d=s+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){s=C+16195|0;d=0;l=hb-16|0;hb=l;j=C+2940|0;i=j+2304|0;I=x[m>>2];k=y[m+14|0];q=k+y[m+13|0]|0;e=l+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(q|0)){t=d+I|0;h=y[t|0];f=0;P:{while(1){if(f>>>0>=h>>>0){break P}H=f<<2;if(B[H+i>>2]==E(0)){f=f+2|0;if(B[(H|4)+i>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;h=y[t|0]}d=d+1|0;i=(h<<2)+i|0;continue}break}if(y[m+13|0]){d=x[l+4>>2];e=x[l+8>>2];d=(d|0)>(e|0)?d:e;e=x[l+12>>2];d=(d|0)>(e|0)?d:e;x[l+12>>2]=d;x[l+8>>2]=d;x[l+4>>2]=d}e=k?3:1;h=q-e|0;d=0;while(1){if((d|0)!=(e|0)){i=d+h|0;f=i-e|0;if((f|0)<=x[(l+4|0)+(d<<2)>>2]){f=y[X+1|0]<<28>>31&3}else{f=y[f+s|0]}v[i+s|0]=f;d=d+1|0;continue}break}h=x[m>>2];q=l+4|0;I=w[m+36>>1]&1;i=0;k=y[X+1|0]&8?7:64;while(1){t=h+i|0;e=y[t|0];if(e){f=y[X+3|0]&32;Q:{R:{if(x[q+((i>>>0)%3<<2)>>2]>=(i|0)){break R}d=y[i+s|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[X+1|0]&8){d=d<<3;A=B[d+69732>>2];R=B[d+69728>>2];break S}O=ax(E(1),d+1>>>1<<I);d=d&1;A=d?E(1):O;R=d?O:E(1)}O=E(L*R);L=E(L*A);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+j|0;A=B[f>>2];B[f+2304>>2]=A*L;B[f>>2]=A*O;d=d+1|0;continue}break}break Q}if(!f){break Q}_H(j,e)}i=i+1|0;j=(y[t|0]<<2)+j|0;continue}break}hb=l+16|0;break O}if((d&224)!=96){break O}_H(C+2940|0,576)}j=C+7708|0;d=0;while(1){if((d|0)!=(ka|0)){e=y[G+6153|0];s=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(C+D(d,2304)|0)+2940|0;i=l;if(y[m+14|0]){h=x[m>>2]+y[m+13|0]|0;t=((C+D(d,2304)|0)+D(s,72)|0)+2940|0;e=t;f=j;while(1){q=y[h|0];if(q){k=q<<1;I=0;while(1){if((q|0)!=(I|0)){B[f>>2]=B[e>>2];B[f+4>>2]=B[(q<<2)+e>>2];B[f+8>>2]=B[(k<<2)+e>>2];e=e+4|0;I=I+1|0;f=f+12|0;continue}break}h=h+3|0;e=(k<<2)+e|0;continue}break}pc(t,j,f-j|0);f=s-1|0}else{f=31}while(1){e=0;if((f|0)>0){while(1){if((e|0)!=8){h=e<<2;q=h+i|0;A=B[q+72>>2];O=B[h+69792>>2];L=B[h+69824>>2];h=(17-e<<2)+i|0;R=B[h>>2];B[q+72>>2]=E(A*O)-E(L*R);B[h>>2]=E(A*L)+E(R*O);e=e+1|0;continue}break}i=i+72|0;f=f-1|0;continue}break}e=l;f=D(d,1152)+G|0;h=y[m+11|0];if(s){ZH(e,f,69856,s);f=D(s,36)+f|0;e=D(s,72)+e|0}T:{if((h|0)==2){i=32-s|0;h=hb-80|0;hb=h;q=h|8;I=h|4;while(1){if((i|0)>0){s=pc(h,e,72);k=x[f+20>>2];x[e+16>>2]=x[f+16>>2];x[e+20>>2]=k;k=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=k;k=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=k;J=s;s=f+24|0;$w(J,e+24|0,s);$w(I,e+48|0,s);$w(q,f,s);e=e+72|0;f=f+36|0;i=i-1|0;continue}break}hb=h+80|0;break T}ZH(e,f,D((h|0)==3,72)+69856|0,32-s|0)}h=0;i=l+72|0;while(1){e=1;if(h>>>0<=31){while(1){if(e>>>0<=17){f=(e<<2)+i|0;B[f>>2]=-B[f>>2];e=e+2|0;continue}break}i=i+144|0;h=h+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}aI(ma,pa,18,x[n+32>>2],U,na);o=o+1|0;U=D(x[n+32>>2],1152)+U|0;continue}}e=r+912|0;m=x[e+8>>2]>>>3|0;j=x[e+4>>2]+7>>>3|0;d=m-j|0;f=(d|0)>=511?511:d;if((d|0)>0){Ji(G+6156|0,(e+(d>>>0>511?m-511|0:j)|0)+12|0,f)}x[G+6144>>2]=f;break x}cz(G);break l}j=r+17152|0;o=0;m=0;i=0;e=r;d=0;U:{V:{W:{g=y[u+3|0];h=g>>>6|0;switch(h-1|0){case 2:break U;case 0:break W;default:break V}}d=(g>>>2&12)+4|0;break U}d=32}g=y[u+1|0];X:{if((g&6)==6){g=32;f=71260;break X}if(!(g&8)){g=30;f=71263;break X}l=y[u+2|0];f=l>>>2&3;g=cx(g,l)>>>((h|0)!=3)|0;g=g?g:192;if(g>>>0<=55){g=(f|0)==2?12:8;f=71284;break X}g=g>>>0<=95?27:(f|0)!=1?30:27;f=71272}v[e+768|0]=g;v[e+769|0]=(d|0)<(g|0)?d:g;g=f;f=71168;while(1){d=y[e+768|0];if(o>>>0>=d>>>0){o=0;while(1){f=d<<1&510;if(f>>>0>o>>>0){f=e+o|0;Y:{if(!y[f+770|0]){g=6;break Y}g=2;if((y[u+1|0]&6)==6){break Y}g=ce(j,2);d=y[e+768|0]}v[f+834|0]=g;o=o+1|0;continue}break}m=e+770|0;h=e+834|0;g=0;i=f;while(1){if((g|0)!=(i|0)){l=y[m|0];f=l?19>>>y[g+h|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;A=E(0);d=4;while(1){if(d){if(d&f){C=ce(j,6);s=(C|0)/3|0;A=E(B[(l+(D(s,-3)+C|0)<<2)+71296>>2]*E(2097152>>>s|0))}B[e>>2]=A;d=d>>>1|0;e=e+4|0;continue}break}g=g+1|0;continue}break}o=y[r+769|0];g=y[r+768|0];g=g>>>0<o>>>0?o:g;while(1){if((g|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((i|0)==(o|0)){f=y[g|0]+71168|0;i=y[g+2|0]+o|0;m=y[g+1|0];g=g+3|0}h=o<<1;d=y[ce(j,m)+f|0];v[(h+e|0)+770|0]=d;l=y[e+769|0];if(l>>>0>o>>>0){d=y[ce(j,m)+f|0];l=y[e+769|0]}v[((h|1)+e|0)+770|0]=l?d:0;o=o+1|0;continue}break}g=0;e=Tb(r+3852|0,0,4608);I=G+2304|0;k=r+8620|0;o=0;Z:{while(1){if((o|0)==3){break Z}u=e+(g<<2)|0;C=r+17152|0;h=0;l=x[n+40>>2]|1;s=(l|0)>0?l:0;j=576;while(1){if((h|0)!=4){m=u+(D(h,l)<<2)|0;f=0;while(1){if(y[r+768|0]<<1>>>0>f>>>0){_:{i=y[(f+r|0)+770|0];if(!i){break _}if(i>>>0<=16){q=(-1<<i-1)+1|0;d=0;while(1){if((d|0)==(s|0)){break _}ra=(d<<2)+m|0,ta=E(ce(C,i)+q|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<i-17;i=ce(C,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;q=d|1;d=0;while(1){if((d|0)==(s|0)){break _}J=i;i=(i>>>0)/(q>>>0)|0;B[(d<<2)+m>>2]=J-(t+D(q,i)|0)|0;d=d+1|0;continue}}f=f+1|0;m=(j<<2)+m|0;j=18-j|0;continue}break}h=h+1|0;continue}break}g=(l<<2)+g|0;if((g|0)==12){d=(o<<2)+r|0;g=e;f=y[r+769|0];m=e+D(f,72)|0;pc(m+2304|0,m,D(y[r+768|0]-f|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){h=0;while(1){if((h|0)!=12){f=(h<<2)+g|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];h=h+1|0;continue}break}d=d+24|0;g=g+72|0;m=m+1|0;continue}break}aI(I,e,12,x[n+32>>2],U,k);Tb(e,0,4608);U=D(x[n+32>>2],768)+U|0;g=0}o=o+1|0;if(x[r+17156>>2]<=x[r+17160>>2]){continue}break}cz(G);o=0;break l}g=1}o=D(bx(y[G+6153|0]),g)}hb=r+17168|0;g=x[n+24>>2];if((g|0)<0|!g&(o|0)!=0|!(g|o)){break h}if(g){d=x[n+36>>2];if((d|0)!=(F|0)?F:0){break h}g=x[n+32>>2];if((g|0)!=(c|0)?c:0){break h}if(g-3>>>0<4294967294|(d|0)<=0){break i}x[n+4>>2]=0;ra=n,sa=Hc(Y,$),x[ra>>2]=sa;c=x[vj(n+24|0,n+4|0,n)>>2];x[n+4>>2]=0;ra=n,sa=Hc(Y,$),x[ra>>2]=sa;fa=c+fa|0;c=Y;e=x[vj(n+24|0,n+4|0,n)>>2];Y=c-e|0;$=$-((e>>31)+(c>>>0<e>>>0)|0)|0;$:{if(!o){break $}c=x[ba>>2];x[23420]=0;W(527,M|0,c|0,c+(D(g,o)<<1)|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break $}F=V(91780)|0;if((ib|0)==(da(91780)|0)){_(F|0)|0;x[23420]=0;Z(17);e=x[23420];x[23420]=0;c=g;F=d;if((e|0)!=1){break h}F=P()|0}od(ba);break k}F=d;c=g}if((Mc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!Y&($|0)>=0|($|0)>0){continue}break}break h}F=P()|0}VN(aa);break j}F=P()|0}od(M);Oc(n+72|0);S(F|0);p()}c=g;F=d}g=0;aa:{if(!F|!c){break aa}d=x[M>>2];e=x[M+4>>2];if(uc(d,e)){break aa}if((Mc(d,e)>>>0)/(c>>>0)>>>0>268435456){break aa}ct(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Mc(x[M>>2],x[M+4>>2])>>>0)/(c>>>0)|0,x[ra>>2]=sa;d=b+484414|0;g=z[d>>1];w[d>>1]=(c|0)==2?g|65:g&65470|1;Ag(a);b=b+484400|0;g=Td(x[a>>2],x[b>>2]);if(!g){break aa}Vn(Db(x[M>>2]),Db(x[M+4>>2]),x[b>>2]);g=Td(x[a>>2],x[a+20>>2])}od(ba);VN(aa);od(M);Oc(n+72|0)}hb=n+96|0;return g|0}function qA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=E(0);s=hb-1520|0;hb=s;e=s+8|0;M=Tb(e,0,1512),N=-1,x[M+1420>>2]=N;v[s+56|0]=1;x[s+48>>2]=a+b;x[s+40>>2]=a;m=hb-1024|0;hb=m;v[e+1377|0]=1;a:{if(!Zr(e)){break a}b=y[e+1375|0];if(!(b&2)){ec(e,34);break a}if(b&4){ec(e,34);break a}if(b&1){ec(e,34);break a}if(x[e+1116>>2]!=1){ec(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Yw(e,m+1018|0,6)|y[m+1018|0]!=102|(y[m+1019|0]!=105|y[m+1020|0]!=115)){break b}if(y[m+1021|0]!=104|y[m+1022|0]!=101|y[m+1023|0]!=97){break b}if((Ne(e)|0)!=100){break b}if(Ne(e)){break b}ec(e,38);break a}ec(e,34);break a}if((Ne(e)|0)!=1){ec(e,34);break a}if(!Yw(e,m+1018|0,6)){ec(e,10);break a}if(!Ww(m+1018|0)){ec(e,34);break a}if($i(e)){ec(e,34);break a}b=Ne(e);x[e+4>>2]=b;if(!b){ec(e,34);break a}if(b>>>0>=17){ec(e,5);break a}b=$i(e);x[e>>2]=b;if(!b){ec(e,34);break a}$i(e);$i(e);$i(e);b=Ne(e);j=b>>>4|0;x[e+116>>2]=1<<j;h=b&15;x[e+112>>2]=1<<h;if(h-14>>>0<=4294967287){ec(e,20);break a}if((b<<24)+536870912>>24>=0){ec(e,20);break a}c:{if(h>>>0>j>>>0){ec(e,20);break c}if(!(Ne(e)&1)){ec(e,34);break c}if(!Zr(e)){break a}if(!Xw(e)){break a}if(!Zw(e)){break a}if((kh(e)|0)==3){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=kh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Ww(m+1018|0)){ec(e,20);break c}b=Vw(e);f=be(e,b+1|0);x[e+20>>2]=f;if(f){f=0;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){j=kh(e);v[x[e+20>>2]+f|0]=j;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=Vw(e);x[e+28>>2]=0;x[e+24>>2]=b;d:{if((b|0)<=0){break d}b=be(e,b<<2);x[e+28>>2]=b;if(b){break d}ec(e,3);break c}while(1){e:{f:{if(x[e+24>>2]>(g|0)){b=Vw(e);f=be(e,b+1|0);h=g<<2;x[h+x[e+28>>2]>>2]=f;if(!x[h+x[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=kh(e);v[x[h+x[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(kh(e)&1)){ec(e,20);break c}NH(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=Zw(e);NH(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!Xw(e)){break a}if(!VH(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;h=0;while(1){if((h|0)!=8){j=j>>31&79764919^j<<1;h=h+1|0;continue}break}x[(b<<2)+462560>>2]=j;b=b+1|0;continue}break}if((kh(e)|0)==5){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=kh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Ww(m+1018|0)){ec(e,20);break c}b=oc(e,8)+1|0;x[e+120>>2]=b;b=be(e,D(b,2096));x[e+124>>2]=b;if(!b){ec(e,3);break c}Tb(b,0,D(x[e+120>>2],2096));g:{h:{while(1){i:{if(x[e+120>>2]>(C|0)){b=x[e+124>>2];if((oc(e,8)&255)!=66){ec(e,20);break c}if((oc(e,8)&255)!=67){ec(e,20);break c}if((oc(e,8)&255)!=86){ec(e,20);break c}h=b+D(C,2096)|0;M=h,N=oc(e,8)&255|oc(e,8)<<8,x[M>>2]=N;M=h,N=oc(e,8)&255|(oc(e,8)<<8&65280|oc(e,8)<<16),x[M+4>>2]=N;n=h+4|0;f=0;k=oc(e,1);if(!k){f=oc(e,1)}v[h+23|0]=f;g=x[n>>2];if(x[h>>2]){b=g;break i}b=0;if(!g){break i}ec(e,20);break c}b=oc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!oc(e,16)){continue}break}ec(e,20);break c}b=oc(e,6)+1|0;x[e+128>>2]=b;b=be(e,D(b,1596));x[e+260>>2]=b;k:{if(b){C=0;k=0;l:while(1){if(x[e+128>>2]<=(k|0)){break k}b=oc(e,16);w[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){ec(e,20);break c}if(!b){b=x[e+260>>2]+D(k,1596)|0;M=b,N=oc(e,8),v[M|0]=N;M=b,N=oc(e,16),w[M+2>>1]=N;M=b,N=oc(e,16),w[M+4>>1]=N;M=b,N=oc(e,6),v[M+6|0]=N;M=b,N=oc(e,8),v[M+7|0]=N;j=oc(e,4)+1|0;v[b+8|0]=j;g=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+g|0,N=oc(e,8),v[M|0]=N;f=f+1|0;j=y[b+8|0];continue}break}ec(e,4);break c}f=x[e+260>>2]+D(k,1596)|0;b=oc(e,5);v[f|0]=b;n=f+1|0;j=0;h=-1;while(1)if((b&255)>>>0<=j>>>0){g=h+1|0;h=f+82|0;i=f+65|0;o=f+49|0;l=f+33|0;b=0;m:{while(1){if((b|0)!=(g|0)){M=b+l|0,N=oc(e,3)+1|0,v[M|0]=N;r=b+o|0;q=oc(e,2);v[r|0]=q;j=0;if(q&255){q=oc(e,8);v[b+i|0]=q;if(x[e+120>>2]<=(q&255)){break m}}while(1){if(1<<y[r|0]>(j|0)){q=oc(e,8)-1|0;w[(h+(b<<4)|0)+(j<<1)>>1]=q;j=j+1|0;if(x[e+120>>2]>q<<16>>16){continue}break m}break}b=b+1|0;continue}break}h=2;M=f,N=oc(e,2)+1|0,v[M+1588|0]=N;b=oc(e,4);x[f+1592>>2]=2;g=0;w[f+338>>1]=0;v[f+1589|0]=b;w[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(y[f|0]>i>>>0){o=l+y[i+n|0]|0;j=0;while(1){if(y[o|0]>j>>>0){h=oc(e,y[f+1589|0]);w[b+(x[f+1592>>2]<<1)>>1]=h;h=x[f+1592>>2]+1|0;x[f+1592>>2]=h;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((h|0)>(g|0)){h=z[b+(g<<1)>>1];j=(m+16|0)+(g<<2)|0;w[j+2>>1]=g;w[j>>1]=h;g=g+1|0;h=x[f+1592>>2];continue}break}MH(m+16|0,h,1040);h=x[f+1592>>2];g=((h|0)<=1?1:h)-1|0;j=0;while(1){if((g|0)==(j|0)){g=f+838|0;j=0;while(1)if((h|0)<=(j|0)){r=f+1088|0;j=2;while(1){if((h|0)>(j|0)){x[m+12>>2]=0;x[m+8>>2]=0;h=0;q=(j|0)>0?j:0;i=b+(j<<1)|0;n=65536;l=-1;while(1){if((h|0)!=(q|0)){o=b+(h<<1)|0;g=z[o>>1];if(!((l|0)>=(g|0)|z[i>>1]<=g>>>0)){x[m+12>>2]=h;g=z[o>>1];l=g}if(!((g|0)>=(n|0)|z[i>>1]>=g>>>0)){x[m+8>>2]=h;n=z[o>>1]}h=h+1|0;continue}break}g=r+(j<<1)|0;v[g|0]=x[m+12>>2];v[g+1|0]=x[m+8>>2];j=j+1|0;h=x[f+1592>>2];continue}break}C=(h|0)>(C|0)?h:C;k=k+1|0;continue l}else{v[g+j|0]=y[((m+16|0)+(j<<2)|0)+2|0];j=j+1|0;h=x[f+1592>>2];continue}}i=m+16|0;l=z[i+(j<<2)>>1];j=j+1|0;if((l|0)!=z[i+(j<<2)>>1]){continue}break}}ec(e,20);break c}else{b=oc(e,4);v[j+n|0]=b;b=b&255;h=(b|0)>(h|0)?b:h;j=j+1|0;b=y[f|0];continue}}}ec(e,3);break c}b=oc(e,6)+1|0;x[e+264>>2]=b;b=be(e,D(b,24));x[e+396>>2]=b;if(!b){ec(e,3);break c}k=0;Tb(b,0,D(x[e+264>>2],24));n:{o:{while(1){if(x[e+264>>2]>(k|0)){b=x[e+396>>2];g=oc(e,16);w[((k<<1)+e|0)+268>>1]=g;h=20;if((g&65535)>>>0>2){break n}i=b+D(k,24)|0;M=i,N=oc(e,24),x[M>>2]=N;b=oc(e,24);x[i+4>>2]=b;if(b>>>0<A[i>>2]){break n}M=i,N=oc(e,24)+1|0,x[M+8>>2]=N;M=i,N=oc(e,6)+1|0,v[M+12|0]=N;b=oc(e,8);v[i+13|0]=b;if(x[e+120>>2]<=(b&255)){break n}f=0;while(1){b=y[i+12|0];if(b>>>0>f>>>0){g=(m+16|0)+f|0;b=oc(e,3);if(oc(e,1)){l=oc(e,5)}else{l=0}v[g|0]=b+(l<<3);f=f+1|0;continue}break}b=be(e,b<<4);x[i+20>>2]=b;if(!b){break o}g=0;while(1){if(y[i+12|0]>g>>>0){b=y[(m+16|0)+g|0];f=0;while(1){if((f|0)!=8){p:{if(b>>>f&1){j=oc(e,8);l=f<<1;n=g<<4;w[l+(n+x[i+20>>2]|0)>>1]=j;if(x[e+120>>2]<=w[l+(n+x[i+20>>2]|0)>>1]){break n}break p}w[(x[i+20>>2]+(g<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}g=g+1|0;continue}break}g=be(e,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);x[i+16>>2]=g;if(!g){break o}b=0;Tb(g,0,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);while(1){g=x[e+124>>2]+D(y[i+13|0],2096)|0;if(x[g+4>>2]>(b|0)){f=x[g>>2];h=be(e,f);g=b<<2;x[g+x[i+16>>2]>>2]=h;j=b;if(!x[g+x[i+16>>2]>>2]){break o}while(1){if((f|0)>0){f=f-1|0;v[f+x[g+x[i+16>>2]>>2]|0]=(j|0)%y[i+12|0];j=(j|0)/y[i+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=oc(e,6)+1|0;x[e+400>>2]=b;b=be(e,D(b,40));x[e+404>>2]=b;if(!b){ec(e,3);break c}Tb(b,0,D(x[e+400>>2],40));i=0;while(1){if(x[e+400>>2]>(i|0)){b=x[e+404>>2];if(oc(e,16)){ec(e,20);break c}g=b+D(i,40)|0;b=be(e,D(x[e+4>>2],3));x[g+4>>2]=b;if(!b){ec(e,3);break c}if(oc(e,1)){b=oc(e,4)+1|0}else{b=1}v[g+8|0]=b;q:{if(oc(e,1)){b=oc(e,8)+1|0;w[g>>1]=b;f=0;h=x[e+4>>2];if((h|0)<(b&65535)){ec(e,20);break c}while(1){if(z[g>>1]<=f>>>0){break q}h=oc(e,Ml(h-1|0));b=D(f,3);v[b+x[g+4>>2]|0]=h;h=oc(e,Ml(x[e+4>>2]-1|0));v[(b+x[g+4>>2]|0)+1|0]=h;h=x[e+4>>2];b=b+x[g+4>>2]|0;j=y[b|0];if((h|0)<=(j|0)){ec(e,20);break c}b=y[b+1|0];if((b|0)>=(h|0)){ec(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}ec(e,20);break c}w[g>>1]=0}if(oc(e,2)){ec(e,20);break c}h=0;b=0;f=0;r:{if(y[g+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break r}f=oc(e,4);j=D(b,3);v[(j+x[g+4>>2]|0)+2|0]=f;b=b+1|0;if(y[(j+x[g+4>>2]|0)+2|0]<y[g+8|0]){continue}break}ec(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break r}v[(x[g+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}s:{while(1){if(y[g+8|0]<=h>>>0){break s}oc(e,8);b=h+g|0;M=b,N=oc(e,8),v[M+9|0]=N;f=oc(e,8);v[b+24|0]=f;if(x[e+128>>2]<=y[b+9|0]){ec(e,20);break c}h=h+1|0;if(x[e+264>>2]>(f&255)){continue}break}ec(e,20);break c}i=i+1|0;continue}break}M=e,N=oc(e,6)+1|0,x[M+408>>2]=N;g=e+412|0;j=0;t:{while(1){if(x[e+408>>2]<=(j|0)){break t}b=g+D(j,6)|0;M=b,N=oc(e,1),v[M|0]=N;M=b,N=oc(e,16),w[M+2>>1]=N;M=b,N=oc(e,16),w[M+4>>1]=N;f=oc(e,8);v[b+1|0]=f;if(z[b+2>>1]){ec(e,20);break c}if(z[b+4>>1]){ec(e,20);break c}j=j+1|0;if(x[e+400>>2]>(f&255)){continue}break}ec(e,20);break c}TH(e);x[e+992>>2]=0;g=C<<1;f=0;while(1){if(x[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=be(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=b,N=be(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;h=be(e,g);x[b+996>>2]=h;j=x[b+800>>2];if(h?!j|!x[b+928>>2]:1){ec(e,3);break c}Tb(j,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!LH(e,0,x[e+112>>2])){break a}if(!LH(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];g=x[e+116>>2];x[e+108>>2]=g;b=x[e+264>>2];i=(b|0)>0?b:0;b=(g|0)/2|0;h=0;while(1){if((f|0)!=(i|0)){j=x[e+396>>2]+D(f,24)|0;k=x[j+4>>2];l=b>>>0>k>>>0?k:b;k=x[j>>2];j=(l-(b>>>0>k>>>0?k:b)>>>0)/A[j+8>>2]|0;h=(h|0)<(j|0)?j:h;f=f+1|0;continue}break}b=g<<1&2147483646;g=D(x[e+4>>2],(h<<2)+4|0);b=b>>>0>g>>>0?b:g;x[e+12>>2]=b;u:{v:{if(!x[e+80>>2]){break v}g=x[e+92>>2];if((g|0)!=x[e+84>>2]){break u}if(g>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break v}ec(e,3);break c}w:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break w}x[e+52>>2]=0}f=1;break a}aa(7262,13048,4196,8731);p()}h=3}ec(e,h);break c}x:{if(f&255){j=vn(e,b);break x}j=be(e,b);x[h+8>>2]=j}if(!j){ec(e,3);break c}i=0;y:{if(!k){f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}z:{A:{if(y[h+23|0]){if(!oc(e,1)){break A}}b=oc(e,5)+1|0;v[f+j|0]=b;if((b&255)!=32){i=i+1|0;break z}ec(e,20);break c}v[f+j|0]=255}f=f+1|0;continue}}g=oc(e,5);f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}k=oc(e,Ml(b-f|0));g=g+1|0;if((g|0)>=32){ec(e,20);break c}b=f+k|0;if((b|0)>x[n>>2]){ec(e,20);break c}else{Tb(f+j|0,g,k);f=b;continue}}}B:{C:{D:{if(y[h+23|0]){if(b>>2>(i|0)){break D}if(x[e+16>>2]<(b|0)){x[e+16>>2]=b;b=x[n>>2]}b=be(e,b);x[h+8>>2]=b;if(!b){ec(e,3);break c}pc(b,j,x[n>>2]);_i(e,j,x[n>>2]);j=x[h+8>>2];v[h+23|0]=0;b=x[n>>2]}g=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){g=((y[f+j|0]-11&255)>>>0<244)+g|0;f=f+1|0;continue}break}x[h+2092>>2]=g;b=be(e,b<<2);x[h+32>>2]=b;if(b){k=h+2092|0;f=0;break C}ec(e,3);break c}x[h+2092>>2]=i;k=h+2092|0;E:{if(!i){f=0;g=0;break E}b=be(e,i);x[h+8>>2]=b;if(!b){ec(e,3);break c}b=vn(e,x[k>>2]<<2);x[h+32>>2]=b;if(!b){ec(e,3);break c}f=vn(e,x[k>>2]<<2);if(!f){break B}b=x[n>>2];g=x[k>>2]}b=(g<<3)+b|0;if(b>>>0<=A[e+16>>2]){break C}x[e+16>>2]=b}l=x[n>>2];b=0;g=hb-128|0;hb=g;o=Tb(g,0,128);g=(l|0)>0?l:0;while(1){F:{G:{if((b|0)!=(g|0)){if(y[b+j|0]==255){break G}g=b}if((g|0)==(l|0)){b=1;if(!x[h+2092>>2]){break F}aa(15552,13048,1103,7506);p()}b=g+j|0;i=y[b|0];if(i>>>0<32){JH(h,0,g,0,i,f);r=1;i=y[b|0]+1|0;b=1;H:{while(1){if((b|0)==(i|0)){I:while(1){J:{b=1;g=g+1|0;if((l|0)<=(g|0)){break F}G=g+j|0;i=y[G|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break J}while(1){if((b|0)<=0){b=0;break F}H=o+(b<<2)|0;q=x[H>>2];if(!q){b=b-1|0;continue}break}x[H>>2]=0;JH(h,Kl(q),g,r,i,f);r=r+1|0;i=y[G|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue I}G=o+(i<<2)|0;if(x[G>>2]){break H}x[G>>2]=q+(1<<32-i);i=i-1|0;continue}}break}}else{x[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15010,13048,1118,7506);p()}aa(15596,13048,1133,7506);p()}aa(15017,13048,1104,7506);p()}b=b+1|0;continue}break}hb=o+128|0;if(!b){if(y[h+23|0]){_i(e,f,0)}ec(e,20);break c}b=x[k>>2];if(b){b=be(e,(b<<2)+4|0);x[h+2084>>2]=b;if(!b){ec(e,3);break c}b=be(e,(x[k>>2]<<2)+4|0);x[h+2088>>2]=b;if(!b){ec(e,3);break c}x[h+2088>>2]=b+4;x[b>>2]=-1;b=0;i=0;K:{L:{M:{if(y[h+23|0]){while(1){i=x[h+2092>>2];if((i|0)<=(b|0)){break M}g=b<<2;M=g+x[h+2084>>2]|0,N=Kl(x[g+x[h+32>>2]>>2]),x[M>>2]=N;b=b+1|0;continue}}while(1){if(x[h+4>>2]>(b|0)){if(IH(y[h+23|0],y[b+j|0])){M=x[h+2084>>2]+(i<<2)|0,N=Kl(x[x[h+32>>2]+(b<<2)>>2]),x[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(x[h+2092>>2]!=(i|0)){break L}}MH(x[h+2084>>2],i,1041);x[x[h+2084>>2]+(x[h+2092>>2]<<2)>>2]=-1;g=0;b=x[h+(y[h+23|0]?2092:4)>>2];q=(b|0)>0?b:0;N:{while(1){if((g|0)!=(q|0)){b=g;i=y[h+23|0];b=i?x[(b<<2)+f>>2]:b;G=y[b+j|0];O:{if(!IH(i,G)){break O}H=g<<2;l=Kl(x[H+x[h+32>>2]>>2]);b=x[h+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;K=o+i|0;r=l>>>0<A[x[h+2084>>2]+(K<<2)>>2];b=r?o:b-o|0;i=r?i:K;continue}break}b=i<<2;if((l|0)!=x[b+x[h+2084>>2]>>2]){break N}if(y[h+23|0]){x[b+x[h+2088>>2]>>2]=x[f+H>>2];v[x[h+8>>2]+i|0]=G;break O}x[b+x[h+2088>>2]>>2]=g}g=g+1|0;continue}break}break K}aa(12089,13048,1230,9874);p()}aa(7447,13048,1200,9874);p()}}if(y[h+23|0]){_i(e,f,x[k>>2]<<2);_i(e,x[h+32>>2],x[k>>2]<<2);_i(e,j,x[n>>2]);x[h+32>>2]=0}i=h;b=0;f=0;while(1){if((b|0)!=1024){w[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[i+(y[i+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){P:{if(y[x[i+8>>2]+f|0]>10){break P}Q:{if(y[i+23|0]){b=Kl(x[x[i+2084>>2]+(f<<2)>>2]);break Q}b=x[x[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break P}w[(i+(b<<1)|0)+36>>1]=f;b=(1<<y[x[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=oc(e,4);v[i+21|0]=b;b=b&255;if(b>>>0>=3){ec(e,20);break c}if(b){M=i,O=KH(oc(e,32)),B[M+12>>2]=O;M=i,O=KH(oc(e,32)),B[M+16>>2]=O;M=i,N=oc(e,4)+1|0,v[M+20|0]=N;M=i,N=oc(e,1),v[M+22|0]=N;f=x[i>>2];g=x[n>>2];R:{if(y[i+21|0]==1){u=J(sr(+E(E(Zo(+E(g|0)))/E(f|0))));S:{if(F(u)<2147483648){b=~~u;break S}b=-2147483648}u=+(f|0);L=J(Gj(+E(E(b|0)+E(1)),u));T:{if(F(L)<2147483648){f=~~L;break T}f=-2147483648}b=((f|0)<=(g|0))+b|0;t=E(b|0);if(Gj(+E(t+E(1)),u)<=+(g|0)){f=-1}else{u=J(Gj(+t,u));U:{if(F(u)<2147483648){f=~~u;break U}f=-2147483648}f=(f|0)>(g|0)?-1:b}if((f|0)>=0){break R}ec(e,20);break c}f=D(f,g)}x[i+24>>2]=f;if(!f){ec(e,20);break c}l=vn(e,f<<1);if(!l){break h}f=0;while(1){j=x[i+24>>2];if((j|0)>(f|0)){b=oc(e,y[i+20|0]);if((b|0)==-1){_i(e,l,x[i+24>>2]<<1);ec(e,20);break c}else{w[l+(f<<1)>>1]=b;f=f+1|0;continue}}break}V:{W:{if(y[i+21|0]==1){o=y[i+23|0];X:{if(o){f=x[k>>2];if(f){break X}break V}f=x[n>>2]}b=be(e,D(x[i>>2],f)<<2);x[i+28>>2]=b;if(!b){_i(e,l,x[i+24>>2]<<1);ec(e,3);break c}g=0;b=x[(o?k:n)>>2];n=(b|0)>0?b:0;r=i+2088|0;t=E(0);while(1){if((g|0)==(n|0)){break W}h=g;h=o?x[x[r>>2]+(h<<2)>>2]:h;j=x[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=E(t+E(E(E(z[l+(((h>>>0)/(b>>>0)>>>0)%A[i+24>>2]<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(D(g,j)+f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;j=x[i>>2];if((f|0)>=(j|0)){continue}k=x[i+24>>2];Wia(k,0,b,0);if(lb){_i(e,l,k<<1);ec(e,20);break c}else{b=D(b,k);continue}}break}g=g+1|0;continue}}b=be(e,j<<2);x[i+28>>2]=b;if(!b){break g}f=0;t=E(0);while(1){j=x[i+24>>2];if((j|0)<=(f|0)){break V}I=E(t+E(E(E(z[l+(f<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;continue}}v[i+21|0]=2;j=x[i+24>>2]}_i(e,l,j<<1)}C=C+1|0;continue}break}ec(e,3);break c}ec(e,3);break c}_i(e,l,x[i+24>>2]<<1);ec(e,3);break c}ec(e,20);break c}ec(e,3);break c}v[b+x[x[e+28>>2]+(g<<2)>>2]|0]=0;g=g+1|0;continue}}ec(e,3);break c}ec(e,20)}f=0}hb=m+1024|0;Y:{Z:{if(!f){x[d>>2]=x[s+104>>2]?1:x[s+108>>2];break Z}b=be(s+8|0,1512);if(b){M=c,N=x[pc(b,s+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break Y}}WH(s+8|0);b=0}hb=s+1520|0;return b}function EG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;s=hb-48|0;hb=s;a:{if(c>>>0<=2){c=c<<2;I=x[c+78364>>2];J=x[c+78352>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=nd(b)}if(Ak(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=nd(b)}e:{f:{while(1){if(v[g+4913|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=nd(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=hb-16|0;hb=i;l=(q(E(E(o|0)*E(O))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=G(b);wf(i,c,0,0,0,b+81|0);k=x[i>>2];h=x[i+4>>2];r=x[i+8>>2];c=x[i+12>>2]^65536|16265-b<<16}x[s>>2]=k;x[s+4>>2]=h;x[s+8>>2]=r;x[s+12>>2]=l&-2147483648|c;hb=i+16|0;k=x[s+8>>2];h=x[s+12>>2];i=x[s>>2];l=x[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9870|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=nd(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=nd(b)}if((g&-33)==88){g=d;c=0;f=hb-432|0;hb=f;p:{q:{d=x[b+4>>2];if((d|0)!=x[b+104>>2]){x[b+4>>2]=d+1;c=y[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=nd(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=x[b+4>>2];if((d|0)==x[b+104>>2]){break x}n=1;x[b+4>>2]=d+1;c=y[d|0]}d=1;continue}n=1;break s}c=x[b+4>>2];z:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break z}c=nd(b)}if((c|0)==48){break u}w=1}break t}while(1){c=r;r=c-1|0;t=t-!c|0;w=1;c=x[b+4>>2];A:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break A}c=nd(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(w){break r}w=1;r=k;t=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){z=c+(z<<4)|0;break D}if(!h&k>>>0<=28){Ig(f+48|0,c);Ed(f+32|0,F,H,i,l,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];i=x[f+40>>2];l=x[f+44>>2];Ed(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,i,l);xg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],m,p,B,C);B=x[f+8>>2];C=x[f+12>>2];m=x[f>>2];p=x[f+4>>2];break D}if(!c|u){break D}Ed(f+80|0,F,H,i,l,0,0,0,1073610752);xg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],m,p,B,C);B=x[f+72>>2];C=x[f+76>>2];u=1;m=x[f+64>>2];p=x[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0]}else{c=nd(b)}continue}}d=0;continue}break}E:{if(!n){c=x[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!g){break G}x[b+4>>2]=c-2;if(!w){break F}x[b+4>>2]=c-3;break F}if(g){break F}}ci(b,0,0)}Ii(f+96|0,+(o|0)*0);m=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){z=z<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=DG(b,g);c=lb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;p=0;ci(b,0,0);c=0;b=0;break E}i=0;l=0;if(x[b+116>>2]<0){break H}}x[b+4>>2]=x[b+4>>2]-1}i=0;l=0}if(!z){Ii(f+112|0,+(o|0)*0);m=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break E}b=w?r:k;h=(w?t:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[115896]=68;Ig(f+160|0,o);Ed(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Ed(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);m=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((z|0)>=0){while(1){xg(f+416|0,m,p,B,C,0,0,0,-1073807360);c=KN(m,p,B,C,1073610752);b=(c|0)<0;xg(f+400|0,m,p,B,C,b?m:x[f+416>>2],b?p:x[f+420>>2],b?B:x[f+424>>2],b?C:x[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;B=x[f+408>>2];C=x[f+412>>2];m=x[f+400>>2];p=x[f+404>>2];z=z<<1|(c|0)>=0;if((z|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){Ig(f+384|0,o);r=x[f+392>>2];t=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];h=0;b=0;break K}Ii(f+352|0,Dj(1,144-c|0));Ig(f+336|0,o);F=x[f+336>>2];H=x[f+340>>2];r=x[f+344>>2];t=x[f+348>>2];GG(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,r,t);K=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}c=!(z&1)&((dm(m,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);Um(f+320|0,c+z|0);Ed(f+304|0,F,H,r,t,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);d=b;xg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,K,L);b=c;Ed(f+288|0,F,H,r,t,b?0:m,b?0:p,b?0:B,b?0:C);xg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);kw(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],d,h,K,L);b=x[f+240>>2];c=x[f+244>>2];d=x[f+248>>2];h=x[f+252>>2];if(!dm(b,c,d,h,0,0,0,0)){x[115896]=68}FG(f+224|0,b,c,d,h,k);m=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break E}x[115896]=68;Ig(f+208|0,o);Ed(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Ed(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);m=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[s+16>>2]=m;x[s+20>>2]=p;x[s+24>>2]=b;x[s+28>>2]=c;hb=f+432|0;k=x[s+24>>2];h=x[s+28>>2];i=x[s+16>>2];l=x[s+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;f=o;w=d;d=0;o=0;e=hb-8976|0;hb=e;L=0-I|0;K=L-J|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=x[g+4>>2];if((b|0)==x[g+104>>2]){break N}x[g+4>>2]=b+1;c=y[b|0];break M}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){d=1;x[g+4>>2]=b+1;c=y[b|0]}else{d=1;c=nd(g)}continue}break}c=nd(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=x[g+4>>2];O:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break O}c=nd(g)}if((c|0)==48){continue}break}d=1}x[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){z=(c|0)==48?z:i;b=(e+784|0)+(o<<2)|0;if(u){m=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=m;d=1;c=u+1|0;b=(c|0)==9;u=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}x[e+8960>>2]=x[e+8960>>2]|1;z=18396}b=x[g+4>>2];W:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break W}c=nd(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=DG(g,w);b=lb;p=b;X:{if(m|(b|0)!=-2147483648){break X}if(!w){break R}m=0;p=0;if(x[g+116>>2]<0){break X}x[g+4>>2]=x[g+4>>2]-1}if(!d){break S}h=h+p|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(x[g+116>>2]<0){break T}x[g+4>>2]=x[g+4>>2]-1}if(!b){break Q}}x[115896]=28}i=0;l=0;ci(g,0,0);c=0;b=0;break P}b=x[e+784>>2];if(!b){Ii(e,+(f|0)*0);i=x[e>>2];l=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){Ig(e+48|0,f);Um(e+32|0,b);Ed(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);i=x[e+16>>2];l=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break P}if(k>>>0>L>>>1>>>0&(h|0)>=0|(h|0)>0){x[115896]=68;Ig(e+96|0,f);Ed(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Ed(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);i=x[e+64>>2];l=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){x[115896]=68;Ig(e+144|0,f);Ed(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Ed(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);i=x[e+112>>2];l=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break P}if(u){if((u|0)<=8){b=(e+784|0)+(o<<2)|0;g=x[b>>2];while(1){g=D(g,10);u=u+1|0;if((u|0)!=9){continue}break}x[b>>2]=g}o=o+1|0}Y:{n=k;if((z|0)>(k|0)|(z|0)>8|(k|0)>17){break Y}if((n|0)==9){Ig(e+192|0,f);Um(e+176|0,x[e+784>>2]);Ed(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);i=x[e+160>>2];l=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break P}if((n|0)<=8){Ig(e+272|0,f);Um(e+256|0,x[e+784>>2]);Ed(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);Ig(e+224|0,x[(0-n<<2)+78352>>2]);uK(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);i=x[e+208>>2];l=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break P}b=(J+D(n,-3)|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Ig(e+352|0,f);Um(e+336|0,c);Ed(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);Ig(e+304|0,x[(n<<2)+78280>>2]);Ed(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);i=x[e+288>>2];l=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!x[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){u=0;b=0;break Z}u=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=x[(0-d<<2)+78352>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=x[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;x[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=D(l,o-D(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}x[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(A[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;w=(e+784|0)+(i<<2)|0;d=x[w>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=Zia(k,h,1e9,0);d=Wia(m,lb,-1e9,-1)+k|0;k=d}x[w>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}u=u-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;x[k>>2]=x[k>>2]|x[d+(c<<2)>>2]}n=n+9|0;x[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=x[(e+784|0)+(b<<2)>>2];i=x[(g<<2)+78304>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;x[((c<<2)+e|0)+780>>2]=0}Um(e+768|0,x[(e+784|0)+(b<<2)>>2]);Ed(e+752|0,k,h,i,l,0,0,1342177280,1075633366);xg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);i=x[e+744>>2];l=x[e+748>>2];k=x[e+736>>2];h=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Ig(e+720|0,f);Ed(e+704|0,k,h,i,l,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);i=x[e+712>>2];l=x[e+716>>2];k=0;h=0;m=x[e+704>>2];p=x[e+708>>2];w=u+113|0;o=w-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}u=h+u|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;w=x[g>>2];i=i+(w>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=D(o,m&w);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}x[l>>2]=x[l>>2]|1;continue}break}break}Ii(e+656|0,Dj(1,225-b|0));GG(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],m,p,i,l);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];Ii(e+640|0,Dj(1,113-b|0));SJ(e+672|0,m,p,i,l,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];h=x[e+676>>2];r=x[e+680>>2];t=x[e+684>>2];kw(e+624|0,m,p,i,l,k,h,r,t);xg(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);i=x[e+616>>2];l=x[e+620>>2];m=x[e+608>>2];p=x[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=x[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Ii(e+496|0,+(f|0)*.25);xg(e+480|0,k,h,r,t,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);r=x[e+488>>2];t=x[e+492>>2];k=x[e+480>>2];h=x[e+484>>2];break ha}if((g|0)!=5e8){Ii(e+592|0,+(f|0)*.75);xg(e+576|0,k,h,r,t,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);r=x[e+584>>2];t=x[e+588>>2];k=x[e+576>>2];h=x[e+580>>2];break ha}N=+(f|0);if((d+5&2047)==(c|0)){Ii(e+528|0,N*.5);xg(e+512|0,k,h,r,t,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);r=x[e+520>>2];t=x[e+524>>2];k=x[e+512>>2];h=x[e+516>>2];break ha}Ii(e+560|0,N*.75);xg(e+544|0,k,h,r,t,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);r=x[e+552>>2];t=x[e+556>>2];k=x[e+544>>2];h=x[e+548>>2]}if((b|0)>111){break ga}SJ(e+464|0,k,h,r,t,0,0,0,1073676288);if(dm(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break ga}xg(e+448|0,k,h,r,t,0,0,0,1073676288);r=x[e+456>>2];t=x[e+460>>2];k=x[e+448>>2];h=x[e+452>>2]}xg(e+432|0,m,p,i,l,k,h,r,t);kw(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);i=x[e+424>>2];l=x[e+428>>2];m=x[e+416>>2];p=x[e+420>>2];ia:{if((K-2|0)>=(w&2147483647)){break ia}x[e+408>>2]=i;x[e+412>>2]=l&2147483647;x[e+400>>2]=m;x[e+404>>2]=p;Ed(e+384|0,m,p,i,l,0,0,0,1073610752);d=KN(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);c=(d|0)<0;i=c?i:x[e+392>>2];l=c?l:x[e+396>>2];m=c?m:x[e+384>>2];p=c?p:x[e+388>>2];u=((d|0)>=0)+u|0;if(!((dm(k,h,r,t,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0)))&(u+110|0)<=(K|0)){break ia}x[115896]=68}FG(e+368|0,m,p,i,l,u);i=x[e+368>>2];l=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[s+40>>2]=b;x[s+44>>2]=c;x[s+32>>2]=i;x[s+36>>2]=l;hb=e+8976|0;k=x[s+40>>2];h=x[s+44>>2];i=x[s+32>>2];l=x[s+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ja:{c=x[b+4>>2];ka:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ka}c=nd(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];la:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break la}c=nd(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[115896]=28;ci(b,0,0)}h=0}x[a>>2]=i;x[a+4>>2]=l;x[a+8>>2]=k;x[a+12>>2]=h;hb=s+48|0}function Eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;d=hb-384|0;hb=d;zc(b);a:{if(!oo(b,d+368|0)){break a}if(!WQ(d+368|0)){break a}r=he(d+344|0,b);o=Qb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){x[23420]=0;R(590,d+40|0,r|0);b=x[23420];x[23420]=0;if((b|0)==1){break z}break B}x[23420]=0;R(591,d+40|0,r|0);b=x[23420];x[23420]=0;if((b|0)==1){break A}}b=d+40|0;Dt(o,b);_d(b);x[23420]=0;U(592,b|0,o|0,1413891155);b=x[23420];x[23420]=0;C:{D:{if((b|0)!=1){x[23420]=0;e=Q(593,d+40|0,13970)|0;b=x[23420];x[23420]=0;if((b|0)==1){break D}zb(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;break c}b=P()|0;zb(d+40|0);break c}x[23420]=0;R(234,a|0,4194304);b=x[23420];x[23420]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[23420]=0;U(592,d+304|0,o|0,1280592212);b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;b=T(148,x[d+304>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break g}x[23420]=0;U(391,d+304|0,a+1298308|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Gc(Yb(x[i>>2],y[j|0]));k=Qb(d+288|0);v[d+287|0]=0;x[23420]=0;U(594,d+272|0,o|0,1196314451);b=x[23420];x[23420]=0;if((b|0)==1){break i}B=d,C=Db(x[d+272>>2]),x[B+264>>2]=C;q=d+252|0;s=Db(x[d+276>>2]);E:{F:{while(1){b=x[d+264>>2];if(!Pb(b,s)){break F}l=he(d+40|0,b);x[23420]=0;e=Q(595,l|0,d+24|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break E}b=1;if(!(!e|y[d+33|0]!=1)){B=a,C=Wd(y[d+34|0],z[a+480188>>1],127),w[B+480188>>1]=C;x[23420]=0;h=T(596,d+208|0)|0;b=x[23420];x[23420]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;ef(b,d+24|0,9,1);x[23420]=0;R(210,d+160|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break K}b=d+8|0;fc(b,q,10);e=b;b=d+160|0;pl(e,b);xb(b);b=Yb(x[a+484360>>2],y[j|0]);if(uc(x[b>>2],x[b+4>>2])){break H}x[23420]=0;b=T(259,i|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=Yb(x[a+484360>>2],y[j|0])}x[23420]=0;U(5,d+160|0,5,q|0);e=x[23420];x[23420]=0;if((e|0)==1){break n}x[23420]=0;R(260,b|0,d+160|0);b=x[23420];x[23420]=0;if((b|0)==1){break o}yb(d+160|0);x[23420]=0;R(591,d+192|0,l|0);b=x[23420];x[23420]=0;if((b|0)==1){break p}B=d,C=Db(x[d+192>>2]),x[B+184>>2]=C;n=Db(x[d+196>>2]);L:{M:{while(1){b=x[d+184>>2];if(!Pb(b,n)){b=0;if(z[d+244>>1]==65535|z[d+246>>1]==65535){break L}b=y[j|0];e=x[a+484360>>2];x[23420]=0;Y(597,Yb(e,b)|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;R(598,k|0,h|0);e=x[23420];x[23420]=0;b=0;if((e|0)!=1){break L}}b=P()|0;break m}so(d+160|0,b);yi(d+8|0,x[b>>2],x[b+4>>2]);e=1;N:{g=x[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(z[a+480188>>1]<=b>>>0){break O}x[23420]=0;g=W(144,x[d+160>>2],x[d+168>>2],2)|0;f=x[23420];x[23420]=0;if((f|0)!=1){if(!g){break O}x[23420]=0;R(247,d+136|0,d+160|0);g=x[23420];x[23420]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(y[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=jd(d+136|0);B=Kb(x[h>>2],b),C=y[g|0]^128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);vg(g,0);break P}B=Kb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);vg(g,1);break P}B=Kb(x[h>>2],b),C=128,v[B|0]=C;g=d+144|0;Ab(g,x[d+232>>2],b);vg(g,0)}b=b+1|0;continue}break}break q}if(A[d+12>>2]<9){break O}b=0;x[23420]=0;Q(176,d+160|0,2)|0;e=x[23420];x[23420]=0;g=65535;if((e|0)==1){break N}while(1){T:{x[23420]=0;e=W(144,x[d+160>>2],x[d+168>>2],1)|0;f=x[23420];x[23420]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}x[23420]=0;f=T(194,d+160|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Yb(x[a+484360>>2],y[j|0]);if(z[d+244>>1]==65535){B=d,C=fl(x[e>>2],x[e+4>>2]),w[B+244>>1]=C}e=fl(x[e>>2],x[e+4>>2]);x[23420]=0;w[d+246>>1]=e;e=Q(599,d+160|0,d+287|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=y[j|0];m=x[a+484360>>2];x[23420]=0;R(472,Yb(m,f)|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}x[23420]=0;e=T(182,d+160|0)|0;f=x[23420];x[23420]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=z[d+248>>1];break ca}break q}e=e-g|0;w[d+248>>1]=e}Ze(Yb(x[a+484360>>2],y[j|0]),e&65535);break U}x[23420]=0;e=T(194,d+160|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}v[d+251|0]=e;break U}x[23420]=0;e=T(194,d+160|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}v[d+250|0]=e;break U}x[23420]=0;f=Q(570,d+160|0,d+144|0)|0;m=x[23420];x[23420]=0;if((m|0)!=1){if(y[d+144|0]|!f|(y[d+146|0]|y[d+145|0]!=255)){break O}if(y[d+147|0]|y[d+148|0]!=1){break O}if(!y[d+149|0]){break U}break O}break q}x[23420]=0;R(484,d+152|0,d+160|0);e=x[23420];x[23420]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=jd(d+152|0);e=x[h>>2];u=Wc(e,x[d+212>>2]);f=y[d+152|0];if(u>>>0<=f>>>0){break U}switch(y[Ue(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}B=Kb(e,f),C=y[m|0]^128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);vg(e,0);break ea}B=Kb(e,f),C=128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);vg(e,1);break ea}B=Kb(e,f),C=128,v[B|0]=C;e=d+144|0;Ab(e,x[d+232>>2],y[d+152|0]);vg(e,0)}ia:{if(t){break ia}t=0;e=x[k+4>>2];if(!Op(x[k>>2],e)){break U}f=e-56|0;e=y[d+152|0];if(y[Kb(x[f>>2],e)|0]!=y[Kb(x[h>>2],e)|0]){break ia}Ab(d+144|0,x[f+24>>2],e);e=Bb(x[x[d+144>>2]>>2],x[d+148>>2]);Ab(d+136|0,x[d+232>>2],y[d+152|0]);if((Bb(x[x[d+136>>2]>>2],x[d+140>>2])|0)==(e|0)){break U}}t=1;break U}x[23420]=0;R(247,d+144|0,d+160|0);e=x[23420];x[23420]=0;if((e|0)==1){break q}e=x[d+220>>2];m=Wc(e,x[d+224>>2]);f=y[d+144|0];if(m>>>0<=f>>>0){break U}m=jd(d+144|0);B=Kb(e,f),C=(y[m|0]>>>2|0)+1|0,v[B|0]=C}b=b+1|0;continue}break}e=1}zb(d+160|0);if(!e){break M}um(d+184|0);continue}break}break q}b=1}_d(d+192|0)}Ct(h)}zb(l);if(!b){th(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;zi(i,0);b=x[k>>2];if(uc(b,x[k+4>>2])){break w}if(!(c&2)){break x}x[23420]=0;U(594,d+160|0,o|0,1347244868);b=x[23420];x[23420]=0;if((b|0)!=1){B=d,C=Db(x[d+160>>2]),x[B+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Db(x[d+164>>2]);l=y[d+287|0];while(1){b=x[d+8>>2];if(!Pb(b,j)){kd(d+160|0);b=x[k>>2];break x}ja:{ka:{la:{if(!l){x[23420]=0;f=Q(600,b|0,d+40|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break ja}if(!f){break ka}f=z[d+92>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[Ve(e,d+144|0)>>1],w[B+480190>>1]=C;x[23420]=0;R(601,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[23420];x[23420]=0;if((f|0)==1){break ja}f=d+24|0;VQ(f,g);x[23420]=0;R(210,d+192|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}f=d+192|0;Dc(((z[d+144>>1]<<5)+a|0)+946304|0,f);xb(f);break la}x[23420]=0;f=Q(602,b|0,d+40|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break y}if(!f){break ka}f=z[d+96>>1];i=f+1|0;w[d+144>>1]=i;if(f>>>0>3998){break la}B=a,C=z[Ve(e,d+144|0)>>1],w[B+480190>>1]=C;x[23420]=0;R(603,d+40|0,(D(i&65535,104)+a|0)+484380|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}f=d+24|0;VQ(f,h);x[23420]=0;R(210,d+192|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}f=d+192|0;Dc(((z[d+144>>1]<<5)+a|0)+946304|0,f);xb(f)}f=z[d+144>>1];if((f-1&65535)>>>0>3998){break ka}i=_c(d+40|0,8,1,0,2);x[23420]=0;W(207,i|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break ka}break y}th(d+8|0);continue}break}break y}b=P()|0;break j}b=P()|0;break k}b=P()|0;break c}b=P()|0;break c}b=P()|0;kd(d+160|0);break j}b=Yz(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);Ze(Yb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;Te(g);h=Yz(x[k>>2],0);B=e+480286|0,C=y[Kb(x[h+12>>2],b)|0],w[B>>1]=C;B=e+480284|0,C=y[Kb(x[h>>2],b)|0],w[B>>1]=C;Ab(d+40|0,x[h+24>>2],b);B=g,C=x[g>>2]&-257|(Bb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[B>>2]=C;b=b+1|0;continue}break}x[23420]=0;b=Q(1,d+192|0,(y[d+287|0]?16950:16823)|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break r}Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,d+24|0,10029)|0;e=x[23420];x[23420]=0;if((e|0)==1){break s}Gb(a+1298356|0,b);yb(b);x[a+1298404>>2]=5;e=1;if(!(c&1)|!z[a+480188>>1]){break w}x[23420]=0;U(594,d+8|0,o|0,1146045008);b=x[23420];x[23420]=0;if((b|0)==1){break t}b=x[d+12>>2];c=x[d+8>>2];x[23420]=0;l=a+484344|0;R(213,l|0,Ff(c,b)&65535);b=x[23420];x[23420]=0;if((b|0)==1){break v}B=d,C=Db(x[d+8>>2]),x[B+144>>2]=C;s=Db(x[d+12>>2]);while(1){j=x[d+144>>2];if(!Pb(j,s)){ma:{na:{b=x[k>>2];e=x[k+4>>2];if(Op(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(Op(b,e)>>>0<=g>>>0){break na}i=x[a+484344>>2];n=x[j>>2];h=pj(x[a+484360>>2],g&255);m=x[h>>2];c=Yz(b,g);f=z[c+36>>1];if(oe(i,n,z[bc(m,f)>>1])){x[23420]=0;e=Q(346,h|0,f|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ma}oa:{if(!t){break oa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break oa}Ab(d+40|0,x[c+24>>2],b);f=Bb(x[x[d+40>>2]>>2],x[d+44>>2]);h=_b(x[l>>2],e);pa:{if(f){ie(h,xh(po(Fe(ye(d+40|0,20,145),0),b&65535)));break pa}ie(h,xh(po(Fe(ye(d+40|0,9,y[Kb(x[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;ie(_b(x[l>>2],e),xh(Fe(ye(b,16,y[c+43|0]),0)));ie(_b(x[l>>2],e),xh(Fe(ye(b,17,y[c+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}g=g+1|0;continue}}kd(d+8|0);e=1;break w}b=P()|0;break u}b=x[j>>2];x[23420]=0;b=T(148,b|0)|0;c=x[23420];x[23420]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}x[23420]=0;c=T(145,j|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=x[j>>2];x[23420]=0;b=Q(604,b|0,8)|0;c=x[23420];x[23420]=0;if((c|0)==1){break wa}if(!b){break qa}x[23420]=0;i=Q(599,j|0,d+287|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ra}x[23420]=0;q=T(182,j|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break sa}x[23420]=0;b=W(214,l|0,i|0,q|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(q|0)){break qa}b=_b(x[l>>2],i);c=pf(x[b>>2],x[x[b+48>>2]+12>>2],f);x[23420]=0;b=T(182,j|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){x[23420]=0;U(178,d+160|0,j|0,b-2|0);b=x[23420];x[23420]=0;if((b|0)==1){break ta}b=d+160|0;h=jc(d+40|0,b);zb(b);while(1){b=x[h>>2];x[23420]=0;b=W(144,b|0,x[d+48>>2],3)|0;e=x[23420];x[23420]=0;if((e|0)==1){break xa}if(b){x[23420]=0;R(247,d+160|0,h|0);b=x[23420];x[23420]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){w[d+136>>1]=z[a+480188>>1]-1;B=d,C=y[jd(d+160|0)|0],w[B+264>>1]=C;e=z[Zc(d+136|0,d+264|0)>>1];g=c+D(e,6)|0;b=v[d+160|0];if((b|0)>=0){break ya}x[23420]=0;b=T(194,h|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break ua}if(y[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}v[g|0]=b;b=y[d+160|0]}if(b&64){x[23420]=0;b=T(194,h|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break ua}v[g+1|0]=b+1;b=y[d+160|0]}if(b&32){x[23420]=0;b=T(194,h|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break ua}v[d+136|0]=b;v[g+2|0]=1;v[d+264|0]=127;B=g,C=y[Wb(d+136|0,d+264|0)|0]+1>>>1|0,v[B+4|0]=C;b=y[d+160|0]}if(!(b&16)){continue}x[23420]=0;R(247,d+136|0,h|0);b=x[23420];x[23420]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=y[jd(d+136|0)|0];v[g+5|0]=b;switch(y[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4|15;continue}v[g+5|0]=b<<3|15;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b<<4;continue}v[g+5|0]=b<<3&240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1|240;continue}v[(c+D(e,6)|0)+3|0]=11;if(y[d+287|0]){v[g+5|0]=b&15;continue}if(b>>>0<=1){v[g+5|0]=b|240;continue}v[g+5|0]=b>>>1&15;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=Bt(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=2;B=g,C=Bt(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=Bt(b,y[d+287|0])|240,v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=3;B=g,C=Bt(b,y[d+287|0]),v[B+5|0]=C;continue}v[(c+D(e,6)|0)+3|0]=4;if(y[d+287|0]){continue}v[g+5|0]=(b&252)>>>2;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&1|16;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=b&240;continue}v[(c+D(e,6)|0)+3|0]=6;v[g+5|0]=(b&240)>>>4;continue}v[(c+D(e,6)|0)+3|0]=20;continue}v[(c+D(e,6)|0)+3|0]=5;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|48;continue}v[(c+D(e,6)|0)+3|0]=7;v[g+5|0]=b|240;continue}v[(c+D(e,6)|0)+3|0]=7;continue}v[(c+D(e,6)|0)+3|0]=8;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|64;continue}v[(c+D(e,6)|0)+3|0]=10;x[23420]=0;b=T(194,h|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break La}break ua}v[(c+D(e,6)|0)+3|0]=15;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|192;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|208;continue}v[(c+D(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}v[g+5|0]=b;x[23420]=0;Q(176,h|0,1)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}break ua}v[(c+D(e,6)|0)+3|0]=14;v[g+5|0]=0;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|176;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|224;continue}v[(c+D(e,6)|0)+3|0]=16;continue}v[(c+D(e,6)|0)+3|0]=17;continue}v[(c+D(e,6)|0)+3|0]=1;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|32;continue}v[(c+D(e,6)|0)+3|0]=20;v[g+5|0]=b&15|128;continue}v[(c+D(e,6)|0)+3|0]=0;continue}break}zb(h)}f=f+1|0;continue}break}break ua}b=P()|0;break u}b=P()|0;break u}b=P()|0;zb(h);break u}b=P()|0;break u}b=P()|0;break u}b=P()|0;break u}th(d+144|0);continue}}kd(d+272|0);UQ(k);zb(d+304|0);break b}b=P()|0}kd(d+8|0);break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;break j}b=P()|0;zb(d+160|0);break m}b=P()|0;break l}b=P()|0;yb(d+160|0);break l}b=P()|0;break l}_d(d+192|0)}Ct(h)}zb(l)}kd(d+272|0);break h}b=P()|0}UQ(k);break f}b=P()|0}zb(d+304|0);break c}b=P()|0;break c}b=P()|0}_d(o);zb(r);S(b|0);p()}_d(o);zb(r)}hb=d+384|0;return e|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=hb-480|0;hb=d;zc(b);f=d+472|0;e=zu(b,f);if(!e){wS(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!xS(d+472|0)){break k}if(!c){G=1;break k}H=he(d+448|0,b);x[23420]=0;R(440,d+432|0,H|0);b=x[23420];x[23420]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){x[23420]=0;U(441,d+408|0,d+432|0,20041);b=x[23420];x[23420]=0;if((b|0)==1){break u}x[23420]=0;e=T(166,x[d+408>>2])|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}if(!e){break l}x[23420]=0;e=Q(442,d+408|0,d+312|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}if(!e){break l}x[23420]=0;R(234,a|0,16384);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[a+480208>>2]=8;x[23420]=0;e=W(251,a+1074312|0,9,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;e=W(251,e|0,114,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;e=Q(252,e|0,21)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;Q(252,e|0,30)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;e=Q(1,d+296|0,8198)|0;b=x[23420];x[23420]=0;if((b|0)==1){break r}Gb(a+1298344|0,e);yb(e);x[23420]=0;e=Q(1,d+280|0,10614)|0;b=x[23420];x[23420]=0;if((b|0)==1){break q}Gb(a+1298356|0,e);yb(e);x[23420]=0;j=Q(1,d+264|0,17320)|0;b=x[23420];x[23420]=0;if((b|0)==1){break p}e=14891;b=y[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}h=P()|0;break a}h=P()|0;break b}e=14872;break n}if(!b){break o}e=21473;break n}h=P()|0;break c}h=P()|0;break c}h=P()|0;break c}e=13112}x[23420]=0;f=Q(1,d+248|0,e|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;U(2,d+208|0,j|0,f|0);b=x[23420];x[23420]=0;if((b|0)==1){break f}e=d+208|0;Gb(a+1298368|0,e);yb(e);yb(f);yb(j);x[a+1298404>>2]=5;b=d+96|0;Ye(b,3,d+312|0);x[23420]=0;R(210,e|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break g}b=d+208|0;Ac(a+1298308|0,b);xb(b);b=d+232|0;tj(b,3,d+344|0);x[23420]=0;R(210,d+96|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break h}x[23420]=0;U(11,d+208|0,5,d+96|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}b=d+208|0;Gb(a+1298320|0,b);yb(b);xb(d+96|0);x[a+480200>>2]=y[d+368|0]+1;I=a,J=Wd(y[d+369|0],1,255),x[I+480196>>2]=J;I=a,J=D(Wd(y[d+370|0],4,255),1e4),x[I+480204>>2]=J;f=x[a+484360>>2];e=a+484376|0;b=y[e|0];x[23420]=0;ea(326,Yb(f,b)|0,d+408|0,z[d+364>>1],65535,65535);b=x[23420];x[23420]=0;if((b|0)==1){break m}Ze(Yb(x[a+484360>>2],y[e|0]),z[d+366>>1]);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[23420]=0;U(441,d+208|0,d+432|0,17741);b=x[23420];x[23420]=0;if((b|0)!=1){b=d+208|0;f=bd(d+408|0,b);zb(b);b=x[f>>2];x[23420]=0;e=T(148,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;X(317,a+1298332|0,f|0,e|0,0);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;U(441,d+208|0,d+432|0,21321);b=x[23420];x[23420]=0;if((b|0)!=1){b=d+208|0;k=bd(f,b);zb(b);b=x[k>>2];x[23420]=0;e=T(166,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}v:{w:{if(e){x[23420]=0;U(441,d+208|0,d+432|0,16723);b=x[23420];x[23420]=0;if((b|0)==1){break v}x[23420]=0;j=T(194,k|0)|0;b=x[23420];x[23420]=0;x:{if((b|0)!=1){f=c&2;F=a+480190|0;while(1){if(j>>>0<=(m&255)>>>0){break x}x[23420]=0;i=T(194,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}if(!i){break x}e=x[k+8>>2];b=x[k>>2];x[23420]=0;e=W(144,b|0,e|0,56)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}if(!e){break x}if(i>>>0>z[F>>1]){w[F>>1]=i}x[23420]=0;o=D(i,104)+a|0;q=o+484380|0;R(264,q|0,0);b=x[23420];x[23420]=0;if((b|0)==1){break w}nB(q);x[23420]=0;U(300,k|0,((i<<5)+a|0)+946304|0,32);b=x[23420];x[23420]=0;if((b|0)==1){break w}x[23420]=0;R(303,k|0,o+484423|0);b=x[23420];x[23420]=0;if((b|0)==1){break w}y:{if(y[d+476|0]<=15){x[23420]=0;h=T(182,k|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break y}break w}x[23420]=0;h=T(145,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}}x[o+484404>>2]=h<<1;x[23420]=0;e=T(145,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}x[q>>2]=e;x[23420]=0;e=T(145,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}g=o+484384|0;x[g>>2]=e;x[23420]=0;e=T(145,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}B=o+484388|0;x[B>>2]=e;if(e){b=o+484414|0;w[b>>1]=z[b>>1]|2;x[B>>2]=e+x[g>>2]}x[23420]=0;e=T(194,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}if(y[d+476|0]<=15){w[o+484410>>1]=e}x[23420]=0;E=T(194,k|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}i=o+484414|0;e=z[i>>1];b=8;if(E&1){e=e|1;w[i>>1]=e;x[q>>2]=x[q>>2]>>>1;x[g>>2]=x[g>>2]>>>1;x[B>>2]=x[B>>2]>>>1;b=16}w[i>>1]=e&65531|E<<1&4;b=_c(d+96|0,b,1,0,((E&12)!=0)<<3);z:{if(!f){break z}x[23420]=0;W(207,b|0,q|0,d+208|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break z}break w}m=m+1|0;continue}}break w}zb(d+208|0)}x[23420]=0;U(441,d+208|0,d+432|0,18761);b=x[23420];x[23420]=0;A:{if((b|0)!=1){b=d+208|0;l=bd(k,b);zb(b);b=x[l>>2];x[23420]=0;e=T(166,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break m}if(!e){break A}r=Qb(d+96|0);s=Qb(d+232|0);u=Qb(d+192|0);x[23420]=0;U(441,d+168|0,d+432|0,17750);b=x[23420];x[23420]=0;B:{if((b|0)==1){break B}b=x[d+180>>2];e=d- -64|0;x[e>>2]=x[d+176>>2];x[e+4>>2]=b;x[d+72>>2]=x[d+184>>2];x[23420]=0;b=x[d+172>>2];x[d+56>>2]=x[d+168>>2];x[d+60>>2]=b;R(443,d+56|0,r|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}x[23420]=0;U(441,d+144|0,d+432|0,17744);b=x[23420];x[23420]=0;if((b|0)==1){break B}b=x[d+156>>2];x[d+40>>2]=x[d+152>>2];x[d+44>>2]=b;x[d+48>>2]=x[d+160>>2];x[23420]=0;b=x[d+148>>2];x[d+32>>2]=x[d+144>>2];x[d+36>>2]=b;R(443,d+32|0,s|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}x[23420]=0;U(441,d+120|0,d+432|0,17734);b=x[23420];x[23420]=0;if((b|0)==1){break B}b=x[d+132>>2];x[d+16>>2]=x[d+128>>2];x[d+20>>2]=b;x[d+24>>2]=x[d+136>>2];x[23420]=0;b=x[d+124>>2];x[d+8>>2]=x[d+120>>2];x[d+12>>2]=b;R(443,d+8|0,u|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}x[23420]=0;q=T(194,l|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break B}o=d+208|1;g=a+480190|0;while(1){if(q>>>0<=(G&255)>>>0){ko(u);ko(s);ko(r);break A}x[23420]=0;R(247,d+80|0,l|0);b=x[23420];x[23420]=0;C:{if((b|0)!=1){C=jd(d+80|0);D:{E:{if(!y[d+80|0]){break E}f=x[l+8>>2];e=x[l>>2];b=y[C|0];x[23420]=0;e=W(144,e|0,f|0,D(b,14)+32|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break B}if(!e){break E}x[23420]=0;n=W(239,a|0,y[d+80|0],0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break B}if(n){break D}}b=y[C|0];x[23420]=0;Q(176,l|0,D(b,14)+32|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break C}break B}x[23420]=0;U(300,l|0,n+492|0,32);b=x[23420];x[23420]=0;if((b|0)==1){break B}B=n+88|0;E=n+68|0;F=n+48|0;i=n+236|0;b=0;m=0;while(1){if(y[C|0]<=(m&255)>>>0){break C}x[23420]=0;R(444,l|0,d+208|0);e=x[23420];x[23420]=0;if((e|0)==1){break B}e=y[d+208|0];F:{if(!e|e>>>0>z[g>>1]){break F}if(y[o|0]>=129){v[o|0]=128}while(1){e=b&255;j=y[d+209|0];if(e>>>0>j>>>0){e=x[r+4>>2];b=x[r>>2];x[23420]=0;X(445,F|0,y[d+211|0],b|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}e=x[s+4>>2];b=x[s>>2];x[23420]=0;X(445,E|0,y[d+213|0],b|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}e=x[u+4>>2];b=x[u>>2];x[23420]=0;X(445,B|0,y[d+221|0],b|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break B}x[n>>2]=z[d+214>>1]+1>>>1;e=y[d+208|0];G:{if(y[d+211|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+210|0];break G}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+118>>1]=y[d+212|0]<<1;w[d+116>>1]=254;t=D(e,104)+a|0;I=t+484408|0,J=z[Zc(d+118|0,d+116|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[d+219|0]&3)+26500|0];e=t+484419|0;k=y[d+218|0];v[e|0]=k;f=y[d+217|0]+3>>>2|0;v[t+484420|0]=f;v[t+484421|0]=y[d+216|0];b=j+1|0;if(k){f=Cm(Vc(((f<<8|k>>>1)>>>0)/(k>>>0)|0,0))}else{f=255}v[e|0]=f;if(!(y[d+213|0]&64)){break F}e=t+484414|0;w[e>>1]=z[e>>1]|32}else{I=bc(i,e),J=y[d+208|0],w[I>>1]=J;b=b+1|0;continue}break}}m=m+1|0;continue}}break B}G=G+1|0;continue}}h=P()|0;ko(u);ko(s);ko(r);break c}h=P()|0;break c}G=1;r=Qb(d+232|0);H:{if(!(c&1)){break H}x[23420]=0;U(441,d+208|0,d+432|0,21076);b=x[23420];x[23420]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){j=bd(l,d+208|0);b=x[j>>2];x[23420]=0;c=T(166,b|0)|0;b=x[23420];x[23420]=0;O:{P:{Q:{if((b|0)!=1){zb(d+208|0);if(!c){break O}x[23420]=0;e=T(182,j|0)|0;c=x[23420];x[23420]=0;b=1;if((c|0)==1){break Q}x[23420]=0;f=e+1|0;R(446,r|0,f|0);c=x[23420];x[23420]=0;if((c|0)==1){break Q}while(1){if((b|0)==(f|0)){break O}x[23420]=0;e=T(182,j|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break P}x[23420]=0;U(178,d+96|0,j|0,e|0);c=x[23420];x[23420]=0;if((c|0)==1){break P}c=d+96|0;e=jc(d+208|0,c);bd(Bg(x[r>>2],b),e);zb(e);b=b+1|0;zb(c);continue}}h=P()|0;zb(d+208|0);break I}h=P()|0;break I}h=P()|0;break I}x[23420]=0;U(441,d+208|0,d+432|0,16720);b=x[23420];x[23420]=0;if((b|0)==1){break K}l=bd(j,d+208|0);b=x[l>>2];x[23420]=0;c=T(166,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break L}zb(d+208|0);if(!c){break N}x[23420]=0;k=T(194,l|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break J}c=0;R:{S:{T:while(1){U:{if(k>>>0<=(c&65535)>>>0){x[23420]=0;Q(143,l|0,1)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break U}break J}m=32;V:{if(y[d+476|0]<16){break V}x[23420]=0;R(447,l|0,d+208|0);b=x[23420];x[23420]=0;if((b|0)==1){break R}m=y[d+208|0];if(m>>>0<=z[a+480188>>1]|m>>>0>32){break V}w[a+480188>>1]=m}b=0;while(1){j=b&65535;if(j>>>0>=m>>>0){c=c+1|0;continue T}x[23420]=0;f=T(182,l|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break S}if(!(!f|j>>>0>31|j>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[23420]=0;s=a+484344|0;R(213,s|0,k|0);b=x[23420];x[23420]=0;if((b|0)==1){break J}E=d+208|2;n=0;while(1){if((k|0)==(n|0)){break N}u=Jb(d+96|0);W:{if(y[d+476|0]<16){o=32;j=64;break W}x[23420]=0;R(447,l|0,d+208|0);b=x[23420];x[23420]=0;if((b|0)==1){break M}c=y[d+209|0];o=y[d+208|0];b=d+80|0;ef(b,E,16,3);x[23420]=0;R(210,d+192|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break M}b=d+192|0;Ac(u,b);xb(b);j=c+1|0}x[23420]=0;c=W(214,s|0,n&65535,j|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break M}X:{if(!c){x[23420]=0;Q(176,l|0,o<<1)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break X}break M}b=x[s>>2];x[23420]=0;R(268,_b(b,n)|0,u|0);b=x[23420];x[23420]=0;if((b|0)==1){break M}F=j-1|0;q=0;while(1){t=q&65535;if(t>>>0>=o>>>0){break X}x[23420]=0;c=T(182,l|0)|0;b=x[23420];x[23420]=0;Y:{if((b|0)!=1){if(!c){break Y}b=x[r>>2];if(Ff(b,x[r+4>>2])>>>0<=c>>>0|t>>>0>=z[a+480188>>1]){break Y}A=Bg(b,c);zc(A);c=0;Z:while(1){e=c;if(j>>>0<=e>>>0){break Y}c=x[A+8>>2];b=x[A>>2];x[23420]=0;c=W(144,b|0,c|0,1)|0;b=x[23420];x[23420]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=_b(x[s>>2],n);b=ed(x[b>>2],x[x[b+48>>2]+12>>2],e,t);x[23420]=0;f=T(194,A|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}g=f<<24>>24;h=(g&252)>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+h|0)+1|0;continue}c=0;if(!e){continue}c=_b(x[s>>2],n);i=ed(x[c>>2],x[x[c+48>>2]+12>>2],e-1|0,t);while(1){c=y[i|0]|y[i+1|0]<<8|(y[i+2|0]<<16|y[i+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[i+4|0]|y[i+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(F|0)){continue Z}b=D(z[a+480188>>1],6)+b|0;f=h&255;e=c;h=h-1|0;if(f){continue}break}continue}if(e>>>0<=h>>>0){break _}c=_b(x[s>>2],n);f=ed(x[c>>2],x[x[c+48>>2]+12>>2],h,t);c=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;break _}if(h&1){x[23420]=0;f=T(194,A|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}v[b|0]=f>>>0>120?-1:f}if(h&2){x[23420]=0;f=T(194,A|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}v[b+1|0]=f}c=0;m=0;da:{if(h&4){x[23420]=0;m=T(194,A|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break da}}C=0;if(h&8){x[23420]=0;f=T(194,A|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break da}C=f>>>4|0;c=f&15}B=0;i=0;if(h&16){x[23420]=0;i=T(194,A|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break da}}if((g|0)<0){x[23420]=0;B=T(194,A|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break da}}g=hb-16|0;hb=g;v[g+14|0]=C;v[g+15|0]=c;v[g+13|0]=i;v[g+12|0]=B;if((C-1&255)>>>0<=5){v[g+14|0]=C+15}tS(g+15|0,g+13|0);tS(g+14|0,g+12|0);ea:{fa:{c=y[g+15|0];ga:{if((c|0)==10){i=y[g+12|0];f=y[g+13|0]&15;v[g+13|0]=f?-1:i;c=y[g+14|0];c=(c|0)!=10?c:0;v[g+14|0]=c;f=i|f<<8;break ga}if(y[g+14|0]!=10){break fa}f=y[g+12|0]&15;v[g+12|0]=f?-1:0;f=f<<8}if(f-256>>>0>4294967038){break fa}if(Ai(c)>>>0>=Ai(10)>>>0){break fa}v[b+5|0]=f;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=f>>>8;break ea}if(m){v[b+2|0]=1;v[b+4|0]=m+2>>>2}Fu(g+15|0,g+13|0,g+14|0,g+12|0);f=y[g+15|0];ha:{if(!f){break ha}c=y[g+14|0];if(!c){v[g+14|0]=f;v[g+12|0]=y[g+13|0];break ha}if((c|0)==(f|0)&(f|0)!=20){break ha}if(!m){vq(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);v[b+2|0]=y[g+15|0];v[b+4|0]=y[g+13|0];break ha}if(Ai(f)>>>0<=Ai(c)>>>0){break ha}uh(g+15|0,g+14|0);uh(g+13|0,g+12|0)}v[b+3|0]=y[g+14|0];v[b+5|0]=y[g+12|0]}hb=g+16|0;break _}break M}c=e+1|0;continue}}break M}q=q+1|0;continue}}xb(u);n=n+1|0;continue}}h=P()|0;break I}h=P()|0;break I}h=P()|0;break I}x[23420]=0;U(441,d+208|0,d+432|0,20048);b=x[23420];x[23420]=0;ia:{ja:{if((b|0)!=1){f=bd(l,d+208|0);b=x[f>>2];x[23420]=0;c=T(166,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ja}zb(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!of(x[a+484344>>2],x[e>>2])){break H}c=x[f+8>>2];b=x[f>>2];x[23420]=0;c=W(144,b|0,c|0,16)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ia}if(!c){break H}x[23420]=0;R(448,f|0,d+208|0);b=x[23420];x[23420]=0;if((b|0)!=1){b=x[a+484344>>2];x[23420]=0;R(449,_b(b,0)|0,d+208|0);b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}h=P()|0;break I}h=P()|0;break I}h=P()|0;zb(d+208|0);break I}h=P()|0;break I}h=P()|0;xb(u);break I}h=P()|0;zb(d+208|0);break I}h=P()|0;break I}h=P()|0}kd(r);break c}kd(r);break l}h=P()|0;zb(d+208|0);break c}h=P()|0;break c}h=P()|0;break c}h=P()|0;break c}i=(b<<5)+a|0;j=i+480280|0;Te(j);f=v[(b+d|0)+371|0];e=f<<1&254;w[i+480284>>1]=(e|0)==254?256:e;ka:{if((f|0)<0){x[j>>2]=x[j>>2]|1024;break ka}w[a+480188>>1]=b+1}x[23420]=0;R(450,d+408|0,i+480289|0);e=x[23420];x[23420]=0;if((e|0)==1){break j}b=b+1|0;continue}}h=P()|0;break c}zb(d+408|0);_d(d+432|0);zb(H)}hb=d+480|0;return G|0}h=P()|0;break c}h=P()|0;xb(d+96|0);break c}h=P()|0;break c}h=P()|0;break c}h=P()|0;yb(f);break d}h=P()|0}yb(j)}zb(d+408|0)}_d(d+432|0)}zb(H);S(h|0);p()}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-240|0;hb=d;zc(b);e=hb-16|0;hb=e;i=d+216|0;gu(e+8|0,i);g=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(g|0)){$b(b,x[e+12>>2])}hb=e+16|0;e=(g|0)==(j|0);if(!e){CT(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!DT(d+216|0)){break n}if(!c){f=1;break n}Dd(a,1024);Cg(a);x[a+480208>>2]=x[a+480208>>2]|12;Cf(a+1074312|0,21);e=Lb(z[d+232>>1]);if(e){x[a+480204>>2]=D(e,1e4)}e=Lb(z[d+230>>1]);if(e){x[a+480196>>2]=e}if(!y[d+226|0]){wh(a,1)}vu(b,a+1298308|0,ac(x[d+220>>2])-14|0);b=he(d+112|0,b);x[23420]=0;R(324,d+200|0,b|0);e=x[23420];x[23420]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){zb(b);x[23420]=0;U(325,d+112|0,d+200|0,1395544366);b=x[23420];x[23420]=0;if((b|0)==1){break s}x[23420]=0;b=T(262,x[d+112>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break y}if(!b){break r}x[23420]=0;b=T(258,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break y}x[23420]=0;e=T(258,d+112|0)|0;f=x[23420];x[23420]=0;A:{if((f|0)==1){break A}x[23420]=0;Q(176,d+112|0,4)|0;f=x[23420];x[23420]=0;if((f|0)==1){break A}f=a+484376|0;g=y[f|0];i=x[a+484360>>2];x[23420]=0;ea(326,Yb(i,g)|0,d+112|0,b|0,65535,65535);b=x[23420];x[23420]=0;if((b|0)!=1){break z}}break y}a=P()|0;zb(b);break a}Ze(Yb(x[a+484360>>2],y[f|0]),e);b=d+112|0;zb(b);x[23420]=0;U(325,b|0,d+200|0,1346458708);b=x[23420];x[23420]=0;if((b|0)==1){break x}x[23420]=0;e=T(262,x[d+112>>2])|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}x[23420]=0;e=T(258,d+112|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break w}w[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}x[23420]=0;b=T(258,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}x[23420]=0;R(213,a+484344|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break w}b=0;x[23420]=0;m=T(266,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=P()|0;zb(d+112|0);break b}a=P()|0;break b}a=P()|0;zb(d+112|0);break b}if(m){break t}}b=1}zb(d+112|0);if(!b){break o}x[23420]=0;U(325,d+176|0,d+200|0,1398157625);b=x[23420];x[23420]=0;if((b|0)==1){break d}x[23420]=0;b=T(262,x[d+176>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}if(!b){break q}x[23420]=0;Q(176,d+176|0,2)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}x[23420]=0;b=T(266,d+176|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}H=a,I=Ie((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[H+480204>>2]=I;b=0;x[23420]=0;Q(327,d+176|0,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){H=d,I=Lb(z[(d+112|0)+(b<<1)>>1]),x[H+48>>2]=I;x[d+32>>2]=180;e=x[td(d+48|0,d+32|0)>>2]-90|0;g=e>>31;H=((b<<5)+a|0)+480284|0,I=Hc(Xia(e<<7|45,g<<7|e>>>25,90,0),lb)+128|0,w[H>>1]=I;b=b+1|0;continue}else{B:{x[23420]=0;Q(176,d+176|0,16)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break B}break c}}break}x[23420]=0;b=W(144,x[d+176>>2],x[d+184>>2],2)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}C:{if(b){x[23420]=0;b=T(258,d+176|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;H=a,I=z[Zc(d+48|0,d+32|0)>>1],x[H+480200>>2]=I}x[23420]=0;Q(176,d+176|0,128)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}x[23420]=0;b=Q(327,d+176|0,d+48|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){H=d,I=Lb(z[(d+48|0)+(b<<1)>>1]),x[H+32>>2]=I;x[d+16>>2]=128;H=((b<<5)+a|0)+480286|0,I=x[td(d+32|0,d+16|0)>>2]/2&255,w[H>>1]=I;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}a=P()|0;break b}zb(d+112|0);break p}zb(d+176|0);x[23420]=0;U(325,d+112|0,d+200|0,1413830740);b=x[23420];x[23420]=0;D:{E:{if((b|0)!=1){x[23420]=0;b=T(262,x[d+112>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break e}if(!b){break D}x[23420]=0;R(328,d+112|0,d+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}if((Lb(z[d+58>>1])|0)!=65535){break E}x[23420]=0;Q(176,d+112|0,1)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break E}break e}a=P()|0;break b}x[23420]=0;b=T(190,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break e}x[23420]=0;X(317,a+1298332|0,d+112|0,b|0,2);b=x[23420];x[23420]=0;if((b|0)==1){break e}}zb(d+112|0);x[23420]=0;U(325,d+48|0,d+200|0,1229869908);b=x[23420];x[23420]=0;if((b|0)==1){break h}x[23420]=0;b=T(262,x[d+48>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}F:{if(!b){break F}x[23420]=0;b=T(258,d+48|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[23420]=0;e=W(144,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;i=d+130|0;j=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[23420]=0;b=T(258,d+48|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break I}break g}M:{if(j){o=b}else{x[23420]=0;e=T(258,d+48|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break M}o=e+1|0}w[d+16>>1]=o;x[23420]=0;R(329,d+48|0,d+112|0);e=x[23420];x[23420]=0;if((e|0)==1){break L}e=z[d+16>>1];if((e-4e3&65535)>>>0>=61537){H=a,I=z[Ve(g,d+16|0)>>1],w[H+480190>>1]=I;l=z[d+234>>1]|z[d+236>>1]<<16;x[23420]=0;X(330,d+112|0,(D(e,104)+a|0)+484380|0,ac(l)|0,m|0);e=x[23420];x[23420]=0;if((e|0)==1){break K}e=d+32|0;ml(e,2,i);x[23420]=0;R(210,d+176|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break J}e=d+176|0;Dc(((z[d+16>>1]<<5)+a|0)+946304|0,e);xb(e)}b=b+1|0;continue}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+176>>1]=255;i=a+480192|0;b=d+176|0;H=i,I=z[Zc(d+112|0,b)>>1],w[H>>1]=I;x[23420]=0;U(325,b|0,d+200|0,1229278806);b=x[23420];x[23420]=0;if((b|0)==1){break j}N:while(1){O:{x[23420]=0;b=W(144,x[d+48>>2],x[d+56>>2],15)|0;e=x[23420];x[23420]=0;if((e|0)==1){break O}if(!b){break G}x[23420]=0;R(331,d+48|0,d+32|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}b=Lb(z[d+32>>1]);if(b>>>0>=z[i>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[23420]=0;b=b+1&65535;e=W(239,a|0,b|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break k}if(!e){continue}H=d,I=Lb(y[d+37|0]|y[d+38|0]<<8),w[H+112>>1]=I;w[d+16>>1]=4095;H=e,I=z[Zc(d+112|0,d+16|0)>>1],x[H>>2]=I;b=y[d+35|0];if((b|0)==255){continue}x[23420]=0;b=Q(143,d+176|0,D(b,34)+2|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}if(!b){continue}x[23420]=0;R(332,d+176|0,d+112|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+20>>2]=16;x[d+24>>2]=240;H=d,I=Lb(b),x[H+16>>2]=I;b=AB(d+16|0);x[23420]=0;R(278,e+48|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}g=x[e+52>>2];f=x[e+48>>2];b=0;while(1){j=qe(f,g);if(j>>>0<=b>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(uc(f,g)){continue N}b=j-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+16|0]=64;j=(d+112|0)+(b<<1)|0;v[d+12|0]=y[j+2|0];l=Wb(d+16|0,d+12|0);h=Cb(f,b);v[h+2|0]=y[l|0];w[h>>1]=y[j+3|0];b=b+1|0;continue}}}break}break k}zb(d+48|0);break p}zb(d+176|0)}zb(d+48|0);x[23420]=0;U(333,d+176|0,d+200|0,1145131092);b=x[23420];x[23420]=0;if((b|0)==1){break m}H=d,I=Db(x[d+176>>2]),x[H+16>>2]=I;l=a+484344|0;C=c&1;s=d+48|4;E=Db(x[d+180>>2]);t=(m|0)!=841887798;u=a+480188|0;F=(m|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{g=x[d+16>>2];if(!Pb(g,E)){kd(d+176|0);x[23420]=0;U(325,d+112|0,d+200|0,1346458702);b=x[23420];x[23420]=0;if((b|0)!=1){break ba}a=P()|0;break b}x[23420]=0;Q(176,g|0,4)|0;b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;f=T(258,g|0)|0;b=x[23420];x[23420]=0;ca:{if((b|0)!=1){x[23420]=0;j=T(258,g|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break R}j=t?j:(j>>>0)/A[a+480196>>2]|0;if(!C|f>>>0>255){break P}x[23420]=0;b=W(214,l|0,f|0,j|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break R}if(b){break ca}break P}a=P()|0;break Q}if(!t){i=0;x[23420]=0;Q(176,g|0,4)|0;b=x[23420];x[23420]=0;if((b|0)==1){break R}while(1){B=i&65535;if(B>>>0>=z[u>>1]){break P}x[23420]=0;b=T(258,g|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break aa}x[23420]=0;U(178,d+48|0,g|0,b+(b&1)&65535);b=x[23420];x[23420]=0;if((b|0)==1){break S}b=d+48|0;e=jc(d+112|0,b);zb(b);x[d+48>>2]=0;x[d+52>>2]=0;n=0;da:{while(1){b=x[e>>2];x[23420]=0;b=W(144,b|0,x[d+120>>2],6)|0;h=x[23420];x[23420]=0;if((h|0)==1){break da}h=x[d+48>>2];if(b&h>>>0<j>>>0){b=_b(x[l>>2],f);b=ed(x[b>>2],x[x[b+48>>2]+12>>2],h,B);x[23420]=0;R(334,d+32|0,e|0);h=x[23420];x[23420]=0;ea:{fa:{if((h|0)!=1){h=d+32|0;k=jd(h);G=Ue(h);o=Bi(h);q=ic(h);r=v[d+32|0];if((r-1&255)>>>0>95){break fa}v[b|0]=r+13;if(!x[d+52>>2]){break ea}v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[td(s,d+12|0)|0]|208,v[H+5|0]=I;break ea}break T}if((r|0)>=0){break ea}if(x[d+52>>2]){v[b+3|0]=19;x[d+12>>2]=15;H=b,I=y[td(s,d+12|0)|0]|192,v[H+5|0]=I;break ea}v[b|0]=254}if(y[k|0]){v[b+2|0]=1;v[d+12|0]=64;H=b,I=y[Wb(k,d+12|0)|0],v[H+4|0]=I}k=y[G|0];if(k){v[b+1|0]=k}k=y[o|0];if(k|y[q|0]){v[b+3|0]=k;v[b+5|0]=y[q|0];Of(b)}h=v[h+5|0];b=h&255;k=d+48|0;if((h|0)<0){x[23420]=0;h=T(194,e|0)|0;q=x[23420];x[23420]=0;if((q|0)==1){break T}b=h|b<<8&32512}n=b+n|0;sB(k,n,x[a+480196>>2]);continue}break}zb(e);i=i+1|0;continue}break}break T}i=0;b=_b(x[l>>2],f);b=ed(x[b>>2],x[x[b+48>>2]+12>>2],0,0);ga:while(1){f=0;if((i|0)==(j|0)){break P}while(1){if(z[u>>1]<=(f&65535)>>>0){i=i+1|0;continue ga}x[23420]=0;R(335,d+112|0,g|0);e=x[23420];x[23420]=0;if((e|0)==1){break $}ha:{if(!F){e=x[d+112>>2];x[d+48>>2]=e;h=d+48|0;n=jd(h);k=Ue(h);h=Bi(h);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[n|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[n|0]}v[b+1|0]=e<<4&48|y[k|0]>>>4;v[b+3|0]=y[k|0]&15;v[b+5|0]=y[h|0];break ha}e=x[d+112>>2];x[d+8>>2]=e;x[d+4>>2]=e;fu(d+4|0,b);H=b,I=y[b+1|0]|y[Kb(d+112|0,0)|0]&48,v[H+1|0]=I}Of(b);e=y[b+3|0];ia:{if(e>>>0>11){break ia}e=1<<e;ja:{if(!(e&2240)){if(!(e&12)){break ia}if(!y[b+5|0]){break ja}break ia}e=y[b+5|0];h=e&240;if(h){v[b+5|0]=h;break ia}if(e){break ia}}v[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=P()|0;break Q}x[23420]=0;b=T(262,x[d+112>>2])|0;e=x[23420];x[23420]=0;ka:{la:{ma:{na:{oa:{if((e|0)!=1){if(b){e=Jb(d+48|0);f=a+484348|0;b=0;pa:{while(1){qa:{x[23420]=0;g=W(144,x[d+112>>2],x[d+120>>2],1)|0;i=x[23420];x[23420]=0;if((i|0)==1){break qa}if(!g){break pa}if(of(x[a+484344>>2],x[f>>2])>>>0<=b>>>0){break pa}x[23420]=0;U(336,d+112|0,e|0,32);g=x[23420];x[23420]=0;if((g|0)==1){break qa}g=x[l>>2];x[23420]=0;R(268,_b(g,b)|0,e|0);g=x[23420];x[23420]=0;if((g|0)==1){break qa}b=b+1|0;continue}break}a=P()|0;xb(e);break oa}xb(e)}b=d+112|0;zb(b);x[23420]=0;U(325,b|0,d+200|0,1414679374);b=x[23420];x[23420]=0;if((b|0)==1){break na}x[23420]=0;b=T(262,x[d+112>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break V}if(!b){break ka}e=Jb(d+48|0);f=a+480188|0;b=0;while(1){x[23420]=0;g=W(144,x[d+112>>2],x[d+120>>2],1)|0;i=x[23420];x[23420]=0;if((i|0)==1){break ma}if(!(g&z[f>>1]>b>>>0)){break la}x[23420]=0;U(336,d+112|0,e|0,32);g=x[23420];x[23420]=0;if((g|0)==1){break ma}ym(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=P()|0}zb(d+112|0);break b}a=P()|0;break b}a=P()|0;xb(e);break U}xb(e)}b=d+112|0;zb(b);x[23420]=0;U(333,b|0,d+200|0,1145129300);b=x[23420];x[23420]=0;if((b|0)==1){break W}H=d,I=Db(x[d+112>>2]),x[H+48>>2]=I;e=c&2;f=Db(x[d+116>>2]);g=a+480190|0;ra:{sa:{ta:{ua:{va:{wa:{while(1){b=x[d+48>>2];if(!Pb(b,f)){kd(d+112|0);b=Jb(d+48|0);if((m|0)!=841887798){break va}x[23420]=0;c=Q(1,d+112|0,9392)|0;e=x[23420];x[23420]=0;if((e|0)==1){break wa}Gb(b,c);yb(c);break ua}x[23420]=0;c=T(258,b|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break X}xa:{if(!(!e|c>>>0>=z[g>>1])){c=D(c,104)+a|0;i=z[c+484518>>1];i=_c(d+176|0,i&1?16:8,i&64?2:1,1,0);x[23420]=0;W(207,i|0,c+484484|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break xa}}th(d+48|0);continue}break}break X}a=P()|0;break Y}x[23420]=0;U(325,d+112|0,d+200|0,1447383635);c=x[23420];x[23420]=0;ya:{za:{Aa:{Ba:{Ca:{if((c|0)!=1){x[23420]=0;c=T(262,x[d+112>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break ta}if(!c){break za}x[23420]=0;c=T(266,d+112|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Ca}x[23420]=0;R(253,d+32|0,4253);e=x[23420];x[23420]=0;if((e|0)==1){break Ba}x[d+16>>2]=c>>>4;x[23420]=0;x[d+12>>2]=c&15;X(337,d+176|0,d+32|0,d+16|0,d+12|0);c=x[23420];x[23420]=0;if((c|0)==1){break Aa}c=d+176|0;Gb(b,c);yb(c);cc(d+32|0);break ya}a=P()|0;break Y}a=P()|0;break Z}a=P()|0;break Z}a=P()|0;cc(d+32|0);break Z}x[23420]=0;c=Q(1,d+176|0,8427)|0;e=x[23420];x[23420]=0;if((e|0)==1){break _}Gb(b,c);yb(c)}zb(d+112|0)}x[23420]=0;c=Q(1,d+32|0,8427)|0;e=x[23420];x[23420]=0;if((e|0)==1){break sa}Gb(a+1298344|0,c);yb(c);x[23420]=0;c=Q(1,d+16|0,10025)|0;e=x[23420];x[23420]=0;if((e|0)==1){break ra}Gb(a+1298356|0,c);yb(c);Gb(a+1298368|0,b);x[a+1298404>>2]=13;yb(b);f=1;break o}a=P()|0;break Z}a=P()|0;break Y}a=P()|0;break Y}a=P()|0;break Q}a=P()|0;break Q}a=P()|0}zb(d+112|0)}yb(b);break b}a=P()|0;kd(d+112|0);break b}a=P()|0;break b}a=P()|0}zb(d+112|0);break b}a=P()|0;zb(e);break Q}a=P()|0;break Q}a=P()|0}kd(d+176|0);break b}th(d+16|0);continue}}f=0}_d(d+200|0)}hb=d+240|0;return f|0}a=P()|0;break b}a=P()|0;break f}a=P()|0;zb(d+176|0);break f}a=P()|0;break f}a=P()|0;break f}a=P()|0;break b}a=P()|0}zb(d+48|0);break b}a=P()|0;zb(d+112|0);break b}a=P()|0;break b}a=P()|0;zb(d+176|0)}_d(d+200|0)}S(a|0);p()}function SU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=hb-448|0;hb=d;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Yh(b,d+440|0)){break F}if(!FB(d+440|0)){break F}if(!c){o=1;break F}q=he(d+416|0,b);x[23420]=0;R(248,d+400|0,q|0);b=x[23420];x[23420]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[23420]=0;U(249,d+224|0,d+400|0,1229866575);b=x[23420];x[23420]=0;if((b|0)==1){break da}x[23420]=0;o=Q(250,d+224|0,d+384|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break fa}zb(d+224|0);if(!o){break G}x[23420]=0;R(234,a|0,524288);b=x[23420];x[23420]=0;ga:{if((b|0)==1){break ga}Cg(a);x[a+480208>>2]=12;H=a+480188|0,I=Wd(Lb(z[d+392>>1]),1,127),w[H>>1]=I;H=d,I=Lb(z[d+384>>1]),w[H+224>>1]=I;w[d+328>>1]=255;H=a+480192|0,I=z[Zc(d+224|0,d+328|0)>>1],w[H>>1]=I;H=d,I=Lb(z[d+386>>1]),w[H+224>>1]=I;w[d+328>>1]=3999;H=a+480190|0,I=z[Zc(d+224|0,d+328|0)>>1],w[H>>1]=I;x[23420]=0;b=W(251,a+1074312|0,6,1)|0;e=x[23420];x[23420]=0;if((e|0)==1){break ga}x[23420]=0;b=Q(252,b|0,21)|0;e=x[23420];x[23420]=0;if((e|0)==1){break ga}x[23420]=0;Q(252,b|0,13)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break ea}}b=P()|0;break b}b=P()|0;break a}b=P()|0;zb(d+224|0);break b}x[23420]=0;b=Q(1,d+368|0,9184)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,d+352|0,10209)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}Gb(a+1298356|0,b);yb(b);x[23420]=0;R(253,d+328|0,4297);b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;R(254,d+304|0,d+440|4);b=x[23420];x[23420]=0;if((b|0)==1){break g}x[23420]=0;R(254,d+280|0,d+440|5);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;X(99,d+224|0,d+328|0,d+304|0,d+280|0);b=x[23420];x[23420]=0;if((b|0)==1){break j}b=d+224|0;Gb(a+1298368|0,b);yb(b);yb(d+280|0);yb(d+304|0);b=d+328|0;cc(b);x[a+1298404>>2]=13;x[23420]=0;U(249,b|0,d+400|0,1312902469);b=x[23420];x[23420]=0;if((b|0)==1){break k}x[23420]=0;b=T(148,x[d+328>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break m}x[23420]=0;g=a+1298308|0;U(255,d+328|0,g|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;U(249,d+304|0,d+400|0,1397706311);b=x[23420];x[23420]=0;if((b|0)==1){break n}k=a+484360|0;e=a+484376|0;Gc(Yb(x[k>>2],y[e|0]));h=Lb(z[d+388>>1]);ha:{ia:{while(1){if(h>>>0<=(f&65535)>>>0){break ha}x[23420]=0;b=W(144,x[d+304>>2],x[d+312>>2],46)|0;i=x[23420];x[23420]=0;ja:{if((i|0)!=1){if(!b){break ha}x[23420]=0;R(256,d+304|0,d+224|0);b=x[23420];x[23420]=0;if((b|0)!=1){if(!De(g)){break ja}x[23420]=0;R(257,g|0,d+224|0);b=x[23420];x[23420]=0;if((b|0)!=1){break ja}}b=P()|0;break o}b=P()|0;break o}x[23420]=0;i=T(258,d+304|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break ca}b=Yb(x[a+484360>>2],y[e|0]);if(!uc(x[b>>2],x[b+4>>2])){x[23420]=0;b=T(259,k|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break ca}if((b|0)==255){break ha}b=Yb(x[a+484360>>2],y[e|0])}x[23420]=0;U(5,d+280|0,13,d+224|0);l=x[23420];x[23420]=0;if((l|0)!=1){x[23420]=0;R(260,b|0,d+280|0);b=x[23420];x[23420]=0;if((b|0)==1){break ia}yb(d+280|0);b=y[e|0];l=x[a+484360>>2];x[23420]=0;U(261,Yb(l,b)|0,d+304|0,i|0);b=x[23420];x[23420]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;break o}b=P()|0;yb(d+280|0);break o}zi(k,0);x[23420]=0;U(249,d+280|0,d+400|0,1229869908);b=x[23420];x[23420]=0;if((b|0)==1){break ba}x[23420]=0;b=T(262,x[d+280>>2])|0;f=x[23420];x[23420]=0;if((f|0)==1){break p}ka:{if(!b){break ka}k=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>z[k>>1]){x[23420]=0;U(249,d+200|0,d+400|0,1447382614);b=x[23420];x[23420]=0;if((b|0)!=1){break la}break p}x[23420]=0;R(263,d+280|0,d+224|0);e=x[23420];x[23420]=0;if((e|0)==1){break p}e=z[d+254>>1];x[23420]=0;b=W(239,a|0,b|0,Lb(e)|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Lb(z[d+254>>1])>>>0>3999){break na}e=d+112|0;tu(e,2,d+224|0);x[23420]=0;R(210,d+136|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break ma}e=d+136|0;Dc(b+492|0,e);xb(e);g=d+112|0;tu(g,2,d+224|0);x[23420]=0;R(210,e|0,g|0);e=x[23420];x[23420]=0;if((e|0)==1){break p}e=d+136|0;Dc(((Lb(z[d+254>>1])<<5)+a|0)+946304|0,e);xb(e);x[b>>2]=0;H=b,I=Lb(z[d+270>>1])+128&65535,x[H+8>>2]=I;xc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=z[d+254>>1];x[23420]=0;b=D(Lb(b),104)+a|0;R(264,b+484380|0,0);e=x[23420];x[23420]=0;if((e|0)==1){break p}H=d,I=Lb(z[d+256>>1]),w[H+136>>1]=I;w[d+112>>1]=64;H=b+484410|0,I=z[Zc(d+136|0,d+112|0)>>1]<<2,w[H>>1]=I;e=ac(z[d+258>>1]|z[d+260>>1]<<16);g=Wia(e,e>>31,8303,0)+4181|0;e=lb;H=b+484404|0,I=Hc(Xia(g,g>>>0<4181?e+1|0:e,8363,0),lb),x[H>>2]=I;e=ac(z[d+266>>1]|z[d+268>>1]<<16);if(!e){break na}g=Lb(z[d+272>>1]);if(!(g&3)){break na}h=e;e=ac(z[d+262>>1]|z[d+264>>1]<<16);x[b+484388>>2]=h+e;x[b+484384>>2]=e;b=b+484414|0;e=z[b>>1];w[b>>1]=e|2;if(!(g&2)){break na}w[b>>1]=e|6}f=f+1|0;continue}break}break p}b=x[d+212>>2];x[d+32>>2]=x[d+208>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+216>>2];x[23420]=0;b=x[d+204>>2];x[d+24>>2]=x[d+200>>2];x[d+28>>2]=b;X(265,d+24|0,0,a|0,0);b=x[23420];x[23420]=0;if((b|0)==1){break p}x[23420]=0;U(249,d+176|0,d+400|0,1346719318);b=x[23420];x[23420]=0;if((b|0)==1){break p}b=x[d+188>>2];x[d+8>>2]=x[d+184>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+192>>2];x[23420]=0;b=x[d+180>>2];x[d>>2]=x[d+176>>2];x[d+4>>2]=b;X(265,d|0,1,a|0,y[d+444|0]>2|0);b=x[23420];x[23420]=0;if((b|0)==1){break p}e=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}zb(d+280|0);x[23420]=0;U(249,d+224|0,d+400|0,1346458708);b=x[23420];x[23420]=0;if((b|0)==1){break q}x[23420]=0;b=T(166,x[d+224>>2])|0;f=x[23420];x[23420]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){x[23420]=0;U(249,d+280|0,d+400|0,1347305805);b=x[23420];x[23420]=0;if((b|0)==1){break t}x[23420]=0;Q(176,d+280|0,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break v}b=z[d+390>>1];x[23420]=0;l=a+484344|0;R(213,l|0,Lb(b)|0);b=x[23420];x[23420]=0;if((b|0)==1){break v}b=d+112|0;s=b|5;t=b|3;u=b|4;A=b|2;B=b|1;k=Qb(d+160|0);C=a+480188|0;f=0;while(1){if(Lb(z[d+390>>1])>>>0<=f>>>0){od(k);zb(d+280|0);if(!(c&4)){break $}f=0;if(!E){break aa}e=z[a+480188>>1];b=0;f=1;while(1){if((b|0)==(e|0)){break aa}g=(b<<5)+a|0;v[g+480288|0]=1;g=g+480280|0;x[g>>2]=x[g>>2]|67108864;b=b+1|0;continue}}x[23420]=0;b=T(258,d+224|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break x}x[23420]=0;e=T(266,d+224|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break y}x[23420]=0;U(178,d+112|0,d+224|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break z}e=d+112|0;g=jc(d+136|0,e);zb(e);x[23420]=0;e=W(214,l|0,f&65535,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break B}oa:{if(e){n=Jb(d+96|0);x[23420]=0;R(267,d+280|0,n|0);e=x[23420];x[23420]=0;if((e|0)==1){break oa}e=x[l>>2];x[23420]=0;R(268,_b(e,f)|0,n|0);e=x[23420];x[23420]=0;if((e|0)==1){break oa}e=0;h=_b(x[l>>2],f);r=pf(x[h>>2],x[x[h+48>>2]+12>>2],0);Gc(k);F=(b>>>0<=1?1:b)-1|0;pa:while(1){b=x[g>>2];x[23420]=0;b=W(144,b|0,x[d+144>>2],1)|0;h=x[23420];x[23420]=0;if((h|0)==1){break C}qa:{if(!b){break qa}x[23420]=0;i=T(194,g|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break C}if(!i){H=d,I=Db(x[k>>2]),x[H+88>>2]=I;h=Db(x[k+4>>2]);while(1){b=x[d+88>>2];if(Pb(b,h)){ie(_b(x[l>>2],f),Fe(ye(d+112|0,y[b|0],y[b+1|0]),e));Re(d+88|0);continue}else{Gc(k);if((e|0)==(F|0)){break qa}b=_b(x[l>>2],f);e=e+1|0;r=pf(x[b>>2],x[x[b+48>>2]+12>>2],e);continue pa}}}Rh(d+112|0);h=z[C>>1];x[23420]=0;b=T(194,g|0)|0;j=x[23420];x[23420]=0;ra:{sa:{if((j|0)!=1){h=h>>>0<i>>>0;i=D(i-1|0,6)+r|0;ta:{if(!(b&1)){break ta}x[23420]=0;j=T(194,g|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break C}m=h?d+112|0:i;if((j|0)!=31){if((j-1&255)>>>0>252){break ta}j=(D(j>>>4|0,12)+(j&15)|0)+13|0}else{j=255}v[m|0]=j}if(!(b&2)){break ra}x[23420]=0;j=T(194,g|0)|0;m=x[23420];x[23420]=0;if((m|0)!=1){break sa}}break C}v[(h?B:i+1|0)|0]=j}if(!(b&60)){continue}v[d+87|0]=0;v[d+86|0]=0;v[d+85|0]=0;v[d+84|0]=0;if(b&4){x[23420]=0;j=T(194,g|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break C}v[d+86|0]=j}if(b&8){x[23420]=0;j=T(194,g|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break C}v[d+84|0]=j}if(b&16){x[23420]=0;j=T(194,g|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break C}v[d+87|0]=j}if(b&32){x[23420]=0;b=T(194,g|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break C}v[d+85|0]=b}HU(d+87|0,d+85|0);HU(d+86|0,d+84|0);b=y[d+86|0];if(!(y[d+87|0]==13|b?(b|0)!=13:0)){uh(d+87|0,d+86|0);uh(d+85|0,d+84|0)}vq(d+88|0,d+87|0,d+85|0,d+86|0,d+84|0);if(GU(y[d+88|0],y[d+89|0])){b=x[gc(d+80|0,Db(x[k>>2]))>>2];x[23420]=0;U(269,k|0,b|0,d+88|0);b=x[23420];x[23420]=0;if((b|0)==1){break C}}v[(h?A:i+2|0)|0]=y[d+87|0];v[(h?u:i+4|0)|0]=y[d+85|0];b=y[d+86|0];v[(h?t:i+3|0)|0]=b;v[(h?s:i+5|0)|0]=y[d+84|0];if((b|0)==43){E=1;continue}if((b|0)!=31){continue}G=1;continue}break}xb(n)}zb(g);f=f+1|0;continue}break}break C}f=0;if(c&4){break aa}break H}b=P()|0;break b}b=P()|0;break o}b=P()|0;break o}x[d+160>>2]=-1778364416;x[d+164>>2]=-16756736;x[23420]=0;U(249,d+280|0,d+400|0,1146310725);b=x[23420];x[23420]=0;if((b|0)==1){break E}x[23420]=0;b=T(262,x[d+280>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break D}if(b){x[23420]=0;k=T(258,d+280|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break D}h=a+480188|0;b=0;e=f;while(1){ua:{if((b|0)==(k|0)){x[23420]=0;R(270,d+280|0,d+160|0);b=x[23420];x[23420]=0;if((b|0)!=1){break ua}break D}x[23420]=0;g=T(194,d+280|0)|0;i=x[23420];x[23420]=0;va:{wa:{if((i|0)!=1){if(z[h>>1]<=b>>>0){break va}if(!f){break wa}i=((b<<5)+a|0)+480280|0;x[i>>2]=x[i>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}e=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=e&1}zb(d+280|0);if(!f){break $}x[23420]=0;Y(271,a+906300|0);b=x[23420];x[23420]=0;if((b|0)==1){break _}b=a+906324|0;x[b>>2]=655376;x[b+4>>2]=0;b=a+906316|0;x[b>>2]=810369604;x[b+4>>2]=1869112133;x[d+280>>2]=0;f=a+906348|0;DU(a+906332|0,f,d+280|0);x[23420]=0;b=Q(54,d+136|0,9458)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Z}BB(f,b);xb(b);x[23420]=0;b=Q(54,d+112|0,9422)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Y}su(a+906380|0,b);xb(b);x[23420]=0;b=a+906304|0;R(272,b|0,8);f=x[23420];x[23420]=0;if((f|0)==1){break _}CU(d+280|0,y[d+161|0],y[d+163|0],y[d+165|0],y[d+167|0]);f=x[d+284>>2];b=x[b>>2];e=x[d+280>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(!G){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+88>>2]=D(b,127)>>>5;x[23420]=0;R(273,d+160|0,4054);e=x[23420];x[23420]=0;if((e|0)==1){break X}x[23420]=0;R(274,d+96|0,d+88|0);e=x[23420];x[23420]=0;if((e|0)==1){break W}x[23420]=0;U(275,d+280|0,d+160|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)==1){break V}e=d+280|0;ue(d+72|0,e);Xe(pe(f,b),x[d+72>>2],x[d+76>>2]);xb(e);xb(d+96|0);e=d+160|0;Sb(e);x[23420]=0;R(273,e|0,4036);e=x[23420];x[23420]=0;if((e|0)==1){break T}x[23420]=0;R(274,d+96|0,d+88|0);e=x[23420];x[23420]=0;if((e|0)==1){break S}x[23420]=0;U(275,d+280|0,d+160|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)==1){break R}e=d+280|0;ue(d- -64|0,e);Xe(pe(f,b+32|0),x[d+64>>2],x[d+68>>2]);xb(e);xb(d+96|0);e=d+160|0;Sb(e);x[23420]=0;R(273,e|0,4027);e=x[23420];x[23420]=0;if((e|0)==1){break P}x[23420]=0;R(274,d+96|0,d+88|0);e=x[23420];x[23420]=0;if((e|0)==1){break O}x[23420]=0;U(275,d+280|0,d+160|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)==1){break N}e=d+280|0;ue(d+56|0,e);Xe(pe(f,b- -64|0),x[d+56>>2],x[d+60>>2]);xb(e);xb(d+96|0);e=d+160|0;Sb(e);x[23420]=0;R(273,e|0,4e3);e=x[23420];x[23420]=0;if((e|0)==1){break L}x[23420]=0;R(274,d+96|0,d+88|0);e=x[23420];x[23420]=0;if((e|0)==1){break K}x[23420]=0;U(275,d+280|0,d+160|0,d+96|0);e=x[23420];x[23420]=0;if((e|0)==1){break J}e=d+280|0;ue(d+48|0,e);Xe(pe(f,b+96|0),x[d+48>>2],x[d+52>>2]);b=b+1|0;xb(e);xb(d+96|0);Sb(d+160|0);continue}}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break r}b=P()|0;break U}b=P()|0;xb(d+96|0)}Sb(d+160|0);break r}b=P()|0;break r}b=P()|0;break Q}b=P()|0;xb(d+96|0)}Sb(d+160|0);break r}b=P()|0;break r}b=P()|0;break M}b=P()|0;xb(d+96|0)}Sb(d+160|0);break r}b=P()|0;break r}b=P()|0;break I}b=P()|0;xb(d+96|0)}Sb(d+160|0);break r}x[23420]=0;U(249,d+280|0,d+400|0,1397575756);b=x[23420];x[23420]=0;xa:{if((b|0)!=1){x[23420]=0;b=T(166,x[d+280>>2])|0;f=x[23420];x[23420]=0;if((f|0)!=1){ya:{f=1;if(!(c&2)|b^1){break xa}c=a+480190|0;while(1){e=f&65535;if(e>>>0>z[c>>1]){break xa}x[23420]=0;b=T(266,d+280|0)|0;g=x[23420];x[23420]=0;za:{if((g|0)!=1){x[23420]=0;g=T(266,d+280|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break ya}if(!(b&7)){break za}e=(D(e,104)+a|0)+484380|0;x[e>>2]=g;b=_c(d+160|0,b&4?32:b&2?16:8,1,1,0);x[23420]=0;W(207,b|0,e|0,d+280|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=P()|0;zb(d+280|0);break r}b=P()|0;break r}zb(d+280|0);zb(d+224|0);zb(d+304|0);zb(d+328|0)}_d(d+400|0);zb(q)}hb=d+448|0;return o|0}b=P()|0;break r}b=P()|0;zb(d+280|0);break r}b=P()|0;xb(n);break A}b=P()|0}zb(g);break w}b=P()|0;break w}b=P()|0;break w}b=P()|0}od(k);break u}b=P()|0}zb(d+280|0);break r}b=P()|0;break r}b=P()|0}zb(d+224|0);break o}b=P()|0;break o}b=P()|0;zb(d+280|0)}zb(d+304|0);break l}b=P()|0;break l}b=P()|0}zb(d+328|0);break b}b=P()|0;break b}b=P()|0;yb(d+280|0);break h}b=P()|0}yb(d+304|0);break f}b=P()|0}cc(d+328|0);break b}b=P()|0;break b}b=P()|0;break b}b=P()|0}_d(d+400|0)}zb(q);S(b|0);p()}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,V=0;e=hb-496|0;hb=e;zc(b);j=hb-16|0;hb=j;m=e+288|0;jQ(j+8|0,m);f=x[j+12>>2];o=b;mc(j,x[b>>2],x[b+8>>2],x[j+8>>2],x[j+12>>2]);b=x[j+4>>2];if((b|0)==(f|0)){$b(o,x[j+12>>2])}hb=j+16|0;b=(b|0)==(f|0);if(!b){iQ(m)}a:{if(!b){break a}if(!kQ(e+288|0)){break a}if(!c){d=1;break a}Dd(a,134217728);b=e+8|0;rg(b,3936);x[23420]=0;U(627,e+120|0,b|0,z[e+292>>1]);b=x[23420];x[23420]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=e+120|0;Gb(a+1298344|0,b);yb(b);cc(e+8|0);b=Vb(b,8876);Gb(a+1298356|0,b);yb(b);x[a+480188>>2]=4;x[a+1298404>>2]=13;O=a,V=Lb(z[e+424>>1]),x[O+480196>>2]=V;b=z[e+428>>1];x[a+480260>>2]=56;x[a+480264>>2]=13696;O=a,V=hQ(Lb(b)),x[O+480204>>2]=V;rq(Yb(x[a+484360>>2],y[a+484376|0]),e+296|0,y[e+294|0]);r=a+480190|0;i=a+480188|0;q=Qb(e+272|0);u=Qb(e+256|0);h:{i:{j:{k:{l:{while(1){if(Lb(z[e+488>>1])>>>0<=(l&65535)>>>0){break k}x[23420]=0;b=T(258,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}w[e+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Lb(z[e+490>>1]);if((Lb(z[e+292>>1])|0)==2){x[23420]=0;b=T(266,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break h}d=b-2|0}x[23420]=0;U(178,e+8|0,o|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}b=e+8|0;j=jc(e+120|0,b);zb(b);C=z[Ve(r,e+232|0)>>1];w[r>>1]=C;x[23420]=0;m=D(z[e+232>>1],104)+a|0;f=m+484380|0;R(264,f|0,1);b=x[23420];x[23420]=0;m:{n:{o:{if((b|0)==1){break o}if(Lb(z[e+292>>1])>>>0>1){break n}x[23420]=0;R(628,j|0,m+484423|0);b=x[23420];x[23420]=0;if((b|0)==1){break o}x[23420]=0;Q(176,j|0,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break o}x[23420]=0;U(311,j|0,((z[e+232>>1]<<5)+a|0)+946304|0,30);b=x[23420];x[23420]=0;if((b|0)!=1){break m}}f=P()|0;break f}b=Jb(e+8|0);x[23420]=0;U(336,j|0,b|0,257);d=x[23420];x[23420]=0;p:{q:{if((d|0)==1){break q}ze(m+484423|0,b);x[23420]=0;Q(176,j|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break q}x[23420]=0;U(336,j|0,b|0,31);d=x[23420];x[23420]=0;if((d|0)==1){break q}Dc(((z[e+232>>1]<<5)+a|0)+946304|0,b);if(!(v[e+128|0]&1)){break p}x[23420]=0;Q(176,j|0,1)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break p}}f=P()|0;xb(b);break f}xb(b)}x[23420]=0;R(629,j|0,e+8|0);b=x[23420];x[23420]=0;if((b|0)==1){break l}h=hb-16|0;hb=h;d=ac(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));x[f>>2]=d;v[h+15|0]=y[e+12|0];v[h+14|0]=64;O=f,V=y[Wb(h+15|0,h+14|0)|0]<<2,w[O+30>>1]=V;g=ac(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24));x[f+4>>2]=g;b=ac(y[e+14|0]|y[e+15|0]<<8|(y[e+16|0]<<16|y[e+17|0]<<24))+ac(y[e+18|0]|y[e+19|0]<<8|(y[e+20|0]<<16|y[e+21|0]<<24))|0;x[f+8>>2]=b;if(d>>>0<=g>>>0){g=d-1|0;x[f+4>>2]=g}if(b>>>0>d>>>0){x[f+8>>2]=d;b=d}r:{if(b>>>0<g>>>0){x[f+4>>2]=0;x[f+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}w[f+34>>1]=z[f+34>>1]|2;O=Cb(f+68|0,0),V=g,x[O>>2]=V}hb=h+16|0;s:{t:{u:{switch(Lb(z[e+292>>1])|0){case 2:v[m+484417|0]=y[e+26|0]<<3;break;case 0:break t;default:break u}}x[23420]=0;R(202,u|0,C|0);b=x[23420];x[23420]=0;if((b|0)==1){break l}x[23420]=0;R(630,q|0,C|0);b=x[23420];x[23420]=0;if((b|0)==1){break l}f=Hd(x[q>>2],z[e+232>>1]-1|0);Gc(f);x[23420]=0;b=T(258,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break j}d=x[o+8>>2];h=x[o>>2];x[23420]=0;d=W(144,h|0,d|0,b<<3)|0;h=x[23420];x[23420]=0;if((h|0)==1){break j}if(!d){break s}x[23420]=0;R(631,f|0,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break j}d=0;x[e+248>>2]=0;if(!(!(y[m+484414|0]&2)|b)){b=x[m+484384>>2];x[e+240>>2]=b;d=x[m+484388>>2];x[23420]=0;x[e+244>>2]=d-b;R(632,f|0,e+240|0);b=x[23420];x[23420]=0;if((b|0)!=1){break t}f=P()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break t}x[23420]=0;m=T(266,o|0)|0;h=x[23420];x[23420]=0;v:{if((h|0)==1){break v}x[23420]=0;x[e+240>>2]=m;m=T(266,o|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break v}x[23420]=0;x[e+244>>2]=m;R(632,f|0,e+240|0);m=x[23420];x[23420]=0;if((m|0)==1){break v}d=d+1|0;continue}break}f=P()|0;break f}zb(j);l=l+1|0;continue}break}zb(j);break c}f=P()|0;break f}w:{x:{y:{z:{if(Lb(z[e+292>>1])){B=y[e+295|0];w[e+238>>1]=4;E=128;break z}x[23420]=0;E=T(258,o|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){f=P()|0;break e}b=z[e+292>>1];B=y[e+295|0];w[e+238>>1]=4;if(!Lb(b)){break y}}d=x[o+8>>2];f=0;while(1){A:{if((f&65535)>>>0>=E>>>0){break A}x[23420]=0;b=T(258,o|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break x}if((b|0)==65535){break A}x[23420]=0;B=T(258,o|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break x}x[23420]=0;b=T(258,o|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break x}w[e+238>>1]=b;if(b>>>0>127){break c}O=i,V=z[Ve(i,e+238|0)>>1],w[O>>1]=V;x[23420]=0;Q(176,o|0,D(b,B)<<2)|0;b=x[23420];x[23420]=0;if((b|0)==1){break x}f=f+1|0;continue}break}x[23420]=0;Q(143,o|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break w}}b=z[i>>1];x[23420]=0;F=Q(633,e+240|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){K=a+484344|0;N=c&1;G=Lb(z[e+426>>1]);b=0;j=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=E>>>0){break E}F:{if(!Lb(z[e+292>>1])){d=z[e+238>>1];f=b;break F}x[23420]=0;f=T(258,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if((f|0)==65535){break E}x[23420]=0;B=T(258,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}x[23420]=0;d=T(258,o|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break B}w[e+238>>1]=d}m=x[o+8>>2];h=x[o>>2];x[23420]=0;g=d&65535;H=B&65535;d=H<<2;m=W(144,h|0,m|0,D(g,d)|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break B}if(!m){break E}if(!N){break D}x[23420]=0;L=f&65535;f=W(214,K|0,L|0,H|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break B}if(!f){break D}t=0;G:while(1){if((t|0)==(H|0)){break C}f=0;d=_b(x[K>>2],L);i=pf(x[d>>2],x[x[d+48>>2]+12>>2],t);I=0;m=0;H:{I:{J:{switch((G&3)-1|0){case 0:m=!(t&3);break I;case 1:m=!(t&1);break I;case 2:break J;default:break H}}m=(t&3)!=3}}while(1){if(z[e+238>>1]<=f>>>0){t=t+1|0;continue G}d=x[F>>2];x[23420]=0;R(335,e+232|0,o|0);h=x[23420];x[23420]=0;if((h|0)==1){break B}h=D(f,9)+d|0;d=e+232|0;g=jd(d);s=Ue(d);l=i+D(f,6)|0;v[l+1|0]=y[e+232|0];k=y[g|0];v[l|0]=k;g=y[Bi(d)|0];v[l+5|0]=g;n=l+5|0;if(k){v[l|0]=k+25;v[h+8|0]=0;v[h|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[h+3|0]=0;v[h+4|0]=0;v[h+5|0]=0;v[h+6|0]=0;v[h+7|0]=0;g=y[n|0]}k=g&255;s=y[s|0];K:{if(s>>>0>=240){d=k|(s&15)<<8;if(d){O=n,V=ho(+(hQ(d)>>>0)/1e4),v[O|0]=V;v[l+3|0]=17;break K}v[l+3|0]=0;break K}J=k>>>4|0;M=k<<4;d=J|M;L:{switch(s|0){case 0:d=i+D(f,6)|0;if(g&255){v[d+3|0]=1;break K}v[d+3|0]=0;break K;case 1:v[(i+D(f,6)|0)+3|0]=2;break K;case 2:v[(i+D(f,6)|0)+3|0]=3;break K;case 3:v[e+228|0]=15;O=h,V=y[Wb(n,e+228|0)|0]|16,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 4:v[e+228|0]=15;O=h,V=y[Wb(n,e+228|0)|0]|32,v[O|0]=V;v[h+7|0]=0;v[h+1|0]=0;v[h+2|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 5:v[h+7|0]=0;v[h+2|0]=0;v[h+1|0]=g;v[h|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 6:v[h+7|0]=0;v[h+2|0]=g;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 7:v[(i+D(f,6)|0)+3|0]=23;j=0;break K;case 8:v[(i+D(f,6)|0)+3|0]=0;j=d;break K;case 9:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|16,v[O|0]=V;break K;case 10:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|32,v[O|0]=V;break K;case 11:v[h+3|0]=d;v[(i+D(f,6)|0)+3|0]=0;break K;case 12:d=i+D(f,6)|0;v[d+4|0]=g;v[d+2|0]=1;v[h+3|0]=0;v[d+3|0]=0;break K;case 13:M:{N:{if((g&255)>>>0>=16){v[(i+D(f,6)|0)+2|0]=4;g=(g&240)>>>4|0;break N}if(!(k&15)){break M}v[(i+D(f,6)|0)+2|0]=3}v[(i+D(f,6)|0)+4|0]=g}v[h+3|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 14:v[(i+D(f,6)|0)+3|0]=19;v[n|0]=!(g&255);break K;case 15:v[(i+D(f,6)|0)+3|0]=16;v[n|0]=(g&240)>>>4;G=g&15;break K;case 16:v[h+5|0]=0;v[h+4|0]=g;v[(i+D(f,6)|0)+3|0]=0;break K;case 17:v[h+6|0]=k&15?g:0;v[(i+D(f,6)|0)+3|0]=0;break K;case 18:v[(i+D(f,6)|0)+3|0]=14;break K;case 19:v[h+8|0]=0;v[h+7|0]=g;v[h+2|0]=0;v[h|0]=0;v[h+1|0]=0;v[(i+D(f,6)|0)+3|0]=0;break K;case 20:v[(i+D(f,6)|0)+3|0]=12;break K;case 22:d=y[l+1|0];O:{if(!d){break O}k=x[q>>2];if(vd(k,x[q+4>>2])>>>0<d>>>0){break O}g=g-1|0;v[n|0]=g;x[23420]=0;T(634,e+120|0)|0;s=x[23420];x[23420]=0;if((s|0)==1){break B}x[e+228>>2]=9;d=Hd(k,d-1|0);O=e,V=vd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Hb(e+228|0,e+116|0)>>2]<=(g&255)>>>0){break O}d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[n|0]}v[(i+D(f,6)|0)+3|0]=0;break K;case 23:d=y[l+1|0];P:{if(!d){break P}k=x[q>>2];if(vd(k,x[q+4>>2])>>>0<d>>>0){break P}g=g-1|0;v[n|0]=g;d=Hd(k,d-1|0);k=x[d>>2];s=vd(k,x[d+4>>2]);d=g&255;if(s>>>0<=d>>>0){break P}d=Hd(k,d);g=z[d+8>>1];Q:{if(g){break Q}g=0;k=z[r>>1];if(!Qh(k)){break Q}g=k+1|0;w[r>>1]=g;w[d+8>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 24:d=y[l+1|0];R:{if(!d){break R}k=x[q>>2];if(vd(k,x[q+4>>2])>>>0<d>>>0){break R}g=g-1|0;v[n|0]=g;x[23420]=0;T(634,e+8|0)|0;s=x[23420];x[23420]=0;if((s|0)==1){break B}x[e+228>>2]=9;d=Hd(k,d-1|0);O=e,V=vd(x[d>>2],x[d+4>>2]),x[O+116>>2]=V;if(A[Hb(e+228|0,e+116|0)>>2]>(g&255)>>>0){d=i+D(f,6)|0;v[d+2|0]=15;v[d+4|0]=y[n|0]}d=bc(x[u>>2],y[l+1|0]-1|0);g=z[d>>1];S:{if(g){break S}g=0;k=z[r>>1];if(!Qh(k)){break S}g=k+1|0;w[r>>1]=g;w[d>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 25:d=y[l+1|0];T:{if(!d){break T}k=x[q>>2];if(vd(k,x[q+4>>2])>>>0<d>>>0){break T}g=g-1|0;v[n|0]=g;d=Hd(k,d-1|0);k=x[d>>2];s=vd(k,x[d+4>>2]);d=g&255;if(s>>>0<=d>>>0){break T}d=Hd(k,d);g=z[d+10>>1];U:{if(g){break U}g=0;k=z[r>>1];if(!Qh(k)){break U}g=k+1|0;w[r>>1]=g;w[d+10>>1]=g}v[l+1|0]=g}v[(i+D(f,6)|0)+3|0]=0;break K;case 29:v[(i+D(f,6)|0)+3|0]=11;v[n|0]=d;if(k&15){v[n|0]=M|15;break K}if((g&255)>>>0<16){break K}v[n|0]=J|240;break K;case 32:if((g&255)>>>0>=16){v[h+3|0]=J;v[(i+D(f,6)|0)+3|0]=0;break K}v[(i+D(f,6)|0)+3|0]=19;v[n|0]=g|192;break K;case 33:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|208,v[O|0]=V;break K;case 34:v[(i+D(f,6)|0)+3|0]=19;v[e+228|0]=15;O=n,V=y[Wb(n,e+228|0)|0]|144,v[O|0]=V;break K;case 73:v[(i+D(f,6)|0)+3|0]=10;break K;case 78:if((g&112|128)==224){v[(i+D(f,6)|0)+3|0]=19;break K}v[(i+D(f,6)|0)+3|0]=0;break K;case 79:d=i+D(f,6)|0;if((g&255)>>>0<=31){v[d+3|0]=16;G=0;break K}v[d+3|0]=17;break K;default:break L}}v[(i+D(f,6)|0)+3|0]=0}k=0;g=y[h+3|0];if(!(y[l+2|0]|!g)){V:{if(g>>>0>=16){v[l+2|0]=5;g=g>>>4|0;break V}v[l+2|0]=6}v[l+4|0]=g;k=1}W:{if(y[l+3|0]){break W}d=y[h+1|0];X:{if(d){v[l+3|0]=2;break X}d=y[h+2|0];if(d){v[l+3|0]=3;break X}d=y[h|0];if(d){v[l+3|0]=19;break X}d=y[h+7|0];if(d){v[l+3|0]=4;v[h+8|0]=d;break X}d=y[h+4|0];if(d){v[l+3|0]=5;v[h+5|0]=d;break X}d=y[h+3|0];if(!(!d|k)){v[l+3|0]=11;v[n|0]=d;if(d&15){d=d|-16;break X}if(d>>>0<16){break W}d=d|15;break X}d=y[h+6|0];if(d){v[l+3|0]=8;break X}if(m){v[l+3|0]=20;m=0;d=97;break X}m=0;if(I){break W}d=j&255;if(!d){break W}v[l+3|0]=24;v[n|0]=j;if(j&15){d=j|-16}else{I=1;if(d>>>0<16){break W}d=j|15}I=1}v[n|0]=d}f=f+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];k=1;wh(a,1);if(Lb(z[e+292>>1])){Y:{while(1){b=x[o+8>>2];d=x[o>>2];x[23420]=0;b=W(144,d|0,b|0,2)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if(!b){break Y}x[23420]=0;b=T(258,o|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break B}if((b|0)==65535){break Y}x[23420]=0;Q(176,o|0,2)|0;b=x[23420];x[23420]=0;if((b|0)==1){break B}x[23420]=0;b=T(266,o|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;Q(176,o|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break B}x[23420]=0;Q(176,o|0,34)|0;b=x[23420];x[23420]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=k&65535;if(b>>>0>C>>>0){break Z}_:{d=(D(b,104)+a|0)+484380|0;if(!x[d>>2]){break _}c=_c(e+232|0,8,1,0,0);x[23420]=0;W(207,c|0,d|0,o|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break B}c=x[q>>2];if(vd(c,x[q+4>>2])>>>0<b>>>0){break _}g=b-1|0;m=Hd(c,g);c=0;b=0;i=hb-112|0;hb=i;$:{h=x[d>>2];if(!Td(h,x[d+20>>2])){break $}n=x[m>>2];j=vd(n,x[m+4>>2]);if(j>>>0<2){break $}f=fo(i+8|0,d);x[f+20>>2]=0;x[f>>2]=0;aa:{while(1){if((c|0)==(j|0)){break aa}ba:{l=Hd(n,c);r=x[l>>2];if(r>>>0>=h>>>0){break ba}l=x[l+4>>2];if(l>>>0>h-r>>>0|268435456-l>>>0<b>>>0){break ba}b=b+l|0;x[f>>2]=b;c=c+1|0;continue}break}j=c}if(!Ag(f)){break $}l=f+68|0;b=0;c=0;while(1){if((c|0)==(j|0)){mm(d);b=fo(d,f);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break $}n=x[f+20>>2]+b|0;r=x[d+20>>2];h=Hd(x[m>>2],c);pc(n,r+x[h>>2]|0,x[h+4>>2]);x[h>>2]=b;if(c-10>>>0>=4294967287){O=Cb(l,c-1|0),V=b,x[O>>2]=V}c=c+1|0;b=x[h+4>>2]+b|0;continue}}hb=i+112|0;b=z[bc(x[u>>2],g)>>1];if(b){Rz(d,(D(b,104)+a|0)+484380|0,0,x[d>>2],0)}b=Hd(x[q>>2],g);O=e,V=Db(x[b>>2]),x[O+232>>2]=V;c=Db(x[b+4>>2]);while(1){b=x[e+232>>2];if(!Pb(b,c)){break _}j=z[b+8>>1];if(j){Rz(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}j=z[b+10>>1];if(j){Rz(d,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}_p(e+232|0);continue}}k=k+1|0;continue}}At(F);d=1;break b}x[23420]=0;Q(176,o|0,D(d,z[e+238>>1])|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break C}break B}b=b+1|0;continue}break}f=P()|0;At(F);break e}f=P()|0;break e}f=P()|0;break e}f=P()|0;break e}f=P()|0;break f}f=P()|0;break e}f=P()|0;break e}f=P()|0;cc(e+8|0);break d}f=P()|0;break e}zb(j)}od(u);fQ(q)}S(f|0);p()}d=0}od(u);fQ(q)}hb=e+496|0;return d|0}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-592|0;hb=d;zc(b);a:{if(!WA(b,d+512|0)){break a}if(!vP(d+512|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(uP(d+512|0),lb))){break a}b:{if(!c){break b}Dd(a,4);Cg(a);v[a+1074368|0]=4;k=Jb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Ob(l,17616,20)|x[d+572>>2]!=276)){if(z[d+570>>1]<260){break g}e=YA(d+529|0,0,20)?1154:34;break e}if(!Ob(l,17595,20)){e=1;break e}g=d- -64|0;tj(g,3,l);x[23420]=0;R(210,d+104|0,g|0);g=x[23420];x[23420]=0;h:{i:{if((g|0)!=1){x[23420]=0;U(11,d+208|0,5,d+104|0);g=x[23420];x[23420]=0;if((g|0)==1){break i}g=d+208|0;Gb(k,g);yb(g);xb(d+104|0);if(Ob(l,17433,8)){break h}e=1048;break e}f=P()|0;break c}f=P()|0;xb(d+104|0);break c}if(!Ob(l,17333,12)){e=16;if(!Ob(d+562|0,17637,8)){break e}v[a+1074368|0]=5;break e}if(Ob(l,11515,20)){break f}}e=48;break e}if(!Ob(l,26928,15)){x[23420]=0;g=Q(252,a+1074312|0,54)|0;e=x[23420];x[23420]=0;C=1;if((e|0)==1){break d}x[23420]=0;Q(252,g|0,51)|0;g=x[23420];x[23420]=0;e=16;if((g|0)==1){break d}break e}j:{if(Ob(l,26944,14)){if(Ob(l,26959,14)){break j}}x[23420]=0;g=Q(252,a+1074312|0,57)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}x[23420]=0;Q(252,g|0,51)|0;g=x[23420];x[23420]=0;e=16;if((g|0)!=1){break e}break d}e=Ob(l,17421,11)?16:256}g=d+104|0;t=d+529|0;tj(g,3,t);x[23420]=0;R(210,d+208|0,g|0);g=x[23420];x[23420]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Ac(a+1298308|0,g);xb(g);x[a+480260>>2]=1;x[a+480264>>2]=31999;Ze(Yb(x[a+484360>>2],y[a+484376|0]),z[d+578>>1]);w[a+480188>>1]=z[d+580>>1];w[d+208>>1]=z[d+584>>1];w[d+104>>1]=255;G=a+480192|0,H=z[Zc(g,d+104|0)>>1],w[G>>1]=H;g=z[d+588>>1];if(g){x[a+480196>>2]=g}g=z[d+590>>1];if(g){g=D(g,1e4);g=g>>>0>=1e7?1e7:g;x[a+480204>>2]=g>>>0<=32e4?32e4:g}g=z[d+586>>1];x[a+480208>>2]=g<<4&16|g<<3&32768;f=y[a+484376|0];n=x[a+484360>>2];x[23420]=0;ea(326,Yb(n,f)|0,b|0,z[d+576>>1],65535,65535);f=x[23420];x[23420]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(z[d+576>>1]|f>>>0>1023)){g=y[a+484376|0];e=x[a+484360>>2];x[23420]=0;Y(684,Yb(e,g)|0);g=x[23420];x[23420]=0;if((g|0)==1){break d}}x[23420]=0;Q(143,b|0,x[d+572>>2]+60|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(z[d+570>>1]>=260){x[23420]=0;U(685,b|0,d+512|0,a|0);g=x[23420];x[23420]=0;if((g|0)==1){break d}}v[d+495|0]=0;u=c&2;E=d+122|0;o=d+241|0;n=Qb(d+480|0);F=a+480192|0;q=1;g=-1;while(1){e=q&65535;if(e>>>0>z[F>>1]){if(!(!(f&2)|r&255)){f=YA(t,0,20)?f|16:f}if(z[d+570>>1]>259){break o}if(c&3){x[23420]=0;U(685,b|0,d+512|0,a|0);c=x[23420];x[23420]=0;if((c|0)==1){break n}}if(!u){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>z[o>>1]){break o}i=x[n>>2];x[23420]=0;W(207,Cb(i,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}x[23420]=0;i=T(145,b|0)|0;h=x[23420];x[23420]=0;r:{s:{if((h|0)!=1){mg(b,4);x[23420]=0;U(686,b|0,d+208|0,(i?i:263)|0);i=x[23420];x[23420]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=x[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}x[a+1074308>>2]=16777381;x[23420]=0;f=Q(1,d+192|0,13208)|0;i=x[23420];x[23420]=0;if((i|0)!=1){Gb(k,f);yb(f);f=17;break t}f=P()|0;break k}x[a+1074308>>2]=16777395;x[23420]=0;f=Q(1,d+176|0,13123)|0;i=x[23420];x[23420]=0;if((i|0)!=1){Gb(k,f);yb(f);f=17;break t}f=P()|0;break k}if(y[d+235|0]|y[d+236|0]<<8){break t}i=x[d+208>>2];if(!(!(f&2)|(y[d+237|0]|y[d+238|0]<<8|(y[d+239|0]<<16|y[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}x[23420]=0;i=W(239,a|0,e|0,0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[23420]=0;R(687,d+208|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break p}e=y[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=y[d+235|0]|y[d+236|0]<<8;if(!e){break r}x[23420]=0;h=y[d+455|0];j=y[d+451|0]|y[d+452|0]<<8;m=y[d+450|0];s=y[d+449|0];U(688,d+160|0,a|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break q}f=h|(j|(m|s))?f&-4:f;i=x[i>>2]+236|0;e=12;h=x[d+160>>2];j=Mc(h,x[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(z[d+570>>1]>259){Gc(n)}e=0;x[23420]=0;i=Q(689,d+144|0,y[d+235|0]|y[d+236|0]<<8)|0;h=x[23420];x[23420]=0;if((h|0)!=1){break w}f=P()|0;break v}m=bc(i,e);if(j>>>0>z[m>>1]){G=m,H=z[bc(h,z[bc(i,e)>>1])>>1],w[G>>1]=H}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=y[d+235|0]|y[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(z[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=y[Cb(x[n>>2],e)+3|0];h=x[Cb(x[i>>2],e)>>2];x[23420]=0;U(178,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[23420];x[23420]=0;if((h|0)!=1){j=d- -64|0;h=jc(d+104|0,j);zb(j);j=x[d+160>>2];if(!(!u|Mc(j,x[d+164>>2])>>>0<=e>>>0)){m=z[bc(j,e)>>1];j=Cb(x[n>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[23420]=0;x[d+56>>2]=j;x[d>>2]=j;j=fa(690,(D(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break B}B=j^1|B}zb(h);e=e+1|0;h=y[d+235|0]|y[d+236|0]<<8;continue}break}f=P()|0;break x}f=P()|0;zb(h);break x}x[23420]=0;R(691,b|0,d+104|0);h=x[23420];x[23420]=0;if((h|0)==1){break y}h=d- -64|0;j=y[d+118|0];C:{if(!(j&48|y[d+121|0]!=173)){_c(h,8,1,0,10);break C}_c(h,j&16?16:8,j&32?3:1,0,2)}x[23420]=0;R(692,n|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){G=Cb(x[i>>2],e),H=x[d+104>>2],x[G>>2]=H;m=y[d+121|0];h=x[d+160>>2];if(Mc(h,x[d+164>>2])>>>0>e>>>0){j=z[bc(h,e)>>1];x[23420]=0;h=(D(j,104)+a|0)+484380|0;R(693,d+104|0,h|0);s=x[23420];x[23420]=0;if((s|0)==1){break A}v[h+38|0]=y[o+202|0];v[h+39|0]=y[o+203|0];v[h+40|0]=y[o+204|0];v[h+41|0]=y[o+205|0];h=d+88|0;ml(h,3,E);x[23420]=0;R(210,d- -64|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break z}h=d- -64|0;Dc(((j<<5)+a|0)+946304|0,h);xb(h);f=(y[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}r=m|r;e=e+1|0;continue}break}f=P()|0;break x}f=P()|0;break x}f=P()|0;break x}f=P()|0}tc(i)}od(d+160|0);break k}f=P()|0;break k}tc(i);od(d+160|0)}q=q+1|0;continue}}f=P()|0;break c}f=P()|0;break k}f=P()|0;break k}D:{if(!(B&1)){break D}x[23420]=0;c=Q(1,d+104|0,16448)|0;e=x[23420];x[23420]=0;E:{if((e|0)!=1){e=x[a+1298464>>2];x[23420]=0;U(353,e|0,2,c|0);e=x[23420];x[23420]=0;if((e|0)==1){break E}yb(c);break D}f=P()|0;break k}f=P()|0;yb(c);break k}x[23420]=0;c=Q(348,b|0,5519)|0;e=x[23420];x[23420]=0;if((e|0)==1){break n}if(c){x[23420]=0;c=T(145,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break n}x[23420]=0;X(317,a+1298332|0,b|0,c|0,0);c=x[23420];x[23420]=0;if((c|0)==1){break n}f=f|16}x[23420]=0;o=Q(348,b|0,13932)|0;c=x[23420];x[23420]=0;if((c|0)==1){break l}if(o){x[23420]=0;c=T(145,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}x[23420]=0;e=a+901404|0;U(694,b|0,e|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break l}XA(e);f=f|16}x[23420]=0;c=Q(348,b|0,13698)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}if(!c){break m}x[23420]=0;c=T(145,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){w[d+208>>1]=c>>>5;G=d,H=of(x[a+484344>>2],x[a+484348>>2]),w[G+64>>1]=H;c=z[Zc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}x[23420]=0;R(518,b|0,d+208|0);i=x[23420];x[23420]=0;F:{if((i|0)==1){break F}i=x[a+484344>>2];x[23420]=0;R(519,_b(i,e)|0,d+208|0);i=x[23420];x[23420]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[23420]=0;c=Q(348,b|0,13703)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}G:{if(!c){break G}x[23420]=0;c=T(145,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){w[d+208>>1]=(c>>>0)/20;w[d+64>>1]=z[a+480188>>1];c=z[Zc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}x[23420]=0;U(359,b|0,((e<<5)+a|0)+480289|0,20);i=x[23420];x[23420]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;break k}f=P()|0;break k}c=x[b+8>>2];e=x[b>>2];x[23420]=0;c=W(144,e|0,c|0,8)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=x[b+8>>2];x[23420]=0;Q(360,a|0,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break K}f=(c|0)==x[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){x[a+1074308>>2]=17367040;x[23420]=0;c=Q(1,d+208|0,14539)|0;e=x[23420];x[23420]=0;if((e|0)!=1){Gb(k,c);yb(c);break L}f=P()|0;break k}if(!(f&2)){break L}x[a+1074308>>2]=18219008;x[23420]=0;c=Q(1,d+208|0,14696)|0;e=x[23420];x[23420]=0;if((e|0)==1){break J}Gb(k,c);yb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Ob(l,17433,8)){x[23420]=0;c=Q(695,d- -64|0,d+558|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break S}x[23420]=0;U(11,d+160|0,1,c|0);e=x[23420];x[23420]=0;if((e|0)==1){break R}x[23420]=0;e=T(696,d+160|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Q}x[a+1074308>>2]=e;yb(d+160|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;xb(c);f=24}if(!(!x[a+1074308>>2]|f&8)){v[a+1074368|0]=0;cu(a+1074312|0)}c=f&32;T:{if(!c){break T}v[a+1074368|0]=5;if(!o){bq(a+901404|0)}if(z[d+570>>1]<260){break T}x[23420]=0;W(251,a+1074312|0,4,1)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}}if(!eh(x[k+4>>2],y[k+11|0])){break M}if(!(f&256)|r&255|g+1>>>0>1){break N}x[23420]=0;c=Q(1,d+160|0,8210)|0;g=x[23420];x[23420]=0;if((g|0)==1){break O}Gb(k,c);yb(c);break M}f=P()|0;break k}f=P()|0;break P}f=P()|0;yb(d+160|0)}xb(c);break k}f=P()|0;break k}if(c){x[23420]=0;c=Q(1,d+160|0,11927)|0;g=x[23420];x[23420]=0;if((g|0)!=1){Gb(k,c);yb(c);break M}f=P()|0;break k}x[23420]=0;c=Q(1,d+160|0,9642)|0;g=x[23420];x[23420]=0;if((g|0)==1){break I}Gb(k,c);yb(c)}v[d+55|0]=0;U:{if(z[a+480192>>1]){x[23420]=0;c=Q(369,a|0,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break U}v[d+55|0]=c}x[23420]=0;X(370,a|0,b|0,1,d+55|0);b=x[23420];x[23420]=0;if((b|0)==1){break U}e=x[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(y[d+55|0]){if(e>>>0>18284543){break ha}x[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}x[23420]=0;b=Q(1,d+40|0,17433)|0;c=x[23420];x[23420]=0;if((c|0)==1){break fa}c=x[a+1074308>>2];x[23420]=0;R(697,d+24|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break ea}x[23420]=0;U(2,d+88|0,b|0,d+24|0);c=x[23420];x[23420]=0;if((c|0)==1){break da}c=d+88|0;Gb(k,c);yb(c);yb(d+24|0);yb(b);e=x[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=x[a+484344>>2];f=x[a+484348>>2];if(!oe(b,f,254)){b=y[a+484376|0];c=x[a+484360>>2];x[23420]=0;Y(698,Yb(c,b)|0);b=x[23420];x[23420]=0;if((b|0)==1){break U}f=x[a+484348>>2];b=x[a+484344>>2]}if(oe(b,f,255)){break ia}jA(Yb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[23420]=0;R(699,d+24|0,4063);b=x[23420];x[23420]=0;if((b|0)==1){break ba}b=z[d+570>>1];x[d+20>>2]=b>>>8;x[23420]=0;x[d+4>>2]=b&255;R(380,d+8|0,d+4|0);b=x[23420];x[23420]=0;if((b|0)==1){break aa}x[23420]=0;X(366,d+88|0,d+24|0,d+20|0,d+8|0);b=x[23420];x[23420]=0;if((b|0)==1){break $}c=d+88|0;b=Gb(a+1298344|0,c);yb(c);yb(d+8|0);cc(d+24|0);Gb(a+1298368|0,k);x[a+1298404>>2]=C?8:x[a+1074308>>2]?8:5;if(!y[d+495|0]){break W}Gb(a+1298380|0,b);x[23420]=0;c=Q(1,d+88|0,15058)|0;g=x[23420];x[23420]=0;if((g|0)==1){break Z}Gb(b,c);yb(c);x[23420]=0;b=Q(1,d+24|0,9993)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Y}Gb(a+1298356|0,b);yb(b);x[23420]=0;b=Q(1,d+8|0,9994)|0;c=x[23420];x[23420]=0;if((c|0)==1){break X}Gb(a+1298392|0,b);break V}f=P()|0;break k}f=P()|0;break ca}f=P()|0;yb(d+24|0)}yb(b);break k}f=P()|0;break k}f=P()|0;break _}f=P()|0;yb(d+8|0)}cc(d+24|0);break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}x[23420]=0;b=Q(1,d+88|0,9994)|0;c=x[23420];x[23420]=0;if((c|0)==1){break H}Gb(a+1298356|0,b)}yb(b);tc(n);yb(k);break b}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0;break k}f=P()|0}tc(n);break c}f=P()|0}yb(k);S(f|0);p()}e=1}hb=d+592|0;return e|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;e=hb-336|0;hb=e;zc(b);a:{b:{c:{if(!Et(b,e+240|0)){break c}if(!FQ(e+240|0)){break c}if(!Nb(x[b>>2],x[b+8>>2],Vc(EQ(e+240|0),lb))){break c}if(!c){l=1;break c}Dd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Jb(e+224|0);d=z[e+280>>1];i=(d|0)==20479?z[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}x[23420]=0;d=Q(1,e+208|0,12167)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,d);break e}b=P()|0;break a;case 1:j:{if((d|0)!=4896){break j}d=z[e+302>>1];if(d){break j}if(!(z[e+278>>1]&65455|(y[e+292|0]|y[e+272|0]&15))){k:{if(v[e+291|0]<0){x[a+1074308>>2]=18219008;x[23420]=0;d=Q(1,e+208|0,14609)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break k}b=P()|0;break a}x[a+1074308>>2]=16777216;x[23420]=0;d=Q(1,e+208|0,13208)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}}Gb(j,d);yb(d);x[23420]=0;f=1;W(251,a+1074312|0,81,1)|0;d=x[23420];x[23420]=0;g=1;if((d|0)!=1){break d}break b}if(y[e+292|0]|d|(z[e+278>>1]|y[e+293|0])){break j}x[23420]=0;d=Q(1,e+208|0,9378)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,d);break e}b=P()|0;break a}x[23420]=0;d=Q(1,e+208|0,8412)|0;f=x[23420];x[23420]=0;k=1;if((f|0)!=1){Gb(j,d);yb(d);break f}b=P()|0;break a;case 2:x[23420]=0;d=Q(1,e+208|0,6734)|0;f=x[23420];x[23420]=0;g=1;if((f|0)!=1){Gb(j,d);yb(d);break f}b=P()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){x[23420]=0;f=Q(1,e+208|0,8459)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,f);yb(f);break o}b=P()|0;break a}x[23420]=0;R(378,e+208|0,3976);f=x[23420];x[23420]=0;if((f|0)==1){break n}x[23420]=0;x[e+192>>2]=z[e+280>>1]-12820;U(379,e+48|0,e+208|0,e+192|0);f=x[23420];x[23420]=0;if((f|0)==1){break m}f=e+48|0;Gb(j,f);yb(f);cc(e+208|0)}f=z[e+280>>1];if(f>>>0<12807){break g}h=x[e+296>>2];if(h){break l}break g}b=P()|0;break a}b=P()|0;cc(e+208|0);break a}f=PC(f,h);h=qq(e+48|0);x[h+44>>2]=f;x[23420]=0;R(381,a+1298408|0,h|0);f=x[23420];x[23420]=0;if((f|0)!=1){break g}b=P()|0;break a;case 4:p:{q:{if((d|0)==16640){x[23420]=0;f=Q(1,e+208|0,8258)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,f);yb(f);f=81;break q}b=P()|0;break a}x[23420]=0;U(382,e+48|0,d|0,z[e+294>>1]);f=x[23420];x[23420]=0;r:{if((f|0)!=1){f=e+48|0;Gb(j,f);yb(f);x[a+480260>>2]=1;if((i|0)<4201){break r}x[23420]=0;W(251,a+1074312|0,7,1)|0;h=x[23420];x[23420]=0;f=38;if((h|0)==1){break b}break q}b=P()|0;break a}f=38;if((i|0)<2386){break p}}x[23420]=0;W(251,a+1074312|0,f|0,1)|0;f=x[23420];x[23420]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?z[e+294>>1]:0)&65535;x[23420]=0;d=Q(1,e+208|0,17433)|0;f=x[23420];x[23420]=0;s:{t:{u:{if((f|0)!=1){f=x[a+1074308>>2];x[23420]=0;R(128,e+192|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break u}f=0;x[23420]=0;U(2,e+48|0,d|0,e+192|0);h=x[23420];x[23420]=0;if((h|0)==1){break t}h=e+48|0;Gb(j,h);yb(h);yb(e+192|0);break e}b=P()|0;break a}b=P()|0;break s}b=P()|0;yb(e+192|0)}yb(d);break a;case 6:x[23420]=0;d=Q(1,e+208|0,8258)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,d);yb(d);x[23420]=0;W(251,a+1074312|0,81,1)|0;d=x[23420];x[23420]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;break a;case 7:x[23420]=0;d=Q(1,e+208|0,8270)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,d);break e}b=P()|0;break a;default:break i}}if((d|0)!=51712){break d}x[23420]=0;d=Q(1,e+208|0,9177)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Gb(j,d);break e}b=P()|0;break a}b=P()|0;break a}x[23420]=0;f=W(251,a+1074312|0,7,1)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}x[23420]=0;f=W(251,f|0,23,1)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}x[23420]=0;f=W(251,f|0,38,1)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}x[23420]=0;W(251,f|0,107,1)|0;f=x[23420];x[23420]=0;if((f|0)==1){break b}g=1;x[a+480260>>2]=1;f=0;h=0;if(d>>>0>12820){break d}}x[23420]=0;Y(619,e+192|0);d=x[23420];x[23420]=0;v:{w:{x:{if((d|0)!=1){d=z[e+280>>1];x[e+160>>2]=d>>>8&15;x[23420]=0;x[e+136>>2]=d&255;R(380,e+176|0,e+136|0);d=x[23420];x[23420]=0;if((d|0)==1){break x}f=0;x[23420]=0;ea(620,e+48|0,e+192|0,j|0,e+160|0,e+176|0);d=x[23420];x[23420]=0;if((d|0)==1){break w}d=e+48|0;Gb(j,d);yb(d);yb(e+176|0);cc(e+192|0);break d}b=P()|0;break a}b=P()|0;break v}b=P()|0;yb(e+176|0)}cc(e+192|0);break a}yb(d);h=0}x[23420]=0;d=Q(1,e+192|0,14876)|0;n=x[23420];x[23420]=0;y:{z:{A:{B:{C:{D:{E:{F:{if((n|0)!=1){Gb(a+1298344|0,d);yb(d);x[23420]=0;d=Q(1,e+176|0,10366)|0;n=x[23420];x[23420]=0;if((n|0)==1){break F}Gb(a+1298356|0,d);yb(d);r=Gb(a+1298368|0,j);x[a+1298404>>2]=x[a+1074308>>2]?8:5;if(g){x[23420]=0;d=Q(252,a+1074312|0,77)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;d=Q(252,d|0,78)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;d=Q(252,d|0,79)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;d=Q(252,d|0,80)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;d=Q(252,d|0,82)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;d=Q(252,d|0,96)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}x[23420]=0;Q(252,d|0,113)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}}d=z[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}x[23420]=0;d=a+901404|0;Y(621,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break b}if(!f){bq(d)}d=e+160|0;el(d,1,e+240|0);x[23420]=0;R(210,e+48|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break C}d=e+48|0;Ac(a+1298308|0,d);xb(d);d=z[e+278>>1];if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=z[e+280>>1];if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+289|0];x[a+480196>>2]=d;if(!(!k|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+290|0];x[a+480204>>2]=d>>>0<33?k?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+288|0];v[e+160|0]=64;d=y[Wb(e+48|0,e+160|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+291|0];if(z[e+282>>1]!=1|g>>>0>7){break E}x[e+48>>2]=(g<<4)+16;x[e+160>>2]=127;f=x[td(e+48|0,e+160|0)>>2];break D}b=P()|0;break a}b=P()|0;break a}f=32;if((g|16)==18){break D}d=g&127;f=48;if(!d){break D}x[e+48>>2]=d;x[e+160>>2]=16;f=x[Le(e+48|0,e+160|0)>>2]}x[a+480228>>2]=f;d=0;n=x[a+1074308>>2]!=0|g<<24>>24<0;if(!n){I=a,J=Vc(Zia(f<<3|5,f>>>29|0,11,0),lb),x[I+480228>>2]=J}s=a+480188|0;w[s>>1]=4;x[a+480232>>2]=h?(i|0)<3299?64:36:36;f=Bc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!z[d>>1]){w[d>>1]=1}d=y[a+484376|0];h=x[a+484360>>2];x[23420]=0;ea(326,Yb(h,d)|0,b|0,z[e+272>>1],255,254);d=x[23420];x[23420]=0;if((d|0)!=1){n=Qb(e+160|0);x[23420]=0;W(205,b|0,n|0,z[e+274>>1])|0;d=x[23420];x[23420]=0;if((d|0)!=1){s=Qb(e+136|0);x[23420]=0;W(205,b|0,s|0,z[e+276>>1])|0;d=x[23420];x[23420]=0;G:{if((d|0)!=1){if(y[e+293|0]!=252){break B}d=0;x[23420]=0;R(622,b|0,e+48|0);h=x[23420];x[23420]=0;if((h|0)==1){break G}while(1){if((d|0)==32){break B}h=y[(e+48|0)+d|0];H:{if(!(h&32)){break H}if(k){sk(e+32|0,f,d);if(Bb(x[x[e+32>>2]>>2],x[e+36>>2])){break H}}w[((d<<5)+a|0)+480284>>1]=(((h&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;break z}b=P()|0;break a}h=(d<<5)+a|0;i=h+480280|0;Te(i);g=y[(d+e|0)+304|0];o=g&126;I:{if((g|0)!=255){g=g<<24>>24;w[s>>1]=d+1;if(n){w[h+480284>>1]=g&8?204:51}if((g|0)>=0){break I}}x[i>>2]=1024}if((o-16&255)>>>0<=13){w[h+480284>>1]=128;h=e+48|0;sk(h,f,d);pm(h)}d=d+1|0;continue}}b=P()|0;break a}w[e+48>>1]=z[e+274>>1];w[e+32>>1]=3999;f=z[Zc(e+48|0,e+32|0)>>1];w[a+480190>>1]=f;i=c&2;o=e+96|0;d=0;g=0;h=0;J:{K:{L:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break K}if(!(!(g&1)|h&65535)&z[e+280>>1]!=4864){break L}x[23420]=0;d=h&65535;f=W(251,a+1074312|0,79,d>>>0>1|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break A}x[23420]=0;d=d>>>0<2;f=W(251,f|0,107,d|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break A}x[23420]=0;W(251,f|0,38,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break A}x[23420]=0;d=h&65535;Q(121,r|0,(d>>>0>1?16994:17001)|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break A}if(d>>>0<2){break K}x[a+480228>>2]=48;break K}f=bc(x[n>>2],d);f=y[f|0]|y[f+1|0]<<8;x[23420]=0;f=Q(143,b|0,f<<4)|0;m=x[23420];x[23420]=0;if((m|0)==1){break J}M:{N:{if(!f){break N}x[23420]=0;f=Q(623,b|0,e+48|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break J}if(!f){break N}x[23420]=0;f=d+1|0;m=(D(f,104)+a|0)+484380|0;U(624,e+48|0,m|0,k|0);l=x[23420];x[23420]=0;if((l|0)==1){break J}l=e+16|0;el(l,1,o);x[23420]=0;R(210,e+32|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break M}l=((f<<5)+a|0)+946304|0;f=e+32|0;Dc(l,f);xb(f);if(y[e+48|0]>1){break N}O:{if(!i|!x[e+64>>2]){break O}f=CQ(e+48|0);x[23420]=0;f=Q(143,b|0,f|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break A}if(!f){break O}f=e+32|0;BQ(f,y[e+78|0],y[e+79|0],z[e+282>>1]==1);x[23420]=0;W(207,f|0,m|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break A}g=1}h=z[e+88>>1]|h}d=d+1|0;f=z[a+480190>>1];continue}break}break A}x[23420]=0;d=Q(1,e+48|0,9642)|0;f=x[23420];x[23420]=0;if((f|0)==1){break A}Gb(r,d);yb(d)}l=1;if(!(c&1)){break y}c=z[e+280>>1];w[e+32>>1]=z[e+276>>1];w[e+16>>1]=255;t=z[Zc(e+32|0,e+16|0)>>1];x[23420]=0;k=a+484344|0;R(213,k|0,t|0);d=x[23420];x[23420]=0;if((d|0)==1){break J}u=c>>>0<4896;c=e+32|0;C=c|5;E=c|3;A=c|4;F=c|2;G=c|1;H=a+480188|0;h=0;r=0;o=0;while(1){if((h|0)==(t|0)){if(!u){break y}a=z[a+480188>>1];if((a|0)>(o+r|0)|(a|0)<=(r-o|0)){break y}d=of(x[k>>2],x[k+4>>2])-1&65535;b=0;P:{if(of(x[k>>2],x[k+4>>2])>>>0<=d>>>0){break P}while(1){c=b&65535;if(c>>>0>d>>>0){break P}a=Pf(x[k>>2],c);f=x[a>>2];if(Pb(f,x[a+4>>2])){a=Db(f);f=Db(x[Pf(x[k>>2],c)+4>>2]);c=hb-16|0;hb=c;x[c+8>>2]=a;while(1){if(Pb(a,f)){if(y[a+3|0]==31){v[a+3|0]=20;v[a+5|0]=y[a+5|0]|128}a=x[jk(c+8|0)>>2];continue}break}hb=c+16|0}b=b+1|0;continue}}break y}x[23420]=0;c=W(214,k|0,h&65535,64)|0;d=x[23420];x[23420]=0;if((d|0)==1){break J}Q:{if(!c){break Q}c=bc(x[s>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break Q}x[23420]=0;c=Q(143,b|0,c<<4)|0;d=x[23420];x[23420]=0;if((d|0)==1){break J}if(!c){break Q}x[23420]=0;Q(176,b|0,2)|0;c=x[23420];x[23420]=0;if((c|0)==1){break J}d=0;c=_b(x[k>>2],h);c=pf(x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break Q}f=d;x[23420]=0;d=T(194,b|0)|0;g=x[23420];x[23420]=0;R:{if((g|0)!=1){m=d<<24>>24;if(m){break R}d=64;if(f>>>0>62){continue}c=_b(x[k>>2],h);d=f+1|0;c=pf(x[c>>2],x[x[c+48>>2]+12>>2],d);continue}break A}g=m&31;d=D(g,6)+c|0;q=Sh(e+32|0);i=g>>>0<z[H>>1];B=i?d:q;if(m&32){x[23420]=0;R(247,e+16|0,b|0);g=x[23420];x[23420]=0;S:{T:{U:{if((g|0)!=1){q=jd(e+16|0);g=y[e+16|0];if(g>>>0>239){break U}g=AQ((D(g>>>4|0,12)+(g&15)|0)+13|0);break T}break A}V:{switch(g-254|0){case 0:break T;case 1:break V;default:break S}}g=0}v[B|0]=g}v[(i?d+1|0:G)|0]=y[q|0]}W:{if(!(m&64)){break W}x[23420]=0;q=T(194,b|0)|0;g=x[23420];x[23420]=0;X:{if((g|0)!=1){g=i?d+2|0:F;q=q<<24>>24;v[e+16|0]=q;if((q|0)>-64){break X}v[g|0]=2;v[(i?d+4|0:A)|0]=y[e+16|0]^128;break W}break A}v[g|0]=1;v[e+15|0]=64;I=i?d+4|0:A,J=y[Wb(e+16|0,e+15|0)|0],v[I|0]=J}Y:{if((m|0)>=0){break Y}x[23420]=0;R(247,e+16|0,b|0);g=x[23420];x[23420]=0;Z:{_:{if((g|0)!=1){g=i?d+3|0:E;v[g|0]=y[e+16|0];d=i?d+5|0:C;I=d,J=y[jd(e+16|0)|0],v[I|0]=J;VA(B,0);i=y[g|0];if((i|0)==10){break Z}if((i|0)==31){break _}if((i|0)!=20){break Y}g=y[d|0];if((g&240)!=160|z[e+280>>1]>4895){break Y}v[d|0]=g&15^136;break Y}break A}d=y[d|0];if(d>>>0>15){u=0;break Y}if(d>>>0<=7){o=o+1|0;break Y}r=((d|0)!=8)+r|0;break Y}if(y[d|0]|z[e+280>>1]>4865){break Y}v[g|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;od(s)}od(n);break a}od(s);od(n);yb(j)}hb=e+336|0;return l|0}b=P()|0}yb(j);S(b|0);p()}function N9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),N=0,O=0;f=hb-48|0;hb=f;c=x[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){Cf(a+1074312|0,0)}i=a+1074308|0;c=f+32|0;g=a+1074312|0;Ab(c,g,0);d=Bb(x[x[f+32>>2]>>2],x[f+36>>2]);b=a+480180|0;e=x[b>>2];Ab(c,g,0);t=d&(e&16777248)!=0;I=Bb(x[x[f+32>>2]>>2],x[f+36>>2]);J=x[b>>2];a:{c=x[a+1074308>>2];if(c>>>0>18874367){break a}e=!t;h=a+480192|0;d=1;while(1){b:{c=d&65535;if(c>>>0<=z[h>>1]){c=x[((c<<2)+a|0)+900380>>2];if(!c){break b}x[f+32>>2]=D(y[c+20|0],100)>>>6;x[f+16>>2]=100;N=c,O=x[Hb(f+32|0,f+16|0)>>2],v[N+20|0]=O;if(!(e|A[i>>2]<18350080)){break b}k=v[c+26|0];v[c+26|0]=((k>>31|1)+k|0)/2;if(!(e|A[i>>2]<18285314)){break b}ZA(Ci(c,2),x[b>>2]);k=x[a+1074308>>2];c:{if(k>>>0<18284544){break c}if(k>>>0>18285135){break b}if(!y[c+34|0]){break c}if(!mj(y[c+31|0])){break c}Mb(g,2,1);if(A[i>>2]>18285135){break b}}if(!(y[c+24|0]|(y[c+23|0]|(y[c+19|0]|y[c+20|0])))){break b}Mb(g,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[i>>2]>18285313&t){break d}d=z[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(d|0)){break d}c=D(b,104)+a|0;e=c+484419|0;if(!(y[e|0]|!(y[c+484421|0]|y[c+484420|0]))){v[e|0]=255}b=b+1|0;continue}}d=a+901404|0;h=Cz(d);while(1){if((d|0)!=(h|0)){c=d;k=$n(c);while(1){if((c|0)!=(k|0)){b=y[c|0];e:{f:{if((b-97&255)>>>0<=5){n=b-32|0;break f}if(!(b-88>>>0<2|b-120>>>0<2)){n=99;if((b|0)==75|(b|0)==107){break f}break e}n=122}v[c|0]=n}c=c+1|0;continue}break}d=d+32|0;continue}break}c=x[a+1074308>>2];break a}d=d+1|0;continue}}g:{if(!(x[a+480180>>2]&16777252)|((c|0)==18874368|c>>>0>18874895)){break g}h=z[a+480192>>1]+1&65535;d=0;b=1;while(1){if((b|0)==(h|0)){if(!d){break g}Mb(g,3,1);c=x[i>>2]}else{e=x[((b<<2)+a|0)+900380>>2];if(!(!e|!y[e+31|0])){v[e+33|0]=13;d=1}b=b+1|0;continue}break}}h:{if(!(x[a+480180>>2]&16777248)|((c|0)==19005440|c>>>0>19006225)){break h}Ab(f+32|0,g,0);if(!Bb(x[x[f+32>>2]>>2],x[f+36>>2])){Ab(f+16|0,g,1);if(!Bb(x[x[f+16>>2]>>2],x[f+20>>2])){break h}}d=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(d|0)){break h}c=x[((b<<2)+a|0)+900380>>2];if(!(!c|!y[c+19|0]|!(v[c+80|0]&1))){v[c+19|0]=0}b=b+1|0;continue}}i:{if(A[i>>2]>19007232){break i}c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break i}d=f+16|0;e=b+80|0;jM(d,e);x[23420]=0;X(223,f+32|0,0,8,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){xb(f+16|0);d=f+32|0;su(e,d);b=b+160|0;xb(d);continue}break}a=P()|0;xb(f+16|0);S(a|0);p()}j:{k:{l:{m:{n:{o:{if(x[a+480180>>2]!=4){break o}d=x[i>>2];if(d>>>0<19007257){break m}if(d>>>0>19071235){break n}if(y[a+1074368|0]!=4){break o}uy(a,5)}d=x[i>>2]}if(d>>>0>19202054){break l}c=19202048;if((d|0)==19202048){break k}}h=z[a+480192>>1]+1&65535;c=1;while(1){if((c|0)==(h|0)){break l}e=x[((c<<2)+a|0)+900380>>2];p:{if(!e|!y[e+20|0]|!y[e+31|0]){break p}b=e+236|0;k=fq(b);while(1){if((b|0)!=(k|0)){o=z[b>>1];b=b+2|0;if(!o){continue}break p}break}v[e+20|0]=0}c=c+1|0;continue}}c=d;if(c>>>0>19267583){break j}}e=!t;h=z[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(h|0)){break j}d=x[((b<<2)+a|0)+900380>>2];q:{if(!d){break q}c=v[d+26|0];v[d+26|0]=((c>>31|1)+c|0)/2;c=x[i>>2];if(!(e|c>>>0<18350080)){break q}v[d+19|0]=y[d+19|0]+3>>>2}b=b+1|0;continue}}r:{if(c>>>0>19398673){break r}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break r}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){b=b+1|0;continue}else{Mb(g,94,1);c=x[i>>2]}break}}s:{if(c>>>0>19399427){break s}d=z[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break s}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){b=b+1|0;continue}else{Mb(g,101,1);c=x[i>>2]}break}}t:{if(c>>>0>19923027){break t}d=z[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break t}c=D(c,104)+a|0;if(!Td(x[c+484380>>2],x[c+484400>>2])|!(y[c+484414|0]&20)){b=b+1|0;continue}else{Mb(g,116,1)}break}}c=hb-16|0;hb=c;w[f+12>>1]=0;x[f+8>>2]=a;Ab(c+8|0,a+1074312|0,0);N=f,O=Bb(x[x[c+8>>2]>>2],x[c+12>>2]),v[N+14|0]=O;hb=c+16|0;B=x[f+8>>2];C=x[f+12>>2];c=a+484344|0;n=c;G=of(x[c>>2],x[c+4>>2])-1&65535;k=hb-32|0;hb=k;u:{if(of(x[c>>2],x[c+4>>2])>>>0<=G>>>0){break u}while(1){c=H&65535;if(c>>>0>G>>>0){break u}d=Pf(x[n>>2],c);b=x[d>>2];if(Pb(b,x[d+4>>2])){b=Db(b);K=Db(x[Pf(x[n>>2],c)+4>>2]);x[k+24>>2]=B;x[k+28>>2]=C;x[k+8>>2]=B;x[k+12>>2]=C;h=k+8|0;u=hb-16|0;hb=u;x[u+8>>2]=b;while(1){if(Pb(b,K)){o=hb-16|0;hb=o;F=z[h+4>>1];c=F+1|0;w[h+4>>1]=c;d=x[h>>2];w[h+4>>1]=z[d+480188>>1]>(c&65535)>>>0?c:0;v:{if(Rg(y[b|0])){break v}e=x[d+1074308>>2];w:{m=x[d+480180>>2];x:{y:{if((m|0)==2){if(e>>>0>18415615){break y}if(y[b+3|0]!=23){break x}nf(b+5|0,64);break x}if(m&16777248){z:{A:{if(e>>>0>=18285314){if(y[h+6|0]){break A}c=0;d=0;if(e>>>0>18874367){break z}}B:{switch(y[b+3|0]-20|0){case 3:nf(b+5|0,128);break A;case 0:break B;default:break A}}c=y[b+5|0];if((c|0)!=208){if((c|0)!=192){break A}v[b|0]=254;v[b+3|0]=0;break A}v[b+3|0]=0}C:{D:{if(e>>>0>=18350080){if(y[h+6|0]){break D}c=0;d=0;if(e>>>0>18874367){break z}}d=y[b+3|0];c=0;if(d>>>0>29){break C}c=536873152>>>d&1;break C}c=0;d=0;if(e>>>0>18874367){break z}d=y[b+3|0];c=0}d=(d|0)==24|(d|0)==22}E:{if(!(c|d)){break E}d=y[b+5|0];c=d&15;if(!c|(c|0)==15){break E}d=d&240;if(!d|(d|0)==240){break E}v[b+5|0]=y[b+3|0]==24?d:c}F:{if((e|0)==19005440|e>>>0>19005699){break F}c=z[x[h>>2]+480192>>1];if(y[h+6|0]|(!c|c>>>0>=y[b+1|0])){break F}v[b+4|0]=0;v[b+2|0]=1}if(y[b+5|0]!=17|e>>>0>19468801|y[b+3|0]!=18){break y}Ab(o+8|0,x[h>>2]+1074312|0,22);if(!Bb(x[x[o+8>>2]>>2],x[o+12>>2])|x[x[h>>2]+480208>>2]&4){break y}v[b+5|0]=0;break y}if((m|0)!=4){break y}G:{if((!y[h+6|0]|e>>>0<18285314)&e>>>0<18874368){break G}if(e>>>0>19137025){break w}if(y[b+3|0]!=23|y[b+5|0]<65){break G}v[b+3|0]=0}H:{I:{J:{if(!(y[h+6|0]|e>>>0>18874367?e>>>0>=18415616:0)){c=y[b+3|0];d=y[b+2|0];if((c|0)!=10|(d|0)!=11){break J}c=0;v[b+3|0]=0;break H}if(e>>>0>18874639){break I}c=y[b+3|0];d=y[b+2|0]}if((d|0)!=11|(c|0)!=4){break H}d=y[b+4|0];if(!(d|y[h+6|0])){c=4;break H}c=4;s=y[b+5|0];if(!s){break H}v[b+2|0]=0;N=b,O=hu((d<<4)+s|0),v[N+5|0]=O;break H}if(e>>>0>19007240){break w}c=y[b+3|0]}if(y[b+5|0]|(c|0)!=16){break y}v[b+3|0]=0}if(e>>>0>18874367){break w}}c=y[b+3|0];s=y[b+5|0]&240;K:{L:{if((c|0)!=28|(s|0)!=96){d=0}else{if(!y[h+6|0]|(m|0)!=4){break L}d=e>>>0<18350080}if(!(d|(c|0)==20&(s|0)==96)){break K}}d=D(F,-6)+b|0;while(1){if(b>>>0>d>>>0){if(!((y[d+3|0]|8)!=28|(y[d+5|0]&240)!=96)){v[d+3|0]=0}d=d+6|0;continue}break}c=y[b+3|0]}if((c|0)!=20|(y[b+5|0]&240)!=224){break w}d=D(F,-6)+b|0;while(1){if(b>>>0<=d>>>0){break w}if(!(y[d+3|0]!=20|(y[d+5|0]&240)!=224)){v[d+3|0]=0}d=d+6|0;continue}}d=b+2|0;c=y[b+2|0];M:{if((c|0)==8){if((e|0)==19333120|e>>>0>19333174){break v}e=y[b+4|0];c=y[b+3|0];if(!(!e|(c|0)!=7)){v[b+3|0]=11;break v}N:{switch(c-5|0){default:if((c|0)!=26){break v}break;case 1:break v;case 2:break M;case 0:break N}}m=y[b+5|0];if(!(m&15)){v[b+3|0]=5;v[b+5|0]=m|e&15;break M}O:{switch(c-5|0){case 1:break v;case 0:case 2:break M;default:break O}}if((c|0)==26){break M}break v}P:{if(!((m|0)==16777216|(c|0)!=15)){c=y[b+3|0];if(c){break P}v[b+3|0]=10;v[b+5|0]=y[b+4|0]<<3;break M}if((c|0)!=15){break v}c=y[b+3|0]}if((c|0)!=10|e>>>0>19922963){break v}d=y[b+5|0]?d:y[b+4|0]?b+3|0:d}v[d|0]=0}hb=o+16|0;b=x[jk(u+8|0)>>2];continue}break}c=x[h+4>>2];x[k+16>>2]=x[h>>2];x[k+20>>2]=c;hb=u+16|0}H=H+1|0;continue}}x[f+32>>2]=B;x[f+36>>2]=C;hb=k+32|0;Q:{c=A[a+1074308>>2]<19267584;if(c&t){b=41872;while(1){if((b|0)==42216){break Q}c=x[i>>2];d=x[b+4>>2];Mb(g,x[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(c&((J|0)==4&I))){break Q}b=42224;while(1){if((b|0)==42464){break Q}Mb(g,x[b>>2],A[i>>2]>=A[b+4>>2]);b=b+8|0;continue}}R:{S:{c=x[a+480180>>2];if(c&16777248){b=42464;while(1){if((b|0)==42520){break S}c=x[i>>2];d=x[b+4>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(c>>>0<=e>>>0|c>>>0>=d>>>0))){Cf(g,x[b>>2])}b=b+8|0;continue}}b=42592;d=42528;T:{switch(c-2|0){case 2:while(1){if((d|0)==42592){break S}if(A[i>>2]<A[d+4>>2]){Cf(g,x[d>>2])}d=d+8|0;continue};case 0:break T;default:break R}}while(1){if((b|0)==42680){break S}if(A[i>>2]<A[b+4>>2]){Cf(g,x[b>>2])}b=b+8|0;continue}}c=x[a+480180>>2]}U:{if((c|0)==4){b=x[i>>2];if(b>>>0>18415615){break U}Mb(g,98,1)}b=x[i>>2]}d=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Ab(f+32|0,g,c);Cf(Mb(g,b+86|0,Bb(x[x[f+32>>2]>>2],x[f+36>>2])),c);b=b+1|0;continue}break}b=x[i>>2]}V:{if(b>>>0>=18284544){if(b>>>0>18874627){break V}d=6;if((b|0)==18874368){break V}}Mb(g,d,1)}c=x[a+1074308>>2];W:{if(y[a+480208|0]&16){if(c>>>0<=19136511){Cf(g,7);break W}if(!(x[a+480180>>2]&16777248)|c>>>0>19267583){break W}Mb(g,7,1);break W}if((c|0)==19922944|c>>>0>19922997){break W}Cf(g,7)}Ab(f+32|0,g,31);X:{if(!Bb(x[x[f+32>>2]>>2],x[f+36>>2])){break X}c=x[i>>2];if(c>>>0<19071234|c>>>0>19398722){break X}d=z[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break X}Y:{c=x[((c<<2)+a|0)+900380>>2];if(!c){break Y}e=y[c+65|0];if(!(y[c+60|0]&4)|(e|0)==255|e>>>0<=y[c- -64|0]){break Y}Mb(g,97,1);break X}b=b+1|0;continue}}c=x[a+480180>>2];Z:{if(!(c&16777218)){break Z}d=z[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break Z}b=b+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}_:{$:{aa:{if(!(!z[a+480192>>1]|(c|0)!=16777216)){b=x[i>>2];if(b>>>0<19398688){break $}if(b>>>0>19464277){break aa}Mb(g,109,1)}b=x[i>>2]}if((b|0)==19922944|b>>>0>19922996){break _}}Cf(g,111);b=x[i>>2]}c=x[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Mb(g,108,1);break Z}if((c|0)==2){break Z}Cf(g,108)}ba:{b=x[i>>2];ca:{da:{if(b>>>0>=19333186){if(b>>>0>19923013){break da}if(!(x[a+480180>>2]&16777252)){break ca}c=a+946300|0;b=a+906300|0;while(1){if((b|0)!=(c|0)){ea:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-271958638){break ea}if((Wc(x[b+4>>2],x[b+8>>2])|0)!=32){break ea}d=Vb(f+32|0,16671);su(b+80|0,d);xb(d)}b=b+160|0;continue}break}b=x[i>>2]}if(b>>>0<19333120){break ba}}if(b>>>0>19924479){break ba}}if(!(x[a+480180>>2]&16777252)){break ba}d=a+946300|0;b=a+906300|0;while(1){if((b|0)==(d|0)){break ba}fa:{if((y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24))!=1146637647|(y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24))!=-281111764){break fa}a=x[b+4>>2];if((Wc(a,x[b+8>>2])|0)!=24){break fa}L=Fd(E(E(E((l(2,y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));M=Fd(E(E(E((l(2,y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(L),j(2));v[a+12|0]=c;v[a+13|0]=c>>>8;v[a+14|0]=c>>>16;v[a+15|0]=c>>>24;a=x[b+4>>2];c=(q(M),j(2));v[a+16|0]=c;v[a+17|0]=c>>>8;v[a+18|0]=c>>>16;v[a+19|0]=c>>>24}b=b+160|0;continue}}hb=f+48|0}function Ld(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=x[23296];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+93224|0;d=x[a+93232>>2];a=x[d+8>>2];l:{if((b|0)==(a|0)){m=93184,n=_ia(-2,c)&e,x[m>>2]=n;break l}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[23298];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+93224|0;g=x[a+93232>>2];a=x[g+8>>2];m:{if((b|0)==(a|0)){e=_ia(-2,d)&e;x[23296]=e;break m}x[a+12>>2]=b;x[b+8>>2]=a}x[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+g>>2]=d;if(k){b=(k&-8)+93224|0;f=x[23301];a=1<<(k>>>3);n:{if(!(a&e)){x[23296]=a|e;a=b;break n}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=g+8|0;x[23301]=c;x[23298]=d;break a}j=x[23297];if(!j){break k}b=j-1&(j^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=x[((c|a)+(b>>>a|0)<<2)+93488>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){o:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break o}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break j}b=c+16|0}while(1){g=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=x[23297];if(!j){break k}f=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}b=x[(e<<2)+93488>>2];q:{r:{s:{if(!b){a=0;break s}a=0;c=h<<((e|0)!=31?25-(e>>>1|0)|0:0);while(1){t:{g=(x[b+4>>2]&-8)-h|0;if(g>>>0>=f>>>0){break t}d=b;f=g;if(f){break t}f=0;a=b;break r}g=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=g?(g|0)==(b|0)?a:g:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=a-1&(a^-1);a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=x[((c|a)+(b>>>a|0)<<2)+93488>>2]}if(!a){break q}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[23298]-h>>>0<=f>>>0){break k}e=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break i}b=d+16|0}while(1){g=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[g>>2]=0;break c}c=x[23298];if(c>>>0>=h>>>0){d=x[23301];b=c-h|0;u:{if(b>>>0>=16){x[23298]=b;a=d+h|0;x[23301]=a;x[a+4>>2]=b|1;x[c+d>>2]=b;x[d+4>>2]=h|3;break u}x[23301]=0;x[23298]=0;x[d+4>>2]=c|3;a=c+d|0;x[a+4>>2]=x[a+4>>2]|1}a=d+8|0;break a}i=x[23299];if(i>>>0>h>>>0){b=i-h|0;x[23299]=b;c=x[23302];a=c+h|0;x[23302]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[23414]){c=x[23416]}else{x[23417]=-1;x[23418]=-1;x[23415]=4096;x[23416]=4096;x[23414]=l+12&-16^1431655768;x[23419]=0;x[23407]=0;c=4096}g=j+c|0;f=0-c|0;b=g&f;if(b>>>0<=h>>>0){break a}d=x[23406];if(d){c=x[23404];e=c+b|0;if(d>>>0<e>>>0|c>>>0>=e>>>0){break a}}if(y[93628]&4){break f}v:{w:{d=x[23302];if(d){a=93632;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break w}a=x[a+8>>2];if(a){continue}break}}c=gm(0);if((c|0)==-1){break g}e=b;d=x[23415];a=d-1|0;if(a&c){e=(b-c|0)+(a+c&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=x[23406];if(d){a=x[23404];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=gm(e);if((c|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}c=gm(e);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break h}a=c}if(!((a|0)==-1|h+48>>>0<=e>>>0)){c=x[23416];c=c+(j-e|0)&0-c;if(c>>>0>2147483646){c=a;break e}if((gm(c)|0)!=-1){e=c+e|0;c=a;break e}gm(0-e|0);break g}c=a;if((a|0)!=-1){break e}break g}d=0;break b}c=0;break c}if((c|0)!=-1){break e}}x[23407]=x[23407]|4}if(b>>>0>2147483646){break d}c=gm(b);a=gm(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}e=a-c|0;if(e>>>0<=h+40>>>0){break d}}a=x[23404]+e|0;x[23404]=a;if(a>>>0>A[23405]){x[23405]=a}x:{y:{z:{g=x[23302];if(g){a=93632;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break z}a=x[a+8>>2];if(a){continue}break}break y}a=x[23300];if(!(a>>>0<=c>>>0?a:0)){x[23300]=c}a=0;x[23409]=e;x[23408]=c;x[23304]=-1;x[23305]=x[23414];x[23411]=0;while(1){d=a<<3;b=d+93224|0;x[d+93232>>2]=b;x[d+93236>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[23299]=b;a=a+c|0;x[23302]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[23303]=x[23418];break x}if(y[a+12|0]&8|d>>>0>g>>>0|c>>>0<=g>>>0){break y}x[a+4>>2]=b+e;a=g+8&7?-8-g&7:0;c=a+g|0;x[23302]=c;b=x[23299]+e|0;a=b-a|0;x[23299]=a;x[c+4>>2]=a|1;x[(b+g|0)+4>>2]=40;x[23303]=x[23418];break x}if(A[23300]>c>>>0){x[23300]=c}b=c+e|0;a=93632;A:{B:{C:{D:{E:{F:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break F}break}if(!(y[a+12|0]&8)){break E}}a=93632;while(1){b=x[a>>2];if(b>>>0<=g>>>0){f=b+x[a+4>>2]|0;if(f>>>0>g>>>0){break D}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+e;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;e=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=e-i|0;if((e|0)==(g|0)){x[23302]=i;a=x[23299]+a|0;x[23299]=a;x[i+4>>2]=a|1;break B}if(x[23301]==(e|0)){x[23301]=i;a=x[23298]+a|0;x[23298]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break B}f=x[e+4>>2];if((f&3)==1){g=f&-8;G:{if(f>>>0<=255){d=x[e+8>>2];b=f>>>3|0;c=x[e+12>>2];if((c|0)==(d|0)){m=93184,n=x[23296]&_ia(-2,b),x[m>>2]=n;break G}x[d+12>>2]=c;x[c+8>>2]=d;break G}h=x[e+24>>2];c=x[e+12>>2];H:{if((e|0)!=(c|0)){b=x[e+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break H}I:{f=e+20|0;b=x[f>>2];if(b){break I}f=e+16|0;b=x[f>>2];if(b){break I}c=0;break H}while(1){d=f;c=b;f=b+20|0;b=x[f>>2];if(b){continue}f=c+16|0;b=x[c+16>>2];if(b){continue}break}x[d>>2]=0}if(!h){break G}d=x[e+28>>2];b=(d<<2)+93488|0;J:{if(x[b>>2]==(e|0)){x[b>>2]=c;if(c){break J}m=93188,n=x[23297]&_ia(-2,d),x[m>>2]=n;break G}x[h+(x[h+16>>2]==(e|0)?16:20)>>2]=c;if(!c){break G}}x[c+24>>2]=h;b=x[e+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[e+20>>2];if(!b){break G}x[c+20>>2]=b;x[b+24>>2]=c}e=e+g|0;f=x[e+4>>2];a=a+g|0}x[e+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+93224|0;c=x[23296];a=1<<(a>>>3);K:{if(!(c&a)){x[23296]=a|c;a=b;break K}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break B}f=31;if(a>>>0<=16777215){b=a>>>8|0;f=b+1048320>>>16&8;b=b<<f;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|f))|0;f=(b<<1|a>>>b+21&1)+28|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+93488|0;d=x[23297];c=1<<f;L:{if(!(d&c)){x[23297]=c|d;x[b>>2]=i;break L}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[b+4>>2]&-8)==(a|0)){break C}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break B}d=e-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[23299]=b;a=a+c|0;x[23302]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[23303]=x[23418];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<g+16>>>0?g:a;x[d+4>>2]=27;a=x[23411];x[d+16>>2]=x[23410];x[d+20>>2]=a;a=x[23409];x[d+8>>2]=x[23408];x[d+12>>2]=a;x[23410]=d+8;x[23409]=e;x[23408]=c;x[23411]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(g|0)){break x}x[d+4>>2]=x[d+4>>2]&-2;f=d-g|0;x[g+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+93224|0;c=x[23296];a=1<<(f>>>3);M:{if(!(c&a)){x[23296]=a|c;a=b;break M}a=x[b+8>>2]}x[b+8>>2]=g;x[a+12>>2]=g;x[g+12>>2]=b;x[g+8>>2]=a;break x}a=31;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}x[g+28>>2]=a;x[g+16>>2]=0;x[g+20>>2]=0;b=(a<<2)+93488|0;d=x[23297];c=1<<a;N:{if(!(d&c)){x[23297]=c|d;x[b>>2]=g;break N}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break A}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=g}x[g+24>>2]=b;x[g+12>>2]=g;x[g+8>>2]=g;break x}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}a=x[b+8>>2];x[a+12>>2]=g;x[b+8>>2]=g;x[g+24>>2]=0;x[g+12>>2]=b;x[g+8>>2]=a}a=x[23299];if(a>>>0<=h>>>0){break d}b=a-h|0;x[23299]=b;c=x[23302];a=c+h|0;x[23302]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[115896]=48;a=0;break a}O:{if(!e){break O}b=x[d+28>>2];a=(b<<2)+93488|0;P:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break P}j=_ia(-2,b)&j;x[23297]=j;break O}x[e+(x[e+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break O}}x[c+24>>2]=e;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break O}x[c+20>>2]=a;x[a+24>>2]=c}Q:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break Q}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+93224|0;c=x[23296];a=1<<(f>>>3);R:{if(!(c&a)){x[23296]=a|c;a=b;break R}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break Q}a=31;if(f>>>0<=16777215){a=f>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|f>>>a+21&1)+28|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+93488|0;S:{c=1<<a;T:{if(!(c&j)){x[23297]=c|j;x[b>>2]=e;break T}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break Q}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}U:{if(!i){break U}b=x[c+28>>2];a=(b<<2)+93488|0;V:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break V}m=93188,n=_ia(-2,b)&j,x[m>>2]=n;break U}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break U}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break U}x[d+20>>2]=a;x[a+24>>2]=d}W:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break W}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+93224|0;g=x[23301];a=1<<(k>>>3);X:{if(!(a&e)){x[23296]=a|e;a=b;break X}a=x[b+8>>2]}x[b+8>>2]=g;x[a+12>>2]=g;x[g+12>>2]=b;x[g+8>>2]=a}x[23301]=d;x[23298]=f}a=c+8|0}hb=l+16|0;return a|0}function P5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;a:{b:{c:{d:{e:{f:{if(ne(b,21473)){Jb(a);break f}if(ne(b,9785)){b=hb-128|0;hb=b;f=Jb(a);x[23420]=0;Y(122,b+96|0);a=x[23420];x[23420]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23420]=0;x[b+64>>2]=0;R(1003,b+80|0,b- -64|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}x[23420]=0;a=Q(755,f|0,b+80|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break p}xb(b+80|0);x[23420]=0;a=Q(891,a|0,16590)|0;c=x[23420];x[23420]=0;r:{if((c|0)==1){break r}x[23420]=0;x[b+64>>2]=6;R(1003,b+80|0,b- -64|0);c=x[23420];x[23420]=0;if((c|0)==1){break o}x[23420]=0;a=Q(755,a|0,b+80|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break n}xb(b+80|0);x[23420]=0;a=Q(891,a|0,16590)|0;c=x[23420];x[23420]=0;if((c|0)==1){break r}x[23420]=0;x[b+64>>2]=7;R(1003,b+80|0,b- -64|0);c=x[23420];x[23420]=0;if((c|0)==1){break m}x[23420]=0;a=Q(755,a|0,b+80|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break l}c=b+80|0;xb(c);x[23420]=0;c=Q(54,c|0,15464)|0;d=x[23420];x[23420]=0;if((d|0)==1){break k}d=Eb(c);xb(c);if(!d){break j}x[23420]=0;Q(891,a|0,15464)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break j}}a=P()|0;break i}a=P()|0;break h}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}a=P()|0;xb(b+80|0);break i}a=P()|0;break i}c=Qb(b- -64|0);s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{d=x[b+108>>2];if(d){x[23420]=0;x[b+16>>2]=d;R(1003,b+32|0,b+16|0);d=x[23420];x[23420]=0;if((d|0)==1){break E}x[23420]=0;U(917,b+48|0,8866,b+32|0);d=x[23420];x[23420]=0;if((d|0)==1){break D}x[23420]=0;R(171,c|0,b+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break C}xb(b+48|0);xb(b+32|0)}if(!Rd(y[b+112|0])){break y}x[23420]=0;d=Q(54,b+48|0,12628)|0;e=x[23420];x[23420]=0;if((e|0)==1){break A}x[23420]=0;R(171,c|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break z}xb(d);break x}a=P()|0;break s}a=P()|0;break B}a=P()|0;xb(b+48|0)}xb(b+32|0);break s}a=P()|0;break s}a=P()|0;xb(d);break s}if(!Rd(y[b+113|0])){break x}x[23420]=0;d=Q(54,b+48|0,12399)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}x[23420]=0;R(171,c|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break v}xb(d)}if(Rd(y[b+114|0])){break u}break t}a=P()|0;break s}a=P()|0;xb(d);break s}x[23420]=0;d=Q(54,b+32|0,10992)|0;e=x[23420];x[23420]=0;F:{if((e|0)!=1){x[23420]=0;R(171,c|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break F}xb(d);break t}a=P()|0;break s}a=P()|0;xb(d);break s}if(uc(x[c>>2],x[c+4>>2])){break g}x[23420]=0;a=Q(891,a|0,16620)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;d=Q(54,b|0,16590)|0;e=x[23420];x[23420]=0;G:{H:{I:{if((e|0)!=1){x[23420]=0;U(1004,b+16|0,c|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break I}x[23420]=0;Q(755,a|0,b+16|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break H}xb(b+16|0);xb(d);break g}a=P()|0;break s}a=P()|0;break G}a=P()|0;xb(b+16|0)}xb(d);break s}a=P()|0}Ke(c)}rf(b+96|0)}xb(f);break b}Ke(c);rf(b+96|0);hb=b+128|0;break f}if(ne(b,8050)){x[g>>2]=0;kp(a,g);break f}if(ne(b,8028)){x[g>>2]=6;kp(a,g);break f}if(ne(b,10712)){x[g>>2]=7;kp(a,g);break f}if(ne(b,10488)){Vb(a,15464);break f}if(ne(b,11261)){b=Vb(g,15464);c=Eb(b);x[23420]=0;Q(54,a|0,(c?15625:15227)|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break e}xb(b);break f}if(ne(b,7330)){b=hb-48|0;hb=b;TD(b+16|0);x[23420]=0;Y(139,b|0);c=x[23420];x[23420]=0;J:{K:{L:{M:{if((c|0)!=1){x[23420]=0;U(140,b+32|0,b+16|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break M}x[23420]=0;R(964,a|0,b+32|0);a=x[23420];x[23420]=0;if((a|0)==1){break L}yb(b+32|0);yb(b);yb(b+16|0);hb=b+48|0;break f}a=P()|0;break J}a=P()|0;break K}a=P()|0;yb(b+32|0)}yb(b)}yb(b+16|0);break b}if(ne(b,9801)){b=hb-16|0;hb=b;e=hb-16|0;hb=e;x[e+8>>2]=101;c=hb-112|0;hb=c;f=Qb(c+96|0);N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{d=x[e+8>>2];if(d&1){x[23420]=0;R(128,c- -64|0,19924737);d=x[23420];x[23420]=0;if((d|0)==1){break aa}x[23420]=0;R(112,f|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break $}yb(c- -64|0);d=x[e+8>>2]}if(!(d&4)){break Z}x[23420]=0;d=ga(129)|0;h=x[23420];x[23420]=0;if((h|0)==1){break Y}if(!d){break _}break Z}d=P()|0;break O}d=P()|0;yb(c- -64|0);break O}x[23420]=0;Y(130,c- -64|0);d=x[23420];x[23420]=0;ba:{if((d|0)!=1){x[23420]=0;R(112,f|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break ba}yb(c- -64|0);break Z}d=P()|0;break O}d=P()|0;yb(c- -64|0);break O}ca:{d=x[e+8>>2];if(!(d&32)){break ca}x[23420]=0;Y(122,c- -64|0);d=x[23420];x[23420]=0;da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{if((d|0)!=1){x[23420]=0;R(131,c+48|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break ea}d=eh(x[c+52>>2],y[c+59|0]);yb(c+48|0);if(!d){x[23420]=0;Y(132,c+32|0);d=x[23420];x[23420]=0;if((d|0)==1){break va}x[23420]=0;R(131,c+16|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break ua}x[23420]=0;U(133,c+48|0,c+32|0,c+16|0);d=x[23420];x[23420]=0;if((d|0)==1){break ta}x[23420]=0;R(112,f|0,c+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break sa}yb(c+48|0);yb(c+16|0);cc(c+32|0)}d=Mo(c- -64|0);if(!eh(x[d+4>>2],y[d+11|0])){x[23420]=0;Y(134,c+32|0);h=x[23420];x[23420]=0;if((h|0)==1){break pa}x[23420]=0;U(135,c+48|0,c+32|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break oa}x[23420]=0;R(112,f|0,c+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break na}yb(c+48|0);cc(c+32|0)}x[23420]=0;R(136,c+48|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break la}d=eh(x[c+52>>2],y[c+59|0]);yb(c+48|0);if(!d){x[23420]=0;Y(132,c+32|0);d=x[23420];x[23420]=0;if((d|0)==1){break ka}x[23420]=0;R(136,c+16|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break ja}x[23420]=0;U(133,c+48|0,c+32|0,c+16|0);d=x[23420];x[23420]=0;if((d|0)==1){break ia}x[23420]=0;R(112,f|0,c+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break ha}yb(c+48|0);yb(c+16|0);cc(c+32|0)}rf(c- -64|0);d=x[e+8>>2];break ca}d=P()|0;break O}d=P()|0;break da}d=P()|0;break qa}d=P()|0;break ra}d=P()|0;yb(c+48|0)}yb(c+16|0)}cc(c+32|0);break da}d=P()|0;break da}d=P()|0;break ma}d=P()|0;yb(c+48|0)}cc(c+32|0);break da}d=P()|0;break da}d=P()|0;break da}d=P()|0;break fa}d=P()|0;break ga}d=P()|0;yb(c+48|0)}yb(c+16|0)}cc(c+32|0);break da}d=P()|0}rf(c- -64|0);break O}wa:{if(!(d&64)){break wa}x[23420]=0;d=ga(129)|0;h=x[23420];x[23420]=0;if((h|0)==1){break Y}if(d){break wa}d=c- -64|0;Jb(d);x[23420]=0;R(112,f|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break P}yb(c- -64|0)}if(y[e+8|0]&128){x[23420]=0;Y(137,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break X}x[23420]=0;R(112,f|0,c- -64|0);d=x[23420];x[23420]=0;if((d|0)==1){break W}yb(c- -64|0)}x[23420]=0;h=Q(1,c- -64|0,21473)|0;d=x[23420];x[23420]=0;if((d|0)==1){break V}x[23420]=0;U(138,c|0,f|0,h|0);d=x[23420];x[23420]=0;if((d|0)==1){break U}x[23420]=0;Y(139,c+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break T}x[23420]=0;U(140,b|0,c|0,c+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break S}yb(c+48|0);yb(c);yb(h);yl(f);hb=c+112|0;break N}d=P()|0;break O}d=P()|0;break O}d=P()|0;yb(c- -64|0);break O}d=P()|0;break O}d=P()|0;break Q}d=P()|0;break R}d=P()|0;yb(c+48|0)}yb(c)}yb(h);break O}d=P()|0;yb(c- -64|0)}yl(f);S(d|0);p()}hb=e+16|0;x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,10417)){b=hb-48|0;hb=b;kr(b);x[23420]=0;R(131,b+32|0,b|0);c=x[23420];x[23420]=0;xa:{ya:{if((c|0)!=1){x[23420]=0;R(964,a|0,b+32|0);a=x[23420];x[23420]=0;if((a|0)==1){break ya}yb(b+32|0);rf(b);hb=b+48|0;break f}a=P()|0;break xa}a=P()|0;yb(b+32|0)}rf(b);break b}if(ne(b,11224)){b=hb-32|0;hb=b;kr(b);x[23420]=0;R(964,a|0,Mo(b)|0);a=x[23420];x[23420]=0;if((a|0)!=1){rf(b);hb=b+32|0;break f}a=P()|0;rf(b);break b}if(ne(b,9814)){b=hb-48|0;hb=b;kr(b+16|0);c=x[b+28>>2];za:{if(c){x[23420]=0;x[b+12>>2]=c;R(1003,a|0,b+12|0);a=x[23420];x[23420]=0;if((a|0)!=1){break za}a=P()|0;rf(b+16|0);break b}Jb(a)}rf(b+16|0);hb=b+48|0;break f}if(ne(b,12618)){kr(g);b=y[g+16|0];x[23420]=0;Q(54,a|0,(Rd(b)?15227:15625)|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){rf(g);break f}a=P()|0;rf(g);break b}if(ne(b,9830)){kr(g);b=y[g+17|0];x[23420]=0;Q(54,a|0,(Rd(b)?15227:15625)|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){rf(g);break f}a=P()|0;rf(g);break b}if(ne(b,12071)){kr(g);b=y[g+18|0];x[23420]=0;Q(54,a|0,(Rd(b)?15227:15625)|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){rf(g);break f}a=P()|0;rf(g);break b}if(ne(b,12373)){b=hb-16|0;hb=b;c=hb-32|0;hb=c;d=Jb(b);x[23420]=0;Y(122,c|0);f=x[23420];x[23420]=0;Aa:{Ba:{if((f|0)!=1){x[23420]=0;R(123,d|0,Mo(c)|0);f=x[23420];x[23420]=0;if((f|0)==1){break Ba}rf(c);hb=c+32|0;break Aa}a=P()|0;break a}a=P()|0;rf(c);break a}x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,8171)){b=hb-16|0;hb=b;c=hb-48|0;hb=c;d=Jb(b);x[23420]=0;R(125,c+16|0,4096);f=x[23420];x[23420]=0;Ca:{Da:{Ea:{Fa:{if((f|0)!=1){x[c+12>>2]=16;x[c+8>>2]=0;x[23420]=0;x[c+4>>2]=0;ea(126,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=x[23420];x[23420]=0;if((f|0)==1){break Fa}x[23420]=0;Q(87,d|0,c+32|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Ea}yb(c+32|0);cc(c+16|0);hb=c+48|0;break Ca}a=P()|0;break a}a=P()|0;break Da}a=P()|0;yb(c+32|0)}cc(c+16|0);break a}x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,6783)){b=hb-16|0;hb=b;Mm(b,0,19419);x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,6416)){b=hb-48|0;hb=b;c=Vb(b+16|0,17480);x[23420]=0;R(1005,b|0,2);d=x[23420];x[23420]=0;Ga:{Ha:{Ia:{Ja:{if((d|0)!=1){x[23420]=0;U(2,b+32|0,c|0,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break Ja}x[23420]=0;R(964,a|0,b+32|0);a=x[23420];x[23420]=0;if((a|0)==1){break Ia}yb(b+32|0);yb(b);yb(c);hb=b+48|0;break f}a=P()|0;break Ga}a=P()|0;break Ha}a=P()|0;yb(b+32|0)}yb(b)}yb(c);break b}if(ne(b,11247)){b=hb-16|0;hb=b;Mm(b,0,17819);x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,10424)){b=hb-16|0;hb=b;hr(b,0);x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,10399)){b=hb-16|0;hb=b;hr(b,2);x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}if(ne(b,10384)){b=hb-16|0;hb=b;hr(b,3);x[23420]=0;R(964,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(b);hb=b+16|0;break f}break c}Jb(a)}hb=g+32|0;break d}a=P()|0;xb(b);break b}return}a=P()|0;yb(b)}S(a|0);p()}yb(d);S(a|0);p()}function HV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=yh(b,13672);if(!n){break a}o=a+480192|0;b:while(1){if(!Nb(x[b>>2],x[b+8>>2],6)){break a}c:{f=pg(b);d:{if((f|0)==(Bm(13491)|0)){break d}c=y[21449]|y[21450]<<8|(y[21451]<<16|y[21452]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}mg(b,4);break a}l=1;c=Eg(b);while(1){d=l&65535;if(d>>>0>z[o>>1]){continue b}d=x[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Bm(16574)|0)==(f|0)){$b(b,c);break e}e=hb-48|0;hb=e;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Xu(b,c),x[q>>2]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+15|0]=r;break g}if(c>>>0>4){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Xu(b,c),x[q+4>>2]=r;break g}if(c>>>0>4){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=Xu(b,c),x[q+8>>2]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+61|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+62|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+63|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d- -64|0,r=yd(b,c),v[q|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+81|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+82|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+83|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+84|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+101|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+102|0]=r;break g;case 0:if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+103|0]=r;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+104|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+16|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+17|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+18|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+19|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+20|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+21|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+22|0]=r;break g}if(c>>>0>2){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=NC(b,c),w[q+28>>1]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+30|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+31|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=MC(b,c),v[q+26|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+27|0]=r;break g}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,0);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(185,i|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break j}h=x[j>>2];q=Cb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,1);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(185,i|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){h=x[j>>2];q=Cb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,2);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(185,i|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){h=x[j>>2];q=Cb(h,g),r=k,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,0);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(186,i|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){h=x[j>>2];q=Cb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,1);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(186,i|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){h=x[j>>2];q=Cb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}Xd(e,b,c);i=jc(e+24|0,e);zb(e);j=Ci(d,2);h=x[j>>2];while(1){if(qe(h,x[j+4>>2])>>>0<=g>>>0){zb(i);break g}x[23420]=0;k=T(186,i|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){h=x[j>>2];q=Cb(h,g),r=k,v[q+2|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>128){break f}h=d+108|0;Xd(e,b,c);i=jc(e+24|0,e);zb(e);while(1){if((g|0)==128){zb(i);break g}x[23420]=0;j=T(186,i|0)|0;k=x[23420];x[23420]=0;if((k|0)!=1){q=Kb(h,g),r=j,v[q|0]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>256){break f}h=d+236|0;Xd(e,b,c);i=jc(e+24|0,e);zb(e);while(1){if((g|0)==128){zb(i);break g}x[23420]=0;j=T(185,i|0)|0;k=x[23420];x[23420]=0;if((k|0)!=1){q=bc(h,g),r=j,w[q>>1]=r;g=g+1|0;continue}break}g=P()|0;break i}if(c>>>0>32){break f}j=d+492|0;Xd(e,b,c);i=jc(e+24|0,e);zb(e);h=Jb(e);while(1){if((c|0)==(g|0)){break h}x[23420]=0;k=T(187,i|0)|0;m=x[23420];x[23420]=0;ka:{if((m|0)==1){break ka}x[23420]=0;Q(188,h|0,k|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;xb(h);break i}if(c>>>0>32){break f}j=d+524|0;Xd(e,b,c);i=jc(e+24|0,e);zb(e);h=Jb(e);la:{while(1){if((c|0)!=(g|0)){x[23420]=0;k=T(187,i|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break la}x[23420]=0;Q(188,h|0,k|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Dc(j,h);xb(h);zb(i);break g}g=P()|0;xb(h);break i}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+34|0]=r;break g}if(c>>>0>2){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=NC(b,c),w[q+12>>1]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+23|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+24|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+25|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+35|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+36|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+105|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+85|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+65|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+100|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+80|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=yd(b,c),v[q+60|0]=r;break g}if(c>>>0>1){break f}if(!Nb(x[b>>2],x[b+8>>2],c)){break f}q=d,r=MC(b,c),v[q+33|0]=r;break g}g=1;i=xo(b,c);if(!wo(i)){break f}v[d+14|0]=i;break f}q=d,r=D(Vu(b,c),1e4)+(A[d+40>>2]%1e4|0)|0,x[q+40>>2]=r;break g}h=(Vu(b,c)>>>0)%1e4|0;g=x[d+40>>2];x[d+40>>2]=h+g-(g>>>0)%1e4;break g}x[e+24>>2]=240;q=e,r=xo(b,c),x[q>>2]=r;bh(d+48|0,x[Hb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=xo(b,c),x[q>>2]=r;bh(d+68|0,x[Hb(e+24|0,e)>>2]);break g}x[e+24>>2]=240;q=e,r=xo(b,c),x[q>>2]=r;bh(d+88|0,x[Hb(e+24|0,e)>>2]);break g}g=P()|0}zb(i);S(g|0);p()}Dc(j,h);xb(h);zb(i)}g=1}hb=e+48|0;if(!g){$b(b,c);break e}if((Bm(16579)|0)==(f|0)){e=y[d+15|0];v[d+15|0]=0;v[d+100|0]=y[d+100|0]&224|(e>>>5&4|e>>>6&1);v[d+60|0]=e>>>1&2|(e<<1&4|(y[d+60|0]&240|e&1));v[d+80|0]=y[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function dV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=hb-304|0;hb=e;zc(b);if(Hq(b,17646)){o=Jb(e+288|0);x[23420]=0;f=Q(218,b|0,o|0)|0;g=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}x[23420]=0;f=Q(233,b|0,e+280|0)|0;g=x[23420];x[23420]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!TB(y[e+280|0],y[e+281|0])){break a}f=Vc(SB(e+280|0),lb);g=x[b+8>>2];m=x[b>>2];x[23420]=0;f=W(144,m|0,g|0,f|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}x[23420]=0;R(234,a|0,4096);d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;R(235,a+1298308|0,o|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}d=y[e+282|0];w[a+480188>>1]=32;w[a+480192>>1]=d;wh(a,1);x[23420]=0;d=Q(1,e+264|0,9378)|0;f=x[23420];x[23420]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Gb(a+1298344|0,d);yb(d);x[23420]=0;d=Q(1,e+248|0,7011)|0;f=x[23420];x[23420]=0;if((f|0)==1){break p}Gb(a+1298356|0,d);yb(d);x[23420]=0;Y(236,e+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break o}v[e+216|0]=y[e+281|0];x[23420]=0;v[e+8|0]=y[e+280|0];R(237,e+232|0,e+8|0);d=x[23420];x[23420]=0;if((d|0)==1){break n}x[23420]=0;X(238,e+96|0,e+48|0,e+216|0,e+232|0);d=x[23420];x[23420]=0;if((d|0)==1){break m}d=e+96|0;Gb(a+1298368|0,d);yb(d);yb(e+232|0);cc(e+48|0);x[a+1298404>>2]=5;if(y[e+280|0]<2){break i}w[e+96>>1]=8192;x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}w[e+48>>1]=d;s=a,t=D(z[Ve(e+96|0,e+48|0)>>1],1e4)>>>8|0,x[s+480204>>2]=t;x[23420]=0;v[e+96|0]=1;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break j}v[e+48|0]=d;s=a,t=y[_e(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[23420]=0;Q(176,b|0,3)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break h}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break l}b=P()|0;yb(e+232|0)}cc(e+48|0);break c}b=P()|0;break c}b=P()|0;break c}v[e+96|0]=32;x[23420]=0;d=T(194,b|0)|0;f=x[23420];x[23420]=0;q:{if((f|0)!=1){v[e+48|0]=d;s=a,t=D(y[_e(e+96|0,e+48|0)|0],1e4),x[s+480204>>2]=t;x[23420]=0;v[e+96|0]=1;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}v[e+48|0]=d;s=a,t=y[_e(e+96|0,e+48|0)|0],x[s+480196>>2]=t;x[23420]=0;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break h}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}x[a+480208>>2]=d>>>2&16|12;m=Qb(e+232|0);q=e+96|12;n=Qb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>z[a+480192>>1]){break s}x[23420]=0;f=W(239,a|0,d|0,0)|0;d=x[23420];x[23420]=0;t:{if((d|0)==1){break t}if(!f){break s}x[23420]=0;d=Q(228,b|0,f+492|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break t}if(!d){break s}x[23420]=0;k=T(194,b|0)|0;d=x[23420];x[23420]=0;u:{v:{w:{if((d|0)!=1){Tb(e+96|0,0,120);if(!k){break r}x:{if(y[e+280|0]){x[23420]=0;d=Q(240,b|0,e+96|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break w}if(!d){break r}if(y[e+280|0]){break x}}d=fc(e+88|0,q,96);g=x[d+4>>2];d=x[d>>2];x[23420]=0;bn(153,e+48|0,b,d,g);d=x[23420];x[23420]=0;if((d|0)==1){break v}if(!x[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}while(1){if((d|0)!=120){s=bc(g,d),t=(y[(e+96|0)+d|0]+z[h>>1]|0)+1|0,w[s>>1]=t;d=d+1|0;continue}break}x[23420]=0;d=f+48|0;U(241,e+8|0,d|0,b|0);g=x[23420];x[23420]=0;if((g|0)==1){break e}x[23420]=0;g=f+68|0;U(241,e+32|0,g|0,b|0);j=x[23420];x[23420]=0;if((j|0)==1){break e}x[23420]=0;j=f+88|0;U(241,e+80|0,j|0,b|0);l=x[23420];x[23420]=0;if((l|0)==1){break e}x[23420]=0;R(242,b|0,e+72|0);l=x[23420];x[23420]=0;if((l|0)==1){break f}x[f>>2]=(y[e+73|0]|y[e+74|0]<<8)&4095;l=y[e+73|0]|y[e+74|0]<<8;Au(y[e+75|0]|y[e+76|0]<<8,d,0);Au(y[e+75|0]|y[e+76|0]<<8,g,1);Au(y[e+75|0]|y[e+76|0]<<8,j,2);s=e,t=Db(x[d>>2]),x[s+48>>2]=t;l=l>>>12&3;r=Db(x[f+52>>2]);while(1){d=x[e+48>>2];if(Pb(d,r)){v[e+44|0]=64;v[e+70|0]=((y[d+2|0]<<6)- -64>>>0)/127;s=d,t=y[Wb(e+44|0,e+70|0)|0],v[s+2|0]=t;Ce(e+48|0);continue}else{s=e,t=Db(x[g>>2]),x[s+48>>2]=t;d=Db(x[f+72>>2])}break}while(1){g=x[e+48>>2];if(Pb(g,d)){v[e+44|0]=64;v[e+70|0]=((y[g+2|0]<<6)+128>>>0)/255;s=g,t=y[Wb(e+44|0,e+70|0)|0],v[s+2|0]=t;Ce(e+48|0);continue}break}s=e,t=Db(x[j>>2]),x[s+48>>2]=t;j=1<<l;l=Db(x[f+92>>2]);while(1){d=x[e+48>>2];if(Pb(d,l)){g=d;d=v[d+2|0];d=Wia(d^-128,d>>31^-1,j,0);f=lb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}s=g,t=Hc(d,f)^128,v[s+2|0]=t;Ce(e+48|0);continue}else{f=z[h>>1]+1|0;w[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0<=4e3?g:0;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){x[23420]=0;Q(176,b|0,20)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break A}b=P()|0;break d}x[23420]=0;j=d+f|0;Q(228,b|0,((j<<5)+a|0)+946304|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break z}x[23420]=0;R(243,b|0,e+48|0);l=x[23420];x[23420]=0;C:{if((l|0)==1){break C}x[23420]=0;R(244,e+48|0,(D(j,104)+a|0)+484380|0);j=x[23420];x[23420]=0;if((j|0)==1){break C}x[23420]=0;w[e+44>>1]=y[e+72|0]|d<<8&32512|((y[e+67|0]&3)!=0)<<15;R(245,n|0,e+44|0);j=x[23420];x[23420]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[23420]=0;R(245,m|0,e+70|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[e+48>>2]=3999;x[e+44>>2]=k+z[h>>1];s=h,t=x[td(e+48|0,e+44|0)>>2],w[s>>1]=t;break r}b=P()|0;break d}b=P()|0;break d}}}b=P()|0;break d}d=Jb(e+96|0);x[23420]=0;f=Q(218,b|0,d|0)|0;g=x[23420];x[23420]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){x[23420]=0;U(11,e+48|0,7,d|0);f=x[23420];x[23420]=0;if((f|0)==1){break I}f=e+48|0;Gb(a+1298320|0,f);yb(f)}xb(d);d=0;J:{while(1){if((d|0)==32){x[23420]=0;d=Q(246,b|0,e+32|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break G}if(!d){break F}d=x[e+32>>2];if(d>>>0<12){break H}f=x[b+8>>2];g=x[b>>2];x[23420]=0;d=W(144,g|0,f|0,d-11|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;Te(f+480280|0);x[23420]=0;R(219,b|0,f+480289|0);f=x[23420];x[23420]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}d=x[e+32>>2]-11|0;x[e+80>>2]=d;h=Qb(e+96|0);x[23420]=0;U(222,b|0,h|0,d|0);d=x[23420];x[23420]=0;K:{if((d|0)!=1){x[e+48>>2]=50529027;d=e+48|0;s=e,t=D(x[Hb(e+80|0,d)>>2],85),x[s+72>>2]=t;g=Jb(d);x[e+8>>2]=x[e+36>>2];d=x[Hb(e+72|0,e+8|0)>>2];x[23420]=0;R(45,g|0,d|0);d=x[23420];x[23420]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=x[e+80>>2];if(f>>>0<=d>>>0){break M}i=x[h>>2];k=y[Kb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=v[Kb(i,f)|0];i=y[Kb(i,d+2|0)|0];s=e,t=mh(g),x[s+8>>2]=t;k=x[Gf(e+24|0,e+8|0)>>2];x[23420]=0;X(225,g|0,k|0,i|0,f|0);f=x[23420];x[23420]=0;if((f|0)!=1){d=d+3|0;continue}break L}x[23420]=0;R(46,g|0,k<<24>>24);i=x[23420];x[23420]=0;d=f;if((i|0)!=1){continue}break}break L}x[23420]=0;X(223,e+8|0,5,7,g|0);d=x[23420];x[23420]=0;if((d|0)!=1){N:{f=e+8|0;d=Ac(g,f);xb(f);f=Ic(d);i=Eb(d);x[23420]=0;ea(224,a+1298332|0,f|0,i|0,74,0);f=x[23420];x[23420]=0;if((f|0)==1){break N}xb(d);dc(h);break H}}}b=P()|0;xb(g);break K}b=P()|0}dc(h);break d}}b=P()|0;xb(d);break d}d=y[a+484376|0];f=x[a+484360>>2];x[23420]=0;U(226,Yb(f,d)|0,b|0,y[e+285|0]|y[e+286|0]<<8);d=x[23420];x[23420]=0;if((d|0)==1){break G}i=c&1;if(i){x[23420]=0;R(213,a+484344|0,y[e+283|0]|y[e+284|0]<<8);d=x[23420];x[23420]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((y[e+283|0]|y[e+284|0]<<8)>>>0>d>>>0){b=x[f+8>>2];g=x[f>>2];x[23420]=0;b=W(144,g|0,b|0,4)|0;g=x[23420];x[23420]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=z[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=z[bc(x[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=x[m>>2];g=g-1&65535;if(Mc(h,x[m+4>>2])>>>0<=g>>>0){break P}j=b;b=z[bc(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=D(b,104);g=b+a|0;c=g+484380|0;h=x[c>>2];if(!Td(h,x[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=z[g+34>>1];b=b+D(d+1|0,104)|0;x[b>>2]=h;w[b+34>>1]=z[b+34>>1]&65534|i&1;if(!Ag(b)){break P}pc(x[b+20>>2],x[g+20>>2],uj(x[c>>2],z[c+34>>1]))}d=d+1|0;b=z[f>>1];continue}}b=z[bc(x[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=D(d,104)+a|0;b=_c(e+96|0,w[g+484414>>1]&1?16:8,1,0,b<<16>>16<0?6:0);x[23420]=0;W(207,b|0,g+484380|0,f|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}break}b=P()|0;break d}x[23420]=0;b=T(145,f|0)|0;g=x[23420];x[23420]=0;Q:{R:{S:{T:{if((g|0)!=1){x[23420]=0;U(178,e+48|0,f|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break T}b=e+48|0;g=jc(e+96|0,b);zb(b);if(!i){break R}x[23420]=0;b=T(194,g|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break Q}x[23420]=0;Q(176,g|0,1)|0;k=x[23420];x[23420]=0;if((k|0)==1){break Q}x[23420]=0;b=W(214,h|0,d&65535,b+1|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break Q}if(!b){break R}x[23420]=0;b=Q(220,g|0,e+48|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break E}if(!b){break S}b=x[h>>2];x[23420]=0;R(221,_b(b,d)|0,e+48|0);b=x[23420];x[23420]=0;if((b|0)!=1){break S}break E}b=P()|0;break d}b=P()|0;break d}b=x[h>>2];x[23420]=0;U(227,_b(b,d)|0,1,g|0);b=x[23420];x[23420]=0;if((b|0)==1){break E}}zb(g);d=d+1|0;continue}break}break E}b=P()|0;break d}od(n);od(m);break b}b=P()|0;zb(g);break d}b=P()|0;break d}i=i+1|0;continue}}b=P()|0;break c}b=P()|0;break c}b=P()|0;break d}b=P()|0}od(n);od(m)}xb(o);S(b|0);p()}d=1}xb(o)}hb=e+304|0;return d|0}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=hb-400|0;hb=e;zc(b);g=e+376|0;f=WB(b,g);if(!f){Du(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!LT(e+376|0)){break e}if(!Nb(x[b>>2],x[b+8>>2],Vc(72,0))){break e}if(!c){d=1;break e}Dd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;g=y[e+385|0];w[a+480190>>1]=63;w[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Tb(e+304|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>z[a+480190>>1]){aC(b,a+1298308|0);g=e+296|0;d=hb-16|0;hb=d;k:{if(!Nb(x[b>>2],x[b+8>>2],8)){v[d|0]=0;Xh(g,8,d);break k}Lm(d+8|0,g);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;n=Qb(e+280|0);g=z[e+386>>1];if(!g){break i}d=0;x[23420]=0;g=W(307,b|0,n|0,D(g,y[e+385|0])<<1)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break j}g=P()|0;break a}f=(D(g,104)+a|0)+484380|0;pd(f,1);i=g+(e+304|0)|0;g=Ee(b);v[i|0]=g;if(g<<24>>24>=0){B=f,C=JT(b)<<1,x[B>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=x[n>>2];hc(e+272|0,d,Wc(d,x[n+4>>2])>>>1|0);m=Qb(e+256|0);x[23420]=0;R(308,m|0,z[e+388>>1]<<8);d=x[23420];x[23420]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=z[e+388>>1];if(g>>>0>=d>>>0){break m}x[e+208>>2]=d-g;x[e+152>>2]=2e3;d=e+208|0;f=x[td(d,e+152|0)>>2];d=Qb(d);x[23420]=0;f=W(307,b|0,d|0,f<<8)|0;h=x[23420];x[23420]=0;if((h|0)==1){break l}if(!f){break n}f=gc(e+248|0,Db(x[m+4>>2]));h=Db(x[d>>2]);j=Db(x[e+212>>2]);f=x[f>>2];x[23420]=0;X(309,m|0,f|0,h|0,j|0);f=x[23420];x[23420]=0;if((f|0)!=1){dc(d);d=g+2e3|0;continue}break}break c}dc(d);d=0;break g}ke(e+232|0,x[m>>2],x[m+4>>2]);Lg(e+240|0,x[e+232>>2],x[e+236>>2]);q=a+484376|0;d=y[q|0];g=x[a+484360>>2];x[23420]=0;R(310,Yb(g,d)|0,z[e+386>>1]);d=x[23420];x[23420]=0;if((d|0)==1){break d}r=a+484344|0;t=c&1;j=0;while(1){if(z[e+386>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>z[a+480190>>1]){break v}x[23420]=0;d=y[c+(e+304|0)|0];U(311,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[23420];x[23420]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}x[23420]=0;d=T(312,b|0)|0;f=x[23420];x[23420]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[23420]=0;d=T(312,b|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break I}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[23420]=0;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break s}v[e+72|0]=d;v[e+176|0]=64;B=c+484410|0,C=y[Wb(e+72|0,e+176|0)|0]<<2,w[B>>1]=C;x[23420]=0;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break J}v[c+484417|0]=d<<4;c=c+484380|0;nB(c);if(!x[c>>2]){break B}x[23420]=0;f=T(194,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;break b}g=P()|0;break b}if(h){f=Qb(e+72|0);j=x[b+8>>2];i=x[b>>2];k=x[c>>2];x[23420]=0;j=W(144,i|0,j|0,k|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break r}if(!j){break w}d=x[c>>2];x[23420]=0;U(313,b|0,f|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break r}B=e,C=Db(x[f>>2]),x[B+176>>2]=C;j=Db(x[e+76>>2]);while(1){d=x[e+176>>2];if(Pb(d,j)){i=d;d=y[d|0];v[i|0]=d<<7|(d^-1)>>>1&127;Be(e+176|0);continue}break}ke(e+200|0,x[f>>2],x[e+76>>2]);d=$d(e+192|0);x[23420]=0;j=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=j;d=wg(314,e+208|0,x[e+200>>2],x[e+204>>2],e+16|0);j=x[23420];x[23420]=0;K:{if((j|0)!=1){j=_c(e+176|0,16,1,0,16);x[23420]=0;W(207,j|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break K}zb(d);dc(f);break B}g=P()|0;break o}g=P()|0;zb(d);break o}c=x[c>>2];break E}f=Qb(e+72|0);d=x[c>>2];x[23420]=0;U(315,e+176|0,b|0,d|0);d=x[23420];x[23420]=0;L:{M:{N:{if((d|0)!=1){d=e+176|0;j=rm(f,d);dc(d);if(h){ke(e+144|0,x[j>>2],x[e+76>>2]);d=$d(e+136|0);x[23420]=0;i=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=i;d=wg(314,e+152|0,x[e+144>>2],x[e+148>>2],e+24|0);i=x[23420];x[23420]=0;if((i|0)==1){break N}i=_c(e+176|0,8,1,0,2);x[23420]=0;W(207,i|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break M}zb(d)}dc(j);break B}g=V(30320)|0;if((ib|0)!=(da(30320)|0)){break L}_(g|0)|0;d=0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){break u}g=P()|0;break L}g=P()|0;break L}g=P()|0;zb(d)}dc(f);break b}if(h){d=_c(e+72|0,(f|0)==2?8:16,1,0,0);x[23420]=0;W(207,d|0,c|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break B}g=P()|0;break b}c=D(x[c>>2],f-1|0)}x[23420]=0;Q(176,b|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break B}}g=P()|0;break b}j=Qb(e+72|0);d=x[c>>2];x[23420]=0;U(316,e+176|0,b|0,d|0);d=x[23420];x[23420]=0;O:{P:{if((d|0)!=1){i=e+176|0;d=rm(j,i);dc(i);if(!h){break O}if((f|0)!=5){break P}B=e,C=Db(x[d>>2]),x[B+176>>2]=C;k=Db(x[e+76>>2]);while(1){i=x[e+176>>2];if(!Pb(i,k)){break P}l=i;i=y[i|0];v[l|0]=y[(i>>>7|0)+26209|0]^i;Be(e+176|0);continue}}g=V(30320)|0;if((ib|0)!=(da(30320)|0)){break x}_(g|0)|0;d=0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){break A}g=P()|0;break x}ke(e+104|0,x[d>>2],x[e+76>>2]);i=$d(e+96|0);x[23420]=0;k=x[i+4>>2];x[e+32>>2]=x[i>>2];x[e+36>>2]=k;i=wg(314,e+112|0,x[e+104>>2],x[e+108>>2],e+32|0);k=x[23420];x[23420]=0;if((k|0)==1){break z}f=(f|0)==5;f=_c(e+176|0,f?16:8,1,0,f?16:1);x[23420]=0;W(207,f|0,c|0,i|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break y}zb(i)}dc(d)}g=g+1|0;continue}break}dc(j);break g}g=P()|0;break x}g=P()|0;zb(i)}dc(j);break b}dc(f);break g}Q:{R:{S:{T:{d=z[e+390>>1]|y[e+392|0]<<16;if(d){c=Qb(e+176|0);x[23420]=0;b=W(307,b|0,c|0,d|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break q}if(!b){break R}ke(e- -64|0,x[c>>2],x[c+4>>2]);b=$d(e+56|0);x[23420]=0;g=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=g;b=wg(314,e+72|0,x[e+64>>2],x[e+68>>2],e+8|0);g=x[23420];x[23420]=0;if((g|0)==1){break T}x[23420]=0;X(317,a+1298332|0,b|0,d|0,1);d=x[23420];x[23420]=0;if((d|0)==1){break S}zb(b);dc(c)}x[23420]=0;Y(318,e+40|0);b=x[23420];x[23420]=0;if((b|0)!=1){break Q}g=P()|0;break b}g=P()|0;break p}g=P()|0;zb(b);break p}dc(c);d=0;break g}x[23420]=0;U(201,e+176|0,e+40|0,y[e+384|0]);b=x[23420];x[23420]=0;U:{V:{if((b|0)!=1){b=e+176|0;Gb(a+1298344|0,b);yb(b);cc(e+40|0);x[23420]=0;b=Q(1,b|0,9988)|0;c=x[23420];x[23420]=0;if((c|0)==1){break V}Gb(a+1298356|0,b);yb(b);x[23420]=0;b=Q(1,e+40|0,5062)|0;c=x[23420];x[23420]=0;if((c|0)==1){break U}Gb(a+1298368|0,b);yb(b);x[a+1298404>>2]=10;d=1;break g}g=P()|0;cc(e+40|0);break b}g=P()|0;break b}g=P()|0;break b}dc(f);break g}g=P()|0;break b}g=P()|0;break b}g=P()|0;break o}g=P()|0}dc(c);break b}dc(f);break b}B=bc(x[Yb(x[a+484360>>2],y[q|0])>>2],j),C=j,w[B>>1]=C;W:{X:{if(!t){break X}x[23420]=0;s=j&65535;d=W(214,r|0,s|0,64)|0;g=x[23420];x[23420]=0;if((g|0)==1){break W}if(!d){break X}f=z[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break X}d=bc(x[e+272>>2],D(d,j)+i|0);d=y[d|0]|y[d+1|0]<<8;Y:{if(d>>>0>=z[e+388>>1]){break Y}g=0;u=0-i|0;A=d<<8;d=_b(x[r>>2],j);d=ed(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Y}iq(e+208|0,x[e+240>>2],x[e+244>>2],(g<<2)+A|0,4);f=x[e+208>>2];h=Kb(f,0);o=y[h|0]&63;v[d|0]=o?o+48|0:0;k=Kb(f,1);v[d+1|0]=y[k|0]<<2&60|y[h|0]>>>6;h=y[k|0];l=Kb(f,2);k=y[Kb(f,3)|0];l=y[l|0];f=k<<4|l>>>4;w[e+72>>1]=f;l=l<<2&60;h=l|h>>>6;Z:{if(!(y[Kb(e+296|0,l>>>3|0)|0]>>>(h&7)&1)|!(f|h)){break Z}v[d+5|0]=f;v[d+3|0]=h;l=k>>>4|0;v[d+4|0]=l;_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(h|0){case 0:case 1:case 2:case 32:case 33:case 34:v[d+3|0]=h&15;Of(d);if(!y[d+4|0]){break Z}v[d+2|0]=h>>>0<32?3:4;break Z;case 9:v[d+3|0]=10;v[d+5|0]=f>>>1;if(f>>>0<512){break Z}v[d+2|0]=15;v[d+4|0]=k>>>5;break Z;case 10:case 42:if(f>>>0>254){break ia}v[d+3|0]=h&15;break;case 50:break $;case 48:break aa;case 43:break ba;case 47:break ca;case 17:case 18:case 26:case 27:break da;case 22:case 25:case 28:case 29:case 30:break ea;case 16:case 19:case 20:case 21:case 23:case 31:break fa;case 13:break ga;case 11:case 15:break ha;case 3:case 4:case 5:case 6:case 7:case 12:break ja;default:break _}}Of(d);break Z}v[d+3|0]=19;v[d+5|0]=l|(h>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(f&240)>>>4;break Z}v[d+2|0]=4;v[d+4|0]=f&15;break Z}v[d+3|0]=(h|0)==11?12:16;B=d,C=hu(f),v[B+5|0]=C;break Z}v[d+3|0]=14;if((f&255)>>>0<64){break Z}v[d+5|0]=0;break Z}v[d+3|0]=19;v[d+5|0]=f&15|h<<4;break Z}v[d+3|0]=19;w[e+152>>1]=15;B=d,C=y[Zc(e+72|0,e+152|0)|0]|h<<4,v[B+5|0]=C;break Z}v[d+3|0]=19;if(f&255){v[d+5|0]=f&15|((h|0)==17?16:(h|0)==26?16:32);if(k>>>0<16){break Z}v[d+2|0]=h>>>0>25?6:5;break Z}v[d+5|0]=l|(h>>>0>25?-80:-96);break Z}if(!f){break _}v[d+3|0]=17;x[e+152>>2]=8;x[e+112>>2]=f+4;B=d,C=xi(x[Le(e+152|0,e+112|0)>>2]/8|0),v[B+5|0]=C;break Z}v[d+3|0]=14;k=D(u,6)+d|0;o=z[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break Z}h=k+D(f,6)|0;if(!y[h+3|0]){v[h+3|0]=12;B=h,C=hu(s),v[B+5|0]=C}f=f+1|0;continue}}v[d+3|0]=9;h=f&7;if(h){v[d+5|0]=y[h+26201|0];break Z}h=f>>>4|0;if((h|0)==128){break _}v[d+5|0]=h;if(f>>>0<=2047){v[d+5|0]=h^128;break Z}v[d+5|0]=h^-1;break Z}v[d+5|0]=0;v[d+3|0]=0;if(!o){v[d|0]=255;break Z}v[d+3|0]=25;break Z}v[d+3|0]=0}g=g+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;break b}break c}}else{lB(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=z[a+480188>>1];continue}break}g=P()|0;break b}dc(m)}dc(n)}hb=e+400|0;return d|0}g=P()|0;break b}g=P()|0;dc(d)}dc(m)}dc(n);S(g|0);p()}function BG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=hb-144|0;hb=e;d=Tb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1067;x[d+84>>2]=a;t=c;a=0;h=hb-304|0;hb=h;a:{b:{c:{d:{if(x[d+4>>2]){break d}Nw(d);if(x[d+4>>2]){break d}break c}g=y[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(Ak(c)){while(1){g=b;b=b+1|0;if(Ak(y[g+1|0])){continue}break}ci(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=nd(d)}if(Ak(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;c=b>>31;i=b;e=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=y[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}ci(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;g=y[c|0];break p}g=nd(d)}if(Ak(g)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;g=y[c|0];break o}g=nd(d)}if(y[b|0]!=(g|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(u){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;g=c>>31;f=c;c=n+x[d+124>>2]|0;e=m+x[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!Mj(c)|y[b+2|0]!=36)){e=hb-16|0;x[e+12>>2]=t;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+t|0;x[e+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[t>>2];t=t+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Mj(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=y[g|0];e=(b&47)==3;z=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)<=1?1:c;break s}CG(l,z,m,n);break j}ci(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=nd(d)}if(Ak(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;f=b>>31;j=b;e=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;ci(d,c,s);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((nd(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:EG(h+8|0,d,z,0);b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-b|0)|x[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Tb(h+32|0,-1,257);v[h+32|0]=0;if((p|0)!=115){break x}v[h+65|0]=0;v[h+46|0]=0;w[h+42>>1]=0;w[h+44>>1]=0;break x}e=y[g+1|0];f=(e|0)==94;Tb(h+32|0,f,257);v[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=y[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;v[h+78|0]=k;break C}k=(e|0)!=94;v[h+126|0]=k}b=b+1|0}g=b;while(1){e=y[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=y[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(h+32|0)|0]=k;e=y[i|0];if(e>>>0>b>>>0){continue}break}}g=i}v[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;A=hb-16|0;hb=A;G:{if((b|0)==1){x[115896]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=nd(d)}if(Ak(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=nd(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=nd(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=nd(d)}if(y[c+78033|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}ci(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+78033|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}ci(d,0,0);x[115896]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=nd(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=Wia(j,0,10,0);f=lb;b=e;while(1){c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=nd(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=Wia(j,i,10,0);f=lb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=y[c+78033|0];if(f>>>0<b>>>0){while(1){e=D(b,e)+f|0;j=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=nd(d)}f=y[c+78033|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=Wia(j,i,b,0);e=lb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=nd(d)}f=y[c+78033|0];if(b>>>0<=f>>>0){break L}lf(A,b,0,0,0,j,i,0,0);if(!(x[A+8>>2]|x[A+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+78289|0];e=y[c+78033|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=nd(d)}e=y[c+78033|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=nd(d)}e=y[c+78033|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(y[c+78033|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=nd(d)}if(y[c+78033|0]<b>>>0){continue}break}x[115896]=68;j=-1;i=-1;s=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}hb=A+16|0;b=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-b|0)&x[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){x[l>>2]=j;break w}CG(l,z,j,i);break w}if(!l){break w}b=x[h+16>>2];c=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];Y:{switch(z|0){case 0:G=l,H=MD(e,f,b,c),B[G>>2]=H;break w;case 1:G=l,I=Ev(e,f,b,c),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=e;x[l+4>>2]=f;x[l+8>>2]=b;x[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((z|0)==1){e=l;if(r){e=Ld(c<<2);if(!e){break h}}x[h+296>>2]=0;x[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=nd(d)}if(!y[(e+h|0)+33|0]){break _}v[h+27|0]=e;e=Ir(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=Mt(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?x[h+296>>2]:0){break f}break Z}if(r){b=0;e=Ld(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=nd(d)}if(!y[(e+h|0)+33|0]){c=0;o=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=Mt(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=nd(d)}if(y[(a+h|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=nd(d)}if(y[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=x[d+4>>2];f=x[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;x[d+4>>2]=e}f=e-x[d+44>>2]|0;k=f;e=f+x[d+120>>2]|0;f=x[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){x[l>>2]=a}da:{if(i){break da}if(c){x[(b<<2)+c>>2]=0}if(!o){o=0;break da}v[b+o|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b>>31;i=b;c=n+x[d+124>>2]|0;b=m+x[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;u=((l|0)!=0)+u|0}b=g+1|0;g=y[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(u){break b}}u=-1}if(!f){break a}Ib(o);Ib(a)}hb=h+304|0;hb=d+144|0;return u}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;g=hb-32|0;hb=g;d=Vb(g+16|0,11458);h=Pg(c,d);xb(d);a:{b:{c:{d:{e:{if(h){Mk(a,x[b+24>>2]+1298356|0);break e}d=Vb(g+16|0,10864);h=Pg(c,d);xb(d);if(h){Mk(a,x[b+24>>2]+1298344|0);break e}d=Vb(g+16|0,11288);h=Pg(c,d);xb(d);if(h){Mk(a,x[b+24>>2]+1298392|0);break e}d=Vb(g+16|0,10856);h=Pg(c,d);xb(d);if(h){Mk(a,x[b+24>>2]+1298380|0);break e}d=Vb(g+16|0,8161);h=Pg(c,d);xb(d);if(h){c=g+16|0;d=x[x[b+24>>2]+480184>>2];b=32624;f:{g:{while(1){if((b|0)==32672){break g}if((d|0)!=x[b>>2]){b=b+12|0;continue}break}Mm(c,0,x[b+8>>2]);break f}Jb(c)}x[23420]=0;R(964,a|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}yb(g+16|0);break e}d=Vb(g+16|0,10841);h=Pg(c,d);xb(d);if(h){f=x[x[b+24>>2]+480184>>2];c=hb+-64|0;hb=c;b=32624;e=gg(c+48|0);j=g+16|0;d=Jb(j);while(1){if((b|0)!=32672){if((f|0)==x[b>>2]){h=x[b+4>>2];x[23420]=0;h=Q(1,c+32|0,h|0)|0;i=x[23420];x[23420]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){x[23420]=0;U(800,c+24|0,e|0,h|0);i=x[23420];x[23420]=0;if((i|0)==1){break k}if(!y[c+28|0]){break h}if(!eh(x[d+4>>2],y[d+11|0])){x[23420]=0;i=Q(1,c+8|0,17591)|0;k=x[23420];x[23420]=0;if((k|0)==1){break m}x[23420]=0;Q(87,d|0,i|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break l}yb(i)}x[23420]=0;Q(87,d|0,h|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){break h}b=P()|0;break j}b=P()|0;break i}b=P()|0;break j}b=P()|0;yb(i);break j}b=P()|0}yb(h)}yb(d);QL(e);S(b|0);p()}yb(h)}b=b+12|0;continue}break}QL(e);hb=c- -64|0;x[23420]=0;R(964,a|0,j|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(g+16|0);break e}c=P()|0;yb(g+16|0);break a}d=Vb(g+16|0,8227);h=Pg(c,d);xb(d);if(h){Mk(a,x[b+24>>2]+1298368|0);break e}d=Vb(g+16|0,5581);h=Pg(c,d);xb(d);if(h){Mk(a,x[b+24>>2]+1298320|0);break e}d=Vb(g+16|0,11862);h=Pg(c,d);xb(d);if(h){c=g+16|0;Oh(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[23420]=0;U(958,a|0,b|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(g+16|0);break e}c=P()|0;xb(g+16|0);break a}d=Vb(g+16|0,11231);h=Pg(c,d);xb(d);if(h){c=x[b+24>>2]+1298408|0;b=x[c+4>>2];n:{if(!uc(x[c>>2],b)){b=b-48|0;if(wd(x[b+12>>2])){break n}}Jb(a);break e}o=g+16|0;j=hb-144|0;hb=j;pc(j+96|0,b,44);e=x[b+44>>2];if(e){pc(j+44|0,b,44);h=hb-16|0;hb=h;b=Cw(x[j+64>>2]+1900|0,x[j+60>>2]+1|0,x[j+56>>2])-Cw(1970,1,1)|0;b=Wia(b,b>>31,86400,0);c=D(x[j+52>>2],3600);b=b+c|0;d=lb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=D(x[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=x[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=Bk(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=x[c>>2];i=x[c+4>>2];hb=h+16|0;h=j+88|0;d=2147483647;m=fe(+(e>>>0)/18.2);c=-1;o:{if(m>=0x8000000000000000){break o}d=-2147483648;c=0;if(m<=-0x8000000000000000){break o}if(F(m)<0x8000000000000000){d=F(m)>=1?~~(m>0?H(J(m*2.3283064365386963e-10),4294967295):K((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break o}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=Bk(h,c,d);i=x[b+4>>2];h=x[b>>2];k=hb-16|0;hb=k;x[k+12>>2]=0;x[k+8>>2]=0;x[k+4>>2]=0;b=Cw(1970,1,1)+Xia(h,i,86400,0)|0;f=b>>31;d=Wia(b,f,1e4,0)+14780|0;c=lb;e=d;c=d>>>0<14780?c+1|0:c;l=Xia(d,c,-14609700,-1)+b|0;d=f+lb|0;d=b>>>0>l>>>0?d+1|0:d;n=Xia(e,c,365242500,0);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=Xia(e,c,-146097e4,-1);l=n+l|0;d=lb+d|0;d=l>>>0<n>>>0?d+1|0:d;c=Xia(e,c,3652425,0);e=lb;n=e;q=l;l=Wia(c,e,-365,-1);e=q+l|0;d=lb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=Wia(c,d,-365,-1)+b|0;d=f+lb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=Wia(e,d,100,0)+52|0;c=lb;b=Xia(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;x[k+12>>2]=f+d;x[k+8>>2]=(c+D(d,-12)|0)+1;b=Wia(b,lb,306,0)+5|0;d=lb;b=Xia(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;x[k+4>>2]=b+1;x[j+136>>2]=0;x[j+128>>2]=0;x[j+132>>2]=0;x[j+120>>2]=0;x[j+124>>2]=0;x[j+116>>2]=x[k+12>>2]-1900;x[j+112>>2]=x[k+8>>2]-1;b=x[k+4>>2];r=j,s=Yia(Xia(h,i,3600,0),lb,24),x[r+104>>2]=s;x[j+108>>2]=b;b=Xia(h,i,60,0);c=lb;r=j,s=Yia(b,c,60),x[r+100>>2]=s;b=Wia(b,c,-60,0)+h|0;x[j+96>>2]=b;hb=k+16|0}c=pc(j,j+96|0,44);b=hb-176|0;hb=b;h=Jb(b+160|0);x[23420]=0;d=Q(1,b+144|0,13324)|0;e=x[23420];x[23420]=0;p:{q:{r:{s:{t:{if((e|0)!=1){e=x[c+20>>2];if(!e){break q}x[23420]=0;x[b+112>>2]=e+1900;R(86,b+128|0,b+112|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;i=Q(87,h|0,b+128|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break t}yb(b+128|0);f=x[c+16>>2];if(f>>>0>11){break q}x[23420]=0;e=Q(1,b+112|0,16618)|0;j=x[23420];x[23420]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){x[23420]=0;x[b+80>>2]=f+1;R(88,b+96|0,b+80|0);f=x[23420];x[23420]=0;if((f|0)==1){break z}x[23420]=0;U(2,b+128|0,e|0,b+96|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}x[23420]=0;i=Q(87,i|0,b+128|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break x}yb(b+128|0);yb(b+96|0);yb(e);if(x[c+12>>2]-32>>>0>=4294967265){break u}break q}a=P()|0;break s}a=P()|0;break v}a=P()|0;break w}a=P()|0;yb(b+128|0)}yb(b+96|0)}yb(e);break s}x[23420]=0;e=Q(1,b+96|0,16618)|0;f=x[23420];x[23420]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){x[23420]=0;R(88,b+80|0,c+12|0);f=x[23420];x[23420]=0;if((f|0)==1){break Z}x[23420]=0;U(2,b+128|0,e|0,b+80|0);f=x[23420];x[23420]=0;if((f|0)==1){break Y}x[23420]=0;i=Q(87,i|0,b+128|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break X}yb(b+128|0);yb(b+80|0);yb(e);j=x[c>>2];e=x[c+8>>2];f=x[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break q}x[23420]=0;e=Q(1,b+128|0,13484)|0;f=x[23420];x[23420]=0;if((f|0)==1){break U}x[23420]=0;i=Q(87,i|0,e|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break T}yb(e);if(x[c+32>>2]>0){x[23420]=0;e=Q(1,b+80|0,15401)|0;f=x[23420];x[23420]=0;if((f|0)==1){break S}Gb(d,e);yb(e)}x[23420]=0;R(88,b+32|0,c+8|0);e=x[23420];x[23420]=0;if((e|0)==1){break R}x[23420]=0;e=Q(1,b+16|0,14489)|0;f=x[23420];x[23420]=0;if((f|0)==1){break Q}x[23420]=0;U(2,b+48|0,b+32|0,e|0);f=x[23420];x[23420]=0;if((f|0)==1){break P}x[23420]=0;R(88,b|0,c+4|0);f=x[23420];x[23420]=0;if((f|0)==1){break O}x[23420]=0;U(2,b- -64|0,b+48|0,b|0);f=x[23420];x[23420]=0;if((f|0)==1){break N}x[23420]=0;i=Q(87,i|0,b- -64|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break M}yb(b- -64|0);yb(b);yb(b+48|0);yb(e);yb(b+32|0);if(j>>>0<62){break H}x[23420]=0;U(89,o|0,i|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break G}break p}a=P()|0;break s}a=P()|0;break V}a=P()|0;break W}a=P()|0;yb(b+128|0)}yb(b+80|0)}yb(e);break s}a=P()|0;break s}a=P()|0;yb(e);break s}a=P()|0;break s}a=P()|0;break s}a=P()|0;break I}a=P()|0;break J}a=P()|0;break K}a=P()|0;break L}a=P()|0;yb(b- -64|0)}yb(b)}yb(b+48|0)}yb(e)}yb(b+32|0);break s}x[23420]=0;e=Q(1,b+48|0,14489)|0;f=x[23420];x[23420]=0;if((f|0)==1){break F}x[23420]=0;R(88,b+32|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break E}x[23420]=0;U(2,b- -64|0,e|0,b+32|0);f=x[23420];x[23420]=0;if((f|0)==1){break D}x[23420]=0;i=Q(87,i|0,b- -64|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break C}yb(b- -64|0);yb(b+32|0);yb(e);x[23420]=0;Q(87,i|0,d|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break q}}a=P()|0;break s}a=P()|0;break s}a=P()|0;break A}a=P()|0;break B}a=P()|0;yb(b- -64|0)}yb(b+32|0)}yb(e);break s}a=P()|0;break s}a=P()|0;break r}a=P()|0;yb(b+128|0)}yb(d)}yb(h);S(a|0);p()}Rc(o,h)}yb(d);yb(h);hb=b+176|0;hb=c+144|0;x[23420]=0;R(964,a|0,o|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(g+16|0);break e}c=P()|0;yb(g+16|0);break a}d=Vb(g+16|0,12063);h=Pg(c,d);xb(d);if(h){c=g+16|0;lP(c,x[b+24>>2]+1298332|0);_:{if(!De(c)){break _}d=x[x[b+24>>2]+480180>>2];$:{aa:{if((d|0)==33554432){break aa}c=1;if((d|0)==32){break $}if((d|0)==16384){break aa}if((d|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:x[23420]=0;R(965,g|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){Ac(g+16|0,g);xb(g);break _}break b;case 1:break ba;default:break _}}if(De(g+16|0)){x[23420]=0;R(966,g|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}Ac(g+16|0,g);xb(g)}if(!De(g+16|0)){break _}x[23420]=0;R(965,g|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}Ac(g+16|0,g);xb(g)}b=x[b+24>>2];x[23420]=0;U(958,a|0,b|0,g+16|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(g+16|0);break e}break b}d=Vb(g+16|0,5433);h=Pg(c,d);xb(d);if(h){c=g+16|0;lP(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[23420]=0;U(958,a|0,b|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(g+16|0);break e}c=P()|0;xb(g+16|0);break a}e=c;c=Vb(g+16|0,7253);d=Pg(e,c);xb(c);if(d){a=Jb(a);r=g,s=Db(x[b+68>>2]),x[r+16>>2]=s;b=Db(x[b+72>>2]);c=1;while(1){d=x[g+16>>2];if(!Pb(d,b)){break e}if(!(c&1)){x[23420]=0;Q(891,a|0,21443)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}}x[23420]=0;Q(755,a|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}_p(g+16|0);c=0;continue}}Vb(a,21473)}hb=g+32|0;return}c=P()|0;yb(g+16|0);break a}c=P()|0;xb(a);break a}c=P()|0;xb(g+16|0)}S(c|0);p()}function Gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;l=hb-208|0;hb=l;if(!vt(a)){e=l+48|0;pc(e,a,128);f=l+176|0;ef(f,e,128,2);e=l+192|0;Fc(e,f);Dc(b+492|0,e);xb(e)}w[c+34>>1]=z[c+34>>1]&65489;p=l+192|0;f=hb-32|0;hb=f;a:{b:{switch(y[a+128|0]-4|0){default:x[f+28>>2]=0;bo(p,0,f+28|0);break a;case 0:case 4:break b}}v[f+28|0]=y[a+129|0];v[f+24|0]=100;e=f+24|0;i=y[Wb(f+28|0,e)|0];v[f+24|0]=y[a+130|0];v[f+20|0]=100;e=y[Wb(e,f+20|0)|0];x[f+28>>2]=e;c:{if(y[a+140|0]&16){g=Lb(y[a+150|0]|y[a+151|0]<<8);j=Lb(y[a+152|0]|y[a+153|0]<<8);k=x[c>>2];r=+(k>>>0)/6553600;i=hq(r*+((g|i<<16)>>>0));x[f+24>>2]=k-i;s=f,t=hq(r*+((j|e<<16)>>>0)),x[s+20>>2]=t;s=f,t=x[Hb(f+24|0,f+20|0)>>2],x[s+28>>2]=t;break c}g=x[c>>2];j=x[c+20>>2];if(!Td(g,j)){break c}k=g>>>7|0;i=D(k,(i<<7>>>0)/100|0);x[f+24>>2]=g-i;x[f+20>>2]=D(k,(e<<7>>>0)/100|0);e=x[Hb(f+24|0,f+20|0)>>2];k=z[c+34>>1];g=D(Gd(k),g);d:{if(k&1){hc(f+8|0,j,g);j=x[f+8>>2];k=Gd(z[c+34>>1]);g=j+(D(k,e+i|0)<<1)|0;n=w[j+(D(i,k)<<1)>>1];k=0-k<<1;while(1){e:{f:{if(e){o=w[g>>1]-n|0;j=o>>31;if((j^o)-j>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;g=g+k|0;continue}break}break d}hc(f,j,g);j=x[f>>2];k=Gd(z[c+34>>1]);n=0-k|0;g=j+D(k,e+i|0)|0;k=v[j+D(i,k)|0];while(1){g:{h:{if(e){o=v[g|0]-k|0;j=o>>31;if((j^o)-j>>>0>=6){break h}}else{e=0}break g}e=e-1|0;g=g+n|0;continue}break}}x[f+28>>2]=e}bo(p,i,f+28|0)}hb=f+32|0;p=ic(p);if(!(!x[p>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;e=x[l+192>>2];x[c+4>>2]=e;x[c+8>>2]=e+x[p>>2]}e=y[a+134|0];if((e-1&255)>>>0<=198){v[l+48|0]=e;v[l+176|0]=100;e=(y[Wb(l+48|0,l+176|0)|0]<<7>>>0)/100|0}else{e=128}v[l+47|0]=e;v[l+48|0]=64;e=l+47|0;f=l+48|0;s=c,t=y[_e(e,f)|0]>>>1|0,w[s+32>>1]=t;v[l+48|0]=64;s=b,t=y[Wb(e,f)|0],x[s+4>>2]=t;x[c+24>>2]=40460;gq(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){Em(b,127,1);Dm(b,0,1)}i:{if(!Td(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];e=x[c+20>>2];j:{if(!Td(b,e)|b>>>0<2){break j}k:{l:{switch(lk(z[c+34>>1])-1|0){case 3:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){nc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){jy(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){uh(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}lj(c,d)}b=y[a+140|0]}if(b&4){m:{e=x[c>>2];b=x[c+20>>2];if(!Td(e,b)){break m}f=z[c+34>>1];e=D(Gd(f),e);n:{o:{switch(Im(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){g=b+(f<<1)|0;w[g>>1]=z[g>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){g=b+f|0;v[g|0]=y[g|0]^-1;f=f+1|0;continue}break}}lj(c,d)}}m=y[a+170|0]!=2|y[a+171|0]>100?m:y[a+172|0]<101;b=z[c+34>>1];if(!(!(m|y[a+160|0]!=0|y[a+141|0])|b&1)){e=ut(x[c>>2],Gd(b)<<1&254);if(!e){break i}b=e;g=x[c>>2];i=z[c+34>>1];j=D(Gd(i),g);f=x[c+20>>2];g=uj(g,i);i=hb-16|0;hb=i;x[i+12>>2]=j;xc(i+12|0,g);g=x[i+12>>2];while(1){if(g){w[b>>1]=v[f|0]<<8;f=f+1|0;b=b+2|0;g=g-1|0;continue}break}hb=i+16|0;w[c+34>>1]=z[c+34>>1]|1;PP(c,e,x[c>>2],d)}p:{if(v[a+141|0]>=0){break p}hc(l+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));f=x[l+52>>2];e=x[l+48>>2];q:while(1){if((0-v[a+141|0]|0)<=(h|0)){break p}i=w[e>>1];g=bc(e,f);b=e;while(1)if((b|0)==(g|0)){h=h+1|0;continue q}else{i=hd(w[b>>1]-hd(i,1)|0,1);w[b>>1]=i;b=b+2|0;continue}}}r:{if(!m){break r}hc(l+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));h=x[l+52>>2];b=(h|0)/2|0;g=b>>31;n=b;b=y[a+172|0];m=y[a+171|0];e=m;f=0-(b>>>0<e>>>0)|0;b=b-e|0;i=b<<24;e=n+i|0;b=(f<<24|b>>>8)+g|0;b=Hc(Xia(e,e>>>0<i>>>0?b+1|0:b,h,h>>31),lb);f=b;i=f>>31;b=m<<24;g=b;e=b>>31;b=x[l+48>>2];m=bc(b,h);while(1){if((b|0)==(m|0)){break r}h=w[b>>1];h=Wia(g,e,h,h>>31)+838860800|0;j=lb;s=b,t=Hc(Xia(h,h>>>0<838860800?j+1|0:j,1677721600,0),lb),w[s>>1]=t;b=b+2|0;e=e+i|0;h=f+g|0;e=h>>>0<f>>>0?e+1|0:e;g=h;continue}}s:{if(!y[a+160|0]){break s}hc(l+176|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));b=y[a+163|0];h=y[a+162|0];i=0;e=x[l+180>>2];f=0;g=0;if(y[a+161|0]>=2){g=(e|0)/2|0;f=g>>31;m=f;f=y[a+164|0];j=0-(h>>>0>f>>>0)|0;f=f-h|0;n=f<<23;k=n+g|0;f=(j<<23|f>>>9)+m|0;f=k>>>0<n>>>0?f+1|0:f;n=e>>31;f=Hc(Xia(k,f,e,n),lb);j=y[a+165|0];o=0-(b>>>0>j>>>0)|0;k=j-b|0;j=o<<23|k>>>9;k=g+(k<<23)|0;m=j+m|0;g=Hc(Xia(k,g>>>0>k>>>0?m+1|0:m,e,n),lb)}m=b<<23;h=h<<23;j=(l+48|0)+((y[a+160|0]&2)<<2)|0;b=x[l+176>>2];k=bc(b,e);e=0;while(1){if((b|0)==(k|0)){break s}n=(w[b>>1]>>1)-e|0;x[l+56>>2]=n;o=n;n=(h|0)/8388608|0;i=hd(D(o,n),8)+i|0;x[l+52>>2]=i;e=hd(D(i,n),6)+e|0;e=hd(hd(D(e,(m|0)/8388608|0),6)+e|0,2);x[l+48>>2]=e;s=b,t=Xc(x[j>>2]),w[s>>1]=t;b=b+2|0;m=g+m|0;h=f+h|0;continue}}t:{if(v[a+141|0]<=0){break t}hc(l+48|0,x[c+20>>2],D(x[c>>2],Gd(z[c+34>>1])));h=0;f=x[l+52>>2];e=x[l+48>>2];u:while(1){if(v[a+141|0]<=(h|0)){break t}i=w[e>>1];g=bc(e,f);b=e;while(1)if((b|0)==(g|0)){h=h+1|0;continue u}else{i=((w[b>>1]<<1)+i|0)/3|0;w[b>>1]=i;b=b+2|0;continue}}}b=x[c+20>>2];f=z[c+34>>1];e=D(x[c>>2],Gd(f));v:{if(f&1){hc(l+32|0,b,e);m=hb-16|0;hb=m;b=x[l+32>>2];i=bc(b,x[l+36>>2]);k=hb-16|0;hb=k;x[k+12>>2]=b;q=m+8|0;e=bo(q,b,k+12|0);w:{if((b|0)==(i|0)){break w}f=b+2|0;if((i|0)==(f|0)){break w}s=(Xj(z[f>>1],z[x[e>>2]>>1])?0:4)+e|0,t=f,x[s>>2]=t;g=e+4|0;while(1){h=f+2|0;if((i|0)==(h|0)){break w}j=z[f+2>>1];f=f+4|0;if((i|0)==(f|0)){if(!Xj(j,z[x[e>>2]>>1])){e=g;if(Xj(j,z[x[e>>2]>>1])){break w}}x[e>>2]=h;break w}n=z[x[e>>2]>>1];o=z[f>>1];x:{if(Xj(o,j)){if(Xj(o,n)){x[e>>2]=f}if(Xj(j,z[x[g>>2]>>1])){continue}break x}if(Xj(j,n)){x[e>>2]=h}h=f;if(Xj(o,z[x[g>>2]>>1])){continue}}x[g>>2]=h;continue}}hb=k+16|0;x[m+4>>2]=0-w[x[m+8>>2]>>1];s=m,t=w[x[ic(q)>>2]>>1],x[s>>2]=t;y:{e=x[Le(m+4|0,m)>>2];if((e|0)>32766|!e){break y}while(1){if((b|0)==(i|0)){break y}w[b>>1]=(D(w[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break v}hc(l+24|0,b,e);m=hb-16|0;hb=m;b=x[l+24>>2];i=Kb(b,x[l+28>>2]);k=hb-16|0;hb=k;x[k+12>>2]=b;q=m+8|0;e=bo(q,b,k+12|0);z:{if((b|0)==(i|0)){break z}f=b+1|0;if((i|0)==(f|0)){break z}s=(Zk(y[f|0],y[x[e>>2]])?0:4)+e|0,t=f,x[s>>2]=t;g=e+4|0;while(1){h=f+1|0;if((i|0)==(h|0)){break z}j=y[f+1|0];f=f+2|0;if((i|0)==(f|0)){if(!Zk(j,y[x[e>>2]])){e=g;if(Zk(j,y[x[e>>2]])){break z}}x[e>>2]=h;break z}n=y[x[e>>2]];o=y[f|0];A:{if(Zk(o,j)){if(Zk(o,n)){x[e>>2]=f}if(Zk(j,y[x[g>>2]])){continue}break A}if(Zk(j,n)){x[e>>2]=h}h=f;if(Zk(o,y[x[g>>2]])){continue}}x[g>>2]=h;continue}}hb=k+16|0;x[m+4>>2]=0-v[x[m+8>>2]];s=m,t=v[x[ic(q)>>2]],x[s>>2]=t;B:{e=x[Le(m+4|0,m)>>2];if((e|0)>126|!e){break B}while(1){if((b|0)==(i|0)){break B}v[b|0]=(D(v[b|0],127)|0)/(e|0);b=b+1|0;continue}}}hb=m+16|0;C:{if((y[a+134|0]-101&255)>>>0>98){break C}f=z[c+34>>1];e=D(x[c>>2],Gd(f));b=x[c+20>>2];if(f&1){h=l+16|0;x[h>>2]=b;x[h+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;e=x[h>>2];m=bc(e,x[h+4>>2]);while(1){if((e|0)!=(m|0)){h=w[e>>1];D:{if((h|0)>(b|0)){n=f+((D(b,h-b|0)|0)/(f|0)|0)|0;break D}n=((D(b,b+h|0)|0)/(f|0)|0)-f|0;if((g|0)>(h|0)){break D}n=(D(f,h)|0)/(b|0)|0}s=e,t=Xc(n),w[s>>1]=t;e=e+2|0;continue}break}break C}h=gn(l+8|0,b,b+e|0);e=x[h>>2];b=(3276800-(y[a+134|0]<<14)|0)/100|0;g=0-b|0;f=32768-b|0;m=Kb(e,x[h+4>>2]);while(1){if((e|0)!=(m|0)){h=v[e|0]<<8;E:{if((h|0)>(b|0)){n=f+((D(b,h-b|0)|0)/(f|0)|0)|0;break E}n=((D(b,b+h|0)|0)/(f|0)|0)-f|0;if((g|0)>(h|0)){break E}n=(D(f,h)|0)/(b|0)|0}s=e,t=OR((n|0)/256|0),v[s|0]=t;e=e+1|0;continue}break}}OP(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}e=x[p>>2];if(!e){break i}s=Cb(c+68|0,0),t=x[l+192>>2]+D(e,b+1|0)|0,x[s>>2]=t;b=x[l+192>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[p>>2];g=x[p>>2];h=y[a+131|0];if(g>>>0>268435456/(h>>>0)>>>0){break i}f=x[c>>2];e=D(g,h);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=lk(z[c+34>>1]);i=ut(f,e);if(!i){break i}m=b+D(g,h+1|0)|0;x[c>>2]=f;b=i;i=x[c+20>>2];h=x[l+192>>2];g=pc(b,i,D(e,h+x[p>>2]|0));j=i+D(e,h)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){pc(g+D(e,m)|0,i+D(e,h+x[p>>2]|0)|0,D(e,f-m|0));PP(c,g,f,d)}else{b=b+1|0;k=x[p>>2];pc(g+D(e,h+D(b,k)|0)|0,j,D(e,k));continue}break}}hb=l+208|0}function o9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-784|0;hb=d;zc(b);a:{b:{c:{d:{e:{f:{if(!Yh(b,d+776|0)){break f}if(!HL(x[d+776>>2],x[d+780>>2])){break f}if(!zA(b,d+768|0)){break f}g=x[d+768>>2];if(!FL(g)){break f}g:{if((g|0)==1179012417){f=1;e=1313423693;break g}if((g|0)!=538987841){break f}f=2;e=1414090313}m=he(d+744|0,b);j=Qb(d+728|0);h:{i:{j:{k:{l:{m:{n:{if(!c){x[23420]=0;X(806,d+136|0,m|0,f|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break n}a=P()|0;break a}x[23420]=0;U(807,d+136|0,m|0,f|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}}b=d+136|0;Dt(j,b);_d(b);x[23420]=0;U(808,d+704|0,j|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;b=T(166,x[d+704>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}f=0;if(!b){break h}x[23420]=0;b=Q(809,d+704|0,d+624|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}if(!b){break h}b=y[d+689|0];if(!b){break h}x[23420]=0;f=W(144,x[d+704>>2],x[d+712>>2],b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break l}if(!c|f^1){break h}x[23420]=0;R(234,a|0,8388608);b=x[23420];x[23420]=0;if((b|0)==1){break l}x[a+480208>>2]=y[d+688|0]<<4&16^28;w[d+136>>1]=y[d+689|0];w[d+496>>1]=127;q=a,r=z[Zc(d+136|0,d+496|0)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+690|0];x[a+480204>>2]=D(y[d+691|0],1e4);x[a+480200>>2]=y[d+696|0]<<1;x[23420]=0;R(124,a+1298344|0,((g|0)==1179012417?16789:16755)|0);b=x[23420];x[23420]=0;if((b|0)==1){break l}x[23420]=0;b=Q(1,d+608|0,13108)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}Gb(a+1298356|0,b);yb(b);x[a+1298404>>2]=5;b=d+496|0;cA(b,2,d+624|0);x[23420]=0;R(210,d+136|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}k=(g|0)!=1179012417;b=d+136|0;Ac(a+1298308|0,b);xb(b);l=(g|0)==1179012417;b=0;while(1){o:{p:{q:{if(z[a+480188>>1]<=b>>>0){b=Db(x[j>>2]);f=Db(x[j+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=b;while(1){r:{if(!Pb(b,f)){break r}if($T(1380209231,x[b>>2],x[b+4>>2])){break r}b=x[um(e+8|0)>>2];continue}break}hb=e+16|0;if(Pb(b,Db(x[j+4>>2]))){break q}break i}f=(b<<5)+a|0;h=f+480280|0;Te(h);x[23420]=0;e=T(194,d+704|0)|0;n=x[23420];x[23420]=0;s:{t:{if((n|0)!=1){if(l){break s}if(e>>>0<129){break t}break p}a=P()|0;break b}w[f+480284>>1]=e<<1;break o}if(e<<24>>24<0){break p}x[d+136>>2]=e<<2;x[d+496>>2]=256;q=f+480284|0,r=x[td(d+136|0,d+496|0)>>2],w[q>>1]=r;break o}x[23420]=0;U(808,d+136|0,j|0,1380209231);b=x[23420];x[23420]=0;u:{if((b|0)!=1){x[23420]=0;b=T(194,d+136|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break u}e=y[a+484376|0];f=x[a+484360>>2];x[23420]=0;ea(326,Yb(f,e)|0,d+136|0,b+1&255,255,254);b=x[23420];x[23420]=0;if((b|0)==1){break u}zb(d+136|0);break i}a=P()|0;break b}a=P()|0;zb(d+136|0);break b}x[h>>2]=1024}b=b+1|0;continue}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}v:{if(!(c&1)){break v}w[d+56>>1]=0;x[23420]=0;U(810,d+560|0,j|0,1414807888);b=x[23420];x[23420]=0;if((b|0)==1){break c}b=x[d+564>>2];e=x[d+560>>2];x[23420]=0;f=a+484344|0;R(213,f|0,Ff(e,b)&65535);b=x[23420];x[23420]=0;w:{if((b|0)!=1){q=d,r=Db(x[d+560>>2]),x[q+88>>2]=r;l=Db(x[d+564>>2]);x:{y:{z:{A:{B:{while(1){b=x[d+88>>2];if(!Pb(b,l)){k=a+484348|0;b=0;break x}b=he(d+136|0,b);x[23420]=0;e=T(194,b|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;w[d+480>>1]=e;e=T(145,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break B}x[23420]=0;U(178,d+496|0,b|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break A}e=jc(d+584|0,d+496|0);x[23420]=0;h=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=h;x[d+16>>2]=x[e+16>>2];h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;X(811,d|0,z[d+480>>1],k|0,a|0);e=x[23420];x[23420]=0;if((e|0)==1){break z}zb(d+496|0);q=d,r=z[Ve(d+56|0,d+480|0)>>1],w[q+56>>1]=r;zb(b);th(d+88|0);continue}break}a=P()|0;break y}a=P()|0;break y}a=P()|0;break y}a=P()|0;zb(d+496|0)}zb(b);break w}while(1){e=b&65535;if(e>>>0>=z[d+56>>1]){kd(d+560|0);break v}C:{if(!oe(x[a+484344>>2],x[k>>2],e)){x[23420]=0;W(214,f|0,e|0,64)|0;e=x[23420];x[23420]=0;if((e|0)==1){break C}}b=b+1|0;continue}break}a=P()|0;break w}a=P()|0}kd(d+560|0);break b}D:{if((g|0)==1179012417){x[23420]=0;U(810,d+88|0,j|0,1414745673);b=x[23420];x[23420]=0;if((b|0)==1){break d}q=d,r=Db(x[d+88>>2]),x[q+120>>2]=r;g=c&2;k=d+504|0;l=Db(x[d+92>>2]);e=a+480190|0;while(1){b=x[d+120>>2];if(!Pb(b,l)){kd(d+88|0);break D}c=he(d+560|0,b);x[23420]=0;b=Q(812,c|0,d+136|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){E:{if(!b){break E}b=y[d+137|0];if((b|0)==255){break E}x[23420]=0;f=W(239,a|0,b+1|0,0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}if(!f){break E}h=z[e>>1];b=0;x[23420]=0;U(813,d+136|0,f|0,h|0);f=x[23420];x[23420]=0;if((f|0)==1){break e}while(1){if(y[d+166|0]<=b>>>0){break E}F:{if(!Qh(z[e>>1])){break F}x[23420]=0;f=Q(814,c|0,d+496|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break e}if(!f){break F}f=z[e>>1]+1|0;w[e>>1]=f;if(x[d+496>>2]!=1347240275){break F}h=d+480|0;el(h,2,k);x[23420]=0;R(210,d+56|0,h|0);h=x[23420];x[23420]=0;G:{if((h|0)!=1){f=f&65535;h=d+56|0;Dc(((f<<5)+a|0)+946304|0,h);xb(h);x[23420]=0;f=(D(f,104)+a|0)+484380|0;U(815,d+496|0,d+136|0,f|0);h=x[23420];x[23420]=0;if((h|0)==1){break e}if(!g){break G}h=d+56|0;EL(h,z[d+534>>1]);x[23420]=0;W(207,h|0,f|0,c|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break F}break e}break e}h=z[f+34>>1];f=x[f>>2];x[23420]=0;Q(176,c|0,uj(f,h)|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}}b=b+1|0;continue}}zb(c);th(d+120|0);continue}break}break e}x[23420]=0;U(810,d+480|0,j|0,1179011410);b=x[23420];x[23420]=0;if((b|0)!=1){q=d,r=Db(x[d+480>>2]),x[q+472>>2]=r;k=c&2;l=d+496|4;h=Db(x[d+484>>2]);f=a+480190|0;H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+472>>2];if(!Pb(b,h)){kd(d+480|0);break D}c=he(d+560|0,b);x[23420]=0;b=T(145,c|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[23420]=0;b=Q(816,c|0,d+464|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break P}if(!(b&x[d+464>>2]==1414745673)){break S}x[23420]=0;b=Q(817,c|0,d+136|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+141|0];if((b|0)==255){break S}x[23420]=0;b=W(239,a|0,b+1|0,0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break N}if(!b){break S}e=z[f>>1];x[23420]=0;U(818,d+136|0,b|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break N}x[23420]=0;U(807,d+496|0,c|0,2);b=x[23420];x[23420]=0;if((b|0)==1){break R}x[23420]=0;U(810,d+120|0,d+496|0,1179011410);b=x[23420];x[23420]=0;if((b|0)==1){break M}_d(d+496|0);q=d,r=Db(x[d+120>>2]),x[q+112>>2]=r;n=Db(x[d+124>>2]);T:{U:{while(1){b=x[d+112>>2];if(!Pb(b,n)){break T}b=he(d+88|0,b);x[23420]=0;e=T(145,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[f>>1];if(!Qh(e)){break W}g=z[d+460>>1];w[d+460>>1]=g-1;if(!g){zb(b);break T}i=e+1|0;w[f>>1]=i;x[23420]=0;e=Q(816,b|0,d+80|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break K}if(!(e&x[d+80>>2]==1347240275)){break U}x[23420]=0;U(178,d+496|0,b|0,x[d+84>>2]);e=x[23420];x[23420]=0;X:{if((e|0)!=1){g=d+496|0;e=jc(d+56|0,g);zb(g);x[23420]=0;g=Q(819,e|0,g|0)|0;o=x[23420];x[23420]=0;if((o|0)==1){break V}if(g){break X}zb(e);zb(b);break T}a=P()|0;break I}g=d+24|0;Ye(g,2,l);x[23420]=0;R(210,d+40|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break J}g=i&65535;i=d+40|0;Dc(((g<<5)+a|0)+946304|0,i);xb(i);x[23420]=0;g=(D(g,104)+a|0)+484380|0;U(820,d+496|0,d+136|0,g|0);i=x[23420];x[23420]=0;if((i|0)==1){break V}Y:{if(!k){break Y}x[23420]=0;Q(143,e|0,x[d+496>>2]+4|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break V}i=d+40|0;EL(i,z[d+536>>1]);x[23420]=0;W(207,i|0,g|0,e|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){break Y}break J}zb(e)}zb(b);th(d+112|0);continue}break}break J}zb(b)}kd(d+120|0)}zb(c);th(d+472|0);continue}break}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;break H}a=P()|0;_d(d+496|0);break H}a=P()|0;break I}a=P()|0;break I}a=P()|0;zb(e)}zb(b);kd(d+120|0)}zb(c);kd(d+480|0);break b}a=P()|0;break b}f=1}zb(d+704|0);_d(j);zb(m)}hb=d+784|0;return f|0}a=P()|0;zb(c);kd(d+88|0);break b}a=P()|0;break b}a=P()|0}zb(d+704|0)}_d(j);zb(m);S(a|0);p()}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;e=hb+-64|0;hb=e;zc(a);a:{b:{if(b>>>0<=2){F=e,G=Ee(a),v[F+56|0]=G;$b(a,2);F=e,G=Eg(a),w[F+58>>1]=G;F=e,G=pg(a),x[F+60>>2]=G;break b}nq(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{n=d+484344|0;A=Wd(z[e+58>>1],1,1024);m=tB(n,A);if((m|0)==65535){break c}b=_b(x[d+484344>>2],m);g=pf(x[b>>2],x[x[b+48>>2]+12>>2],0);f=z[d+480188>>1];w[e>>1]=f-1;w[e+40>>1]=y[e+56|0];B=z[Zc(e,e+40|0)>>1];k=B+1|0;b=k&65535;f=b>>>0<f>>>0?f:b;while(1){if((b|0)==(f|0)){d:{v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e|0]=0;b=(b|0)!=0;r=wm(e+40|0,k,e);C=d+480188|0;e:while(1){if((j|0)==(A|0)){dc(r);break c}f:{d=Kb(x[r>>2],0);f=y[d|0];g:{if(!f){x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}d=d<<24>>24;if((d|0)<0){x[23420]=0;f=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}F=Kb(x[r>>2],0),G=f,v[F|0]=G}v[e|0]=0;h:{i:{d=d&63;if(!d){break i}x[23420]=0;i=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}v[e|0]=i;j:{k:{switch(d-1|0){case 0:v[c+12|0]=0;v[e+36|0]=1;F=c,G=y[_e(e+36|0,e)|0],v[F+14|0]=G;v[c+15|0]=0;break j;case 1:if(!i){break i}v[c+15|0]=i;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,i),15);break j;case 2:v[c+13|0]=i>>>4;if(i>>>0>=16){b=y[c+12|0];i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b){break g}break f}i=0;v[c+12|0]=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b&1){break g}break f;case 3:q=0;x[e+36>>2]=0;x[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!i){break i}d=(y[c+12|0]?15:14)+c|0;b=y[d|0];v[d|0]=b>>>0>=256-i>>>0?-1:b+i|0;break j;case 6:break k;default:break i}}if(!i){break i}d=(y[c+12|0]?15:14)+c|0;b=y[d|0];v[d|0]=b>>>0<=i+1>>>0?1:b-i|0}i=0;x[e+36>>2]=0;x[e+32>>2]=0;break g}i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(b&1){break g}break f}break d}v[d|0]=f-1;i=0;x[e+36>>2]=0;x[e+32>>2]=0;q=0;if(!(b&1)){break f}}b=y[c+13|0];d=y[c+12|0];if(d){q=0;if(!b){break f}}l:{if(d){x[e>>2]=1;x[e+28>>2]=D(b,y[c+15|0])<<1;f=x[Le(e,e+28|0)>>2];break l}f=D(y[c+14|0],30)+30|0}b=255;d=0;g=0;while(1){m:{if(b){k=D(b,f);g=(k|0)/48|0;if(k-1536>>>0>=10752){break m}d=b}x[e+32>>2]=g;x[e+36>>2]=d;ge(e+32|0,32,255);q=1;x[e>>2]=1;F=c,G=x[Le(e,e+36|0)>>2],v[F+16|0]=G;break f}b=b-1|0;continue}}t=j-1|0;u=1;b=_b(x[n>>2],m);b=ed(x[b>>2],x[x[b+48>>2]+12>>2],j,1);while(1){h=u&65535;if(h>>>0>B>>>0){if(q){ie(_b(x[n>>2],m),xh(po(Fe(ye(e,17,y[e+32|0]),j),0)));ie(_b(x[n>>2],m),xh(Fe(ye(e,16,y[e+36|0]),j)))}if(i>>>0>=16){ie(_b(x[n>>2],m),hU(Fe(ye(e,20,i>>>4|224),j)))}b=i&15;if(b){ie(_b(x[n>>2],m),hU(Fe(ye(e,20,Wd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),j)))}j=j+1|0;b=0;continue e}n:{o:{p:{q:{r:{d=Kb(x[r>>2],h);f=y[d|0];if(!f){x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}d=d<<24>>24;if((d|0)<0){x[23420]=0;f=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}F=Kb(x[r>>2],h),G=f,v[F|0]=G}E=1;l=d&255;if(l&64){x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}v[b+1|0]=d;E=!d}if(!(l&32)){d=y[b|0];break r}x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}v[b|0]=d;if((d-1&255)>>>0<=107){d=sm(d+24|0);v[b|0]=d;F=Cd(x[c>>2],h),G=d,v[F+1|0]=G;d=y[b|0];break o}if((d+127&255)>>>0<=107){d=sm((d&127)+24|0);F=Cd(x[c>>2],h),G=d,v[F|0]=G;v[b|0]=0;break q}if((d|0)!=255){break r}d=254;break p}v[d|0]=f-1;break n}if(d&255){break o}}if(!y[b+1|0]){d=0;break o}d=y[Cd(x[c>>2],h)+1|0];v[b+1|0]=0}v[b|0]=d}if(Uc(d)){F=Cd(x[c>>2],h),G=0,v[F+5|0]=G}v[e+28|0]=0;v[e+27|0]=0;v[e+26|0]=0;v[e+25|0]=0;v[e+24|0]=0;v[e+23|0]=0;if(l&16){v[b+2|0]=1;x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}v[b+4|0]=d+2>>>2}o=0;k=0;s:{if(!(l&8)){break s}x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}x[23420]=0;f=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}v[e+25|0]=f;t:{u:{switch(d-1|0){case 1:v[b|0]=255;break t;case 2:d=Cd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break t;case 3:d=lu(f,y[c+16|0]);v[e+25|0]=d;v:{if(d){v[e+28|0]=20;v[e+25|0]=d|208;k=20;break v}v[e+28|0]=0;k=0}if(y[b|0]){break s}d=Cd(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 4:v[e|0]=1;F=e,G=lu(f,y[c+16|0]),v[F+22|0]=G;F=e,G=y[_e(e,e+22|0)|0],v[F+25|0]=G;v[e+28|0]=15;F=Cd(x[c>>2],h),G=0,v[F+5|0]=G;k=20;break s;case 5:case 6:case 7:case 8:w:{if(!j){break w}if((d|0)==y[Cd(x[c>>2],h)+4|0]){break w}if(!ie(_b(x[n>>2],m),tm(po(Fe(ye(e,20,(d+122|160)&255),t),h)))){break w}F=Cd(x[c>>2],h),G=d,v[F+4|0]=G}v[e+28|0]=10;d=Cd(x[c>>2],h);if(!y[b|0]){v[b|0]=y[d+1|0]}v[d+5|0]=0;k=20;break s;case 9:k=20;v[e+28|0]=20;d=Cd(x[c>>2],h);f=y[d+5|0];v[e+25|0]=f?-98:-97;v[d+5|0]=f^1;break s;case 0:break u;default:break t}}v[b|0]=254}v[e+28|0]=0}x:{if(!(l&4)){d=0;break x}x[23420]=0;d=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}x[23420]=0;f=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}v[e+24|0]=f;y:{z:{switch(d-1|0){case 0:sB(e,f<<24>>24<<3,128);d=y[b|0];if(Uc(d)){F=b,G=sm(d+x[e>>2]|0),v[F|0]=G}d=35;v[e+27|0]=35;v[e+24|0]=y[e+4|0]^128;break x;case 1:f=lu(f,y[c+16|0]);v[e+24|0]=f;if(f){d=20;v[e+27|0]=20;v[e+24|0]=f|208;o=1;break x}d=0;break y;case 2:d=1;break y;case 3:case 4:o=1;f=fU(f,y[c+16|0],1);d=(d|0)==4?2:3;v[e+27|0]=d;v[e+24|0]=f;break x;case 5:d=4;if(!y[b|0]){F=b,G=y[Cd(x[c>>2],h)|0],v[F|0]=G;f=y[e+24|0]}f=fU(f&255,y[c+16|0],0);v[e+27|0]=4;v[e+24|0]=f;o=1;break x;case 6:F=b,G=sm(f+25|0),v[F|0]=G;v[e+24|0]=255;d=4;break y;case 7:case 8:case 9:A:{if(!j){break A}if((d|0)==y[Cd(x[c>>2],h)+2|0]){break A}if(!ie(_b(x[n>>2],m),tm(po(Fe(ye(e,20,(d-8|48)&255),t),h)))){break A}F=Cd(x[c>>2],h),G=d,v[F+2|0]=G}d=5;v[e+27|0]=5;F=e,G=rB(y[e+24|0],y[c+16|0]),v[F+24|0]=G;o=1;break x;case 10:g=y[c+16|0];d=18;v[e+27|0]=18;F=e,G=eU(f,g),v[F+24|0]=G;o=1;break x;case 11:f=lu(f,y[c+16|0]);v[e+24|0]=f;if(f){d=20;v[e+27|0]=20;v[e+24|0]=f|192;o=1;break x}d=0;v[e+27|0]=0;v[b|0]=254;o=1;break x;default:break z}}d=0;v[e+27|0]=0;break x}v[e+27|0]=d;o=1}s=1;B:{C:{g=0;D:{if(!(l&2)){break D}x[23420]=0;f=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}x[23420]=0;l=T(194,a|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}v[e+23|0]=l;E:{switch(f-1|0){case 0:case 1:g=11;f=dU(l,y[c+16|0],(f|0)==1);v[e+26|0]=11;v[e+23|0]=f;s=0;f=1;break B;case 2:f=y[c+16|0];g=18;v[e+26|0]=18;F=e,G=eU(l,f),v[F+23|0]=G;break C;case 3:case 4:case 5:F:{if(!j){break F}if((f|0)==y[Cd(x[c>>2],h)+3|0]){break F}if(!ie(_b(x[n>>2],m),tm(po(Fe(ye(e,20,(f-4|64)&255),t),h)))){break F}F=Cd(x[c>>2],h),G=f,v[F+3|0]=G}g=8;v[e+26|0]=8;F=e,G=rB(y[e+23|0],y[c+16|0]),v[F+23|0]=G;break C;case 6:v[e+26|0]=9;s=0;g=9;break D;case 7:case 8:g=29;f=dU(l,y[c+16|0],(f|0)==8);v[e+26|0]=29;v[e+23|0]=f;break C;case 9:g=27;v[e+26|0]=27;F=e,G=rB(l,y[c+16|0]),v[F+23|0]=G;break C;default:break E}}v[e+26|0]=0;g=0}f=0;break B}s=0;f=1}if(o){cU(b,j,z[C>>1],d,e+24|0)}if(f){cU(b,j,z[C>>1],g,e+23|0)}G:{H:{if(!E){break H}if(!Uc(y[b|0])){break H}if(!d){v[e+24|0]=255;v[e+27|0]=4;f=4;break G}f=4;if(!s|(d|0)==4){break G}v[e+23|0]=255;g=4;v[e+26|0]=4;f=4;break G}f=d}I:{if(y[b+2|0]!=1){break I}J:{if(!f){v[e+27|0]=13;v[e+24|0]=y[b+4|0];break J}if(g){break I}v[e+26|0]=13;v[e+23|0]=y[b+4|0]}v[b+2|0]=0}vq(e,e+27|0,e+24|0,e+26|0,e+23|0);K:{if(y[b+2|0]){break K}d=y[e+27|0];if(!d){break K}v[b+2|0]=d;v[b+4|0]=y[e+24|0]}L:{if(k){vq(e,e+26|0,e+23|0,e+28|0,e+25|0);M:{if(y[b+2|0]){break M}d=y[e+26|0];if(!d){break M}v[b+2|0]=d;v[b+4|0]=y[e+23|0]}g=e+25|0;d=y[e+28|0];break L}g=e+23|0;d=y[e+26|0];if(!d){break n}}v[b+3|0]=d;v[b+5|0]=y[g|0]}b=b+6|0;u=u+1|0;continue}}}}else{v[g+D(b,6)|0]=254;b=b+1|0;continue}break}a=P()|0;dc(r);S(a|0);p()}hb=e- -64|0;return m|0}function uK(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=hb-336|0;hb=k;n=h;p=i&65535;o=d;m=e&65535;r=(e^i)&-2147483648;t=i>>>16&32767;u=e>>>16&32767;a:{b:{if(t-32767>>>0>4294934529&u-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){y=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){y=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));y=b?0:y;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|o);h=d<<6;j=G(d?b:o)+32|0;b=G(d?c:m);b=h+((b|0)==32?j:b)|0;wf(k+320|0,i,c,o,m,b-15|0);l=16-b|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);e=d<<6;h=G(d?f:n)+32|0;d=G(d?g:p);d=e+((d|0)==32?h:d)|0;wf(k+304|0,f,g,n,p,d-15|0);l=(d+l|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;E=e;F=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;lf(k+288|0,e,j,0,0,d,i,0,0);j=x[k+296>>2];lf(k+272|0,0-j|0,0-(x[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;lf(k+256|0,i,d,0,0,e,h,0,0);j=d;d=x[k+264>>2];lf(k+240|0,i,j,0,0,0-d|0,0-(x[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;lf(k+224|0,j,d,0,0,e,h,0,0);i=d;d=x[k+232>>2];lf(k+208|0,j,i,0,0,0-d|0,0-(x[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;lf(k+192|0,i,d,0,0,e,h,0,0);j=d;d=x[k+200>>2];lf(k+176|0,i,j,0,0,0-d|0,0-(x[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=x[k+184>>2];e=i<<1|x[k+180>>2]>>>31;s=e-1|0;i=(x[k+188>>2]<<1|i>>>31)-!e|0;lf(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;lf(k+144|0,d<<15,j,0,0,s,i,0,0);h=x[k+172>>2];p=x[k+160>>2];e=x[k+152>>2];d=p+e|0;n=x[k+164>>2];j=n+x[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<p>>>0|d>>>0<n>>>0;j=n+x[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;p=!d&e>>>0>1|(d|0)!=0;n=p+j|0;j=h;h=n;lf(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<p>>>0?j+1|0:j)|0)|0,0,0);lf(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);L=(u-t|0)+l|0;e=x[k+116>>2];B=e;d=x[k+112>>2];j=e<<1|d>>>31;C=d<<1;q=j;d=j;h=x[k+140>>2];z=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+C|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;n=d;l=0;j=m|65536;M=j;N=o;d=o;j=j<<1|d>>>31;Q=d<<1;R=j;H=j;w=Wia(n,l,j,0);d=lb;v=d;j=b;d=c<<1|j>>>31;t=j<<1;s=d;p=d;j=0;u=j;i=h-13927|0;l=(e|0)==(n|0)&i>>>0<h>>>0|e>>>0>n>>>0;m=(e|0)==(q|0)&h>>>0<C>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;e=z>>>31|0;d=e+(d<<1|B>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;I=l-!e|0;C=0;j=Wia(p,u,I,C);e=j+w|0;h=lb+v|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(v|0)&e>>>0<w>>>0|h>>>0<v>>>0;j=0;w=l;q=d;d=o;O=c>>>31|0;v=O|d<<1;z=0;l=Wia(q,j,v,z);d=l+e|0;j=lb+h|0;j=d>>>0<l>>>0?j+1|0:j;o=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=w+e|0;l=0;l=d>>>0<e>>>0?1:l;e=Wia(H,u,I,C);d=e+d|0;j=lb+l|0;w=d;d=d>>>0<e>>>0?j+1|0:j;l=Wia(H,u,q,z);h=lb;D=Wia(v,z,I,C);e=D+l|0;j=lb+h|0;j=e>>>0<D>>>0?j+1|0:j;D=e;e=j;j=(h|0)==(j|0)&l>>>0>D>>>0|h>>>0>j>>>0;l=w+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+o|0;j=m+D|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<o>>>0|j>>>0<m>>>0;h=m+h|0;j=l;w=h;l=h>>>0<m>>>0?j+1|0:j;o=d;m=e;D=i;h=Wia(i,0,v,z);e=lb;i=Wia(n,u,p,u);d=i+h|0;j=lb+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;J=w;B=e;K=t&-2;i=Wia(q,z,K,0);e=i+d|0;j=lb+j|0;j=e>>>0<i>>>0?j+1|0:j;w=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=B+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+o|0;d=h+m|0;B=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<o>>>0|d>>>0<m>>>0;d=J+h|0;j=l;J=d;o=d>>>0<h>>>0?j+1|0:j;P=Wia(H,u,D,y);H=lb;h=Wia(I,C,K,y);d=h+P|0;j=lb+H|0;I=d;m=Wia(n,u,v,z);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+lb|0;d=l>>>0<m>>>0?d+1|0:d;v=l;m=Wia(p,u,q,z);j=l+m|0;l=lb+d|0;C=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&v>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&v>>>0<I>>>0|d>>>0<h>>>0;d=j+((h|0)==(H|0)&I>>>0<P>>>0|h>>>0<H>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+B|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<B>>>0|i>>>0>j>>>0;d=h+J|0;j=o;v=d;i=d>>>0<h>>>0?j+1|0:j;B=Wia(n,u,K,y);n=lb;h=Wia(p,u,D,y);d=h+B|0;j=lb+n|0;j=d>>>0<h>>>0?j+1|0:j;o=0;h=(j|0)==(n|0)&d>>>0<B>>>0|j>>>0<n>>>0;n=j;d=j+w|0;j=(h|o)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<w>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=C+d|0;l=e>>>0<o>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+v|0;l=i;l=h>>>0<j>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){N=Q|O;M=z|R;lf(k+80|0,d,e,h,i,f,g,F,E);j=b<<17;b=0;c=x[k+88>>2];m=b-c|0;l=x[k+80>>2];p=x[k+84>>2];n=(l|p)!=0;o=m-n|0;m=(j-(x[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+p|0)|0;b=L+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;lf(k+96|0,d,e,h,i,f,g,F,E);m=0;n=x[k+104>>2];p=m-n|0;l=x[k+96>>2];s=x[k+100>>2];t=(l|s)!=0;o=p-t|0;m=((b<<16)-(x[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(p>>>0<t>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;t=b;s=c;b=L+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=o;l=m<<1|c>>>31;o=c<<1|p>>>31;m=l;t=h;s=i&65535|b<<16;b=n;l=p<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Wl(k- -64|0,d,e,h,i,1-b|0);wf(k+48|0,t,s,N,M,b+112|0);d=x[k+64>>2];e=x[k+68>>2];t=x[k+72>>2];s=x[k+76>>2];lf(k+32|0,f,g,F,E,d,e,t,s);c=x[k+40>>2];i=c<<1;c=x[k+44>>2]<<1|c>>>31;b=x[k+56>>2];h=x[k+36>>2];o=h>>>31|i;i=b-o|0;l=x[k+60>>2]-((b>>>0<o>>>0)+c|0)|0;c=x[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=x[k+52>>2];b=x[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;o=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=b-c|0;l=j-((c>>>0>i>>>0)+h|0)|0}lf(k+16|0,f,g,F,E,3,0,0,0);lf(k,f,g,F,E,5,0,0,0);j=0;h=l+j|0;n=d&1;c=b+n|0;h=c>>>0<b>>>0?h+1|0:h;i=c;b=i;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(h|0)==(j|0)&b>>>0<n>>>0|h>>>0<j>>>0;b=c+o|0;l=m;l=b>>>0<c>>>0?l+1|0:l;f=b;c=(l|0)==(E|0);c=c&(b|0)==(F|0)?g:c&b>>>0>F>>>0|l>>>0>E>>>0;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;c=b;b=j;e=(j|0)==(e|0)&c>>>0<d>>>0|e>>>0>j>>>0;d=e+t|0;j=s;j=d>>>0<e>>>0?j+1|0:j;o=d;d=x[k+20>>2];g=(d|0)==(h|0)&A[k+16>>2]<i>>>0|d>>>0<h>>>0;d=x[k+28>>2];e=x[k+24>>2];g=j>>>0<2147418112&((e|0)==(f|0)&(d|0)==(l|0)?g:(d|0)==(l|0)&e>>>0<f>>>0|d>>>0<l>>>0);e=g+c|0;d=b;d=e>>>0<g>>>0?d+1|0:d;c=(b|0)==(d|0)&c>>>0>e>>>0|b>>>0>d>>>0;b=o+c|0;j=b>>>0<c>>>0?j+1|0:j;g=b;b=x[k+4>>2];h=(b|0)==(h|0)&A[k>>2]<i>>>0|b>>>0<h>>>0;b=x[k+12>>2];c=x[k+8>>2];c=j>>>0<2147418112&((c|0)==(f|0)&(b|0)==(l|0)?h:(b|0)==(l|0)&c>>>0<f>>>0|b>>>0<l>>>0);b=c+e|0;l=b>>>0<c>>>0?d+1|0:d;c=l;f=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;e=g+f|0;d=j;y=e|y;r=r|(e>>>0<f>>>0?d+1|0:d)}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=y;x[a+12>>2]=r;hb=k+336|0}function $s(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=hb-32|0;hb=h;x[h+28>>2]=c;a:{if((c|0)<=0){break a}j=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{k=x[b+656>>2];i:{if(!(!k|x[a+480180>>2]!=16777216)){m=x[k+44>>2]!=0;break i}if(!k){break h}}if((c|0)>128){break g}i=c-1|0;l=z[bc(k+236|0,i)>>1];j:{if((l-1&65535)>>>0<=3998){j=(D(l,104)+a|0)+484380|0;break j}Ab(h+16|0,a+1074312|0,43);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break j}if(!Rj(x[b+656>>2])){break a}}i=y[Kb(k+108|0,i)|0];x[h+28>>2]=i;if(i>>>0<=120){break f}c=i;break g}i=c;n=0;if(c>>>0<121){break e}}k:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){Pn(a,b);if(d){break k}Ab(h+16|0,a+1074312|0,100);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])|!(y[a+480208|0]&4)|!y[b+789|0]){break k}x[b+88>>2]=x[b+88>>2]&-6145;break k}if(!z[a+480192>>1]){break k}x[b+88>>2]=x[b+88>>2]|4096}l:{if((c|0)!=254){break l}d=x[b+88>>2];c=a+480180|0;if(!(!(d&512)|x[c>>2]!=2)){x[b+88>>2]=d|2048;break l}x[b+88>>2]=d|2101248;m:{if(x[c>>2]&16777248){if(!z[a+480192>>1]){break m}Ab(h+16|0,a+1074312|0,50);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break m}}x[b+688>>2]=0}Ab(h+16|0,a+1074312|0,50);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}Ab(h+16|0,a+1074312|0,20);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break a}v[b+797|0]=0;v[b+802|0]=0;break a}n=0;if(!m){break e}if(d){l=y[b+797|0];if(l){break d}}x[b+708>>2]=0;n=1}if(d){break c}n:{o:{if(!(!(x[a+480180>>2]&1048588)|!j)){w[b+770>>1]=v[j+36|0];w[b+772>>1]=v[j+37|0];break o}if(!j){break n}}Ab(h+16|0,a+1074312|0,24);m=0;l=1;if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break b}x[b+704>>2]=x[j+24>>2];break b}j=0;l=0;m=0;break b}l=D((x[x[k+44>>2]+36>>2]<<16>>16)+1|0,(i<<16>>16)-(l<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=l;x[b+852>>2]=0-l;n=1}l=(j|0)!=0;m=1;if(pi(x[b+8>>2],x[b+12>>2])){break b}m=a+1074312|0;Ab(h+16|0,m,54);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){x[b+700>>2]=0;break a}Ab(h+16|0,m,39);m=(Bb(x[x[h+16>>2]>>2],x[h+20>>2])^-1)&d}p:{if(qm(x[a+480180>>2])){x[h+28>>2]=w[b+770>>1]+i;ge(h+28|0,12,131);break p}kR(h+28|0)}i=a+1074312|0;Ab(h+16|0,i,34);q:{if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){d=sm(c);break q}d=x[h+28>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:m)){v[b+803|0]=0}d=Qg(a,x[h+28>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;Ab(h+16|0,i,48);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){hN(a,b,k,j)}Ab(h+16|0,i,115);if(!(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])|!k|!y[k+26|0])){if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}gN(b+692|0,c,y[k+26|0],y[k+27|0])}r:{if(e^1|m){break r}x[b+776>>2]=0;x[b+780>>2]=0;if(!k){break r}Ab(h+16|0,i,29);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){v[b+798|0]=y[k+16|0]}if(!(y[k+60|0]&8)){hj(b+724|0)}if(!(y[k+80|0]&8)){hj(b+732|0)}if(!(y[k+100|0]&8)){hj(b+740|0)}if(y[k+20|0]){c=Zs(On(a));o=y[k+20|0];Ab(h+16|0,i,28);o=((D(c,o)<<16>>16)/64<<16)+65536>>16;s:{if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){c=x[b+752>>2];break s}c=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(c,o)|0)/199}t:{if(!y[k+19|0]){break t}q=b,r=(D(Zs(On(a)),y[k+19|0])<<16>>16)/32|0,w[q+778>>1]=r;Ab(h+16|0,i,28);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])|z[b+784>>1]){break t}w[b+784>>1]=z[b+692>>1]+1}c=y[k+23|0];if(c){o=Zs(On(a));p=y[b+837|0];v[b+796|0]=p+1;w[b+780>>1]=(D(p,(D(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=y[k+24|0];if(!c){break r}o=Zs(On(a));p=y[b+838|0];v[b+795|0]=p+1;w[b+782>>1]=(D(p,(D(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!l){break a}l=0;u:{v:{if(!d){break v}if(!(x[b+700>>2]?m:0)){x[b+700>>2]=d}w:{x:{if(!n){if(!m){Ab(h+16|0,i,69);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break x}Ab(h+8|0,i,46);if(Bb(x[x[h+8>>2]>>2],x[h+12>>2])|x[a+480180>>2]==1){break x}}x[b+708>>2]=d;v[b+851|0]=y[b+851|0]&239}if(!m){break x}if(x[b+76>>2]|y[a+480180|0]&2){break w}}x[b+104>>2]=j;c=x[j>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;y:{z:{if(!(x[a+480208>>2]&2097152)){Ab(h+16|0,i,96);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break z}}if(y[b+789|0]){break z}x[h+16>>2]=x[b+76>>2]-1;q=b,r=x[Hb(b+660|0,h+16|0)>>2],x[q+4>>2]=r;break y}x[b+660>>2]=0}c=z[j+34>>1];d=c&1023;n=d|x[b+88>>2]&-525056;x[b+88>>2]=n;A:{B:{if(c&8){x[b+80>>2]=x[j+12>>2];c=x[j+16>>2];x[b+88>>2]=(d&16?n|4:n&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break B}break A}if(!(d&2)){break A}x[b+80>>2]=x[j+4>>2];c=x[j+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break A}}x[b+76>>2]=c}Ab(h+16|0,i,83);if(!(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])|x[b+80>>2])){c=x[j>>2];x[b+84>>2]=c;x[b+76>>2]=c}c=x[b+88>>2];C:{if(!(c&128)){break C}d=x[b+76>>2];if(!d){break C}x[b+4>>2]=d-1;x[b+88>>2]=c|128}D:{if(y[b+822|0]>3){break D}Ab(h+16|0,i,21);c=x[a+480180>>2];E:{F:{if(!(Bb(x[x[h+16>>2]>>2],x[h+20>>2])|!(c&16777248))){j=16;if(x[a+480208>>2]&4){break F}break E}j=32;if((c|0)==16){break E}}if(c&67633152){break D}j=0}v[b+819|0]=j}Ab(h+16|0,i,21);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])|y[b+825|0]>3){break w}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}if(!m){break v}l=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break v}c=1;if(!(y[a+480208|0]&8)){break u}c=1;if(!y[b+789|0]){break u}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Zl(b);Ab(h+16|0,i,21);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}G:{if(!l){j=y[b+789|0];break G}j=y[b+789|0];if(!(y[a+480208|0]&8)){break G}c=1;if(!(j&255)){break u}}if(!(j&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=l}Ab(h+16|0,i,40);H:{if(!(!c|!Bb(x[x[h+16>>2]>>2],x[h+20>>2])|(y[b+789|0]?y[a+480208|0]&8:0))){d=x[b+88>>2]&-4194305;break H}d=x[b+88>>2]&-4196353}x[b+88>>2]=d;I:{if(c){break I}w[b+842>>1]=65535;x[b+88>>2]=d&-6324225|2097152;Ab(h+16|0,i,23);J:{if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break J}Ab(h+8|0,i,22);if(Bb(x[x[h+8>>2]>>2],x[h+12>>2])){break J}Ab(h+16|0,i,52);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break J}Ab(h+8|0,i,71);if(Bb(x[x[h+8>>2]>>2],x[h+12>>2])){break J}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;d=x[a+480208>>2]&8192;K:{L:{if(k){e=1;l=y[k+22|0];M:{if(!Sf(l)){e=!(d>>>13|0);break M}q=b,r=Pq(l),v[q+838|0]=r}d=y[k+21|0];if(Sf(d)){q=b,r=Pq(d),v[q+837|0]=r;break L}if(e){break L}j=(e|0)!=0;break K}x[b+776>>2]=0;x[b+780>>2]=0;j=!d;break K}j=1;d=y[k+25|0];if((d|0)==255){break K}v[b+845|0]=d}N:{if(y[b+837|0]>=127){Ab(h+16|0,i,36);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break N}}if(!j){break N}if((Cp(a,b,1,256)|0)<0|!(y[b+89|0]&2)){break N}d=x[a+1298300>>2];if(!wd(d)|(g|0)==65535){break N}Gp(d,g,y[b+837|0]>>>1|0,1)}if(!(y[b+89|0]&2)){break I}if(!wd(x[a+1298300>>2])|(g|0)==65535){break I}Ab(h+16|0,i,111);if(Bb(x[x[h+16>>2]>>2],x[h+20>>2])){Tj(x[a+1298300>>2],g);break I}Ab(h+16|0,i,110);if(!Bb(x[x[h+16>>2]>>2],x[h+20>>2])){break I}mz(x[a+1298300>>2],g,0,1,0)}d=x[b+88>>2];O:{P:{Q:{if(f){x[b+88>>2]=d&-1025;break Q}if(!(d&1024)){break Q}if(y[a+24618|0]&16){break P}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break P}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break O}}x[b+700>>2]=0}if(c){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}hb=h+32|0}function HW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=hb-1472|0;hb=e;zc(b);Lo(a);a:{b:{c:{if(!gr(b,e+1448|0)){break c}if(!OD(e+1448|0)){break c}if(!c){j=1;break c}if(!fr(x[b>>2],z[e+1466>>1]|z[e+1468>>1]<<16)){break c}if(!fr(x[b>>2],(z[e+1466>>1]|z[e+1468>>1]<<16)+(z[e+1460>>1]<<2)|0)){break c}Av(a);w=e,B=zv(),x[w+72>>2]=B;c=e+72|0;yv(Cj(x[a+4>>2])+32|0,c);er(c);m=x[Cj(x[a+4>>2])+32>>2];x[e+1444>>2]=z[e+1462>>1]|z[e+1464>>1]<<16;w=e,B=Hg(x[b>>2]),x[w+1184>>2]=B;x[e+1144>>2]=214748364;d=e+1184|0;w=e,B=D(x[Hb(d,e+1144|0)>>2],20),x[w+72>>2]=B;en(m,x[Hb(e+1444|0,c)>>2]);Tb(d,0,256);s=Qb(e+1168|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{j=z[e+1460>>1]<=t>>>0;if(!j){x[23420]=0;c=Q(143,b|0,(z[e+1466>>1]|z[e+1468>>1]<<16)+(t<<2)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break s}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[23420]=0;c=W(144,d|0,c|0,4)|0;d=x[23420];x[23420]=0;if((d|0)==1){break s}if(!c){break h}x[23420]=0;c=T(145,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break r}x[23420]=0;d=Q(143,b|0,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break r}if(!d){break h}x[23420]=0;d=Q(146,b|0,e+1144|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}if(!d){break h}x[23420]=0;d=W(147,b|0,s|0,z[e+1156>>1])|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}if(!d){break h}f=x[s>>2];g=x[b>>2];x[23420]=0;d=z[e+1156>>1];g=T(148,g|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break p}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=z[e+1156>>1];g=i+(f<<3)|0;d=0;i=z[e+1158>>1];if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23420]=0;f=fa(149,i|0,f|0,m|0,x[e+1444>>2])|0;i=x[23420];x[23420]=0;if((i|0)==1){break o}if(!f){break h}x[23420]=0;f=Q(143,b|0,g|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break o}if(!f){break h}f=fc(e+1136|0,Kb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f+4>>2];f=x[f>>2];x[23420]=0;bn(150,e+72|0,b,f,i);f=x[23420];x[23420]=0;if((f|0)==1){break n}if(x[e+76>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=z[e+1156>>1];continue}}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23420]=0;d=fa(149,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[23420];x[23420]=0;if((f|0)==1){break m}if(!d){break h}n=Kb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[23420]=0;f=z[e+1162>>1];d=Q(143,b|0,g+z[e+1160>>1]|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[23420]=0;d=W(144,g|0,d|0,x[e+1148>>2]-z[e+1160>>1]|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break l}if(!d){break h}x[23420]=0;U(151,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[23420];x[23420]=0;if((d|0)==1){break b}d=e+48|0;k=dr(e+72|0,d);zb(d);r=0;i=0;while(1){g=0;u:{while(1){if(z[e+1156>>1]<=(i&65535)>>>0){break e}x[23420]=0;d=Q(152,k|0,f+1|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+25824>>1];v:{w:{if(o>>>0<=d>>>0){x[23420]=0;h=y[h+25872|0];q=Q(152,k|0,h|0)|0;u=x[23420];x[23420]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[23420]=0;d=Q(152,k|0,4)|0;h=x[23420];x[23420]=0;if((h|0)==1){break u}if((d|0)==15){x[23420]=0;h=Q(152,k|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=z[e+1158>>1];x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=z[e+1156>>1]){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23420]=0;g=fa(149,g|0,l|0,m|0,x[e+1444>>2])|0;l=x[23420];x[23420]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=Kb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30320)|0;if((ib|0)==(da(30320)|0)){_(j|0)|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){break e}j=P()|0}zb(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23420]=0;d=fa(149,f|0,d|0,m|0,x[e+1444>>2])|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}if(!d){break h}r=Kb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if(z[e+1160>>1]>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=z[e+1162>>1];x[23420]=0;d=Q(143,b|0,g|0)|0;g=x[23420];x[23420]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=fc(e+40|0,e+1184|0,z[e+1160>>1]);g=x[d+4>>2];d=x[d>>2];x[23420]=0;bn(153,e+72|0,b,d,g);d=x[23420];x[23420]=0;if((d|0)==1){break z}d=z[e+1160>>1];if(d>>>0>A[e+76>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[23420]=0;d=W(144,i|0,g|0,x[e+1148>>2]-d|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){break y}}j=P()|0;break a}j=P()|0;break a}if(!d){break h}x[23420]=0;U(151,e+48|0,b|0,x[e+1148>>2]-z[e+1160>>1]|0);d=x[23420];x[23420]=0;if((d|0)==1){break f}d=e+48|0;k=dr(e+72|0,d);zb(d);l=0;i=0;while(1){g=0;A:{while(1){if(z[e+1156>>1]<=(l&65535)>>>0){break g}x[23420]=0;d=Q(152,k|0,f+1|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break A}h=f&7;o=y[h+25856|0];B:{C:{if(o>>>0<=d>>>0){x[23420]=0;h=y[h+25864|0];q=Q(152,k|0,h|0)|0;u=x[23420];x[23420]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[23420]=0;d=Q(152,k|0,3)|0;h=x[23420];x[23420]=0;if((h|0)==1){break A}if((d|0)==7){x[23420]=0;h=Q(152,k|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1184|0)+d|0];h=d+i|0;q=d;d=z[e+1158>>1]&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=z[e+1156>>1]){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[23420]=0;g=fa(149,g|0,n|0,m|0,x[e+1444>>2])|0;n=x[23420];x[23420]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=Kb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=V(30320)|0;if((ib|0)==(da(30320)|0)){_(j|0)|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){break g}j=P()|0}zb(k);break a}zb(k);break h}ke(e+24|0,x[m>>2],x[m+4>>2]);Lg(e+32|0,x[e+24>>2],x[e+28>>2]);b=$d(e+16|0);x[23420]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=wg(154,e+72|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[23420];x[23420]=0;if((c|0)==1){break i}bd(Cj(x[a+4>>2])+12|0,b);zb(b);break h}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}j=P()|0;break a}zb(k);break h}j=P()|0;break a}je(s);break c}zb(k);break d}j=P()|0;break a}zb(k)}t=t+1|0;continue}}hb=e+1472|0;return j|0}j=P()|0}je(s);S(j|0);p()}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=hb-1344|0;hb=d;zc(b);e=hb-16|0;hb=e;eR(e+8|0,d+232|0);h=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){$b(b,x[e+12>>2])}hb=e+16|0;a:{if((h|0)!=(j|0)){break a}if(!gR(d+232|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(fR(x[d+1336>>2]),lb))){break a}if(!c){l=1;break a}zc(b);b=he(d+232|0,b);x[23420]=0;R(571,d+216|0,b|0);e=x[23420];x[23420]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){zb(b);x[23420]=0;U(572,d+200|0,d+216|0,1196314451);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;U(572,d+184|0,d+216|0,1280331091);b=x[23420];x[23420]=0;if((b|0)==1){break h}if(uc(x[d+200>>2],x[d+204>>2])){break b}if(!uc(x[d+184>>2],x[d+188>>2])){break g}break b}c=P()|0;zb(b);break d}c=P()|0;break e}c=P()|0;break f}x[23420]=0;R(234,a|0,1);b=x[23420];x[23420]=0;j:{k:{l:{m:{if((b|0)!=1){Cg(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;F=d,G=Db(x[d+184>>2]),x[F+48>>2]=G;g=c&2;m=Db(x[d+188>>2]);e=a+480190|0;n:{o:{while(1){h=x[d+48>>2];if(!Pb(h,m)){break o}b=z[e>>1];if(!Qh(b)){break o}b=b+1|0;w[e>>1]=b;x[23420]=0;b=D(b&65535,104)+a|0;j=b+484380|0;R(264,j|0,1);i=x[23420];x[23420]=0;p:{q:{if((i|0)!=1){x[23420]=0;i=Q(573,h|0,d+232|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break q}if(!i){break c}if(Ft(d+232|0)){break p}break c}c=P()|0;break j}c=P()|0;break j}x[23420]=0;i=Q(54,d+168|0,d+232|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break n}Dc(((z[e>>1]<<5)+a|0)+946304|0,i);xb(i);i=x[d+268>>2];x[j>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=x[d+264>>2];i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;r:{if(g){b=_c(d+16|0,8,1,0,0);x[23420]=0;W(207,b|0,j|0,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break r}}th(d+48|0);continue}break}c=P()|0;break j}F=d,G=Db(x[d+200>>2]),x[F+160>>2]=G;s=a+484344|0;t=c&1;u=a+484360|0;E=Db(x[d+204>>2]);o=a+484376|0;q=a+480190|0;A=a+484380|0;B=a+946304|0;c=1;l=1;while(1){s:{t:{u:{v:{w:{x:{b=x[d+160>>2];if(!Pb(b,E)){break x}if(!(c&1)){x[23420]=0;c=T(259,u|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break w}if(!c){break x}}Gc(Yb(x[a+484360>>2],y[o|0]));x[23420]=0;c=Q(574,b|0,d+232|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break v}if(!(c&!z[d+1318>>1])|x[d+1320>>2]-5>>>0<4294967292){break c}c=y[o|0];e=x[a+484360>>2];x[23420]=0;U(5,d+48|0,5,d+232|0);h=x[23420];x[23420]=0;if((h|0)==1){break k}x[23420]=0;R(260,Yb(e,c)|0,d+48|0);c=x[23420];x[23420]=0;if((c|0)==1){break l}yb(d+48|0);y:{if(t){x[23420]=0;U(178,d+48|0,b|0,x[d+1328>>2]);b=x[23420];x[23420]=0;if((b|0)!=1){break y}c=P()|0;break j}x[23420]=0;b=T(162,d+112|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break m}yD(d+48|0,b)}b=d+48|0;m=jc(d+136|0,b);zb(b);if(!t){zb(d+112|0)}Tb(d+48|0,0,64);c=1;z:{A:{B:{while(1){if((c|0)==32){break B}b=(D(c,34)+d|0)+198|0;e=b+32|0;Fm(d,e);C:{D:{if(!y[x[d>>2]]){break D}h=y[b- -64|0];if(h>>>0>15){break A}b=y[b+65|0];if(b>>>0>64){break A}if(!Ft(e)){break A}j=b<<2;i=h<<4;h=0;b=1;E:{while(1){g=b&65535;e=z[q>>1];if(g>>>0>e>>>0){break E}x[23420]=0;U(474,d+16|0,x[d>>2],x[d+4>>2]);e=x[23420];x[23420]=0;if((e|0)==1){break C}e=hb-32|0;hb=e;k=d+16|0;ue(e+24|0,k);cR(e+16|0,((g<<5)+a|0)+946304|0);f=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=f;f=x[e+24>>2];r=x[e+12>>2];n=x[e+28>>2];if((r|0)==(n|0)){f=(OS(f,n,x[e+8>>2],r)|0)!=0}else{f=1}hb=e+32|0;xb(k);F:{G:{if(f){break G}F=bc(d+48|0,c),G=b,w[F>>1]=G;e=D(g,104)+a|0;g=e+484410|0;f=z[g>>1];if((f|0)==255){break F}h=b;if(y[e+484417|0]!=(i&255)){break G}if((f|0)==(j|0)){break F}}b=b+1|0;continue}break}v[e+484417|0]=i;w[g>>1]=j;break D}h=h&65535;if(!h){break D}if(!Qh(e)){break D}b=e+1|0;w[q>>1]=b;F=bc(d+48|0,c),G=b,w[F>>1]=G;b=D(z[q>>1],104)+A|0;mm(b);e=D(h,104)+A|0;g=fo(b,e);w[b+30>>1]=j;v[b+37|0]=i;ZR(g,e);e=(h<<5)+B|0;h=x[e+4>>2];b=(z[q>>1]<<5)+B|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break u}i=0;x[d+40>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;e=64;j=65535;r=z[d+1320>>1];h=0;H:while(1){I:{if(h){break I}b=x[m>>2];x[23420]=0;b=W(144,b|0,x[d+144>>2],1)|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}if(b){break I}c=j;b=e;break t}b=e+1|0;J:{if(e>>>0<63){e=b;break J}x[23420]=0;j=Q(345,s|0,64)|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}c=65535;if((j|0)==65535){break t}b=y[o|0];c=x[a+484360>>2];e=0;x[23420]=0;R(472,Yb(c,b)|0,j|0);b=x[23420];x[23420]=0;if((b|0)==1){break z}}b=0;c=_b(x[s>>2],j&65535);c=ed(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue H}g=(d+16|0)+D(b,7)|0;f=y[g+6|0];K:{if(f){v[g+6|0]=f-1;f=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=f;v[c+5|0]=f>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=h-1|0;break K}f=x[m>>2];x[23420]=0;f=W(144,f|0,x[d+144>>2],1)|0;k=x[23420];x[23420]=0;if((k|0)==1){break u}if(!f){break K}if(x[d+144>>2]==x[d+1324>>2]){i=Yb(x[a+484360>>2],y[o|0]);Ze(i,vB(x[i>>2],x[i+4>>2]));i=e}x[23420]=0;f=T(194,m|0)|0;k=x[23420];x[23420]=0;L:{if((k|0)!=1){f=f<<24>>24;if((f|0)>=0){break L}f=f&127;v[g+6|0]=f;k=y[g+4|0]|y[g+5|0]<<8;v[c+4|0]=k;v[c+5|0]=k>>>8;g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[c|0]=g;v[c+1|0]=g>>>8;v[c+2|0]=g>>>16;v[c+3|0]=g>>>24;h=f+h|0;break K}break u}if((f-1&255)>>>0<=35){v[c|0]=f+48}x[23420]=0;f=T(194,m|0)|0;k=x[23420];x[23420]=0;M:{N:{if((k|0)!=1){f=f<<24>>24;F=c,G=y[bc(d+48|0,f&31)|0],v[F+1|0]=G;if((f|0)>=0){break N}v[c+3|0]=y[g+3|0];v[c+5|0]=y[g+5|0];break M}break u}x[23420]=0;R(247,d|0,m|0);f=x[23420];x[23420]=0;O:{if((f|0)!=1){f=y[d|0];if(f>>>0>19){break M}n=f<<1;C=y[n+26784|0];v[c+3|0]=C;k=y[jd(d)|0];v[c+5|0]=k;if((C|0)!=16|k>>>0<32){break O}v[c+3|0]=17;break M}break u}if(819137>>>f&1){break M}v[c+5|0]=y[n+26785|0]|k&15}f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[g|0]=f;v[g+1|0]=f>>>8;v[g+2|0]=f>>>16;v[g+3|0]=f>>>24;f=y[c+4|0]|y[c+5|0]<<8;v[g+4|0]=f;v[g+5|0]=f>>>8}c=c+6|0;b=b+1|0;continue}}}l=0;break s}break u}zi(u,0);x[23420]=0;b=Q(1,d+232|0,6428)|0;c=x[23420];x[23420]=0;P:{if((c|0)!=1){Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,d+48|0,6730)|0;c=x[23420];x[23420]=0;if((c|0)==1){break P}Gb(a+1298356|0,b);yb(b);x[a+1298404>>2]=5;l=1;break b}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;zb(m);break j}Q:{if(!((i|0)!=0|b>>>0<63)){break Q}c=c&65535;if((c|0)==65535){break Q}ie(_b(x[s>>2],c),xh(Fe(ye(d,14,i&255),b)))}c=32}zb(m);if(c>>>0<32){break b}th(d+160|0);c=0;continue}}c=P()|0;break j}c=P()|0;break j}c=P()|0;break j}c=P()|0;yb(d+48|0);break j}c=P()|0}kd(d+184|0)}kd(d+200|0)}_d(d+216|0)}S(c|0);p()}l=0}kd(d+184|0);kd(d+200|0);_d(d+216|0)}hb=d+1344|0;return l|0}function Aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-304|0;hb=e;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!lU(b,e+232|0)){break p}if(!mU(e+232|0)){break p}if(!c){d=1;break p}Dd(a,131072);d=hb-16|0;hb=d;i=e+136|0;f=Vb(d,3913);Rc(i,f);yb(f);hb=d+16|0;x[23420]=0;U(291,e+184|0,i|0,e+232|4);d=x[23420];x[23420]=0;q:{if((d|0)!=1){d=e+184|0;Gb(a+1298344|0,d);yb(d);i=e+136|0;cc(i);f=Vb(d,11004);Gb(a+1298356|0,f);yb(f);x[a+1298404>>2]=5;tu(i,3,e+245|0);Fc(d,i);Ac(a+1298308|0,d);xb(d);f=e+112|0;tj(f,3,e+275|0);Fc(i,f);x[23420]=0;U(11,d|0,5,i|0);d=x[23420];x[23420]=0;if((d|0)==1){break b}d=e+184|0;Gb(a+1298320|0,d);yb(d);xb(e+136|0);d=qq(d);o=d,q=Wd(y[e+295|0],1,31),x[o+12>>2]=q;o=d,q=Wd(y[e+296|0],1,12)-1|0,x[o+16>>2]=q;x[d+20>>2]=y[e+297|0];i=a+1298408|0;Gc(i);jU(i,d);g=e+144|0;i=Qb(e+168|0);r:{s:{t:{while(1){d=x[b+8>>2];f=x[b>>2];x[23420]=0;d=W(144,f|0,d|0,8)|0;f=x[23420];x[23420]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}x[23420]=0;R(292,b|0,e+72|0);d=x[23420];x[23420]=0;if((d|0)==1){break y}d=x[e+76>>2];z:{l=y[e+236|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(x[e+72>>2]!=1431389523){break v}break u}b=P()|0;break c}b=P()|0;break c}f=4;if(x[e+72>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=x[e+72>>2]==1146113363?-1:d;f=0}l=x[e+76>>2];x[e+136>>2]=x[e+72>>2];x[e+140>>2]=l;x[23420]=0;U(178,e+112|0,b|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break t}jc(g,e+112|0);x[23420]=0;R(293,i|0,e+136|0);d=x[23420];x[23420]=0;if((d|0)==1){break s}Md(e+136|0);zb(e+112|0);x[23420]=0;Q(176,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;Md(e+136|0);zb(e+112|0);break c}x[23420]=0;l=T(162,e+136|0)|0;b=x[23420];x[23420]=0;A:{B:{C:{if((b|0)!=1){x[23420]=0;U(294,e+112|0,i|0,1431389523);b=x[23420];x[23420]=0;if((b|0)==1){break C}d=e+112|0;b=bd(l,d);zb(d);w[e+110>>1]=0;w[e+108>>1]=65534;if(y[e+236|0]<3){break A}x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break B}break e}b=P()|0;break c}b=P()|0;break d}w[e+110>>1]=d;if(y[e+236|0]<4){break A}x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}w[e+108>>1]=y[e+236|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[23420]=0;g=T(190,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break e}x[23420]=0;U(226,Yb(f,d)|0,b|0,g>>>1|0);d=x[23420];x[23420]=0;if((d|0)==1){break e}d=Yb(x[a+484360>>2],y[a+484376|0]);d=vB(x[d>>2],x[d+4>>2]);tg(e+110|0,d);tg(e+108|0,d);x[23420]=0;U(294,e+112|0,i|0,1414807888);d=x[23420];x[23420]=0;if((d|0)==1){break h}d=e+112|0;b=bd(b,d);zb(d);d=x[b>>2];x[23420]=0;d=T(166,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}x[23420]=0;R(295,b|0,e+8|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}o=a+480188|0,q=Wd(y[e+10|0],1,32)+1|0,w[o>>1]=q;x[23420]=0;d=Q(206,e+96|0,z[e+8>>1])|0;f=x[23420];x[23420]=0;if((f|0)==1){break j}o=e,q=Db(x[d>>2]),x[o+48>>2]=q;g=Db(x[d+4>>2]);D:{E:{while(1){h=x[e+48>>2];if(!Pb(h,g)){f=z[a+480188>>1];x[23420]=0;f=Q(296,e+112|0,f|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){g=a+484376|0;h=Yb(x[a+484360>>2],y[g|0]);h=fl(x[h>>2],x[h+4>>2]);x[23420]=0;k=a+484344|0;R(213,k|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break g}g=Yb(x[a+484360>>2],y[g|0]);o=e,q=Db(x[g>>2]),x[o+72>>2]=q;h=Db(x[g+4>>2]);F:{while(1){G:{g=x[e+72>>2];if(!Pb(g,h)){g=y[a+484376|0];h=x[a+484360>>2];x[23420]=0;j=Yb(h,g);h=z[e+108>>1];g=Q(297,j|0,h|0)|0;j=x[23420];x[23420]=0;if((j|0)!=1){break G}break g}j=x[d>>2];n=Ff(j,x[d+4>>2]);m=z[g>>1];if(n>>>0>m>>>0){x[23420]=0;j=fa(298,Bg(j,m)|0,y[e+236|0],f|0,a|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break F}w[g>>1]=j}Re(e+72|0);continue}break}H:{if(!g){break H}g=Yb(x[a+484360>>2],y[a+484376|0]);j=z[e+110>>1];if(!j){if(vB(x[g>>2],x[g+4>>2])>>>0<=h>>>0){break H}}g=_b(x[k>>2],z[bc(x[g>>2],h)>>1]);ie(g,tm(Fe(ye(e+72|0,12,j&255),x[g+12>>2]-1|0)))}ek(f);kd(d);break q}break g}b=P()|0;break f}x[23420]=0;f=y[e+236|0]<3?9:8;Q(176,b|0,f-4|0)|0;k=x[23420];x[23420]=0;if((k|0)!=1){x[23420]=0;k=T(145,b|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break E}mg(b,f);x[23420]=0;U(178,e+72|0,b|0,f+k|0);f=x[23420];x[23420]=0;if((f|0)==1){break D}j=h;f=e+72|0;h=jc(e+112|0,f);bd(j,h);zb(h);zb(f);th(e+48|0);continue}break}b=P()|0;break f}b=P()|0;break f}b=P()|0;break f}b=P()|0;cc(e+136|0);break a}x[23420]=0;U(294,e+72|0,i|0,1196641603);d=x[23420];x[23420]=0;if((d|0)==1){break n}d=e+72|0;b=bd(b,d);zb(d);d=x[b>>2];x[23420]=0;d=T(166,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}if(d){x[23420]=0;Q(176,b|0,1)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}x[23420]=0;d=T(190,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}x[23420]=0;ea(299,a+1298332|0,b|0,d|0,40,0);d=x[23420];x[23420]=0;if((d|0)==1){break e}}x[23420]=0;U(294,e+72|0,i|0,1146113363);d=x[23420];x[23420]=0;if((d|0)==1){break k}x[23420]=0;U(294,e+48|0,i|0,1229999443);d=x[23420];x[23420]=0;if((d|0)==1){break o}d=e+48|0;b=bd(b,d);zb(d);x[23420]=0;d=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break m}h=a+480190|0;w[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(y[e+236|0]>=2){x[23420]=0;d=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break M}}x[23420]=0;U(300,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break M}x[23420]=0;R(301,b|0,e+32|0);d=x[23420];x[23420]=0;if((d|0)==1){break L}x[23420]=0;g=D(c,104)+a|0;j=g+484380|0;R(302,e+32|0,j|0);c=x[23420];x[23420]=0;if((c|0)==1){break L}d=y[e+236|0];if(d>>>0>=8){x[23420]=0;R(303,b|0,g+484423|0);c=x[23420];x[23420]=0;if((c|0)==1){break L}d=y[e+236|0]}x[23420]=0;Q(176,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break L}x[23420]=0;c=T(145,e+72|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;U(178,e+8|0,e+72|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){break K}}b=P()|0;break l}b=P()|0;break l}b=P()|0;break l}d=e+8|0;c=jc(e+48|0,d);zb(d);d=x[c>>2];x[23420]=0;d=T(166,d|0)|0;m=x[23420];x[23420]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=_c(e+8|0,w[g+484414>>1]&1?16:8,1,0,(y[e+47|0]&12)==4?7:0);x[23420]=0;W(207,d|0,j|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break N}break J}zb(c);f=f+1|0;d=z[h>>1];continue}}break}b=P()|0;zb(c);break l}Cg(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[23420]=0;d=1;W(251,a+1074312|0,114,1)|0;a=x[23420];x[23420]=0;if((a|0)==1){break m}zb(e+72|0);zb(b);_d(i)}hb=e+304|0;return d|0}b=P()|0;break l}b=P()|0;break d}b=P()|0}zb(e+72|0);break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;break d}b=P()|0;ek(f)}kd(d);break d}b=P()|0}zb(l)}_d(i);break a}b=P()|0;xb(e+136|0)}S(b|0);p()}function yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;d=hb-336|0;hb=d;a:{if(!$c(b,1080)){break a}if(!mo(b,d+332|0)){break a}Dd(a,1);m=LR(d+312|0);if(!KR(d+332|0,m)){break a}h=z[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){g=1;break a}u=a+480188|0;w[u>>1]=h;t=y[m+14|0];K=y[m+13|0];f=y[m+12|0];E=1;if(!ee(d+332|0,26714)){E=ee(d+332|0,26719)}if(y[m+15|0]){Mb(a+1074312|0,5,1);h=z[a+480188>>1]}g=d+332|0;r=ee(g,16546);e=1;if(!ee(g,17310)){e=ee(d+332|0,13438)}A=(h&65535)==8&(K|0)!=0;$c(b,0);SA(b,a+1298308|0,20);w[a+480190>>1]=31;n=(f|0)!=0;q=a+480188|0;g=1;h=r;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{L=x[m+4>>2];if(L>>>0>=F>>>0){f=d+176|0;GR(b,f);$c(b,z[m+8>>1]);g=y[d+177|0];e=128;i=a+484376|0;rq(Yb(x[a+484360>>2],y[i|0]),f|2,128);h=!g&h;k=h?k:0;f=y[d+176|0];h:{if(f>>>0>128){break h}e=f;if(e){break h}f=x[Yb(x[a+484360>>2],y[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!z[bc(f,g)>>1]){continue}break}}s=FR(b,Yb(x[a+484360>>2],y[i|0]),e&65535,j,u,k,0);G=1;i:{if(!(h&z[a+480188>>1]==8)){G=(t|0)!=0;break i}x[m>>2]=11121}j:{if(!A){break j}f=Yb(x[a+484360>>2],y[a+484376|0]);aa=d,ba=Db(x[f>>2]),x[aa+160>>2]=ba;h=Db(x[f+4>>2]);while(1){f=x[d+160>>2];if(!Pb(f,h)){break j}w[f>>1]=z[f>>1]>>>1;Re(d+160|0);continue}}f=a+484376|0;Ze(Yb(x[a+484360>>2],y[f|0]),y[d+177|0]);M=e-1|0;e=y[d+177|0];k:{if((M&65535)>>>0>=e>>>0){g=z[u>>1];if((e|0)!=120|(g|0)!=4){break k}}Ze(Yb(x[a+484360>>2],y[f|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;x[a+480208>>2]=0;aa=a,ba=Xb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;wh(a,0);v[d+175|0]=0;t=1;g=0;N=1;if(!n){o=d+160|5;n=0;e=0;k=0;f=r;l:while(1){if(s>>>0>(k&65535)>>>0){i=0;g=0;while(1)if((g|0)==256){k=k+1|0;continue l}else{h=Sh(d+160|0);pu(b,h);q=$A(y[h|0]);m:{n:{o:{p:{h=y[d+163|0];if((h-7&255)>>>0<3){f=0;break p}j=y[d+165|0];if(!((h|0)!=14|j>>>0<=1)){f=0;break o}if(!((h|0)==15&(j&255)>>>0>31)){f=q?f:0;if((h|0)!=13){break p}i=i+1|0;if((i&65535)>>>0<2){break m}}f=0;break m}if((h|0)==8){break n}if((h|0)!=14){break m}j=y[d+165|0]}if((j&240)!=128){break m}v[d+144|0]=j<<4;aa=d,ba=y[_e(d+175|0,d+144|0)|0],v[aa+175|0]=ba;break m}aa=d,ba=y[_e(d+175|0,o)|0],v[aa+175|0]=ba;h=v[d+165|0];if((h|0)>=0){n=1;break m}e=(h|0)!=-92&h>>>0>4294967183|e}t=q&t;g=g+1|0;continue}}break}g=0;g=(n^-1|e)&1?g:y[d+175|0]>47;N=f&1}$c(b,z[m+8>>1]);e=z[a+480188>>1];q=a+484344|0;H=s+A&65535;lg(q,H);O=A?4:e;n=a+1074312|0;Z=g^1;_=c&1;k=0;j=0;s=0;o=0;q:{r:{s:{while(1){if((k|0)==(H|0)){break r}t:{if(A){e=(k&65534)>>>1|0;f=k&1;if(!f){if(!$g(q,e,64)){break r}}h=f<<2;e=_b(x[q>>2],e);break t}if(!$g(q,k&65535,64)){break r}h=0;e=_b(x[q>>2],k)}i=0;I=ed(x[e>>2],x[x[e+48>>2]+12>>2],0,h);if(!_){s=0;o=0;break q}e=z[u>>1];v[d+80|0]=0;f=e;e=d+80|0;i=wm(d+160|0,f,e);f=z[u>>1];x[23420]=0;v[d+80|0]=0;B=W(530,d+144|0,f|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){J=0;u:while(1){if((J|0)!=64){h=0;f=0;Q=0;while(1){if((h|0)==(O|0)){J=J+1|0;s=f&Q|s;I=D(z[u>>1],6)+I|0;continue u}x[23420]=0;g=D(h,6)+I|0;R(531,b|0,g|0);e=x[23420];x[23420]=0;v:{w:{if((e|0)!=1){e=y[g+3|0];x:{y:{z:{if(!e){if(y[g+5|0]){break z}break y}if(!K){break z}A:{switch(e-14|0){case 0:v[g+3|0]=0;v[g+5|0]=0;break z;case 1:break A;default:break z}}if(y[g+5|0]<32){break z}v[g+5|0]=31}Of(g);e=1;B:{C:{D:{l=y[g+3|0];switch(l-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}j=y[g+5|0]<100|j;Q=1;break y}if(!N){break y}v[g+5|0]=0;break y}if(!((l|0)!=9|Z)){e=y[g+5|0];if((e|0)==164){v[g+3|0]=20;v[g+5|0]=145;break y}aa=g,ba=xi(e<<1),v[aa+5|0]=ba;break y}if((l|0)!=19){break y}e=y[g+5|0];if(e>>>0>15){break y}l=e&1;e=!l;$=!l;l=T&1;T=(l|0)==(e|0)?T:$;o=((e|0)!=(l|0))+o|0}e=f}if(y[g|0]){break w}f=y[g+1|0];if(!f|A){break v}l=y[Kb(x[i>>2],h)|0];if(!l|(f|0)==(l|0)){break v}l=Kb(x[B>>2],h);f=y[l|0]+1|0;v[l|0]=f;if((f&255)>>>0<4){break v}x[23420]=0;W(251,n|0,85,1)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break v}}h=P()|0;dc(B);break s}aa=Kb(x[B>>2],h),ba=0,v[aa|0]=ba}f=y[g+1|0];if(f){aa=Kb(x[i>>2],h),ba=f,v[aa|0]=ba}h=h+1|0;f=e;continue}}break}dc(B);dc(i);k=k+1|0;continue}break}h=P()|0}dc(i);break b}i=j}E:{F:{G:{if((t^-1|V)&1){break G}H:{if(ee(d+332|0,16546)){break H}if(ee(d+332|0,17315)){break H}if(!ee(d+332|0,13428)){break G}}x[a+480208>>2]=x[a+480208>>2]|2162688;e=Mb(Mb(Mb(n,85,1),91,1),92,1);I:{if(y[d+175|0]>47){break I}e=Mb(e,84,1);if(y[d+177|0]==127){break I}Mb(e,83,1)}if(!(t&1)){break E}break F}if(t&1){break F}if(!(r&(y[d+177|0]==127&(M&65535)>>>0<129))){break E}x[m>>2]=8412;break E}if((o|0)>6|G){break E}x[a+480208>>2]=x[a+480208>>2]|8388608}if((r|G)==1){Mb(n,89,1)}if(E){Mb(n,84,1)}J:{if(!(c&2)){break J}$c(b,z[m+8>>1]+(D(H,O)<<8)|0);f=(t&r^1|X)&1;g=1;while(1){if((g|0)==32){break J}h=D(g,104)+a|0;c=h+484380|0;e=x[c>>2];if(e){j=2;if(!E){j=ER(b,13692)?10:0;e=x[c>>2]}j=_c(d+160|0,8,1,0,j);e=UA(j,e)+x[b+8>>2]|0;if(!f){aa=c,ba=x[Yc(c,h+484388|0)>>2],x[aa>>2]=ba}kg(j,c,b);$c(b,e)}g=g+1|0;continue}}K:{if((i&r^-1|s)&1){break K}b=DR(d+120|0,0);c=x[b+20>>2];x[d+40>>2]=x[b+16>>2];x[d+44>>2]=c;c=x[b+12>>2];x[d+32>>2]=x[b+8>>2];x[d+36>>2]=c;c=x[b+4>>2];x[d+24>>2]=x[b>>2];x[d+28>>2]=c;b=d+160|0;Jt(b,a,0,d+24|0);Y=C[x[d+160>>2]>>3];ui(b);if(!(Y>=480)){break K}c=Mb(n,5,1);b=CR(d+96|0,Y);e=x[b+20>>2];x[d+16>>2]=x[b+16>>2];x[d+20>>2]=e;e=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=e;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=d+160|0;Jt(b,a,0,d);e=y[x[d+160>>2]+26|0];ui(b);if(e){Cf(c,5);break K}x[m>>2]=16898}b=d+332|0;e=b;f=ic(e);c=e;while(1){if((e|0)!=(f|0)){r=y[e|0];v[c|0]=r>>>0<=32?32:r;c=c+1|0;e=e+1|0;continue}break}rg(d+80|0,16651);x[23420]=0;b=W(532,d+48|0,b|0,f|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break g}x[23420]=0;U(11,d- -64|0,1,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}x[23420]=0;U(133,d+160|0,d+80|0,d- -64|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}c=d+160|0;Gb(a+1298344|0,c);yb(c);yb(d- -64|0);xb(b);cc(d+80|0);b=Vb(c,12176);Gb(a+1298356|0,b);yb(b);b=x[m>>2];if(b){xl(a+1298368|0,b)}x[a+1298404>>2]=13}g=F>>>0<=L>>>0;break a}h=P()|0;break c}h=P()|0;break d}h=P()|0;yb(d- -64|0)}xb(b)}cc(d+80|0)}S(h|0);p()}else{i=D(g,104)+a|0;f=i+484380|0;s=lA(b,d+176|0,f,((g<<5)+a|0)+946304|0,z[q>>1]==4);f=x[f>>2];L:{if(e){v[i+484417|0]=0-(y[d+200|0]<<3);break L}n=f>>>0<65536&n}i=Lb(z[d+198>>1]);M:{if(i){V=!Lb(z[d+204>>1])|V;break M}X=y[d+201|0]==64|X}o=h&1;h=0;N:{if(!o){break N}k=(i<<1)+k|0;o=y[d+200|0];h=!o;if(o|!i){break N}h=y[d+201|0]==64}F=s+F|0;j=f+j|0;g=g+1|0;continue}}hb=d+336|0;return g|0}function n6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=0,_=0,$=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];mK(a);if(g==B[a+4268>>2]){break a}Bx(a)}b:{if(!y[a+5045|0]){break b}if(!Uh(a+44|0)){break b}i=x[a+44>>2];p=Ec(i,0);q=Ec(i,1);i=x[a+56>>2];l=Ec(i,0);m=Ec(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;C=a+4628|0;D=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;_=Kc(x[a+4864>>2],x[W>>2],x[a+4880>>2]),$=g,B[_>>2]=$;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;_=Kc(x[a+4888>>2],x[X>>2],x[a+4904>>2]),$=g,B[_>>2]=$;g=E(E(E(E(E(Jh(t,x[a+4356>>2])*E(.6800000071525574))+E(Jh(t,x[a+4360>>2])*E(-.5)))-E(Jh(t,x[a+4364>>2])*E(.6200000047683716)))+E(Jh(t,x[a+4368>>2])*E(-.5)))-E(Jh(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Kc(x[a+4816>>2],x[T>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));_=Kc(x[a+4816>>2],x[T>>2],x[a+4832>>2]),$=E(e-E(g*E(.6180340051651001))),B[_>>2]=$}u=B[a+4280>>2];_=a,$=E(Jh(t,x[a+4352>>2])+B[a+5020>>2]),B[_+5020>>2]=$;e=E(Jh(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Kc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Kc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;P=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(P+E(f*h));_=Kc(x[a+4624>>2],x[C>>2],x[a+4640>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4976>>2]-B[Kc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Kc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));_=Kc(x[a+4600>>2],x[D>>2],x[a+4616>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Kc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Kc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));_=Kc(x[a+4576>>2],x[N>>2],x[a+4592>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4968>>2]-B[Kc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Kc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));_=Kc(x[a+4552>>2],x[O>>2],x[a+4568>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}_=Kc(x[a+4912>>2],x[Q>>2],x[a+4928>>2]),$=f,B[_>>2]=$;e=E(B[Kc(x[a+4912>>2],x[Q>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Kc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Kc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));_=Kc(x[a+4528>>2],x[F>>2],x[a+4544>>2]),$=E(f-E(o*h)),B[_>>2]=$;e=E(E(E(B[a+4960>>2]-B[Kc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Kc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));_=Kc(x[a+4504>>2],x[G>>2],x[a+4520>>2]),$=E(h-E(e*o)),B[_>>2]=$;B[a+5020>>2]=o;e=E(E(E(E(E(Jh(s,x[a+4380>>2])*E(.7070000171661377))+E(Jh(s,x[a+4384>>2])*E(-.6000000238418579)))-E(Jh(s,x[a+4388>>2])*E(.5)))+E(Jh(s,x[a+4392>>2])*E(-.6000000238418579)))-E(Jh(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Kc(x[a+4840>>2],x[S>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));_=Kc(x[a+4840>>2],x[S>>2],x[a+4856>>2]),$=E(f-E(e*E(.6180340051651001))),B[_>>2]=$}Y=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Kc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Kc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;P=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(P+E(f*j));_=Kc(x[a+4768>>2],x[H>>2],x[a+4784>>2]),$=E(f-E(j*k)),B[_>>2]=$;f=E(E(E(B[a+5e3>>2]-B[Kc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Kc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));_=Kc(x[a+4744>>2],x[I>>2],x[a+4760>>2]),$=E(k-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Kc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Kc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));_=Kc(x[a+4720>>2],x[L>>2],x[a+4736>>2]),$=E(f-E(j*h)),B[_>>2]=$;f=E(E(E(B[a+4992>>2]-B[Kc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Kc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));_=Kc(x[a+4696>>2],x[M>>2],x[a+4712>>2]),$=E(h-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*Y);_=Kc(x[a+4936>>2],x[R>>2],x[a+4952>>2]),$=f,B[_>>2]=$;g=E(B[Kc(x[a+4936>>2],x[R>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Kc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Kc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));_=Kc(x[a+4672>>2],x[J>>2],x[a+4688>>2]),$=E(e-E(f*g)),B[_>>2]=$;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Kc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Kc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));_=Kc(x[a+4648>>2],x[K>>2],x[a+4664>>2]),$=E(g-E(u*e)),B[_>>2]=$;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];ji(n,b,c,Ec(a,0),Ec(a,1),d)}}function zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=hb-288|0;hb=g;e=hb-128|0;hb=e;f=he(g+104|0,c);x[23420]=0;n=T(162,f+20|0)|0;c=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[23420]=0;q=T(162,f+40|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break B}x[23420]=0;r=T(162,f+60|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break A}x[23420]=0;i=T(162,f+80|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}x[23420]=0;o=T(162,f+100|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break y}x[23420]=0;k=T(162,f+120|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break x}j=Qb(f+140|0);zc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[23420]=0;d=Q(724,f|0,e+112|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break w}if(!d){break n}d=x[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=x[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(d|0)==1414744396;x[23420]=0;U(725,e+96|0,f|0,2);c=x[23420];x[23420]=0;if((c|0)==1){break v}h=x[e+96>>2];C:{if(uq(h,x[e+100>>2])>>>0<4){break C}c=$x(h,1);d=x[c+4>>2];c=x[c>>2];yi(e+40|0,c,d);if(x[e+40>>2]!=1635017060){break C}yi(e- -64|0,c,d);if(!(v[e+68|0]&1)){break C}c=$x(h,2);yi(e+24|0,x[c>>2],x[c+4>>2]);if(x[e+28>>2]){break C}c=$x(h,3);yi(e+88|0,x[c>>2],x[c+4>>2]);if(x[e+88>>2]){break C}x[23420]=0;Q(143,f|0,12)|0;c=x[23420];x[23420]=0;if((c|0)==1){break u}x[23420]=0;U(725,e+40|0,f|0,1);c=x[23420];x[23420]=0;if((c|0)==1){break t}c=e+40|0;Dt(e+96|0,c);_d(c)}x[23420]=0;U(726,e- -64|0,e+96|0,544501094);c=x[23420];x[23420]=0;if((c|0)==1){break s}x[23420]=0;d=Q(727,e- -64|0,f+156|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}if(!d){break o}d=z[f+156>>1];if((d|0)!=1){break q}x[23420]=0;d=T(190,e- -64|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break r}break k}d=P()|0;break b}d=P()|0;break c}d=P()|0;break d}d=P()|0;break e}d=P()|0;break f}d=P()|0;break g}d=P()|0;break h}d=P()|0;break h}d=P()|0;break i}d=P()|0;break i}d=P()|0;break i}if((d|0)==4){x[23420]=0;h=T(185,e- -64|0)|0;c=x[23420];x[23420]=0;D:{if((c|0)!=1){x[23420]=0;d=T(185,e- -64|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}v[f+177|0]=1;break p}d=P()|0;break j}d=P()|0;break j}d=z[f+156>>1]}if((d&65535)!=65534){break p}x[23420]=0;d=Q(728,e- -64|0,e+40|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break l}if(!d){break o}c=x[e+60>>2];x[e+16>>2]=x[e+56>>2];x[e+20>>2]=c;c=x[e+52>>2];x[e+8>>2]=x[e+48>>2];x[e+12>>2]=c;c=e+24|0;x[c>>2]=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);w[c+4>>1]=y[e+12|0]|y[e+13|0]<<8;w[c+6>>1]=y[e+14|0]|y[e+15|0]<<8;s=c,t=Uz(y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24),y[e+20|0]|y[e+21|0]<<8|(y[e+22|0]<<16|y[e+23|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=lb;w[f+172>>1]=x[c>>2]}x[23420]=0;U(726,e+40|0,e+96|0,1635017060);c=x[23420];x[23420]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=bd(n,c);zb(c);c=x[m>>2];x[23420]=0;d=T(166,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}if(!d){x[23420]=0;U(726,e+40|0,e+96|0,544039792);c=x[23420];x[23420]=0;if((c|0)==1){break J}c=e+40|0;bd(m,c);zb(c)}x[23420]=0;U(726,e+40|0,e+96|0,1952670054);c=x[23420];x[23420]=0;if((c|0)==1){break I}x[23420]=0;d=T(145,e+40|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break H}x[f+152>>2]=d;zb(e+40|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];d=KL(h,z[f+170>>1]);if(!d){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=x[m>>2];x[23420]=0;d=T(148,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}c=KL(z[f+158>>1],z[f+170>>1]);break F}d=P()|0;break j}d=P()|0;break j}d=P()|0;break j}d=P()|0;zb(e+40|0);break j}c=x[m>>2];x[23420]=0;d=T(148,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(d>>>0)/((c&65535)>>>0)}x[23420]=0;d=Q(729,f|0,e+96|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}w[f+174>>1]=d;x[23420]=0;R(730,f|0,e+96|0);c=x[23420];x[23420]=0;if((c|0)==1){break k}x[23420]=0;U(726,e+40|0,e+96|0,1886221175);c=x[23420];x[23420]=0;if((c|0)==1){break m}c=e+40|0;bd(o,c);zb(c)}zb(e- -64|0);_d(e+96|0)}hb=e+128|0;break a}d=P()|0;break j}d=P()|0;break j}d=P()|0}zb(e- -64|0)}_d(e+96|0)}_d(j);zb(k)}zb(o)}zb(i)}zb(r)}zb(q)}zb(n)}zb(f);S(d|0);p()}c=x[f+20>>2];x[23420]=0;d=T(667,c|0)|0;c=x[23420];x[23420]=0;K:{L:{if((c|0)!=1){M:{if(!d|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Wj(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Wj(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Wj(f);c=30080;while(1){Q:{R:{if((c|0)!=30104){if((d|0)!=x[c>>2]){break R}}else{c=30104}break Q}c=c+4|0;continue}break}if((c|0)==30104){break M}ct(a,b);x[23420]=0;d=Q(54,g+88|0,21473)|0;c=x[23420];x[23420]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Dc(((b<<5)+a|0)+946304|0,d);xb(d);x[23420]=0;d=D(b,104)+a|0;i=d+484380|0;R(264,i|0,0);c=x[23420];x[23420]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[d+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[23420]=0;X(668,f|0,i|0,c|0,h|0);c=x[23420];x[23420]=0;if((c|0)==1){break W}he(g- -64|0,f+20|0);d=z[f+158>>1];j=_c(g+56|0,8,d>>>0>1?2:1,0,0);c=Wj(f);if((c|0)!=17|d>>>0>2){break U}xc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((d|0)==2)<<6|1;if(Ag(i)){break V}break S}l=P()|0;break K}l=P()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=he(g+32|0,g- -64|0);d=z[f+158>>1];c=z[f+168>>1];x[23420]=0;b=x[k+12>>2];x[g+16>>2]=x[k+8>>2];x[g+20>>2]=b;x[g+24>>2]=x[k+16>>2];b=x[k+4>>2];x[g+8>>2]=x[k>>2];x[g+12>>2]=b;ea(669,j|0,h|0,g+8|0,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break L}lj(i,a);break T}if((c|0)==85){x[23420]=0;c=W(511,a|0,b|0,g- -64|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(yP(z[f+156>>1])){break Z}_:{if(!Rd(y[f+177|0])){break _}if((Wj(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=d<<2){break _}Dh(j,32);b=12;break Y}if((Wj(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=d<<2){break Z}Dh(j,32);b=13;break Y}if((Wj(f)&65534)!=6){break X}Dh(j,16);b=(Wj(f)|0)==6?17:16}Rf(j,b);x[23420]=0;W(207,j|0,i|0,g- -64|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break T}break L}d=z[f+170>>1];c=d-1|0;b=c&-8;h=b&31;Dh(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&255);if(d>>>0<9){Rf(j,1)}if((Wj(f)|0)==3){Rf(j,3)}x[23420]=0;W(207,j|0,i|0,g- -64|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break L}}yz(i,x[a+480180>>2]);lj(i,a);l=1}zb(g- -64|0)}xP(f);hb=g+288|0;return l|0}l=P()|0;break K}l=P()|0;zb(g- -64|0)}xP(f);S(l|0);p()}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;f=hb-1344|0;hb=f;zc(b);d=hb-16|0;hb=d;k=f+768|0;iT(d+8|0,k);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(j|0);if(!d){hT(k)}a:{if(!d){break a}if(!kT(f+768|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(jT(z[f+802>>1],z[f+804>>1]),lb))){break a}if(!c){e=1;break a}r=Bc(f+760|0);b:{while(1){if((e|0)!=32){d=(e<<5)+a|0;g=d+480280|0;Te(g);k=(f+768|0)+(e<<4)|0;w[d+480284>>1]=((y[k+78|0]<<8&65280)>>>0)/255;l=f+496|0;dk(l,1,k- -64|0);j=f+112|0;Fc(j,l);ym(d+480289|0,j);xb(j);c:{d:{switch(y[k+79|0]){case 0:m=i+1|0;break c;case 1:x[g>>2]=1024;m=e+1|0;break c;case 2:break d;default:break b}}x[g>>2]=1024;d=f+112|0;sk(d,r,e);pm(d)}i=i+1|0;e=e+1|0;continue}break}Dd(a,33554432);w[a+480188>>1]=m&255;d=f+112|0;i=Vb(d,6734);Gb(a+1298344|0,i);yb(i);d=Vb(d,11e3);Gb(a+1298356|0,d);yb(d);x[a+1298404>>2]=5;e:{if(y[f+847|0]){break e}e=1;j=1;while(1){if((e|0)==16){while(1){if((j|0)==16){break e}d=((j<<5)+a|0)+480280|0;x[d>>2]=x[d>>2]&-1025;j=j+1|0;continue}}d=e<<4;e=e+1|0;if(y[(d+f|0)+847|0]==1){continue}break}}d=f+496|0;Ye(d,1,f+768|0);i=f+112|0;Fc(i,d);Ac(a+1298308|0,i);xb(i);x[a+480208>>2]=x[a+480208>>2]&-17|z[f+806>>1]<<4&16;x[a+480196>>2]=y[f+816|0];x[a+480204>>2]=D(y[f+817|0],1e4);x[a+480200>>2]=y[f+818|0]<<2;x[a+480228>>2]=y[f+819|0];i=z[f+804>>1];w[a+480190>>1]=0;w[a+480192>>1]=i;Ru(b,d);Kq(Yb(x[a+484360>>2],y[a+484376|0]),d,z[f+800>>1],65535,255);s=c&1;if(s){lg(a+484344|0,z[f+802>>1])}o=a+484344|0;u=a+480188|0;f:{while(1){g:{if(z[f+802>>1]<=h>>>0){m=c&2;l=f+108|0;r=a+480192|0;i=1;c=0;h:while(1){if(z[r>>1]<=(c&65535)>>>0){e=32;break b}c=c+1|0;e=QB(a,c&65535,0);g=!e;d=hb-16|0;hb=d;k=f+112|0;hc(d+8|0,k,384);h=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(h|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(h|0)==(j|0);if(!d){Tb(k,0,384)}if(!d|g){continue}k=i&65535;h=hb-32|0;hb=h;g=f+112|0;Ye(h,1,g);d=h+16|0;Fc(d,h);Dc(e+492|0,d);xb(d);i:{if(!(y[g+378|0]|y[g+379|0]<<8)){break i}j=e+236|0;d=0;while(1){x[h+16>>2]=120;x[h>>2]=116;if(A[Hb(h+16|0,h)>>2]<=d>>>0){break i}B=bc(j,d+12|0),C=k+y[(d+g|0)+32|0]|0,w[B>>1]=C;d=d+1|0;continue}}d=y[g+376|0]|y[g+377|0]<<8;v[e+33|0]=1;x[e>>2]=d;_A(g,e+48|0,0);_A(g,e+68|0,1);_A(g,e+88|0,2);d=y[e+100|0];if(d&1){v[e+100|0]=d|16}if(!(x[e>>2]|v[e+60|0]&1)){x[e>>2]=32767}hb=h+32|0;e=0;while(1){d=z[f+490>>1];if(d>>>0<=e>>>0){i=d+i|0;continue h}OT(b,f+48|0);j:{k:{if(Ob(l,15349,4)){break k}d=e+i|0;k=d&65535;if(k>>>0>3999){break k}w[a+480190>>1]=d;g=hb-32|0;hb=g;j=D(k,104)+a|0;d=j+484380|0;pd(d,0);Th(g,1,f+48|0);h=g+16|0;Fc(h,g);ze(d+43|0,h);xb(h);o=y[f+64|0]|y[f+65|0]<<8|(y[f+66|0]<<16|y[f+67|0]<<24);x[d>>2]=o;q=y[f+68|0]|y[f+69|0]<<8|(y[f+70|0]<<16|y[f+71|0]<<24);x[d+4>>2]=q;n=y[f+72|0]|y[f+73|0]<<8|(y[f+74|0]<<16|y[f+75|0]<<24);x[d+8>>2]=n;x[d+24>>2]=y[f+76|0]|y[f+77|0]<<8|(y[f+78|0]<<16|y[f+79|0]<<24);w[d+30>>1]=y[f+80|0]<<2;w[d+28>>1]=y[f+81|0];h=y[f+96|0];if(h&1){w[d+34>>1]=z[d+34>>1]|2;h=y[f+96|0]}if(h&2){w[d+34>>1]=z[d+34>>1]|4;h=y[f+96|0]}if(h&4){x[d+8>>2]=n>>>1;x[d+4>>2]=q>>>1;x[d>>2]=o>>>1;w[d+34>>1]=z[d+34>>1]|1;h=y[f+96|0]}if(h&8){w[d+34>>1]=z[d+34>>1]|32}hb=g+32|0;h=hb-16|0;hb=h;$u(h+8|0,j+484423|0);g=f+24|0;Qq(g,x[h+8>>2],x[h+12>>2]);hb=h+16|0;Dc(((k<<5)+a|0)+946304|0,g);xb(g);h=x[f+64>>2];if(!h){break k}Xd(f,b,h);h=jc(f+24|0,f);zb(f);if(m){g=_c(f,w[j+484414>>1]&1?16:8,1,0,0);x[23420]=0;W(207,g|0,d|0,h|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break j}}zb(h)}e=e+1|0;continue}break}break}a=P()|0;zb(h);break f}i=Eg(b);q=Eg(b);d=f+48|0;Xd(d,b,i-4|0);l=jc(f+112|0,d);zb(d);l:{m:{if(!s){break m}x[23420]=0;d=W(214,o|0,h&65535,q|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break l}if(!d){break m}m=0;k=Sh(f+24|0);while(1){if(m>>>0>=q>>>0){break m}x[23420]=0;g=T(194,l|0)|0;d=x[23420];x[23420]=0;n:{if((d|0)!=1){if(g){break n}m=m+1|0;continue}break g}e=k;n=g&31;if(n>>>0<z[u>>1]){d=_b(x[o>>2],h);e=ed(x[d>>2],x[x[d+48>>2]+12>>2],m,n)}if(g&32){x[23420]=0;R(247,f+48|0,l|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}i=y[f+48|0];v[e|0]=i;B=e,C=y[jd(f+48|0)|0],v[B+1|0]=C;o:{p:{if((i|0)==160){d=255;break p}if((i|0)==255){d=0;break p}d=0;i=(D(i>>>4|0,12)+(i&15)|0)+13|0;if(gT(i)){break o}}i=d}v[e|0]=i}d=g&192;q:{if(!d){break q}if((d|0)==192){x[23420]=0;R(335,f+48|0,l|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=f+48|0;g=jd(d);j=Ue(d);i=Bi(d);t=y[f+48|0];r:{s:{if((t|0)==12){v[f|0]=64;B=e,C=y[Wb(g,f)|0],v[B+4|0]=C;d=1;break s}d=y[j|0];t:{if((d|0)==12){v[f|0]=64;B=e,C=y[Wb(i,f)|0],v[B+4|0]=C;j=f+48|0;d=1;break t}if((t|0)==10){v[e+4|0]=(y[g|0]<<6>>>0)/255;d=2;break s}if((d|0)!=10){break r}v[e+4|0]=(y[i|0]<<6>>>0)/255;j=f+48|0;d=2}i=g}v[e+2|0]=d;d=y[j|0]}v[e+3|0]=d;v[e+5|0]=y[i|0];break q}break g}x[23420]=0;R(247,f+48|0,l|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}v[e+3|0]=y[f+48|0];B=e,C=y[jd(f+48|0)|0],v[B+5|0]=C}if(y[e+3|0]){d=e+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{i=y[e+3|0];switch(i-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}d=y[e+5|0];if(!d){d=14;break w}if((d|0)==15){break y}if((d|0)==240){v[e+5|0]=239;break x}if(d>>>0>=16){v[e+5|0]=d|15;break x}v[e+5|0]=d|240;break x}v[e+5|0]=y[e+5|0]^128;break x}d=y[e+5|0];if(d>>>0>=16){v[e+5|0]=d>>>4|240;break x}v[e+5|0]=d|224;break x}v[e+5|0]=((y[e+5|0]^-1)&254)>>>1;break x}v[e+5|0]=y[e+5|0]&15|128;break x}B=e,C=xi(y[e+5|0]<<1),v[B+5|0]=C;break x}g=32;d=0;H:{I:{J:{K:{L:{M:{N:{j=y[e+5|0];switch(j>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}g=64;break H}g=176;break H}g=224;break H}if(j){break x}break w}O:{switch(j&15){case 0:v[e+5|0]=119;break x;case 1:v[e+5|0]=119;break x;case 2:v[e+5|0]=121;break x;case 3:break O;default:break x}}v[e+5|0]=123;break x}g=48}v[e+5|0]=j&15|g;break x}if(i>>>0<=35){break x}break v}v[e+5|0]=254}d=i}v[e+3|0]=y[d+26448|0];if(y[e+2|0]|(d|0)!=12){break u}v[e+2|0]=1;v[e+3|0]=0;v[e+4|0]=y[e+5|0];d=e+5|0}v[d|0]=0}}sk(f+48|0,r,n);if(!Bb(x[x[f+48>>2]>>2],x[f+52>>2])){continue}if(!GU(y[e+3|0],y[e+5|0])){continue}v[e+3|0]=0;continue}}zb(l);h=h+1|0;continue}}break}a=P()|0;zb(l)}S(a|0);p()}e=e>>>0>31}hb=f+1344|0;return e|0}function mN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=E(0),r=0,s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=0,V=E(0),W=0;n=hb-48|0;hb=n;v[n+40|0]=0;j=b+223848|0;k=n+40|0;Ki(j,oi(e,ii(e,$n(e),k))+1|0);ke(k,x[j>>2],x[b+223852>>2]);j=hb-16|0;hb=j;v[j+15|0]=0;fc(n+32|0,e,oi(e,ii(e,$n(e),j+15|0)));hb=j+16|0;G=x[n+32>>2];H=x[n+36>>2];j=0;i=hb-16|0;hb=i;r=a+1074312|0;o=D(c,872)+b|0;I=o+1415|0;J=o+1304|0;K=o+1392|0;u=o+1368|0;C=o+1364|0;L=o+1336|0;M=o+1308|0;N=o+1300|0;O=o+1280|0;P=o+1402|0;g=o+1466|0;Q=E(y[g|0]);R=E(f>>>0);F=o+616|0;l=x[o+1272>>2];S=a+480188|0;p=1;m=255;while(1){if((s|0)!=(H|0)&A[k+4>>2]>j>>>0){h=y[Kb(G,s)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=ul(a,b,c,3,0);if((e-1&255)>>>0>249){break f}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break f}e=Jy(e,47440,44540);if(!e){break f}e=mb[x[x[e>>2]+188>>2]](e,F,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!l){break b}break c}if(l){break c}e=0;break b;case 21:Ab(i+8|0,r,28);g:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){Ab(i,r,1);e=0;if(!Bb(x[x[i>>2]>>2],x[i+4>>2])){break g}}e=w[K>>1]}h=D(x[u>>2],x[C>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Xb((Hc(Xia(Wia(h,h>>31,e,e>>31),lb,1048576,0),lb)|0)/2|0,1,127);break d;case 20:e=D(x[u>>2],x[C>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Xb((Hc(Xia(Wia(h,t,e,e>>31),lb,67108864,0),lb)|0)/2|0,1,127);break d;case 23:x[i+8>>2]=x[M>>2]/2;x[i>>2]=127;e=x[td(i+8|0,i)>>2];break d;case 24:x[i+8>>2]=x[N>>2]/2;x[i>>2]=127;e=x[td(i+8|0,i)>>2];break d;case 0:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!l){break d}h=z[l+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[S>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[o+704|0]>>>7|0;break d;case 15:e=0;if(!l){break d}h=y[l+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[g|0]<0){break h}i:{if(j>>>0<3){break i}e=x[k>>2];if(y[Kb(e,j-3|0)|0]!=240){break i}if(y[Kb(e,j-2|0)|0]>239){break h}}q=xp(b,Q,R);j:{if(q<E(4294967296)&q>=E(0)){e=~~q>>>0;break j}e=0}v[g|0]=e;m=128;break d}m=(m&255)==255?f:m;e=f;break d;case 18:k:{if(!j){e=0;break k}h=x[k>>2];e=j;while(1){e=e-1|0;t=Kb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(j-e>>>0<5){break a}t=x[k>>2];if(y[Kb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(j|0)){h=y[Kb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=Uc(e)?e-1|0:0}h=p^-1;p=1;j=(h&1)+j|0;T=Kb(x[k>>2],j),U=e,v[T|0]=U;j=j+1|0;break a}e=z[F+786>>1];h=y[l+31|0];e=(e?e-1|0:c)&15;l:{if((h|0)==17){break l}e=mj(h)?h-1&15:0}}h=Kb(x[k>>2],j);m:{if(p&1){v[h|0]=e;break m}v[h|0]=y[h|0]<<4|e;j=j+1|0}p=p^1}s=s+1|0;continue}else{if(m<<24>>24>=0){v[g|0]=m}hc(i+8|0,x[k>>2],((p^-1)&1)+j|0);e=x[i+12>>2];x[k>>2]=x[i+8>>2];x[k+4>>2]=e;hb=i+16|0}break}o=x[n+44>>2];j=0;n:while(1){p=0;while(1){e=j;o:{p:{q:{r:{while(1){if(A[n+44>>2]<=e>>>0){break o}f=x[n+40>>2];i=Kb(f,e);g=v[i|0];if((g|0)==-16){g=e;if(o-g>>>0>=4){j=4;if((y[Kb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(o>>>0<=g>>>0){break s}if(y[Kb(f,g)|0]!=247){continue}break}j=(g-e|0)+1|0;if(j){break p}}T=Kb(f,o),U=247,v[T|0]=U;o=o+1|0;j=o-e|0;break q}if((g|0)<0){break r}if(p&255){e=e-1|0;T=Kb(f,e),U=p,v[T|0]=U;continue}break}j=j+1|0;continue n}T=n,U=nP(g&255),x[T+16>>2]=U;x[n+28>>2]=o-e;j=x[Hb(n+16|0,n+28|0)>>2]}if(!j){break o}f=x[n+40>>2];i=Kb(f,e)}s=y[i|0];iq(n+16|0,f,x[n+44>>2],e,j);f=fc(n+8|0,x[n+16>>2],x[n+20>>2]);g=x[f+4>>2];x[n>>2]=x[f>>2];x[n+4>>2]=g;i=hb-32|0;hb=i;k=x[n+4>>2];t:{if(!k){break t}l=Rd(y[b+223884|0]);u:{f=x[n>>2];m=Kb(f,0);g=y[m|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break u}r=(D(g,872)+b|0)+1453|0;v[r|0]=127;v[r+1|0]=0;g=g+1|0;continue}}v:{if((k|0)!=4|y[m|0]!=240){break v}g=y[Kb(f,1)|0];if((g&254)!=240){break v}k=(D(c,872)+b|0)+616|0;m=Kb(f,2);h=y[Kb(f,3)|0];f=h<<24>>24;w:{x:{y:{z:{A:{B:{m=y[m|0];switch(m|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=D(c,872)+b|0;m=g+1453|0;if(d){f=Ug(xp(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1412|0]=0;f=Cp(a,k,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break t}g=x[a+1298300>>2];if(l|wd(g)^1){break t}Gp(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=D(c,872)+b|0;l=g+1454|0;if(d){f=Ug(xp(b,E(y[l|0]),E((f&255)>>>0)))}v[l|0]=f;v[g+1411|0]=0;Cp(a,k,!(x[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;Cp(a,k,!(x[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=ul(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}v[i+24|0]=f;g=f&255;f=x[(D(g,160)+a|0)+906300>>2];if(!f){break t}q=E(E(127-h|0)/E(127));if(l){k=0;g=hb-16|0;hb=g;T=g,U=ak(i+24|0),x[T>>2]=U;f=hb-16|0;hb=f;l=b+223860|0;h=Iy(l,f+12|0,y[i+24|0]);m=x[h>>2];if(!m){k=hb-16|0;hb=k;m=ic(l);r=rh(f,wc(24),sh(k+8|0,m));m=x[r>>2];u=y[x[g>>2]];x[m+20>>2]=0;v[m+16|0]=u;T=ic(r),U=1,v[T+4|0]=U;hb=k+16|0;Yg(l,x[f+12>>2],h,x[f>>2]);m=Zd(f);cl(f);k=1}Xg(g+8|0,x[gc(f,m)>>2],k);hb=f+16|0;f=ud(x[g+8>>2]);hb=g+16|0;B[f+4>>2]=q;break t}if(!d){Us(x[f+20>>2],q);break t}Us(x[f+20>>2],xp(b,B[(D(g,160)+a|0)+906444>>2],q));break t}if(m<<24>>24<0){break w}if((g|0)!=241){break t}}h=ul(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break t}k=x[(D(h&255,160)+a|0)+906300>>2];if(!k){break t}g=(g|0)==241?m+128|0:m&127;q=E(E((f&255)>>>0)/E(127));if(l){T=DN(b+223872|0,XM(i+24|0,h,g)),V=q,B[T>>2]=V;break t}f=x[k>>2];if(!d){mb[x[f+44>>2]](k,g,q);break t}U=k,W=g,V=xp(b,E(mb[x[f+48>>2]](k,g)),q),T=x[x[k>>2]+44>>2],mb[T](U|0,W|0,E(V));break t}if(l){break t}l=z[a+480188>>1];C:{if(l>>>0>c>>>0){g=c+1|0;break C}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break t}}if(y[(D(c,872)+b|0)+707|0]&4|l>>>0<(g&65535)>>>0){break t}g=ul(a,b,c,3,0);if((g-1&255)>>>0>249){break t}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break t}l=y[m|0];if((l|0)==240){Lg(i+16|0,x[n>>2],x[n+4>>2]);f=x[x[g>>2]+72>>2];k=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=k;mb[f|0](g,i)|0;break t}T=i,W=nP(l),x[T+24>>2]=W;x[i+12>>2]=k;k=i+24|0;l=x[Hb(k,i+12|0)>>2];x[i+24>>2]=0;pc(k,f,l);mb[x[x[g>>2]+68>>2]](g,x[i+24>>2])|0}hb=i+32|0;p=s>>>0<240?s:p;j=e+j|0;continue}break}break}hb=n+48|0}function Jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=hb-304|0;hb=d;zc(b);a:{b:{c:{d:{if(!Et(b,d+208|0)){break d}if(!_Q(d+208|0)){break d}if(!Nb(x[b>>2],x[b+8>>2],Vc(ZQ(d+208|0),lb))){break d}if(!c){g=1;break d}if(!$c(b,y[d+212|0])){break d}Dd(a,268435456);Cg(a);x[a+480208>>2]=4;Mb(a+1074312|0,114,1);f=d+88|0;i=Vb(f,15092);Gb(a+1298344|0,i);yb(i);i=Vb(f,10174);Gb(a+1298356|0,i);yb(i);x[a+1298404>>2]=5;i=d+16|0;ef(i,d+208|6,48,3);Fc(f,i);Ac(a+1298308|0,f);xb(f);f=y[d+262|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+265|0];x[a+480204>>2]=D(y[d+266|0],1e4);x[a+480196>>2]=y[d+267|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+300|0];f=z[d+302>>1];i=d+192|0;x[i>>2]=0;x[i+4>>2]=0;Bc(i+8|0);if(f){kl(i,f);HA(i,f)}x[23420]=0;U(584,b|0,i|0,z[d+302>>1]);f=x[23420];x[23420]=0;if((f|0)==1){break b}A=Qb(d+176|0);s=Qb(d+160|0);x[23420]=0;W(355,b|0,A|0,y[d+301|0])|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}x[23420]=0;W(355,b|0,s|0,y[d+300|0])|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}q=c&2;t=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=y[d+300|0]){g=1;if(!(c&1)){break e}x[d+68>>2]=0;r=a+484376|0;Gc(Yb(x[a+484360>>2],y[r|0]));G=d,H=Db(x[i>>2]),x[G+64>>2]=H;u=a+484344|0;C=Db(x[i+4>>2]);E=a+484348|0;break f}x[23420]=0;f=e+1|0;h=D(f,104)+a|0;k=h+484380|0;R(264,k|0,0);g=x[23420];x[23420]=0;g:{if((g|0)!=1){g=Cb(x[s>>2],e);g=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);if(!g){continue}x[23420]=0;g=Q(143,b|0,g|0)|0;j=x[23420];x[23420]=0;h:{if((j|0)==1){break h}if(!g){continue}x[23420]=0;g=Q(585,b|0,d+88|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;Ye(g,2,n);x[23420]=0;R(210,d+16|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break c}g=d+16|0;Dc(((f<<5)+a|0)+946304|0,g);xb(g);j=d+72|0;dk(j,2,t);x[23420]=0;R(210,g|0,j|0);g=x[23420];x[23420]=0;if((g|0)==1){break c}g=d+16|0;ze(h+484423|0,g);xb(g);g=y[d+138|0];if(g>>>0<=15){w[h+484408>>1]=D(g,17);g=h+484414|0;w[g>>1]=z[g>>1]|32}v[d+16|0]=y[d+139|0];v[d+72|0]=64;G=h+484412|0,H=y[Wb(d+16|0,d+72|0)|0],w[G>>1]=H;x[h+484404>>2]=y[d+141|0]|y[d+142|0]<<8;m=h+484384|0;g=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=g;r=h+484388|0;j=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[r>>2]=j;u=y[d+155|0]|y[d+156|0]<<8|(y[d+157|0]<<16|y[d+158|0]<<24);x[k>>2]=u;l=y[d+140|0];if(l&1){g=g>>>1|0;x[m>>2]=g;j=j>>>1|0;x[r>>2]=j;x[k>>2]=u>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=z[h>>1];w[h>>1]=g|2;if(!(l&2)){break i}w[h>>1]=g|6}kk(k);if(!q){continue}e=Cb(x[s>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[23420]=0;Q(143,b|0,e+y[d+92|0]|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break g}}break c}break c}e=_c(d+16|0,v[d+140|0]&1?16:8,1,0,1);x[23420]=0;W(207,e|0,k|0,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=x[d+64>>2];if(!Pb(k,C)){b=x[d+68>>2];c=b&63;if(!c){break k}f=y[a+484376|0];e=x[a+484360>>2];x[23420]=0;b=b>>>6|0;f=Q(297,Yb(e,f)|0,b&65535)|0;e=x[23420];x[23420]=0;if((e|0)!=1){if(!f){break k}b=z[bc(x[Yb(x[a+484360>>2],y[a+484376|0])>>2],b&65535)>>1];f=x[a+484344>>2];x[23420]=0;R(586,_b(f,b)|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break k}}break c}c=y[k+3|0];if(y[k+2|0]>y[d+262|0]|c>>>0>=y[d+301|0]){break j}c=Cb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[23420]=0;c=Q(143,b|0,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}if(!c){break j}x[23420]=0;R(587,b|0,d+88|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}e=y[d+92|0];if(!e){break j}f=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+93|0];v[d+72|0]=y[d+262|0]-y[k+2|0];j=y[Wb(d+16|0,d+72|0)|0];x[d+60>>2]=e+f;G=d,H=x[Yc(d+68|0,d+60|0)>>2],x[G+68>>2]=H;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;c=f&63;q=f>>>6|0;t=0;while(1){if((e&255)>>>0<=t>>>0){break j}e=Yb(x[a+484360>>2],y[r|0]);h=c>>>0>63;q=h+q|0;f=q&65535;if(Mc(x[e>>2],x[e+4>>2])>>>0<=f>>>0){x[23420]=0;R(310,e|0,q+1&65535);e=x[23420];x[23420]=0;if((e|0)==1){break c}x[23420]=0;n=Q(345,u|0,64)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}e=Yb(x[a+484360>>2],y[r|0]);G=bc(x[e>>2],f),H=n,w[G>>1]=H}m=x[a+484344>>2];o=x[E>>2];n=z[bc(x[e>>2],f)>>1];if(!oe(m,o,n)){break j}f=0;e=_b(m,n);m=h?0:c;e=ed(x[e>>2],x[x[e+48>>2]+12>>2],m,y[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=y[d+93|0];if(c>>>0<=j>>>0){break l}x[23420]=0;Q(176,b|0,D(c-j|0,5)|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break l}break c}x[23420]=0;R(588,d+72|0,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){c=d+72|0;h=jd(c);F=Ue(c);l=Bi(c);o=ic(c);c=y[d+72|0];B=c-1&255;m:{if(B>>>0<=142){c=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[e|0]=c;v[(d+16|0)+f|0]=c;break m}v[e|0]=0}c=y[h|0];v[e+2|0]=1;v[e+1|0]=c;c=y[F|0];n:{if((c|0)!=255){v[e+4|0]=c;break n}v[e+2|0]=0}c=y[l|0];o:{if(c>>>0>22){break o}v[e+3|0]=y[c+26832|0];h=y[o|0];v[e+5|0]=h;c=e+5|0;p:{switch(y[l|0]-4|0){case 3:v[c|0]=h&3|64;break o;case 4:v[c|0]=h&3|48;break o;case 7:l=x[i>>2];if(vc(l,x[i+4>>2])>>>0<=h>>>0){break o}o=c;c=Cb(l,h);c=y[c|0]|y[c+1|0]<<8;v[o|0]=c>>>6;h=_b(x[a+484344>>2],n);h=ed(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 8:o=c;c=x[d+60>>2];v[o|0]=c>>>6;h=_b(x[a+484344>>2],n);h=ed(x[h>>2],x[x[h+48>>2]+12>>2],m,z[a+480188>>1]-1&65535);v[h+5|0]=c&63;v[h+3|0]=14;break o;case 10:v[c|0]=h&15|128;break o;case 12:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|208,v[G|0]=H;break o;case 13:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|192,v[G|0]=H;break o;case 14:v[d+15|0]=15;G=c,H=y[Wb(c,d+15|0)|0]|224,v[G|0]=H;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}v[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(B>>>0<143){break o}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;t=t+1|0;e=y[d+92|0];continue}}a=Yb(x[a+484360>>2],y[a+484376|0]);G=d,H=Db(x[a>>2]),x[G+88>>2]=H;b=Db(x[a+4>>2]);c=65535;while(1){a=x[d+88>>2];if(!Pb(a,b)){break e}if(z[a>>1]==65535){q:{if((c&65535)!=65535){break q}x[23420]=0;c=Q(345,u|0,64)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break q}break c}w[a>>1]=c}Re(d+88|0);continue}}Ce(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+268|0],17);e=e+1|0;continue}break}tc(s);tc(A);tc(i)}hb=d+304|0;return g|0}a=P()|0;tc(s);tc(A);break a}a=P()|0}tc(i);S(a|0);p()}function HI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=hb-272|0;hb=h;a:{b:{if(g){Qe(h+256|0,f,32);x[23420]=0;W(477,h+240|0,f|0,32)|0;k=x[23420];x[23420]=0;if((k|0)!=1){break b}f=P()|0;break a}Jb(h+256|0);Jb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(cs(c)){k=x[b+24>>2];i=x[k+484344>>2];if(oe(i,x[k+484348>>2],c&65535)){break j}}x[23420]=0;U(1035,a|0,h+256|0,h+240|0);a=x[23420];x[23420]=0;if((a|0)!=1){break i}f=P()|0;break c}c=_b(i,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[k+480188>>1]>e>>>0)){x[23420]=0;U(1035,a|0,h+256|0,h+240|0);a=x[23420];x[23420]=0;if((a|0)!=1){break i}f=P()|0;break c}c=ed(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);Df(h+256|0);Df(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!Uc(d)){if(!tp(d)){break A}}e=y[c+1|0];k=x[b+24>>2];x[23420]=0;X(1036,h+208|0,k|0,d|0,e|0);d=x[23420];x[23420]=0;e=1;if((d|0)==1){break y}x[23420]=0;R(964,h+224|0,h+208|0);d=x[23420];x[23420]=0;if((d|0)!=1){break z}f=P()|0;break v}e=0;x[23420]=0;Q(54,h+224|0,16584)|0;d=x[23420];x[23420]=0;if((d|0)==1){break x}}x[23420]=0;k=Q(755,h+256|0,h+224|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break w}xb(h+224|0);if(e){yb(h+208|0)}e=9860;d=y[c|0];if(!Uc(d)){e=tp(d)?10170:16584}x[23420]=0;d=Q(54,h+224|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break u}x[23420]=0;e=Q(755,h+240|0,d|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break t}xb(d);if(f-6>>>0>4294967290){break l}x[23420]=0;d=Q(54,h+192|0,17644)|0;i=x[23420];x[23420]=0;if((i|0)==1){break s}x[23420]=0;i=Q(755,k|0,d|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break r}xb(d);x[23420]=0;d=Q(54,h+176|0,17644)|0;l=x[23420];x[23420]=0;if((l|0)==1){break q}x[23420]=0;l=Q(755,e|0,d|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break p}xb(d);d=c+1|0;B:{if(y[c+1|0]){x[23420]=0;R(495,h+160|0,d|0);j=x[23420];x[23420]=0;if((j|0)!=1){break B}break d}x[23420]=0;Q(54,h+160|0,16589)|0;j=x[23420];x[23420]=0;if((j|0)==1){break d}}x[23420]=0;j=Q(755,i|0,h+160|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break o}i=h+160|0;xb(i);d=y[d|0];x[23420]=0;d=Q(54,i|0,(d?10660:16589)|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break n}x[23420]=0;l=Q(755,l|0,d|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){break m}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0;xb(h+224|0);if(!e){break c}}yb(h+208|0);break c}f=P()|0;break c}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;xb(d);break c}f=P()|0;xb(h+160|0);break c}f=P()|0;break c}xb(d);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{i=Rg(y[c|0]);O:{if(i){x[23420]=0;m=Q(54,h+128|0,17644)|0;d=x[23420];x[23420]=0;if((d|0)==1){break N}d=y[c+4|0];n=y[c+2|0];x[23420]=0;o=h,q=Sj(n,d)&255,x[o+96>>2]=q;R(494,h+112|0,h+96|0);d=x[23420];x[23420]=0;if((d|0)==1){break M}d=0;x[23420]=0;U(921,h+144|0,m|0,h+112|0);m=x[23420];x[23420]=0;if((m|0)!=1){break O}f=P()|0;break G}d=y[c+2|0];if(d){d=BL(x[x[x[b+24>>2]+8>>2]+88>>2],d);x[23420]=0;d=W(477,h+128|0,1,d|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break E}x[23420]=0;R(495,h+112|0,c+4|0);m=x[23420];x[23420]=0;if((m|0)==1){break L}x[23420]=0;U(921,h+144|0,d|0,h+112|0);m=x[23420];x[23420]=0;d=1;if((m|0)!=1){break O}f=P()|0;break J}d=0;x[23420]=0;Q(54,h+144|0,16588)|0;m=x[23420];x[23420]=0;if((m|0)==1){break e}}x[23420]=0;j=Q(755,j|0,h+144|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break K}xb(h+144|0);if(d){xb(h+112|0);xb(h+128|0)}if(i){xb(h+112|0);xb(h+128|0)}d=5449;if(!Rg(y[c|0])){d=y[c+2|0]?5445:16588}x[23420]=0;d=Q(54,h+144|0,d|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break D}x[23420]=0;i=Q(755,l|0,d|0)|0;l=x[23420];x[23420]=0;if((l|0)!=1){break C}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;break F}f=P()|0;break I}f=P()|0;xb(h+144|0);if(!d){break H}}xb(h+112|0)}xb(h+128|0)}if(!i){break c}}xb(h+112|0)}xb(h+128|0);break c}f=P()|0;break c}f=P()|0;break c}xb(d);if(f-13>>>0>4294967283){break l}x[23420]=0;d=Q(54,h+96|0,17644)|0;l=x[23420];x[23420]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[23420]=0;l=Q(755,j|0,d|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break Z}xb(d);x[23420]=0;d=Q(54,h+80|0,17644)|0;j=x[23420];x[23420]=0;if((j|0)==1){break Y}x[23420]=0;i=Q(755,i|0,d|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break X}xb(d);_:{if(Rg(y[c|0])){d=y[c+5|0];j=y[c+3|0];b=0;x[23420]=0;o=h,q=Sj(j,d)&4095,x[o+16>>2]=q;R(1037,h- -64|0,h+16|0);d=x[23420];x[23420]=0;if((d|0)!=1){break _}f=P()|0;break c}d=y[c+3|0];if(d){b=AL(x[x[x[b+24>>2]+8>>2]+84>>2],d);x[23420]=0;b=W(477,h+48|0,1,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break W}x[23420]=0;R(495,h+32|0,c+5|0);d=x[23420];x[23420]=0;if((d|0)==1){break V}x[23420]=0;U(921,h- -64|0,b|0,h+32|0);d=x[23420];x[23420]=0;b=1;if((d|0)!=1){break _}f=P()|0;break S}b=0;x[23420]=0;Q(54,h- -64|0,16584)|0;d=x[23420];x[23420]=0;if((d|0)==1){break U}}x[23420]=0;Q(755,l|0,h- -64|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break T}xb(h- -64|0);if(b){xb(h+32|0);xb(h+48|0)}b=11024;if(!Rg(y[c|0])){b=y[c+3|0]?11024:16584}x[23420]=0;b=Q(54,h- -64|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break Q}x[23420]=0;Q(755,i|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break P}f=P()|0;xb(b);break c}f=P()|0;break c}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;xb(d);break c}f=P()|0;break c}f=P()|0;break R}f=P()|0;break c}f=P()|0;xb(h- -64|0);if(!b){break c}}xb(h+32|0)}xb(h+48|0);break c}f=P()|0;break c}xb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Eb(k);da:{if(b>>>0>f>>>0){x[23420]=0;X(118,h+16|0,k|0,0,f|0);b=x[23420];x[23420]=0;if((b|0)!=1){b=h+16|0;Ac(k,b);xb(b);break da}f=P()|0;break c}if(!g){break da}x[23420]=0;b=W(477,h+16|0,f-b|0,32)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ca}x[23420]=0;Q(755,k|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break ba}xb(b)}b=Eb(e);if(b>>>0<=f>>>0){break $}x[23420]=0;X(118,h|0,e|0,0,f|0);b=x[23420];x[23420]=0;if((b|0)==1){break aa}Ac(e,h);xb(h);break k}f=P()|0;break c}f=P()|0;xb(b);break c}f=P()|0;break c}if(!g){break k}x[23420]=0;b=W(477,h|0,f-b|0,32)|0;c=x[23420];x[23420]=0;if((c|0)==1){break h}x[23420]=0;Q(755,e|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break g}xb(b)}x[23420]=0;U(1035,a|0,k|0,e|0);a=x[23420];x[23420]=0;if((a|0)==1){break f}}xb(h+240|0);xb(h+256|0);hb=h+272|0;return}f=P()|0;break c}f=P()|0;xb(b);break c}f=P()|0;break c}f=P()|0;break c}f=P()|0}xb(h+240|0)}xb(h+256|0);S(f|0);p()}
function Ap(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=hb-16|0;hb=g;i=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:i;s=x[b+752>>2];k=y[b+802|0];a:{if(!k){Ab(g+8|0,a+1074312|0,11);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!Uc(k)){break c}d:{l=k-1|0;k=bc(i+236|0,l);if(z[k>>1]){break d}Ab(g+8|0,a+1074312|0,43);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break d}if(mj(y[i+31|0])){break d}x[b+656>>2]=i;break a}if(y[Kb(i+108|0,l)|0]>120){break a}l=z[k>>1];l=(l-1&65535)>>>0<3999?(D(l,104)+a|0)+484380|0:0;break b}l=(D(c,104)+a|0)+484380|0;if(!z[a+480192>>1]){break b}if(k>>>0>250){break a}Ab(g+8|0,a+1074312|0,43);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){if(i){l=0;if(mj(y[i+31|0])){break b}}v[b+803|0]=0;x[b+656>>2]=0;break a}l=0}k=x[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);h=x[b+656>>2];p=!i|x[a+480180>>2]!=16777216?p:x[i+44>>2]!=0;q=d^1;k=(h|0)!=(i|0);if((q|k|n)==1){w[b+774>>1]=0}o=!n;if(!(o|(k|!(d&p)))){break a}e:{if(!(d&n)){break e}r=a+1074312|0;Ab(g+8|0,r,32);if(!(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])|!(y[a+480208|0]&8))){l=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:l}j=x[a+480180>>2];f:{if(!(i?k|!(j&1048580):1)|(j|0)==268435456){break f}if((j|0)==1){if(pi(x[b+8>>2],x[b+12>>2])){break f}}Ab(g+8|0,r,79);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break e}if(!pi(x[b+8>>2],x[b+12>>2])){break e}}m=1}g:{if(!x[b+16>>2]|(k|!z[a+480192>>1]|o)){break g}Ab(g+8|0,a+1074312|0,87);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}m=Uc(y[b+788|0])^1|m}o=(h|0)!=(i|0);h:{if(pi(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break h}if(i){if(mj(y[i+31|0])){break h}}o=1}i:{j:{k:{if(!(n|o)|!d){break k}Ab(g+8|0,a+1074312|0,61);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break k}j=x[b+656>>2];if(j){break j}j=0;h=x[b+104>>2];k=0;if(h){break i}}x[b+656>>2]=i;j=i;h=l;k=o;break i}h=x[b+104>>2];k=0}l:{m:{n:{if(!e){break n}o:{if(y[a+480180|0]&3){if(h){if(Td(x[h>>2],x[h+20>>2])){break o}}if(!Rj(j)){break n}}if(!h){break m}}if(w[h+34>>1]<0){break n}x[b+688>>2]=z[h+30>>1]}i=(h|0)!=0;if(!(n&m)|!h){break l}Ab(g+8|0,a+1074312|0,85);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){w[b+772>>1]=v[h+37|0]}i=1;if(x[a+480180>>2]!=2){break l}if(!Td(x[h>>2],x[h+20>>2])){break l}x[b+704>>2]=x[h+24>>2];break l}if(!(!j|!y[j+34|0])){i=x[b+688>>2];if(j){i=x[j+4>>2]<<2}x[b+688>>2]=i;i=0;break l}i=0;x[b+688>>2]=0}if(m){break a}v[b+803|0]=0;p:{if(!j){break p}Ab(g+8|0,a+1074312|0,29);if(!((Bb(x[x[g+8>>2]>>2],x[g+12>>2])^-1)&i|y[j+34|0]|k)){break p}v[b+798|0]=y[j+16|0]}m=64;x[b+752>>2]=64;if(h){m=z[h+32>>1];x[b+752>>2]=m}if(j){x[b+752>>2]=D(x[j+4>>2],m)>>>6}q:{if(!(x[a+480180>>2]&1048580?e:1)){break q}Ab(g+8|0,a+1074312|0,48);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break q}hN(a,b,j,h)}r:{s:{t:{u:{if(!f){break u}f=a+1074312|0;Ab(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){if(!x[b+76>>2]){e=1;break B}if(!(!c|q)){e=(y[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}D:{c=x[a+480180>>2]&17301536;e=1;E:{if(!d|!c){break E}c=1;e=1;if(y[a+480208|0]&8){break E}e=1;if(!x[b+76>>2]){break E}if(!(y[b+89|0]&16)){break D}e=!x[b+696>>2]}if(!j|(k|!c)){break z}if(!e){break v}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break y}break A}if((k|!j)!=1){break v}break w}if(d){break B}if(!(y[b+89|0]&24)){e=0;break B}e=(y[a+480208|0]&4)>>>2|0}if(k|!x[b+696>>2]){break z}if(!e){break w}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!j){break x}if(c&2048){break y}}if(!(y[j+60|0]&8)){hj(b+724|0)}if(!(y[j+80|0]&8)){hj(b+732|0)}if(y[j+100|0]&8){break x}hj(b+740|0);break x}if(!e){break w}x[b+88>>2]=x[b+88>>2]|2097152;if(!j){break x}}Zl(b)}Ab(g+8|0,f,21);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break u}v[b+818|0]=0;x[b+756>>2]=0;break u}if(!j){break t}}if(v[j+60|0]&1){break u}Ab(g+8|0,f,32);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){hj(b+724|0);break u}Zl(b)}c=0;if(h){break s}if(!j){break r}c=1;if(mj(y[j+31|0])){break s}break r}c=0;if(!h){break r}}F:{if(!(!d|(i^1|x[b+104>>2]!=(h|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break a}G:{H:{if((e|0)!=4){break H}Ab(g+8|0,a+1074312|0,40);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])|y[b+789|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;f=a+1074312|0;Ab(g+8|0,f,18);I:{J:{K:{if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){if(x[a+480180>>2]&16777248){break J}if(x[b+104>>2]==(h|0)){break K}break J}if(x[b+104>>2]!=(h|0)){break J}}e=-640;if(!k){break I}}e=-768}x[b+88>>2]=e&x[b+88>>2];if(!j){break F}v[b+730|0]=y[j+60|0];v[b+738|0]=y[j+80|0];v[b+746|0]=y[j+100|0];L:{if((y[j+100|0]&17)!=17){break L}Ab(g+8|0,f,36);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])|y[b+837|0]){break L}v[b+837|0]=127}e=y[j+21|0];if(Sf(e)){t=b,u=Pq(e),v[t+837|0]=u}e=y[j+22|0];if(!Sf(e)){break F}t=b,u=Pq(e),v[t+838|0]=u}if(c){x[b+76>>2]=0;x[b+104>>2]=0;break a}M:{if(x[b+76>>2]|!d){break M}c=a+1074312|0;Ab(g+8|0,c,54);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){Ab(g,c,39);if(!Bb(x[x[g>>2]>>2],x[g+4>>2])){break M}}x[b+8>>2]=0;x[b+12>>2]=0}N:{if(y[b+788|0]!=255){break N}Ab(g+8|0,a+1074312|0,100);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])|(!(y[a+480208|0]&4)|!n)){break N}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=s;x[b+688>>2]=z[h+30>>1];if(!(y[h+34|0]&32)){break a}Ip(b,z[h+28>>1],a);break a}x[b+104>>2]=h;x[b+76>>2]=x[h>>2];x[b+80>>2]=x[h+4>>2];x[b+84>>2]=x[h+8>>2];c=a+1074312|0;Ab(g+8|0,c,83);if(!(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])|x[b+80>>2])){x[b+84>>2]=x[h>>2]}x[b+88>>2]=x[b+88>>2]|z[h+34>>1]&1023;Ab(g+8|0,c,21);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){v[b+818|0]=0;x[b+756>>2]=0}O:{P:{if(p){x[b+704>>2]=x[h+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break P}if(!(n|q)){d=x[a+480180>>2];if(d&5){break O}}x[b+704>>2]=x[h+24>>2];d=v[h+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(qm(d)){d=v[h+36|0]}else{d=0}w[b+770>>1]=d;Ab(g+8|0,c,69);if(!(Bb(x[x[g+8>>2]>>2],x[g+12>>2])|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;i=x[b+88>>2];if(i&8){x[b+80>>2]=x[h+12>>2];x[b+84>>2]=x[h+16>>2];i=i>>>2&4|i|2;x[b+88>>2]=i}Q:{if(!(i&2)){i=x[b+76>>2];break Q}i=x[b+76>>2];c=x[b+84>>2];if(i>>>0<=c>>>0){break Q}x[b+76>>2]=c;i=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<i>>>0){break a}x[b>>2]=0;x[b+4>>2]=0;break a}x[b+752>>2]=0;x[b+104>>2]=0}hb=g+16|0}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;e=hb-272|0;hb=e;zc(b);d=hb-16|0;hb=d;i=e+112|0;nT(d+8|0,i);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(h|0);if(!d){mT(i)}a:{if(!d){break a}if(!oT(e+112|0)){break a}if(!c){f=1;break a}Dd(a,x[(z[e+228>>1]<<2)+26240>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;d=e+48|0;f=Vb(d,12961);Gb(a+1298344|0,f);yb(f);f=Vb(d,10205);Gb(a+1298356|0,f);yb(f);f=hb-16|0;hb=f;g=e+8|0;i=Vb(f,4350);Rc(g,i);yb(i);hb=f+16|0;x[23420]=0;X(217,d|0,g|0,y[e+191|0],e+188|0);d=x[23420];x[23420]=0;b:{if((d|0)!=1){d=e+48|0;Gb(a+1298368|0,d);yb(d);f=e+8|0;cc(f);xl(a+1298392|0,(z[e+228>>1]<<2)+26288|0);xl(a+1298380|0,x[(z[e+228>>1]<<2)+26336>>2]);x[a+1298404>>2]=5;Ye(f,2,e+112|4);Fc(d,f);Ac(a+1298308|0,d);xb(d);Ye(f,2,e+148|0);Fc(d,f);c:{if(dq(d,9642)){x[23420]=0;U(11,e+8|0,5,e+48|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}d=e+8|0;Gb(a+1298320|0,d);yb(d)}xb(e+48|0);w[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;Te(i);f=y[(d+e|0)+193|0];e:{if(f>>>0<=15){x[e+48>>2]=f<<4|8;x[e+8>>2]=256;u=g+480284|0,A=x[td(e+48|0,e+8|0)>>2],w[u>>1]=A;break e}if((f|0)!=16){if((f|0)!=255){break e}w[a+480188>>1]=d;break d}w[g+480284>>1]=128;x[i>>2]=256}d=d+1|0;continue}break}d=z[a+480188>>1]}f=0;if(!(d&65535)){break a}x[e+48>>2]=y[e+225|0]<<2;x[e+8>>2]=256;u=a,A=x[Hb(e+48|0,e+8|0)>>2],x[u+480200>>2]=A;x[a+480196>>2]=y[e+226|0];x[a+480204>>2]=D(y[e+227|0],1e4);if($c(b,z[e+230>>1]|z[e+232>>1]<<16)){no(Yb(x[a+484360>>2],y[a+484376|0]),b,y[e+234|0]+1|0,255,254)}if(!$c(b,x[e+240>>2])){break a}l=a+480190|0;d=y[e+248|0]+1|0;w[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=hb-16|0;hb=d;g=e+48|0;hc(d+8|0,g,62);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(f|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(f|0)==(h|0);if(!d){Tb(g,0,62)}if(!d){break g}d=0;f=D(j,104)+a|0;k=f+484380|0;pd(k,0);h=e+32|0;Ye(h,2,e+48|0);g=e+8|0;Fc(g,h);Dc(((j<<5)+a|0)+946304|0,g);xb(g);dk(h,2,m);Fc(g,h);ze(f+484423|0,g);xb(g);g=z[e+106>>1];x[f+484404>>2]=g;if(!qm(x[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==z[(d<<1)+26384>>1]){v[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!$c(b,x[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>z[f>>1]){break h}g=D(g,104)+a|0;kg(_c(e+48|0,w[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;lg(n,y[e+239|0]+1|0);f=cq(a);d=hb-16|0;hb=d;x[d+12>>2]=0;Os(d+12|0,f);k=x[d+12>>2];hb=d+16|0;$c(b,y[e+235|0]|y[e+236|0]<<8|(y[e+237|0]<<16|y[e+238|0]<<24));q=c&1;r=a+480188|0;s=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(y[e+239|0]<j>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{d=Eg(b);if(d>>>0>=3){c=e+8|0;Xd(c,b,d-2|0);h=jc(e+48|0,c);zb(c);m:{if(!q){break m}c=x[h>>2];x[23420]=0;c=T(166,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break l}if(!c){break m}x[23420]=0;c=W(214,n|0,j&65535,64)|0;d=x[23420];x[23420]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=_b(x[n>>2],j);t=pf(x[c>>2],x[x[c+48>>2]+12>>2],l);n:{o:while(1){x[23420]=0;c=T(194,h|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=z[r>>1]){break n}f=D(d,6)+t|0;if(c&32){x[23420]=0;R(247,e+8|0,h|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}g=jd(e+8|0);d=y[e+8|0];if(d){d=(d&127)-1|0;v[e+8|0]=d;d=(D((d&240)>>>4|0,12)+(d&15)|0)+13|0;v[f|0]=d;m=$A(d)&m}v[f+1|0]=y[g|0]}if(!(c&64)){continue}v[f+2|0]=0;v[f+3|0]=0;g=f+5|0;while(1){c=x[h>>2];x[23420]=0;c=W(144,c|0,x[e+56>>2],2)|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}if(!c){continue o}o=y[f+5|0];c=y[f+3|0];x[23420]=0;R(247,e+8|0,h|0);d=x[23420];x[23420]=0;if((d|0)!=1){i=y[jd(e+8|0)|0];v[g|0]=i;d=y[(y[e+8|0]&31)+26416|0];v[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(x[s>>2]!=1){break s}break r;case 11:v[e+32|0]=64;u=g,A=y[Wb(g,e+32|0)|0],v[u|0]=A;if(!lT(x[k+88>>2])){break r}v[f+2|0]=1;v[f+4|0]=y[g|0];v[f+3|0]=c;v[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:v[f+3|0]=2;v[g|0]=i&15|224;break p;case 1:v[f+3|0]=3;v[g|0]=i&15|224;break p;default:break u}}if(du(x[k+84>>2],19)){break r}Gu(f);break r;case 13:d=x[k+84>>2];if(du(d,15)){break r}if(!du(d,19)){break r}v[f+3|0]=19;v[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(du(x[k+84>>2],20)){break r}v[f+3|0]=19;break p}v[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}v[g|0]=d}d=y[f+3|0]}if((d&255)!=20){break p}d=y[g|0];if(y[f+2|0]|(d&240)!=128){break p}v[f+2|0]=2;v[f+4|0]=(((d&15)<<6|8)>>>0)/15;v[f+3|0]=c;v[g|0]=o}if(!(y[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}zb(h)}j=j+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?m&1?8454144:0:0)}x[a+480208>>2]=c;f=1;if(!(y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24))){break a}if(!$c(b,y[e+249|0]|y[e+250|0]<<8|(y[e+251|0]<<16|y[e+252|0]<<24))){break a}mB(a+1298332|0,b,y[e+253|0]|y[e+254|0]<<8|(y[e+255|0]<<16|y[e+256|0]<<24),4);break a}d=P()|0;zb(h);break b}w[f+484412>>1]=64;g=y[e+93|0]|y[e+94|0]<<8|(y[e+95|0]<<16|y[e+96|0]<<24);x[k>>2]=g;d=y[e+105|0];if(d&2){h=f+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=g>>>1}x[f+484384>>2]=y[e+97|0]|y[e+98|0]<<8|(y[e+99|0]<<16|y[e+100|0]<<24);x[f+484388>>2]=(y[e+101|0]|y[e+102|0]<<8|(y[e+103|0]<<16|y[e+104|0]<<24))-1;if(d&1){g=f+484414|0;w[g>>1]=z[g>>1]|2}v:{w:{if(!(d&4)){break w}g=y[e+108|0];if((g|0)==255){break w}v[e+8|0]=g;v[e+32|0]=64;u=f+484410|0,A=y[Wb(e+8|0,e+32|0)|0]<<2,w[u>>1]=A;break v}g=f+484414|0;w[g>>1]=z[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=z[d>>1]|32;w[d>>1]=g;j=f+484408|0;f=y[e+109|0];if(f>>>0<=15){x[e+32>>2]=256;x[e+8>>2]=f<<4|8;h=x[td(e+8|0,e+32|0)>>2]}else{h=128}w[j>>1]=h;w[d>>1]=g&65279|((f|0)==16)<<8;break x}w[f+484408>>1]=128}i=i+1|0;d=z[l>>1];continue}}d=P()|0;xb(e+48|0);break b}d=P()|0;cc(e+8|0)}S(d|0);p()}hb=e+272|0;return f|0}function BV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-224|0;hb=e;zc(b);a:{b:{c:{d:{if(!qC(b,e+176|0)){break d}if(!tC(e+176|0)){break d}if(!c){n=1;break d}Dd(a,2048);Cg(a);d=hb-16|0;hb=d;f=e+8|0;h=Vb(d,3927);Rc(f,h);yb(h);hb=d+16|0;x[23420]=0;U(201,e+80|0,f|0,y[e+179|0]);d=x[23420];x[23420]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Gb(a+1298344|0,d);yb(d);f=e+8|0;cc(f);h=Vb(d,11008);Gb(a+1298356|0,h);yb(h);x[a+1298404>>2]=5;h=a+480188|0;w[h>>1]=y[e+216|0];w[a+480190>>1]=y[e+212|0];Ye(f,2,e+176|4);Fc(d,f);Ac(a+1298308|0,d);xb(d);d=y[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=Wu(b);m:{if((h|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break m}x[e+80>>2]=(h<<1)+128;x[e+8>>2]=0;x[e+160>>2]=256;t=((d<<5)+a|0)+480284|0,u=x[vj(e+80|0,e+8|0,e+160|0)>>2],w[t>>1]=u}d=d+1|0;continue}}f=e+80|0;d=hb-16|0;hb=d;n:{if(!Nb(x[b>>2],x[b+8>>2],16)){gC(f);break n}Nu(d+8|0,f);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;d=0;while(1){if((d|0)==16){break l}w[((d<<5)+a|0)+480284>>1]=v[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}w[h>>1]=4;mg(b,1);wh(a,1)}o:{if(y[e+179|0]>=13){d=e+80|0;Qu(d,b);f=jd(d);d=y[e+80|0];if(d>>>0<=31){v[e+80|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break o}x[a+480196>>2]=6;x[a+480204>>2]=125e4}jg(Yb(x[a+484360>>2],y[a+484376|0]),y[e+213|0]);l=Qb(e+160|0);f=y[e+179|0];r=x[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}x[23420]=0;R(202,l|0,y[e+213|0]);f=x[23420];x[23420]=0;if((f|0)!=1){break p}d=P()|0;break b}q:{r:{s:{while(1){t:{if(y[e+213|0]<=d>>>0){d=0;if(y[e+179|0]!=10){break s}m=x[b+8>>2];k=a+480190|0;d=1;while(1){j=z[k>>1];if(j>>>0<(d&65535)>>>0){break t}x[23420]=0;f=Q(203,b|0,e+80|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break r}if(f){f=0;u:{if(y[e+212|0]<(y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24))>>>0|y[e+80|0]>1){break u}h=y[e+130|0]|y[e+131|0]<<8|(y[e+132|0]<<16|y[e+133|0]<<24);if(h>>>0>1048576|y[e+136|0]>64|h>>>0<(y[e+137|0]|y[e+138|0]<<8|(y[e+139|0]<<16|y[e+140|0]<<24))>>>0){break u}f=h>>>0>=(y[e+141|0]|y[e+142|0]<<8|(y[e+143|0]<<16|y[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}t=bc(x[Yb(x[a+484360>>2],y[a+484376|0])>>2],d),u=d,w[t>>1]=u;if(y[e+179|0]>=14){x[23420]=0;f=T(182,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break q}t=bc(x[l>>2],d),u=f,w[t>>1]=u}f=z[a+480188>>1];x[23420]=0;Q(176,b|0,f<<1)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}d=d+1|0;continue}break}x[23420]=0;Q(143,b|0,m|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=z[j>>1];x[23420]=0;x[e+80>>2]=0;m=W(204,e- -64|0,f|0,e+80|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>z[j>>1]){h=Qb(e+48|0);x[23420]=0;n=W(205,b|0,h|0,z[e+214>>1])|0;d=x[23420];x[23420]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=x[h>>2];if(!uc(f,x[h+4>>2])){f=Db(f);g=Db(x[h+4>>2]);k=hb-16|0;hb=k;x:{if(!Pb(f,g)){break x}x[k+8>>2]=f;while(1){j=x[Re(k+8|0)>>2];if(!Pb(j,g)){break x}f=tl(y[f|0]|y[f+1|0]<<8,y[j|0]|y[j+1|0]<<8)?j:f;continue}}hb=k+16|0;k=y[f|0]|y[f+1|0]<<8}x[23420]=0;j=Q(206,e+32|0,k|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=_c(e+80|0,8,1,0,1);o=a+480190|0;f=z[o>>1];g=1;z:{A:while(1){q=g&65535;if(q>>>0>(f&65535)>>>0){break j}d=x[b+8>>2];f=x[b>>2];x[23420]=0;d=W(144,f|0,d|0,1)|0;f=x[23420];x[23420]=0;if((f|0)==1){break z}if(!d){break j}s=x[b+8>>2];d=0;while(1){f=z[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((q|0)!=x[Cb(x[m>>2],d)>>2]){d=d+1|0;continue}x[23420]=0;Q(143,b|0,s|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){x[23420]=0;d=d+1|0;W(207,i|0,(D(d,104)+a|0)+484380|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){continue}}break}break}d=P()|0;break i}d=P()|0;break i}x[23420]=0;f=T(182,b|0)|0;g=x[23420];x[23420]=0;B:{if((g|0)==1){break B}x[23420]=0;Q(176,b|0,1)|0;g=x[23420];x[23420]=0;if((g|0)==1){break B}if(f){x[23420]=0;U(178,e+8|0,b|0,D(f,3)+(y[e+179|0]==1?3:0)|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}g=e+8|0;f=jc(e+80|0,g);bd(Bg(x[j>>2],d),f);zb(f);zb(g)}d=d+1|0;continue}break}d=P()|0;break i}d=P()|0;break i}d=P()|0;break h}d=P()|0;break h}C:{D:{if(y[e+179|0]<=9){x[23420]=0;R(208,b|0,e+80|0);g=x[23420];x[23420]=0;E:{F:{if((g|0)==1){break F}x[23420]=0;R(209,e+80|0,(D(h,104)+a|0)+484380|0);g=x[23420];x[23420]=0;if((g|0)==1){break F}g=e+48|0;Ye(g,2,k);x[23420]=0;R(210,e+8|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break E}break D}d=P()|0;break g}d=P()|0;break g}x[23420]=0;U(211,b|0,e+80|0,n|0);g=x[23420];x[23420]=0;if((g|0)==1){break C}x[23420]=0;U(212,e+80|0,(D(h,104)+a|0)+484380|0,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break C}g=e+48|0;Ye(g,2,k);x[23420]=0;R(210,e+8|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break v}}g=e+8|0;Dc(((h<<5)+a|0)+946304|0,g);xb(g);t=Cb(x[m>>2],h-1|0),u=z[e+126>>1]|z[e+128>>1]<<16,x[t>>2]=u;f=f+1|0;continue}break}d=P()|0;break g}d=P()|0;break g}d=P()|0;break b}d=P()|0;break b}d=P()|0;cc(e+8|0);break a}d=P()|0;break b}if(!(c&1)){break f}x[23420]=0;g=a+484344|0;R(213,g|0,y[e+213|0]);c=x[23420];x[23420]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(y[e+213|0]<=a>>>0){break f}d=64;c=x[l>>2];if(Mc(c,x[l+4>>2])>>>0>a>>>0){d=z[bc(c,a)>>1]}x[23420]=0;c=W(214,g|0,a&65535,d&65535)|0;d=x[23420];x[23420]=0;if((d|0)==1){break G}I:{if(c){c=z[f>>1];x[23420]=0;Q(143,b|0,D(((y[e+179|0]>13)<<1)+(c<<1)|0,a)+r|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break G}c=Qb(e+80|0);d=z[f>>1];x[23420]=0;i=W(205,b|0,c|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(z[f>>1]<=d>>>0){break J}K:{i=bc(x[c>>2],d);i=y[i|0]|y[i+1|0]<<8;if(!i|i>>>0>z[e+214>>1]){break K}i=bc(x[h>>2],i-1|0);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=x[g>>2];q=x[j>>2];x[23420]=0;U(215,_b(o,a)|0,d&65535,Bg(q,i)|0);i=x[23420];x[23420]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}od(c)}a=a+1|0;continue}}break}d=P()|0;od(c);break i}d=P()|0;break i}d=P()|0}kd(j)}od(h)}tc(m);break b}kd(j)}od(h);tc(m);od(l)}hb=e+224|0;return n|0}d=P()|0}od(l)}S(d|0);p()}function h_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=hb-560|0;hb=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(Lj(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+96>>2]=1108;b=l+96|0;s=le(l+136|0,l+144|0,b);m=x[s>>2];x[l+132>>2]=m;x[l+128>>2]=m+400;w=Jb(b);n=Jb(l+80|0);q=Jb(l- -64|0);o=Jb(l+48|0);t=Jb(l+32|0);x[23420]=0;la(1117,c|0,d|0,l+120|0,l+116|0,l+112|0,w|0,n|0,q|0,o|0,l+28|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;B=A>>>9|0;k=x[l+28>>2];e=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[23420]=0;b=Q(1091,a|0,l+552|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if(!b){break g}h:{i:{j:{k:{l:{switch(v[(l+120|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=W(1118,h|0,1,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if(b){x[23420]=0;R(1119,l+16|0,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;R(48,t|0,x[l+16>>2]);b=x[23420];x[23420]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[23420]=0;b=Q(1091,a|0,l+552|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if(!b){break c}b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=W(1118,h|0,1,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if(!b){break c}x[23420]=0;R(1119,l+16|0,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;R(48,t|0,x[l+16>>2]);b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Eb(q)){break m}b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if((b|0)!=x[sc(q)>>2]){break m}x[23420]=0;T(1095,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}v[g|0]=0;r=Eb(q)>>>0>1?q:r;break c}n:{if(!Eb(o)){break n}b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if((b|0)!=x[sc(o)>>2]){break n}x[23420]=0;T(1095,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}v[g|0]=1;r=Eb(o)>>>0>1?o:r;break c}c=Eb(q);b=Eb(o);o:{if(c){if(!b){break o}x[f>>2]=x[f>>2]|4;a=0;break d}if(!b){break c}}C=g,D=!Eb(o),v[C|0]=D;break c}if(!(e>>>0<2|r|((e|0)==2&y[l+123|0]!=0|B))){r=0;break c}c=gc(l+16|0,Yd(n));p:{if(!e|y[(e+l|0)+119|0]>1){break p}q:{while(1){b=yk(n);d=x[c>>2];if(!Pb(d,b)){break q}b=x[d>>2];x[23420]=0;b=W(1118,h|0,1,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){if(!b){break q}Ce(c);continue}break}break a}b=Yd(n);b=Rt(x[c>>2],b);if(Eb(t)>>>0>=b>>>0){d=hm(yk(t),0-b|0);z=yk(t);u=Yd(n);b=hb-16|0;hb=b;x[b>>2]=u;x[b+8>>2]=d;while(1){r:{u=Pb(d,z);if(!u){break r}if(!uc(x[d>>2],x[x[b>>2]>>2])){break r}d=Ce(b+8|0);Ce(b);d=x[d>>2];continue}break}hb=b+16|0;if(u^1){break p}}C=c,D=x[gc(l+8|0,Yd(n))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=yk(n);if(!Pb(x[l+8>>2],b)){break s}x[23420]=0;b=Q(1091,a|0,l+552|0)|0;c=x[23420];x[23420]=0;t:{if((c|0)==1){break t}if(!b){break s}b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[23420]=0;T(1095,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}Ce(l+8|0);continue}break}break a}if(!A){break c}b=yk(n);if(!Pb(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+112>>2];d=m;u:{while(1){v:{x[23420]=0;c=Q(1091,a|0,l+552|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break v}if(!c){break u}c=x[a>>2];x[23420]=0;c=T(1093,c|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break a}x[23420]=0;m=W(1118,h|0,64,c|0)|0;u=x[23420];x[23420]=0;if((u|0)==1){break a}w:{if(m){m=x[j>>2];if((m|0)==x[l+548>>2]){x[23420]=0;U(1120,i|0,j|0,l+548|0);m=x[23420];x[23420]=0;if((m|0)==1){break a}m=x[j>>2]}x[j>>2]=m+4;x[m>>2]=c;b=b+1|0;break w}if(!Eb(w)|!b|(c|0)!=(z|0)){break u}if(x[l+128>>2]==(d|0)){x[23420]=0;U(1114,s|0,l+132|0,l+128|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}d=x[l+132>>2]}c=d+4|0;x[l+132>>2]=c;x[d>>2]=b;d=c;b=0}x[23420]=0;T(1095,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(d|0)){break f}if(x[l+128>>2]==(d|0)){x[23420]=0;U(1114,s|0,l+132|0,l+128|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}d=x[l+132>>2]}m=d+4|0;x[l+132>>2]=m;x[d>>2]=b;break e}x[l+28>>2]=k;x:{if(!r){break x}k=1;while(1){if(Eb(r)>>>0<=k>>>0){break x}x[23420]=0;b=Q(1092,a|0,l+552|0)|0;c=x[23420];x[23420]=0;y:{if((c|0)==1){break y}z:{if(!b){b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break y}if((b|0)==x[fj(r,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23420]=0;T(1095,a|0)|0;b=x[23420];x[23420]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;sf(w,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=d}A:{if((k|0)<=0){break A}x[23420]=0;b=Q(1092,a|0,l+552|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[23420]=0;b=T(1093,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}if((b|0)==x[l+116>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23420]=0;b=T(1095,a|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}while(1){if((k|0)<=0){k=0;break A}x[23420]=0;c=Q(1092,b|0,l+552|0)|0;d=x[23420];x[23420]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[23420]=0;c=T(1093,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break C}x[23420]=0;c=W(1118,h|0,64,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+548>>2]){x[23420]=0;U(1120,i|0,j|0,l+548|0);c=x[23420];x[23420]=0;if((c|0)==1){break C}}c=x[b>>2];x[23420]=0;c=T(1093,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[23420]=0;T(1095,b|0)|0;c=x[23420];x[23420]=0;k=k-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Jc(t);Jc(o);Jc(q);Jc(n);xb(w);Pc(s);break b}e=e+1|0;continue}}break a}hb=l+560|0;return a|0}a=P()|0;Jc(t);Jc(o);Jc(q);Jc(n);xb(w);Pc(s);S(a|0);p()}function o_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=hb-560|0;hb=l;x[l+548>>2]=k;x[l+552>>2]=b;a:{b:{if(Yi(a,l+552|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+104>>2]=1108;b=l+104|0;s=le(l+136|0,l+144|0,b);m=x[s>>2];x[l+132>>2]=m;x[l+128>>2]=m+400;u=Jb(b);n=Jb(l+88|0);q=Jb(l+72|0);o=Jb(l+56|0);t=Jb(l+40|0);x[23420]=0;la(1111,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,n|0,q|0,o|0,l+36|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[j>>2]=x[i>>2];z=e&512;A=z>>>9|0;e=x[l+36>>2];c=h;h=0;while(1){c:{d:{e:{f:{g:{if((h|0)==4){break g}x[23420]=0;b=Q(1075,a|0,l+552|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(!b){break g}h:{i:{j:{k:{l:{switch(v[(l+120|0)+h|0]){case 1:if((h|0)==3){break c}b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(jh(x[c+8>>2],1,b)){x[23420]=0;R(1112,l+24|0,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;R(46,t|0,v[l+24|0]);b=x[23420];x[23420]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((h|0)==3){break c}}while(1){x[23420]=0;b=Q(1075,a|0,l+552|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(!b){break c}b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(!jh(x[c+8>>2],1,b)){break c}x[23420]=0;R(1112,l+24|0,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;R(46,t|0,v[l+24|0]);b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Eb(q)){break m}b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(y[Nc(q,0)|0]!=(b&255)){break m}x[23420]=0;T(1079,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}v[g|0]=0;r=Eb(q)>>>0>1?q:r;break c}n:{if(!Eb(o)){break n}b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(y[Nc(o,0)|0]!=(b&255)){break n}x[23420]=0;T(1079,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}v[g|0]=1;r=Eb(o)>>>0>1?o:r;break c}d=Eb(q);b=Eb(o);o:{if(d){if(!b){break o}x[f>>2]=x[f>>2]|4;a=0;break d}if(!b){break c}}C=g,D=!Eb(o),v[C|0]=D;break c}if(!(h>>>0<2|r|((h|0)==2&y[l+123|0]!=0|A))){r=0;break c}C=l,D=Yd(n),x[C+16>>2]=D;d=Gf(l+24|0,l+16|0);p:{if(!h|y[(h+l|0)+119|0]>1){break p}while(1){q:{C=l,D=mh(n),x[C+16>>2]=D;if(!Lh(d,l+16|0)){break q}if(!jh(x[c+8>>2],1,v[x[d>>2]])){break q}Be(d);continue}break}C=l,D=Yd(n),x[C+16>>2]=D;b=$j(d,l+16|0);if(Eb(t)>>>0>=b>>>0){C=l,D=mh(t),x[C+16>>2]=D;k=Di(l+16|0,0-b|0);w=mh(t);B=Yd(n);b=hb-32|0;hb=b;x[b+16>>2]=w;x[b+24>>2]=k;x[b+8>>2]=B;while(1){k=Lh(b+24|0,b+16|0);if(!(!k|y[x[b+24>>2]]!=y[x[b+8>>2]])){Be(b+24|0);Be(b+8|0);continue}break}hb=b+32|0;if(k^1){break p}}C=l,D=Yd(n),x[C+8>>2]=D;C=d,D=x[Gf(l+16|0,l+8|0)>>2],x[C>>2]=D}x[l+16>>2]=x[d>>2];r:{while(1){C=l,D=mh(n),x[C+8>>2]=D;if(!Lh(l+16|0,l+8|0)){break r}x[23420]=0;b=Q(1075,a|0,l+552|0)|0;d=x[23420];x[23420]=0;s:{if((d|0)==1){break s}if(!b){break r}b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break s}if(y[x[l+16>>2]]!=(b&255)){break r}x[23420]=0;T(1079,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}Be(l+16|0);continue}break}break a}if(!z){break c}C=l,D=mh(n),x[C+8>>2]=D;if(!Lh(l+16|0,l+8|0)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;w=y[l+118|0];d=m;t:{while(1){u:{x[23420]=0;k=Q(1075,a|0,l+552|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break u}if(!k){break t}k=x[a>>2];x[23420]=0;k=T(1077,k|0)|0;m=x[23420];x[23420]=0;if((m|0)==1){break a}v:{if(jh(x[c+8>>2],64,k)){m=x[j>>2];if((m|0)==x[l+548>>2]){x[23420]=0;U(1113,i|0,j|0,l+548|0);m=x[23420];x[23420]=0;if((m|0)==1){break a}m=x[j>>2]}x[j>>2]=m+1;v[m|0]=k;b=b+1|0;break v}if(!Eb(u)|!b|(w|0)!=(k&255)){break t}if(x[l+128>>2]==(d|0)){x[23420]=0;U(1114,s|0,l+132|0,l+128|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}d=x[l+132>>2]}k=d+4|0;x[l+132>>2]=k;x[d>>2]=b;d=k;b=0}x[23420]=0;T(1079,a|0)|0;k=x[23420];x[23420]=0;if((k|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(d|0)){break f}if(x[l+128>>2]==(d|0)){x[23420]=0;U(1114,s|0,l+132|0,l+128|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}d=x[l+132>>2]}m=d+4|0;x[l+132>>2]=m;x[d>>2]=b;break e}x[l+36>>2]=e;w:{if(!r){break w}k=1;while(1){if(Eb(r)>>>0<=k>>>0){break w}x[23420]=0;b=Q(1076,a|0,l+552|0)|0;c=x[23420];x[23420]=0;x:{if((c|0)==1){break x}y:{if(!b){b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break x}if(y[Xf(r,k)|0]==(b&255)){break y}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23420]=0;T(1079,a|0)|0;b=x[23420];x[23420]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+24>>2]=0;sf(u,b,m,l+24|0);if(x[l+24>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=d}z:{if((e|0)<=0){break z}x[23420]=0;b=Q(1076,a|0,l+552|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}A:{if(!b){b=x[a>>2];x[23420]=0;b=T(1077,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(y[l+119|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[23420]=0;b=T(1079,a|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}while(1){if((e|0)<=0){e=0;break z}x[23420]=0;d=Q(1076,b|0,l+552|0)|0;k=x[23420];x[23420]=0;B:{if((k|0)==1){break B}C:{if(!d){d=x[b>>2];x[23420]=0;d=T(1077,d|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break B}if(jh(x[c+8>>2],64,d)){break C}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+548>>2]){x[23420]=0;U(1113,i|0,j|0,l+548|0);d=x[23420];x[23420]=0;if((d|0)==1){break B}}d=x[b>>2];x[23420]=0;d=T(1077,d|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break B}k=x[j>>2];x[j>>2]=k+1;v[k|0]=d;x[23420]=0;T(1079,b|0)|0;d=x[23420];x[23420]=0;e=e-1|0;if((d|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}xb(t);xb(o);xb(q);xb(n);xb(u);Pc(s);break b}h=h+1|0;continue}}break a}hb=l+560|0;return a|0}a=P()|0;xb(t);xb(o);xb(q);xb(n);xb(u);Pc(s);S(a|0);p()}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb+-64|0;hb=g;d=x[b>>2];x[23420]=0;e=T(166,d|0)|0;d=x[23420];x[23420]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){h=Qb(g+48|0);x[23420]=0;f=(c|0)!=0;e=W(777,h|0,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(e){break j}x[23420]=0;e=W(778,h|0,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}d=5;if(e){break j}x[23420]=0;e=W(779,h|0,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}d=6;if(e){break j}e=0;x[23420]=0;f=W(780,h|0,b|0,f|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}d=3;if(!f){break i}}if(!c){d=1;e=0;break h}e=x[h>>2];if(!uc(e,x[h+4>>2])){hv(b,e+12|0)}e=d}d=31392;k:{while(1){f=d;if((f|0)!=31908){i=x[f+8>>2];j=(i>>1)+a|0;d=x[f+4>>2];d=i&1?x[x[j>>2]+d>>2]:d;x[23420]=0;i=W(d|0,j|0,b|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}d=f+12|0;if(!i){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){d=(f|0)!=31908;e=0;break h}if(!(x[a+480184>>2]|!e)){x[a+480184>>2]=e}x[23420]=0;e=1;R(720,a+1298264|0,1);f=x[23420];x[23420]=0;d=1;if((f|0)==1){break g}}nM(h);if(e){break f}break a}break c}x[23420]=0;R(234,a|0,0);d=x[23420];x[23420]=0;if((d|0)==1){break d}x[23420]=0;R(720,a+1298264|0,1);d=x[23420];x[23420]=0;if((d|0)==1){break d}x[a+1074304>>2]=19924737}d=0;while(1){if((d|0)==127){d=1;while(1){e=d&65535;if(e>>>0>z[a+480190>>1]){e=0;j=a+480180|0;d=0;l:{while(1){f=d&65535;if(f>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=e;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{f=x[((f<<2)+a|0)+900380>>2];if(f){i=x[j>>2];xc(f,65536);xc(f+4|0,64);xc(f+8|0,256);tg(f+28|0,16384);nf(f+30|0,128);nf(f+31|0,17);if(y[f+16|0]>=4){v[f+16|0]=0}if(y[f+17|0]>=5){v[f+17|0]=0}if(y[f+18|0]>=3){v[f+18|0]=0}nf(f+19|0,64);nf(f+20|0,100);k=224;e=v[f+26|0];n:{if((e|0)>=-32){k=32;if((e|0)<33){break n}}v[f+26|0]=k}nf(f+23|0,64);nf(f+24|0,64);Az(f+48|0,64);Az(f+68|0,64);Az(f+88|0,(i|0)==4096?255:64);i=f+108|0;k=0;while(1){o:{if((k|0)==128){if(!wo(y[f+14|0])){v[f+14|0]=5}if(y[f+34|0]>=251){v[f+34|0]=0}break o}e=Kb(i,k);if((y[e|0]-121&255)>>>0<=135){v[e|0]=k+1}k=k+1|0;continue}break}e=d}d=d+1|0;continue}break}xc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}e=a+480220|0;d=x[a+480216>>2];if(d>>>0>A[a+480220>>2]){x[e>>2]=d}d=a+480216|0;xc(d,65536);xc(e,65536);xc(a+480200|0,256);p:{e=a+480248|0;if(!uc(x[e>>2],x[a+480252>>2])){d=x[d>>2];x[23420]=0;R(781,e|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];e=a+1074408|0;x[e>>2]=x[a+480216>>2];x[e+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];Py(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(qm(x[a+480180>>2])){x[23420]=0;Q(252,a+1074312|0,7)|0;d=x[23420];x[23420]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;up(a);n=g,o=Db(x[a+484360>>2]),x[n+48>>2]=o;e=Db(x[a+484364>>2]);while(1){f=x[g+48>>2];if(!Pb(f,e)){q:{r:{j=x[a+480180>>2];if(j){Os(a+8|0,cq(a));if(x[a+1074308>>2]){x[23420]=0;Y(782,a|0);d=x[23420];x[23420]=0;if((d|0)==1){break p}}m=Qb(g+48|0);s:{if((c&12)!=12){break s}i=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{e=D(d,160)+a|0;f=e+906316|0;A:{if(!(x[f>>2]|x[e+906320>>2])){break A}x[23420]=0;l=e+906300|0;R(783,l|0,a|0);c=x[23420];x[23420]=0;B:{if((c|0)!=1){h=x[l>>2];if(!h){break B}e=x[e+906448>>2];c=x[x[h>>2]+56>>2];x[23420]=0;R(c|0,h|0,e|0);c=x[23420];x[23420]=0;if((c|0)!=1){break A}}a=P()|0;break q}k=Db(x[m>>2]);e=Db(x[m+4>>2]);h=hb-16|0;hb=h;x[h+8>>2]=k;while(1){C:{if(!Pb(k,e)){break C}c=x[k>>2];if((y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))==(y[l+20|0]|y[l+21|0]<<8|(y[l+22|0]<<16|y[l+23|0]<<24))){c=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))==(y[l+16|0]|y[l+17|0]<<8|(y[l+18|0]<<16|y[l+19|0]<<24))}else{c=0}if(c){break C}k=x[Ce(h+8|0)>>2];continue}break}hb=h+16|0;if(Pb(k,Db(x[m+4>>2]))){break A}x[23420]=0;x[g+32>>2]=f;R(784,m|0,g+32|0);c=x[23420];x[23420]=0;if((c|0)==1){break z}x[23420]=0;e=Q(1,g+16|0,17520)|0;c=x[23420];x[23420]=0;if((c|0)==1){break y}x[23420]=0;R(785,g|0,l|0);c=x[23420];x[23420]=0;if((c|0)==1){break x}x[23420]=0;U(2,g+32|0,e|0,g|0);c=x[23420];x[23420]=0;if((c|0)==1){break w}c=x[i>>2];x[23420]=0;U(353,c|0,2,g+32|0);c=x[23420];x[23420]=0;if((c|0)==1){break v}yb(g+32|0);yb(g);yb(e)}d=d+1|0;continue}break}a=P()|0;break q}a=P()|0;break q}a=P()|0;break t}a=P()|0;break u}a=P()|0;yb(g+32|0)}yb(g)}yb(e);break q}c=y[a+1074368|0];x[23420]=0;R(786,a|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break r}tc(m)}d=(j|0)!=0;break a}a=P()|0}tc(m);break b}x[23420]=0;Y(787,f|0);d=x[23420];x[23420]=0;if((d|0)!=1){if(Mc(x[f>>2],x[f+4>>2])>>>0<=z[f+28>>1]){Ze(f,0)}uz(g+48|0);continue}break}a=P()|0;break b}a=P()|0;break b}i=D(e,104)+a|0;j=i+484380|0;D:{if(Td(x[j>>2],x[i+484400>>2])){lj(j,a);break D}f=i+484414|0;e=z[f>>1];if(e&16384){break D}x[j>>2]=0;x[j+4>>2]=0;x[j+16>>2]=0;x[j+8>>2]=0;x[j+12>>2]=0;w[f>>1]=e&65505}e=i+484412|0;if(z[e>>1]>=65){w[e>>1]=64}E:{F:{if(!(y[i+484415|0]&2)){break F}if(!Uj(x[a+1298300>>2])){break F}x[23420]=0;Y(788,a|0);e=x[23420];x[23420]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;break b}f=(d<<5)+a|0;tg(f+480286|0,64);e=f+480284|0;if(z[e>>1]>=257){w[e>>1]=128}e=f+480288|0;if(y[e|0]>=251){v[e|0]=0}_n((D(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;break b}a=P()|0;nM(h)}zb(b);S(a|0);p()}zb(b);hb=g- -64|0;return d|0}function G0(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=hb-560|0;hb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;A=5257;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;A=5260;break a}u=e&1;A=u?5263:5258;E=!u}b:{if((g&2146435072)==2146435072){d=u+3|0;tf(a,32,c,d,e&-65537);hf(a,A,u);f=f&32;hf(a,b!=b?f?9870:13636:f?10996:13998,3);tf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=zH(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;t=f|32;if((t|0)!=97){break e}break c}t=f|32;if((t|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)>=0?288:0)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)>=29?29:d;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=x[g>>2];p=d&31;B=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=B+q|0;i=i+C|0;i=p>>>0<q>>>0?i+1|0:i;i=Zia(p,i,1e9,0);q=Wia(i,lb,-1e9,0)+p|0;x[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;x[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-d|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;p=(t|0)==102;while(1){d=0-d|0;i=(d|0)>=9?9:d;h:{if(g>>>0<=k>>>0){h=x[k>>2];break h}q=1e9>>>i|0;C=-1<<i^-1;d=0;h=k;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>i|0);d=D(q,d&C);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[k>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=i+x[n+44>>2]|0;x[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=D(r-k>>2,9);h=10;i=x[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((t|0)!=102?d:0)|0)-((t|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+D(p,-9)|0;if((i|0)<=7){while(1){h=D(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=x[l>>2];w=(p>>>0)/(h>>>0)|0;i=D(w,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(y[A|0]!=45|E)){s=-s;b=-b}x[l>>2]=i;if(b+s==b){break j}d=h+i|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;x[k>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(r-k>>2,9);h=10;i=x[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!x[g>>2]){continue}}break}l:{if((t|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=x[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=D(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=D(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;t=l|m;if(((t?2147483645:2147483646)|0)<(m|0)){break b}p=(((t|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((p^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=tn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(p^2147483647)){break b}}d=g+p|0;if((d|0)>(u^2147483647)){break b}f=d+u|0;tf(a,32,c,f,e);hf(a,A,u);tf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=tn(x[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}hf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(t){hf(a,16590,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=tn(x[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}hf(a,g,(m|0)>=9?9:m);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=tn(x[h>>2],0,r);if((r|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}hf(a,g,1);g=g+1|0;if(!(l|m)){break t}hf(a,16590,1)}B=g;g=r-g|0;hf(a,B,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}tf(a,48,m+18|0,18,0);hf(a,w,z-w|0);break o}g=m}tf(a,48,g+9|0,9,0)}tf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(y[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=u|2;k=f&32;h=x[n+44>>2];g=h>>31;g=tn((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}r=g-2|0;v[r|0]=f+15;v[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){g=~~b}else{g=-2147483648}v[h|0]=k|y[g+75920|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;tf(a,32,c,d,e);hf(a,m,l);tf(a,48,c,d,e^65536);hf(a,n+16|0,k);tf(a,48,g-k|0,0,0);hf(a,r,p);tf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}hb=n+560|0;return i|0}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-272|0;hb=e;zc(b);d=hb-16|0;hb=d;f=e+120|0;LQ(d+8|0,f);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);h=x[d+4>>2];if((h|0)==(g|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(h|0);if(!d){KQ(f)}a:{b:{c:{d:{if(!d){break d}if(!MQ(e+120|0)){break d}if(!c){i=1;break d}Dd(a,4194304);d=e+32|0;g=Vb(d,16857);Gb(a+1298344|0,g);yb(g);g=Vb(d,10029);Gb(a+1298356|0,g);yb(g);x[a+1298404>>2]=5;n=a,o=Wd(z[e+198>>1],z[e+200>>1],127),w[n+480188>>1]=o;g=y[e+189|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[e+187|0];x[a+480204>>2]=D(y[e+188|0],1e4);g=e+96|0;ef(g,e+120|4,59,3);Fc(d,g);Ac(a+1298308|0,d);xb(d);d=z[e+202>>1]|z[e+204>>1]<<16;e:{if(d>>>0<5){break e}if(!$c(b,d-4|0)){break e}if(!yh(b,14098)){break e}no(Yb(x[a+484360>>2],y[a+484376|0]),b,z[e+192>>1],65535,65535)}f:{d=z[e+206>>1]|z[e+208>>1]<<16;if(d>>>0<5){break f}if(!$c(b,d-4|0)){break f}if(!yh(b,13631)){break f}d=0;while(1){if((d|0)==32){break f}g=(d<<5)+a|0;Te(g+480280|0);n=g+480284|0,o=((((Ee(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;d=d+1|0;continue}}d=z[e+214>>1]|z[e+216>>1]<<16;g:{if(d>>>0<5){break g}if(!$c(b,d-4|0)){break g}if(!yh(b,13955)){break g}d=e+32|0;Xd(d,b,z[e+196>>1]<<6);k=c&2;h=a+480190|0;g=jc(e+96|0,d);zb(d);j=e+45|0;d=0;h:{while(1){if(z[e+196>>1]<=(d&65535)>>>0){break h}x[23420]=0;f=Q(614,g|0,e+32|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}if(!f){break h}f=y[e+77|0]|y[e+78|0]<<8;w[e+30>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(Td(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[Ve(h,e+30|0)>>1],w[n>>1]=o;x[23420]=0;R(615,e+32|0,i|0);f=x[23420];x[23420]=0;if((f|0)==1){break i}ef(e,j,24,1);x[23420]=0;R(210,e+16|0,e|0);f=x[23420];x[23420]=0;if((f|0)==1){break b}f=e+16|0;Dc(((z[e+30>>1]<<5)+a|0)+946304|0,f);xb(f);if(!k){break j}x[23420]=0;Q(143,b|0,y[e+69|0]|y[e+70|0]<<8|(y[e+71|0]<<16|y[e+72|0]<<24))|0;f=x[23420];x[23420]=0;if((f|0)==1){break i}i=1;l=e+16|0;f=y[e+79|0];m=_c(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}Rf(m,i)}x[23420]=0;W(207,l|0,(D(z[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){break j}break b}d=d+1|0;continue}break}break b}zb(g)}i=1;if(!(c&1)){break d}m:{c=z[e+210>>1]|z[e+212>>1]<<16;if(c>>>0<5){break m}if(!$c(b,c-4|0)){break m}if(!yh(b,13481)){break m}k=a+484344|0;lg(k,z[e+194>>1]);f=0;while(1){if(z[e+194>>1]<=f>>>0){break m}if(!zA(b,e+16|0)){break m}n:{d=z[e+16>>1];if(d>>>0>3){c=e+96|0;Xd(c,b,(d+15&131056)-4|0);g=jc(e+32|0,c);zb(c);x[23420]=0;c=W(214,k|0,f&65535,y[e+18|0])|0;d=x[23420];x[23420]=0;if((d|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[23420]=0;d=W(144,c|0,x[e+40>>2],1)|0;c=x[23420];x[23420]=0;q:{if((c|0)!=1){c=y[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break p}x[23420]=0;c=T(194,g|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}d=c<<24>>24;if(d){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[e+96>>1]=d&31;w[e>>1]=z[a+480188>>1]-1;c=_b(c,f);c=ed(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Zc(e+96|0,e)>>1]);if((d|0)<0){x[23420]=0;R(247,e+96|0,g|0);j=x[23420];x[23420]=0;if((j|0)==1){break c}v[c|0]=y[e+96|0]+36;n=c,o=y[jd(e+96|0)|0],v[n+1|0]=o}d=d&255;if(d&64){v[c+2|0]=1;x[23420]=0;j=T(194,g|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break c}v[e+96|0]=j;v[e|0]=64;n=c,o=y[Wb(e+96|0,e)|0],v[n+4|0]=o}if(!(d&32)){continue}x[23420]=0;R(247,e+96|0,g|0);d=x[23420];x[23420]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((d|0)!=1){d=y[jd(e+96|0)|0];v[c+5|0]=d;switch(y[e+96|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=d<<4|15;continue}v[c+3|0]=11;v[c+5|0]=d<<4;continue}v[c+3|0]=11;v[c+5|0]=d|240;continue}v[c+3|0]=11;v[c+5|0]=d&15;continue}v[c+3|0]=2;v[c+5|0]=d|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=d|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=d|16;continue}v[c+3|0]=6;v[c+5|0]=d<<4;continue}v[c+3|0]=6;v[c+5|0]=d&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=d|48;continue}v[c+3|0]=7;v[c+5|0]=d<<4;continue}v[c+3|0]=7;v[c+5|0]=d&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=d|64;continue}v[c+3|0]=10;x[23420]=0;d=T(194,g|0)|0;j=x[23420];x[23420]=0;if((j|0)!=1){v[c+5|0]=d;x[23420]=0;Q(176,g|0,1)|0;c=x[23420];x[23420]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=d&15;continue}v[c+3|0]=20;v[c+5|0]=d|192;continue}v[c+3|0]=20;v[c+5|0]=d|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=d|176;continue}v[c+3|0]=20;v[c+5|0]=d|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=d&15|32;continue}v[c+3|0]=20;v[c+5|0]=d&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}ie(_b(x[k>>2],f),xh(Fe(ye(e+96|0,14,0),c-1|0)))}zb(g)}f=f+1|0;continue}break}break c}c=z[e+218>>1]|z[e+220>>1]<<16;if(!c){break d}$c(b,c);mB(a+1298332|0,b,Eg(b),4)}hb=e+272|0;return i|0}a=P()|0;break a}a=P()|0}zb(g);S(a|0);p()}function yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=hb-208|0;hb=d;zc(c);a:{if(!oo(c,d+192|0)){break a}if(Ob(d+192|0,13662,4)){break a}f=d+200|0;if(Ob(f,14031,4)){if(Ob(f,14135,4)){break a}}e=hb-32|0;hb=e;i=d+176|0;g=Qb(i);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];j=x[c>>2];x[23420]=0;h=W(144,j|0,h|0,8)|0;j=x[23420];x[23420]=0;if((j|0)==1){break d}if(!h){break e}x[23420]=0;R(742,e|0,c|0);h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;R(743,g|0,e|0);h=x[23420];x[23420]=0;if((h|0)==1){break f}Md(e);continue}break}a=P()|0;break c}a=P()|0;Md(e);break c}hb=e+32|0;break b}a=P()|0}_d(g);S(a|0);p()}x[23420]=0;U(670,d+152|0,i|0,1129270605);c=x[23420];x[23420]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[23420]=0;c=Q(671,d+152|0,d+128|0)|0;e=x[23420];x[23420]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!ac(z[d+130>>1]|z[d+132>>1]<<16)){break g}if((Lb(z[d+128>>1])-3&65535)>>>0<65534){break g}if((Lb(z[d+134>>1])-65&65535)>>>0<65472){break g}x[d+124>>2]=1162760014;c=1;if(!Ob(f,14135,4)){x[23420]=0;c=Q(559,d+152|0,d+124|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+124>>2]!=1936684916}x[23420]=0;U(670,d+104|0,d+176|0,1397968452);e=x[23420];x[23420]=0;p:{q:{if((e|0)!=1){x[23420]=0;k=Q(672,d+104|0,d+96|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;break j}f=(Lb(z[d+134>>1])-1|0)/8|0;g=f<<3;e=g&31;g=_c(d+88|0,(f>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>e|0:((1<<e)-1&1074268168)<<32-e|538447880>>>e)&255,(Lb(z[d+128>>1])|0)==2?2:1,c,0);c=x[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Rf(g,3);break r}Rf(g,17);Dh(g,16);break r}Rf(g,16);Dh(g,16);break r}Rf(g,1)}c=x[d+96>>2];x[23420]=0;c=W(144,x[d+104>>2],x[d+112>>2],ac(c)|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}if(c){c=x[d+96>>2];x[23420]=0;Q(176,d+104|0,ac(c)|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break l}}ct(a,b);x[23420]=0;c=D(b,104)+a|0;i=c+484380|0;R(264,i|0,0);e=x[23420];x[23420]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=i,t=ac(z[d+130>>1]|z[d+132>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+138|0]|y[d+139|0]<<8|(y[d+140|0]<<16|y[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-y[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[23420]=0;W(207,g|0,i|0,d+104|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break D}x[23420]=0;U(670,d- -64|0,d+176|0,1296126539);c=x[23420];x[23420]=0;if((c|0)==1){break C}x[23420]=0;c=T(166,x[d+64>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break B}if(!c){break u}x[23420]=0;U(670,d+16|0,d+176|0,1229869908);c=x[23420];x[23420]=0;if((c|0)==1){break A}x[23420]=0;c=Q(673,d+16|0,d+40|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break z}zb(d+16|0);if(!c){break u}x[23420]=0;f=T(258,d- -64|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break y}e=Qb(d+16|0);x[23420]=0;R(674,e|0,f|0);c=x[23420];x[23420]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[23420]=0;g=Q(675,d- -64|0,d|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break w}if(!g){break x}x[23420]=0;R(676,e|0,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break w}x[23420]=0;Q(176,d- -64|0,y[d+6|0]|1)|0;g=x[23420];x[23420]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;break k}c=P()|0;break k}c=P()|0;break m}c=P()|0;break m}c=P()|0;zb(d+16|0);break m}c=P()|0;break m}c=Lb(z[d+48>>1]);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Lb(z[d+54>>1]);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=Db(x[e>>2]),x[s>>2]=t;c=D(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Db(x[e+4>>2]);n=z[d+50>>1];o=z[d+52>>1];q=z[d+56>>1];r=z[d+58>>1];while(1){c=x[d>>2];if(!Pb(c,m)){break v}f=Lb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Lb(n)|0)){s=l,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((Lb(o)|0)==(f|0)){s=j,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((Lb(q)|0)==(f|0)){s=h,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Lb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Lb(r)|0)){s=g,t=ac(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d>>2]=x[d>>2]+7;continue}}c=P()|0;TN(e);break m}kk(i);TN(e)}x[23420]=0;U(670,d+16|0,d+176|0,1312902469);c=x[23420];x[23420]=0;if((c|0)==1){break n}x[23420]=0;c=T(166,x[d+16>>2])|0;e=x[23420];x[23420]=0;E:{if((e|0)==1){break E}F:{if(c){x[23420]=0;c=T(148,x[d+16>>2])|0;e=x[23420];x[23420]=0;if((e|0)==1){break E}x[23420]=0;U(300,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break F}break E}x[23420]=0;c=Q(54,d|0,21473)|0;e=x[23420];x[23420]=0;if((e|0)==1){break E}Dc(((b<<5)+a|0)+946304|0,c);xb(c)}yz(i,x[a+480180>>2]);lj(i,a);zb(d+16|0);zb(d- -64|0);break h}c=P()|0;zb(d+16|0);break m}c=P()|0;break k}c=P()|0;break j}c=P()|0;break j}c=P()|0;break m}c=P()|0;break i}zb(d- -64|0);break k}c=P()|0}zb(d+104|0)}zb(d+152|0)}_d(d+176|0);S(c|0);p()}zb(d+104|0)}zb(d+152|0);_d(d+176|0)}hb=d+208|0;return k|0}function $da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0;e=hb-224|0;hb=e;zc(b);a:{if(!It(b,e+160|0)){break a}if(!mQ(e+160|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(lQ(e+160|0),lb))){break a}if(!c){d=1;break a}Dd(a,256);f=e+144|0;tj(f,2,e+160|0);d=e+48|0;Fc(d,f);Ac(a+1298308|0,d);xb(d);f=z[e+210>>1];x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Mb(a+1074312|0,107,1);f=y[e+203|0];f=f?f:96;k=Tz(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=k;v[e+48|0]=64;E=a,F=y[Wb(e+202|0,d)|0]<<2,x[E+480200>>2]=F;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Qb(e+144|0);m=Qb(e+128|0);x[23420]=0;Q(143,b|0,z[e+192>>1]<<4)|0;d=x[23420];x[23420]=0;i:{if((d|0)==1){break i}x[23420]=0;W(205,b|0,k|0,z[e+208>>1])|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}x[23420]=0;Q(143,b|0,z[e+194>>1]<<4)|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}x[23420]=0;W(205,b|0,m|0,z[e+210>>1])|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}x[23420]=0;Q(143,b|0,(z[e+196>>1]<<4)+32|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}d=a+484376|0;f=y[d|0];g=x[a+484360>>2];x[23420]=0;R(310,Yb(g,f)|0,z[e+212>>1]);f=x[23420];x[23420]=0;if((f|0)==1){break i}d=Yb(x[a+484360>>2],y[d|0]);E=e,F=Db(x[d>>2]),x[E+48>>2]=F;d=Db(x[d+4>>2]);j:{while(1){f=x[e+48>>2];if(!Pb(f,d)){d=0;if(!pQ(Yb(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;j=e+48|1;d=1;break j}x[23420]=0;g=T(194,b|0)|0;j=x[23420];x[23420]=0;k:{if((j|0)==1){break k}w[f>>1]=g;x[23420]=0;Q(176,b|0,4)|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}Re(e+48|0);continue}break}b=P()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>z[e+210>>1]){break l}i=bc(x[m>>2],f-1|0);i=y[i|0]|y[i+1|0]<<8;x[23420]=0;i=Q(143,b|0,i<<4)|0;h=x[23420];x[23420]=0;p:{if((h|0)!=1){if(i){break p}d=0;break b}b=P()|0;break c}x[23420]=0;Q(623,b|0,e+48|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break o}x[23420]=0;i=(D(f,104)+a|0)+484380|0;U(624,e+48|0,i|0,0);h=x[23420];x[23420]=0;if((h|0)==1){break o}h=e+16|0;dk(h,2,j);x[23420]=0;R(210,e+32|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Dc(h,f);xb(f);q:{r:{if(!g|!x[e+64>>2]){break r}f=CQ(e+48|0);x[23420]=0;f=Q(143,b|0,f|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;BQ(f,y[e+78|0],y[e+79|0],1);x[23420]=0;W(207,f|0,i|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}v[e+15|0]=1;d=x[k>>2];s:{if(uc(d,x[k+4>>2])|z[e+188>>1]==26){break s}f=y[d|0]|y[d+1|0]<<8;d=0;x[23420]=0;f=Q(143,b|0,f<<4)|0;g=x[23420];x[23420]=0;if((g|0)==1){break h}if(!f){break b}x[23420]=0;d=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}if((d|0)!=z[e+188>>1]){break s}v[e+15|0]=0}n=c&1;if(n){x[23420]=0;R(213,a+484344|0,z[e+208>>1]);c=x[23420];x[23420]=0;if((c|0)==1){break h}}i=a+484344|0;c=e+48|0;q=c|5;r=c|3;s=c|4;t=c|2;u=c|1;A=a+480188|0;f=0;while(1){t:{if(!n|z[e+208>>1]<=f>>>0){break t}x[23420]=0;c=W(214,i|0,f&65535,64)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}if(!c){break t}c=bc(x[k>>2],f);c=y[c|0]|y[c+1|0]<<8;x[23420]=0;c=Q(143,b|0,c<<4)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!y[e+15|0]){x[23420]=0;c=T(182,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[e+16>>1]=65535;x[e+32>>2]=63;u:while(1){c=_b(x[i>>2],f);B=pf(x[c>>2],x[x[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){x[23420]=0;d=T(194,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break f}h=d<<24>>24;if(!h){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=h&31;g=D(d,6)+B|0;l=Sh(e+48|0);j=d>>>0<z[A>>1];o=j?g:l;l=h&255;if(l&32){x[23420]=0;R(247,e|0,b|0);d=x[23420];x[23420]=0;w:{x:{y:{if((d|0)!=1){C=jd(e);d=y[e|0];if(d>>>0>239){break y}d=AQ((D(d>>>4|0,12)+(d&15)|0)+37|0);break x}b=P()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}v[o|0]=d}v[(j?g+1|0:u)|0]=y[C|0]}if(l&64){x[23420]=0;d=T(194,b|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break e}v[e|0]=d;v[(j?g+2|0:t)|0]=1;v[e+14|0]=64;E=j?g+4|0:s,F=y[Wb(e,e+14|0)|0],v[E|0]=F}if((h|0)>=0){continue}x[23420]=0;R(247,e|0,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}v[(j?g+3|0:r)|0]=y[e|0];E=j?g+5|0:q,F=y[jd(e)|0],v[E|0]=F;oQ(o,c,255,e+16|0,e+32|0);continue}break}break}break}c=z[e+16>>1];if((c|0)!=65535){ie(_b(x[i>>2],f),tm(Fe(ye(e+48|0,12,c&255),x[e+32>>2])))}f=f+1|0;continue}break}x[23420]=0;b=Q(1,e+48|0,6049)|0;c=x[23420];x[23420]=0;A:{B:{C:{if((c|0)!=1){Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,e+32|0,5235)|0;c=x[23420];x[23420]=0;if((c|0)==1){break C}Gb(a+1298356|0,b);yb(b);x[a+1298404>>2]=5;x[23420]=0;R(626,e|0,4366);b=x[23420];x[23420]=0;if((b|0)==1){break B}x[23420]=0;U(291,e+16|0,e|0,e+15|0);b=x[23420];x[23420]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Gb(b,a);yb(a);cc(e);d=1;break b}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;cc(e);break c}b=P()|0;break c}}else{f=(d<<5)+a|0;Te(f+480280|0);w[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0;break c}b=P()|0}od(m);od(k);S(b|0);p()}od(m);od(k)}hb=e+224|0;return d|0}function xH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=hb-80|0;hb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){hf(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Mj(i)|y[b+2|0]!=36)){q=i-48|0;t=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){m=h;break k}m=h;b=1<<b;if(!(b&75913)){break k}while(1){m=h+1|0;x[j+76>>2]=m;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=m;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[m+1|0];m:{if(!(!Mj(b)|y[m+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=m+3|0;t=1;b=x[((v[m+1|0]<<3)+d|0)-384>>2];break m}if(t){break h}i=m+1|0;if(!a){x[j+76>>2]=i;t=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;t=0;b=x[b>>2]}r=b;x[j+76>>2]=i;if((r|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=wH(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Mj(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(t){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=wH(j+76|0);b=x[j+76>>2];A=1}while(1){o=h;m=28;u=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=u+1|0;h=y[(h+D(o,58)|0)+75391|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;h=(q<<3)+d|0;i=x[h+4>>2];x[j+64>>2]=x[h>>2];x[j+68>>2]=i;break q}if(!a){break f}vH(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5247;m=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[u|0];h=o?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}o=x[j+64>>2];i=x[j+68>>2];z=5247;break z}h=0;I:{switch(o&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;o=x[j+64>>2];i=x[j+68>>2];if(o|i){while(1){k=k-1|0;v[k|0]=F|y[(o&15)+75920|0];G=!i&o>>>0>15|(i|0)!=0;u=i;i=i>>>4|0;o=(u&15)<<28|o>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5247|0;q=2;break y}h=s;k=x[j+68>>2];i=k;o=x[j+64>>2];if(i|o){while(1){h=h-1|0;v[h|0]=o&7|48;u=!i&o>>>0>7|(i|0)!=0;k=i;i=i>>>3|0;o=(k&7)<<29|o>>>3;if(u){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}h=x[j+68>>2];i=h;o=x[j+64>>2];if((h|0)<0){i=0-(i+((o|0)!=0)|0)|0;o=0-o|0;x[j+64>>2]=o;x[j+68>>2]=i;q=1;z=5247;break z}if(n&2048){q=1;z=5248;break z}q=n&1;z=q?5249:5247}k=tn(o,i,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;i=x[j+64>>2];h=x[j+68>>2];if(!((i|h)!=0|l)){k=s;m=k;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:16891;h=l>>>0>=2147483647?2147483647:l;m=Ot(k,0,h);h=m?m-k|0:h;m=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[m|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;tf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}k=uH(j+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-h>>>0)){i=i+4|0;h=h+k|0;if(l>>>0>h>>>0){continue}break J}break}if(m){break b}}m=61;if((h|0)<0){break c}tf(a,32,r,h,n);if(!h){h=0;break t}m=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=uH(j+4|0,k);m=k+m|0;if(m>>>0>h>>>0){break t}hf(a,j+4|0,k);i=i+4|0;if(h>>>0>m>>>0){continue}break}}tf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}m=61;h=mb[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!t){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){vH((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}m=28;break c}o=m-k|0;l=(l|0)>(o|0)?l:o;if((l|0)>(q^2147483647)){break d}m=61;i=l+q|0;h=(i|0)<(r|0)?r:i;if((B|0)<(h|0)){break c}tf(a,32,h,i,n);hf(a,z,q);tf(a,48,h,i,n^65536);tf(a,48,l,o,0);hf(a,k,o);tf(a,32,h,i,n^8192);continue}break}p=0;break a}m=61}x[115896]=m}p=-1}hb=j+80|0;return p}function mha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;f=hb-224|0;hb=f;if(yh(b,13677)){if(d){v[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;q=a+480224|0;l=a+1074368|0;t=a+480228|0;u=a+480232|0;r=a+480200|0;m=a+480268|0;B=a+1298320|0;C=a+480248|0;E=cu(a+1074312|0);F=a+480180|0;G=a+484376|0;H=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Nb(x[b>>2],x[b+8>>2],7)){break a}e=pg(b);g=Eg(b);if((e|0)==(y[21449]|y[21450]<<8|(y[21451]<<16|y[21452]<<24))){mg(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Nb(x[b>>2],x[b+8>>2],g)){break a}d=f+176|0;Xd(d,b,g);h=jc(f+200|0,d);zb(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=u;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=t;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[23420]=0;U(387,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+176>>2],1e4)+(A[k>>2]%1e4|0);break j}x[23420]=0;U(387,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+176>>2]%1e4;break j}e=P()|0;break b}if(c){break j}x[23420]=0;w[f+176>>1]=0;U(388,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)!=1){I=a,J=Wd(z[f+176>>1],z[a+480188>>1],127),w[I+480188>>1]=J;break j}e=P()|0;break b}x[23420]=0;U(389,h|0,g|0,l|0);d=x[23420];x[23420]=0;if((d|0)!=1){break j}break c}x[23420]=0;x[f+176>>2]=0;U(387,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+176>>2];break j}e=P()|0;break b}x[23420]=0;x[f+176>>2]=0;U(387,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)==1){break h}d=x[f+176>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=r}x[23420]=0;U(387,h|0,g|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}break j}if(x[F>>2]==4){break j}x[23420]=0;U(388,h|0,g|0,f+176|0);d=x[23420];x[23420]=0;if((d|0)!=1){Ze(Yb(x[a+484360>>2],y[G|0]),z[f+176>>1]);break j}e=P()|0;break b}x[23420]=0;U(390,h|0,g|0,m|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}if(wo(y[m|0])){break j}v[m|0]=5;break j}d=Jb(f+176|0);e=x[h>>2];x[23420]=0;e=T(148,e|0)|0;g=x[23420];x[23420]=0;x:{if((g|0)==1){break x}x[23420]=0;U(391,h|0,d|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break x}x[23420]=0;U(11,f+160|0,0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break x}e=f+160|0;Gb(B,e);yb(e);xb(d);break j}e=P()|0;xb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+176>>1]=(g>>>1|0)- -64;w[f+160>>1]=127;e=z[Zc(f+176|0,f+160|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[23420]=0;R(247,f+176|0,h|0);e=x[23420];x[23420]=0;if((e|0)==1){break g}e=y[f+176|0];y:{if((e|0)==255){break y}j=y[jd(f+176|0)|0];g=(d<<5)+a|0;s=g+480284|0;w[s>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[s>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[23420]=0;d=T(182,h|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break f}if(!d|d>>>0>z[H>>1]){break j}d=(D(d,104)+a|0)+484448|0;g=$S(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[23420]=0;i=W(144,e|0,x[f+208>>2],4)|0;e=x[23420];x[23420]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[23420]=0;e=T(145,h|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){break z}}e=P()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[23420]=0;R(392,f|0,h|0);d=x[23420];x[23420]=0;A:{B:{C:{D:{if((d|0)!=1){x[23420]=0;U(393,f+176|0,x[f>>2],x[f+4>>2]);d=x[23420];x[23420]=0;if((d|0)==1){break D}x[23420]=0;d=Q(78,f+16|0,f+176|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break C}xb(f+176|0);dc(f);e=x[h>>2];x[23420]=0;T(148,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break A}x[23420]=0;R(394,d|0,C|0);e=x[23420];x[23420]=0;if((e|0)==1){break A}gf(d);break j}e=P()|0;break b}e=P()|0;break B}e=P()|0;xb(f+176|0)}dc(f);break b}e=P()|0;gf(d);break b}e=0;g=cu(E);E:while(1){d=x[h>>2];x[23420]=0;d=W(144,d|0,x[f+208>>2],1)|0;i=x[23420];x[23420]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}x[23420]=0;i=T(194,h|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>116){break F}x[23420]=0;W(251,g|0,e|0,1)|0;j=x[23420];x[23420]=0;if((j|0)!=1){break F}e=P()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[23420]=0;U(395,h|0,g|0,q|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}}zb(h);continue}break}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0;break b}e=P()|0}zb(h);S(e|0);p()}b=x[a+8>>2];Eo(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[q|0]=0}if(y[l|0]>=6){v[l|0]=0}xc(r,256);xc(n,65536);xc(o,65536)}hb=f+224|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,A=0;d=hb-1824|0;hb=d;zc(b);e=hb-16|0;hb=e;i=d+1224|0;xR(e+8|0,i);h=x[e+12>>2];j=b;mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);b=x[e+4>>2];if((b|0)==(h|0)){$b(j,x[e+12>>2])}hb=e+16|0;b=(b|0)==(h|0);if(!b){wR(i)}a:{if(!b){break a}if(!yR(d+1224|0)){break a}if(!kA(j,16,0)){break a}x[d+1216>>2]=x[d+1240>>2];b=x[d+1228>>2];x[d+1200>>2]=x[d+1224>>2];x[d+1204>>2]=b;b=d+1232|0;e=x[b+4>>2];x[d+1208>>2]=x[b>>2];x[d+1212>>2]=e;Dd(a,1);Mb(Mb(Cf(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[d+1196>>2]=0;w[a+480190>>1]=15;$c(j,20);k=a+480188|0;f=1;i=1;while(1){b:{if((f|0)==16){b=d+1064|0;GR(j,b);e=a+484360|0;h=a+484376|0;rq(Yb(x[e>>2],y[h|0]),b|2,128);f=0;m=FR(j,Yb(x[e>>2],y[h|0]),y[d+1064|0],g,k,0,1);if(!(y[d+1065|0]|m>>>0>1|y[d+1064|0])){break a}if(df(j)+65536>>>0<(m<<10)+g>>>0){break a}if(c){break b}f=1;break a}e=D(f,104)+a|0;h=e+484380|0;b=((f<<5)+a|0)+946304|0;lA(j,d+24|0,h,b,1);m=x[h>>2];c:{if(!y[Kb(b,0)|0]){break c}d:{if(Ob(b,16592,3)){if(Ob(b,16596,3)){break d}}if(y[Kb(b,5)|0]==58){break c}}i=0}b=Lb(z[d+52>>1]);if(b>>>0>=2){l=b<<1;b=Lb(z[d+50>>1]);x[e+484388>>2]=l+b;x[e+484384>>2]=b;kk(h)}e:{if(Lb(z[d+46>>1])>>>0<=4999){if(Lb(z[d+50>>1])>>>0<1e4){break e}}x[d+1064>>2]=5;u=d,A=x[Le(d+1196|0,d+1064|0)>>2],x[u+1196>>2]=A}g=g+m|0;f=f+1|0;continue}break}f=y[d+1065|0];if(!f){v[d+1065|0]=120;f=120}f:{if(!Ob(d+1200|0,14772,6)){v[d+1065|0]=120;x[a+480204>>2]=125e4;break f}x[a+480204>>2]=125e4;if((f|0)==120){break f}u=a,A=Ie(1773447.5/(+(240-f|0)*122)*1e4),x[u+480204>>2]=A;if(x[d+1196>>2]>=2){x[d+24>>2]=i?4:5;u=d,A=x[Le(d+1196|0,d+24|0)>>2],x[u+1196>>2]=A;break f}x[d+24>>2]=i?1:2;u=d,A=x[Le(d+1196|0,d+24|0)>>2],x[u+1196>>2]=A}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;g=d+1048|0;tj(g,3,d+1200|0);b=d+24|0;Fc(b,g);Ac(a+1298308|0,b);xb(b);wh(a,0);q=x[j+8>>2];r=a+484376|0;while(1){g:{h:{if(m>>>0>(p&65535)>>>0){b=Yb(x[a+484360>>2],y[r|0]);b=Pb(eA(Db(x[b>>2]),Db(x[b+4>>2]),p),Db(x[b+4>>2]));vR(j,d+24|0);if(b){s=iA(d+24|0,0)+s|0;if(s>>>0>512){break h}}k=0;b=0;g=0;i:while(1){if((g|0)==64){break g}f=0;t=dd(d+24|0,g);while(1){e=b;if((f|0)==4){g=g+1|0;continue i}else{o=Cb(t,f);l=y[Kb(o,2)|0]&15;h=y[Kb(o,3)|0];b=0;j:{if(!(e&255)){break j}if(Ob(o,26724,4)){break j}b=e+1|0;if((b&255)>>>0<33){break j}x[d+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:e=x[d+1196>>2];if((e|0)==1&h>>>0>=32){break l}l=(l|0)!=1;if(!(l|!h|h>>>0>2)){x[d+1048>>2]=2;u=d,A=x[Le(d+1196|0,d+1048|0)>>2],x[u+1196>>2]=A;break k}if(l|(h|0)!=55&(h|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:x[d+1196>>2]=6;break k;case 11:case 12:case 13:x[d+1048>>2]=2;u=d,A=x[Le(d+1196|0,d+1048|0)>>2],x[u+1196>>2]=A;if((l|0)!=13){break k}k=((g|h)!=0)+k|0;b=1;break k;case 14:break m;default:break k}}x[d+1048>>2]=3;u=d,A=x[Le(d+1196|0,d+1048|0)>>2],x[u+1196>>2]=A;break k}x[d+1196>>2]=i}f=f+1|0;continue}}}}if(!(x[d+1196>>2]!=6|m+32>>>0>=n>>>0)){x[d+1196>>2]=5}$c(j,q);o=c&1;if(o){lg(a+484344|0,m)}l=a+484344|0;n=0;while(1)if((m|0)==(n|0)){f=21473;b=x[d+1196>>2];if(b>>>0<7){f=x[(b<<2)+26736>>2]}b=d+24|0;g=Vb(b,8222);Gb(a+1298344|0,g);yb(g);b=Vb(b,10648);Gb(a+1298356|0,b);yb(b);xl(a+1298368|0,f);x[a+1298404>>2]=13;if(!(c&2)){break h}f=1;while(1){if((f|0)==16){break h}b=D(f,104)+a|0;c=b+484384|0;$b(j,x[c>>2]);g=x[c>>2];x[c>>2]=0;c=b+484380|0;x[c>>2]=x[c>>2]-g;b=b+484388|0;x[b>>2]=x[b>>2]-g;b=d+24|0;_c(b,8,1,1,0);kg(b,c,j);f=f+1|0;continue}}else{vR(j,d+24|0);n:{if(!o){break n}if(!$g(l,n&65535,64)){break n}i=0;x[d+1048>>2]=0;o:while(1){if((i|0)==64){break n}f=0;b=_b(x[l>>2],n);q=ed(x[b>>2],x[x[b+48>>2]+12>>2],i,0);r=dd(d+24|0,i);while(1)if((f|0)==4){i=i+1|0;continue o}else{b=Cb(r,f);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[d+12>>2]=b;x[d+16>>2]=b;e=q+D(f,6)|0;fu(d+12|0,e);h=y[e+3|0];b=h;p:{q:{r:{g=y[e+5|0];if(g){b=14;if((h|0)!=14){break r}}v[(d+1048|0)+f|0]=0;if((b|g)&255){break q}break p}b=h;k=y[(d+1048|0)+f|0];if(!k){break q}s:{if(k>>>0>=16){v[e+2|0]=3;k=k>>>4|0;break s}v[e+2|0]=4}v[e+4|0]=k}t:{u:{v:{w:{x:{y:{switch((b&255)-12|0){case 1:b=x[d+1196>>2];if((b|0)==6){break u}h=10;v[e+3|0]=10;break v;case 0:g=g&127;break x;case 2:if(g>>>0<=1&x[d+1196>>2]>3){break t}h=10;v[e+3|0]=10;v[(d+1048|0)+f|0]=g;break w;case 3:break y;default:break w}}g=g&15}v[e+5|0]=g}b=x[d+1196>>2]}if((b|0)>1){break t}z:{A:{B:{switch(h|0){case 0:if(g>>>0>2){break A}break;case 2:break z;case 1:break A;default:break B}}v[e+3|0]=0;break p}v[e+3|0]=1;break p}b=g&15;if(b){v[e+3|0]=2;v[e+5|0]=b;break p}if(g>>>0<16){break p}v[e+3|0]=3;v[e+5|0]=g>>>4;break p}v[e+5|0]=0}Of(e)}f=f+1|0;continue}}}n=n+1|0;continue}}f=m>>>0<=(p&65535)>>>0;break a}if((k-1&255)>>>0<2){x[d+1196>>2]=6}p=p+1|0;n=(k&255)+n|0;continue}}hb=d+1824|0;return f|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-352|0;hb=d;$c(b,60);h=15;a:{if(!yh(b,13983)){$c(b,124);h=31;if(!yh(b,15143)){break a}}Dd(a,536870912);w[a+480190>>1]=h;zc(b);b:{while(1){if(z[a+480190>>1]>f>>>0){e=to(b);x[(d+224|0)+(f<<2)>>2]=e;f=f+1|0;if(e>>>0<=131072){continue}break b}break}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;f=0;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;wh(a,1);$b(b,4);e=wq(b);if(e>>>0<178){break a}q=a,r=Ie(1776930/+(e>>>0)*1e4),x[q+480204>>2]=r;$b(b,14);h=0;k=1;c:while(1){n=k&65535;if(n>>>0<=z[a+480190>>1]){BR(b,d+56|0);e=x[((n<<2)+d|0)+220>>2];l=hb-16|0;hb=l;g=(D(n,104)+a|0)+484380|0;pd(g,1);x[g>>2]=e;v[g+37|0]=y[d+80|0]<<4;v[l+15|0]=y[d+81|0];v[l+14|0]=64;q=g,r=y[Wb(l+15|0,l+14|0)|0]<<2,w[q+30>>1]=r;d:{if(!e){break d}f=Lb(y[d+84|0]|y[d+85|0]<<8);j=Lb(y[d+82|0]|y[d+83|0]<<8);x[g+4>>2]=j;f=(f<<1)+j|0;x[g+8>>2]=f;if(e>>>0<=j>>>0){j=e-1|0;x[g+4>>2]=j}if(e>>>0<f>>>0){x[g+8>>2]=e;f=e}if(!(!(f>>>0<4|f>>>0<j>>>0)&f-j>>>0>3)){x[g+4>>2]=0;x[g+8>>2]=0;break d}if(f>>>0<=j>>>0){break d}w[g+34>>1]=z[g+34>>1]|2}hb=l+16|0;f=0;while(1)if((f|0)==22){if(h>>>0>127){break b}e=d+192|0;ml(e,3,d+56|0);f=d+208|0;Fc(f,e);Dc(((n<<5)+a|0)+946304|0,f);k=k+1|0;xb(f);continue c}else{e=(d+56|0)+f|0;if((y[e|0]-1&255)>>>0<=30){v[e|0]=32;h=h+1|0}f=f+1|0;continue}}break}j=1;e:{f:{g:{h=a+946336|0;f=Vb(d+56|0,13850);if(!vQ(h,f)){x[23420]=0;e=Q(54,d+208|0,13861)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}j=vQ(h,e);xb(e)}xb(f);f=0;e=d+56|0;h=AR(b,e);if(!h){gA(e)}if(!h){break a}e=y[d+56|0];if(!yQ(e)){break a}if(!c){break e}w[d+54>>1]=0;while(1)if((e|0)==(f|0)){f=a+484360|0;h=a+484376|0;i=Yb(x[f>>2],y[h|0]);g=y[d+57|0];Ze(i,e>>>0>g>>>0?g:0);rq(Yb(x[f>>2],y[h|0]),d+56|2,y[d+56|0]);if(z[a+480190>>1]==31){$b(b,4)}x[d+48>>2]=0;x[d+44>>2]=0;x[d+40>>2]=0;v[d+39|0]=0;n=c&1;if(n){lg(a+484344|0,z[d+54>>1])}l=a+484344|0;k=0;while(1){h:{i:{j:{if(z[d+54>>1]<=k>>>0){if(!(c&2)){break j}f=1;while(1){h=z[a+480190>>1];c=f&65535;if(h>>>0<c>>>0){break i}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){kg(_c(d+192|0,8,1,0,0),c,b)}f=f+1|0;continue}}k:{if(n){h=0;if($g(l,k&65535,64)){break k}}$b(b,1024);break h}l:while(1){if((h|0)==64){break h}f=0;e=_b(x[l>>2],k);o=ed(x[e>>2],x[x[e+48>>2]+12>>2],h,0);while(1)if((f|0)==4){h=h+1|0;continue l}else{g=d+192|0;Am(g,b);e=D(f,6)+o|0;m:{n:{o:{p:{if(y[Kb(g,0)|0]!=255){break p}v[(d+48|0)+f|0]=0;v[(d+40|0)+f|0]=0;g=Kb(d+192|0,1);i=y[g|0];if((i|0)==252&j){v[g|0]=254;break n}switch(i-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}g=x[d+192>>2];x[d+32>>2]=g;x[d+12>>2]=g;fu(d+12|0,e);g=y[e|0];q:{if(!g){break q}v[(d+40|0)+f|0]=0;v[(d+48|0)+f|0]=g;if(g>>>0>48){break q}v[d+16|0]=8;q=d,r=y[_e(d+39|0,d+16|0)|0],v[q+39|0]=r}r:{s:{t:{u:{v:{w:{switch(y[e+3|0]){case 1:v[e+3|0]=1;break m;case 2:g=y[e+5|0];if(g>>>0>=16){v[e+3|0]=3;v[e+5|0]=g>>>4;break m}if(g){v[e+3|0]=2;v[e+5|0]=g;break m}v[e+5|0]=0;break s;case 3:if(y[(d+40|0)+f|0]){break t}v[e+3|0]=19;v[e+5|0]=0;break m;case 4:if(y[(d+40|0)+f|0]){break t}v[e+3|0]=19;v[e+5|0]=1;break m;case 5:if(!y[e+1|0]){break t}v[e+3|0]=13;v[d+16|0]=63;v[d+31|0]=y[e+5|0]+(z[(D(y[e+1|0],104)+a|0)+484410>>1]>>>2|0);q=e,r=y[Wb(d+16|0,d+31|0)|0],v[q+5|0]=r;if(!y[(d+40|0)+f|0]){break v}v[e+2|0]=1;v[e+4|0]=y[e+5|0];v[e+5|0]=0;break s;case 6:g=y[e+1|0];if(!g){break t}v[e+3|0]=13;g=z[(D(g,104)+a|0)+484410>>1]>>>2|0;i=y[e+5|0];g=g>>>0>=i>>>0?g-i|0:0;v[e+5|0]=g;if(!y[(d+40|0)+f|0]){break m}v[e+4|0]=g;v[e+2|0]=1;v[e+5|0]=0;break s;case 7:g=y[(d+48|0)+f|0];i=y[e+5|0];m=g-(i>>>4|0)|0;v[(d+44|0)+f|0]=m;v[e+3|0]=3;i=i&15;v[(d+40|0)+f|0]=i;q=e,r=uQ(i,m&255,g),v[q+5|0]=r;break m;case 8:i=y[(d+48|0)+f|0];g=y[e+5|0];m=i+(g>>>4|0)|0;v[(d+44|0)+f|0]=m;v[e+3|0]=2;g=g&15;v[(d+40|0)+f|0]=g;q=e,r=uQ(g,i,m&255),v[q+5|0]=r;break m;case 0:break u;case 9:break w;default:break s}}v[d+16|0]=8;q=d,r=y[_e(d+39|0,d+16|0)|0],v[q+39|0]=r;break s}if(!y[e+3|0]){break r}break m}if(!y[e+5|0]){break r}break s}v[e+5|0]=0}v[e+3|0]=0}i=y[(d+40|0)+f|0];if(!i){break m}m=(d+44|0)+f|0;g=y[m|0];if(g){v[(d+48|0)+f|0]=g;v[e|0]=g;v[e+5|0]=i;v[m|0]=0}v[e+3|0]=4;break m}v[e+3|0]=14;v[d+39|0]=9;break m}v[e+3|0]=13}f=f+1|0;continue}}}h=z[a+480190>>1]}x:{y:{if((h&65535)==15){b=d+16|0;rg(b,4379);x[23420]=0;U(291,d+192|0,b|0,d+39|0);b=x[23420];x[23420]=0;if((b|0)!=1){break y}h=P()|0;cc(d+16|0);break f}x[23420]=0;Q(1,d+192|0,12180)|0;b=x[23420];x[23420]=0;if((b|0)==1){break x}}b=d+192|0;Gb(a+1298344|0,b);yb(b);if((h&65535)==15){cc(d+16|0)}xl(a+1298356|0,z[a+480190>>1]==15?5243:14960);x[a+1298404>>2]=13;break e}h=P()|0;break f}k=k+1|0;continue}}else{w[d+192>>1]=y[(d+f|0)+58|0]+1;q=d,r=z[Ve(d+54|0,d+192|0)>>1],w[q+54>>1]=r;f=f+1|0;continue}}h=P()|0;xb(f)}S(h|0);p()}f=1;break a}f=0}hb=d+352|0;return f|0}function aI(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=hb-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+70112>>2]);h=E(E(m-z)*B[g+70116>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+70120>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=pc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=hb-32|0;hb=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;as(y,d,o+244|0);f=d<<6;as(f+y|0,d,o+500|0);as(x,d,o+240|0);as(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=70208;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=aj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=aj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=aj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=aj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=aj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=aj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=aj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=aj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}hb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}pc(a,C+(b<<2)|0,3840)}}function Xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;f=hb-256|0;hb=f;zc(b);a:{if(!lU(b,f+184|0)){break a}if(!iR(f+184|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(hR(f+184|0),lb))){break a}b:{if(!c){break b}Dd(a,16);e=f+24|0;tj(e,2,f+184|4);d=f+48|0;Fc(d,e);Ac(a+1298308|0,d);xb(d);m=a+480190|0;w[m>>1]=y[f+214|0];w[a+480188>>1]=y[f+217|0];h=Vb(d,8283);Gb(a+1298344|0,h);yb(h);h=Vb(d,10021);Gb(a+1298356|0,h);yb(h);rg(e,4172);h=y[f+187|0];x[f>>2]=h>>>4;x[23420]=0;x[f+176>>2]=h&15;X(288,d|0,e|0,f|0,f+176|0);d=x[23420];x[23420]=0;c:{d:{if((d|0)!=1){d=f+48|0;Gb(a+1298368|0,d);yb(d);cc(f+24|0);x[a+1298404>>2]=5;g=1;while(1){l=g&65535;if(l>>>0>z[m>>1]){g=0;d=a+480188|0;while(1)if(z[d>>1]<=g>>>0){e=f+48|0;d=hb-16|0;hb=d;l=b;e:{if(!Nb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){ug(b+e|0);b=b+1|0;continue}break}break e}DS(d+8|0,e);qd(d,l,x[d+8>>2],x[d+12>>2])}hb=d+16|0;Tu(Yb(x[a+484360>>2],y[a+484376|0]),e,y[f+211|0]+1|0);b=y[f+216|0];Xd(f,l,D(z[f+208>>1],192));m=jc(f+24|0,f);zb(f);f:{r=c&1;if(!r){break f}x[23420]=0;R(213,a+484344|0,y[f+210|0]+1|0);d=x[23420];x[23420]=0;if((d|0)!=1){break f}break d}o=b?b:64;q=a+484344|0;s=a+480188|0;b=0;while(1){g:{h:{i:{if(y[f+210|0]<k>>>0){if(!(b&u)){break h}B=f,C=Db(x[a+484344>>2]),x[B>>2]=C;i=Db(x[a+484348>>2]);j=z[a+480188>>1];break i}j:{if(r){x[23420]=0;d=W(214,q|0,k&65535,o|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}n=0;if(d){break j}}x[23420]=0;Q(176,l|0,64)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break g}break d}while(1){e=n&65535;if(e>>>0>31){break g}x[23420]=0;d=T(182,l|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}k:{if(!d|d>>>0>z[f+208>>1]|e>>>0>=z[s>>1]){break k}x[23420]=0;Q(143,m|0,D(d,192)-192|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break d}d=0;h=_b(x[q>>2],k);g=ed(x[h>>2],x[x[h+48>>2]+12>>2],0,e);while(1){if((d|0)==(o|0)){break k}i=b;x[23420]=0;R(484,f|0,m|0);b=x[23420];x[23420]=0;if((b|0)!=1){j=jd(f);e=Ue(f);b=y[f|0];if(b>>>0>=4){v[g|0]=(b>>>2|0)+37;b=y[f|0]}v[g+1|0]=b<<4&48|y[j|0]>>>4;b=y[e|0];h=0;e=0;l:{m:{n:{o:{p:{q:{r:{j=y[j|0]&15;switch(j-8|0){case 2:break o;case 0:break p;case 6:break r;default:break q}}j=14;t=((b&240)+16&240)>>>4|0;if(t>>>0>8){break n}if(1<<t&435){break p}break n}h=j;e=b}j=h;b=e;if((h|e)&255){break n}break m}b=(b&240?-16:15)&b;j=10}v[g+5|0]=b;v[g+3|0]=j;Of(g);b=1;s:{switch(y[g+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}u=1}b=i}d=d+1|0;g=D(z[s>>1],6)+g|0;continue}break}break d}n=n+1|0;continue}}while(1){t:{b=x[f>>2];if(Pb(b,i)){k=x[b+48>>2];n=x[b+12>>2];o=x[b>>2];e=0;u:while(1){if((e|0)==(n|0)){break t}g=0;q=pf(o,x[k+12>>2],e);d=0;h=0;while(1)if((g|0)==(j|0)){e=e+1|0;if(!(d&h&1)){continue u}break h}else{b=1;v:{switch(y[(q+D(g,6)|0)+3|0]-16|0){case 1:h=1;default:b=d;break;case 0:break v}}g=g+1|0;d=b;continue}}}B=f,C=Db(x[a+484344>>2]),x[B+176>>2]=C;d=Db(x[a+484348>>2]);h=a+480188|0;w:while(1){b=x[f+176>>2];if(!Pb(b,d)){break h}e=0;while(1)if(A[b+12>>2]<=e>>>0){Gt(f+176|0);continue w}else{i=pf(x[b>>2],x[x[b+48>>2]+12>>2],e);j=z[h>>1];g=0;x:{while(1){if((g|0)==(j|0)){break x}k=D(g,6);g=g+1|0;k=y[(i+k|0)+3|0];if((k&254)!=16){continue}break}i=(k|0)==16;ie(b,Fe(ye(f,i?17:16,i?125:6),e))}e=e+1|0;continue}}}Gt(f);continue}}y:{b=z[f+212>>1];if(!b){break y}x[23420]=0;ea(299,a+1298332|0,l|0,b|0,39,1);b=x[23420];x[23420]=0;if((b|0)!=1){break y}break d}z:{if(!(c&2)){break z}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>z[b>>1]){break z}c=D(c,104)+a|0;d=_c(f,w[c+484414>>1]&1?16:8,1,0,1);x[23420]=0;W(207,d|0,c+484380|0,l|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;zb(m);break b}k=k+1|0;continue}}else{e=(g<<5)+a|0;Te(e+480280|0);w[e+480284>>1]=(y[(f+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{e=f+48|0;uC(b,e);i=hb-16|0;hb=i;d=(D(l,104)+a|0)+484380|0;pd(d,0);w[i+14>>1]=y[e+35|0]<<2;w[i+12>>1]=256;B=d,C=z[Zc(i+14|0,i+12|0)>>1],w[B+30>>1]=C;h=y[e+22|0]|y[e+23|0]<<8|(y[e+24|0]<<16|y[e+25|0]<<24);A:{if(h>>>0<3){break A}x[d>>2]=h;x[d+4>>2]=y[e+26|0]|y[e+27|0]<<8|(y[e+28|0]<<16|y[e+29|0]<<24);x[i+8>>2]=y[e+30|0]|y[e+31|0]<<8|(y[e+32|0]<<16|y[e+33|0]<<24);x[i+4>>2]=1;B=d,C=x[Yc(i+8|0,i+4|0)>>2]-1|0,x[B+8>>2]=C;xc(d+8|0,h);h=x[d+8>>2];j=x[d+4>>2];B:{if(h>>>0<=j+4>>>0){x[d+4>>2]=0;x[d+8>>2]=0;h=0;j=0;break B}if(h>>>0<3){break B}w[d+34>>1]=z[d+34>>1]|2}v[d+37|0]=y[e+34|0];B=d,C=Iu(0,v[e+34|0]<<4),x[B+24>>2]=C;if(!(v[e+36|0]&1)){break A}x[d+8>>2]=h>>>1;x[d+4>>2]=j>>>1;w[d+34>>1]=z[d+34>>1]|1;x[d>>2]=x[d>>2]>>>1}hb=i+16|0;ml(f,2,e);d=f+24|0;Fc(d,f);Dc(((l<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);continue}}}g=P()|0;cc(f+24|0);break c}g=P()|0;zb(m)}S(g|0);p()}g=1}hb=f+256|0;return g|0}function pda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;i=hb-208|0;hb=i;zc(b);a:{if(!cB(b,i+160|0)){break a}if(!DP(i+160|0)){break a}b:{if(!c){break b}if(!Nb(x[b>>2],x[b+8>>2],Vc(CP(y[i+207|0]),lb))){break a}Dd(a,128);e=i+144|0;Ye(e,2,i+175|0);d=i+72|0;Fc(d,e);Ac(a+1298308|0,d);xb(d);h=Vb(d,8371);Gb(a+1298344|0,h);yb(h);h=Vb(d,6017);Gb(a+1298356|0,h);yb(h);h=Vb(e,17359);x[23420]=0;U(677,d|0,h|0,x[(y[i+174|0]<<2)+26700>>2]);d=x[23420];x[23420]=0;c:{if((d|0)!=1){d=i+72|0;Gb(a+1298368|0,d);yb(d);yb(h);x[a+480208>>2]=12;x[a+1298404>>2]=5;uB(a+1298332|0,b,y[i+207|0]<<5,32,0);n=a+480190|0;e=Ee(b);w[n>>1]=e;h=1;while(1){m=h&65535;if(m>>>0>(e&65535)>>>0){no(Yb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);h=0;d=Ee(b);if(d>>>0>=127){break a}e=a+480188|0;w[e>>1]=d+1;d=Ee(b);while(1)if(z[e>>1]<=h>>>0){n=a+484344|0;r=d+1|0;lg(n,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){l=0;s=a+480188|0;e:while(1){t=l&65535;e=z[s>>1];if(t>>>0>=e>>>0){d=ao(i+8|0);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=e;x[23420]=0;R(679,d|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){a=P()|0;Je(d);S(a|0);p()}x[23420]=0;U(678,i+32|0,n|0,d|0);e=x[23420];x[23420]=0;h=1;if((e|0)==1){break d}Je(i+32|0);Je(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>z[c>>1]){break b}d=D(d,104)+a|0;kg(_c(i+72|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}m=0;f=Sh(i+72|0);f:while(1){g:{if((m|0)!=(r|0)){if(Nb(x[b>>2],x[b+8>>2],5)){break g}}l=l+1|0;continue e}e=0;d=_b(x[n>>2],m);h=ed(x[d>>2],x[x[d+48>>2]+12>>2],0,t);while(1){h:{i:{if(e>>>0>63){break i}j=y[i+174|0];d=hb-16|0;hb=d;q=1;g=Ee(b);if((g|0)==252){q=Ee(b);g=Ee(b)}v[f|0]=(g-1&255)>>>0<60?g+36|0:0;g=d+8|0;Am(g,b);v[f+1|0]=y[d+8|0];k=y[jd(g)|0];v[d+7|0]=k&15;v[d+6|0]=k>>>4;u=d,A=y[Ue(g)|0],v[u+5|0]=A;u=d,A=y[Bi(g)|0],v[u+4|0]=A;AP(d+7|0,d+5|0,j);AP(d+6|0,d+4|0,j);j=y[d+7|0];k=(j|0)!=10;g=y[d+6|0];j:{if(!(k|(g|0)!=10)){j=y[d+5|0];g=y[d+4|0];v[f+3|0]=10;j=j|g<<8;v[f+5|0]=j>>>6;if(j>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=g>>>6;break j}k:{l:{m:{n:{if(!k){k=y[d+5|0];o=k<<2;u=d,A=Cm(o),v[u+5|0]=A;if(k>>>0<64){break n}if(Ai(g)>>>0>=Ez(10)>>>0){break n}v[f+5|0]=o;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=k>>>6;break j}if((g|0)==10){g=y[d+4|0];k=g<<2;u=d,A=Cm(k),v[u+4|0]=A;if(g>>>0<64){break k}if(Ai(j)>>>0>=Ez(10)>>>0){break k}v[f+5|0]=k;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=g>>>6;break j}if((g|0)!=(j|0)){break n}g=0;v[d+6|0]=0;break m}if((g|0)==13){break l}}if((j|0)==13|g){break k}}uh(d+7|0,d+6|0);uh(d+5|0,d+4|0)}g=d+6|0;j=d+4|0;k=d+7|0;o=d+5|0;Fu(g,j,k,o);vq(d,k,o,g,j);v[f+2|0]=y[d+7|0];v[f+4|0]=y[d+5|0];v[f+3|0]=y[d+6|0];v[f+5|0]=y[d+4|0]}hb=d+16|0;g=e+q|0;e=g>>>0>64?64-e|0:q;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[h|0]=d;v[h+1|0]=d>>>8;v[h+2|0]=d>>>16;v[h+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[h+4|0]=d;v[h+5|0]=d>>>8;e=e-1|0;h=D(z[s>>1],6)+h|0;continue}}m=m+1|0;continue f}e=g>>>0>=64?64:g;continue}}}}e=e+1|0;h=0;if($g(n,f,64)){continue}break a}break}e=P()|0;Je(d);break c}else{f=(h<<5)+a|0;Te(f+480280|0);g=f+480284|0;o:{if(y[i+174|0]>=51){f=(Ee(b)<<4|8)&248;break o}f=h&1?192:64}w[g>>1]=f;h=h+1|0;continue}}else{p:{if(y[i+174|0]>=52){d=i+72|0;if(!TT(b,d)){wB(d)}break p}d=hb-32|0;hb=d;x[d+28>>2]=64;x[d+8>>2]=66;f=x[b>>2];g=x[b+8>>2];e=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(f,g,e)){e=df(b)}g=d+8|0;l=i+72|0;nu(g,l);f=fc(d+16|0,x[d+8>>2],e);mc(d,x[b>>2],x[b+8>>2],x[f>>2],x[f+4>>2]);nu(g,l);Tb(x[d+8>>2]+e|0,0,66-e|0);$b(b,x[d+28>>2]);hb=d+32|0;w[i+136>>1]=z[i+134>>1];w[i+134>>1]=8363}g=hb-32|0;hb=g;f=(D(m,104)+a|0)+484380|0;pd(f,0);nB(f);d=i+72|0;dk(g,2,d+32|0);e=g+16|0;Fc(e,g);ze(f+43|0,e);xb(e);e=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);l=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);q:{if(e>>>0<=l>>>0){break q}x[f>>2]=e-l;x[f+12>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[g+16>>2]=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);u=f,A=x[Hb(g+16|0,f)>>2],x[u+16>>2]=A;w[f+30>>1]=y[d+60|0];x[f+24>>2]=y[d+62|0]|y[d+63|0]<<8;e=y[d+64|0]|y[d+65|0]<<8;if(e){gq(f,+(e<<16>>16)/393216)}e=y[d+61|0];if(e&8){w[f+34>>1]=z[f+34>>1]|8;e=y[d+61|0]}if(e&16){w[f+34>>1]=z[f+34>>1]|16;e=y[d+61|0]}if(!(e&4)){break q}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}hb=g+32|0;e=i+56|0;Ye(e,2,d);d=i+144|0;Fc(d,e);Dc(((m<<5)+a|0)+946304|0,d);h=h+1|0;xb(d);e=z[n>>1];continue}}}e=P()|0;yb(h)}S(e|0);p()}h=1}hb=i+208|0;return h|0}function QM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=hb-16|0;hb=g;a:{if(!Uc(d&255)){break a}n=a+1074376|0;j=(n+D(b,872)|0)+616|0;b:{h=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!h|e)){break b}if(Rj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;h=e+1075012|0;e=e+1075016|0;if(!(x[h>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!wd(c)){break c}ij(c,b,0);break a}c=Gy(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;yp(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;eo(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[h>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;m=x[e+1075096>>2];c=c>>>0<=h>>>0?c:0;h=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!h){break d}k=d-1|0;c=z[bc(h+236|0,k)>>1];f=a+1074312|0;Ab(g+8|0,f,104);e:{if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){Ab(g,f,34);if(Bb(x[x[g>>2]>>2],x[g+4>>2])){break e}}d=y[Kb(h+108|0,k)|0]}if((c-1&65535)>>>0<=3998){m=(D(c,104)+a|0)+484380|0;break d}Ab(g+8|0,f,43);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break d}if(!mj(y[h+31|0])){break a}}if(y[e+1075081|0]&4){break a}p=b>>>0<=256?256:b;k=a+1074312|0;q=b+1|0;r=a+480188|0;c=b;f:{while(1){if((c|0)==(p|0)){g:{e=0;c=0;if(!Rj(x[j+656>>2])){break f}c=0;if(!Uc(y[(D(b,872)+a|0)+1075789|0])){break f}d=ul(a,n,b,2,1);c=0;if((d-1&255)>>>0>249){break f}e=x[(D(d,160)+a|0)+906140>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&z[r>>1]>c>>>0){break h}e=D(c,872)+a|0;if(z[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break h}o=e+1075648|0;f=x[o>>2];if(!f){break h}l=e+1074992|0;i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=y[e+1075789|0]==(d|0)&(f|0)==(h|0);if(!h){break n}if(i){break k}break h;case 1:if(!m|x[e+1075096>>2]!=(m|0)){break h}if((f|0)==(h|0)){break i}Ab(g+8|0,k,104);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(h){break l}i=(f|0)==(h|0)}if(i){break i}break h}if(!h){break h}i=y[h+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(h|0)){break h}}if(!y[h+34|0]){break i}}i=e+1075789|0;if(!y[i|0]|y[f+18|0]>2){break i}Ab(g+8|0,k,34);f=jP(l,Bb(x[x[g+8>>2]>>2],x[g+12>>2]));if(!f){break i}Xl(a,c&65535,f+255|0,0);v[e+1075792|0]=0;v[i|0]=0}p:{q:{switch(y[x[o>>2]+18|0]){case 0:Pn(a,l);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!wd(f)){break p}ij(f,c&65535,1);break p;case 1:Pn(a,l);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!wd(f)){break p}Tj(f,c&65535);break p;case 2:break q;default:break p}}l=e+1075080|0;f=x[l>>2];x[l>>2]=f|4096;if(!(f&512)){break p}if(!wd(x[a+1298300>>2])){break p}Ab(g+8|0,k,105);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break p}Tj(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}Ab(g+8|0,k,34);d=jP(j,Bb(x[x[g+8>>2]>>2],x[g+12>>2]));c=0;if(!d){break f}c=mb[x[x[e>>2]+100>>2]](e,d,b)|0}if(!(pi(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!(c&(e|0)!=0)){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Xl(a,b,255,0);v[(D(b,872)+a|0)+1075792|0]=0}c=Gy(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;h=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!wd(e)){break s}ij(e,c,1)}m=yp(h,j);e=x[d>>2];h=e&-917505;x[d>>2]=h;l=a+1074992|0;f=l+f|0;v[f+831|0]=0;i=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<i>>>0?b+1|0:0;t:{u:{switch(y[(l+D(b,872)|0)+798|0]){case 2:Pn(a,m);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!wd(e)){break t}Tj(e,b);Ab(g+8|0,k,105);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break t}nz(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=h|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!wd(e)){break t}ij(e,b,1);break t;case 3:x[d>>2]=h|4096;if(!(e&512)){break t}if(!wd(x[a+1298300>>2])){break t}Ab(g+8|0,k,105);e=x[a+1298300>>2];if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){nz(e,b,c);break t}Tj(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!wd(e)){break t}nz(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}hb=g+16|0}function Ed(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=hb-96|0;hb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;v=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=G(h?b:d)+32|0;b=G(h?c:p);b=i+((b|0)==32?l:b)|0;wf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=x[k+88>>2];v=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=G(e?f:t)+32|0;e=G(e?g:u);e=h+((e|0)==32?i:e)|0;wf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;A=Wia(p,0,c,0);c=lb;y=c;B=e;i=0;j=Wia(e,0,b,i);e=j+A|0;h=lb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=Wia(b,i,p,i);l=0+n|0;e=lb+e|0;e=l>>>0<n>>>0?e+1|0:e;z=l;n=l;l=e;C=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=Wia(p,i,d,0);H=lb;e=Wia(q,i,B,i);d=e+M|0;j=lb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;D=e<<15|g>>>17;g=Wia(D,0,b,i);e=g+n|0;f=lb+d|0;I=e;f=e>>>0<g>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(y|0)&c>>>0<A>>>0|h>>>0<y>>>0;c=h+I|0;f=e+f|0;A=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;E=v|65536;v=w;N=Wia(p,i,E,w);J=lb;g=Wia(r,o,B,i);f=g+N|0;e=lb+J|0;O=f;e=f>>>0<g>>>0?e+1|0:e;w=e;F=j|-2147483648;y=0;g=Wia(F,y,b,i);b=g+f|0;f=lb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=Wia(D,o,q,i);b=b+e|0;p=f;j=f+lb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+A|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+C|0;C=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=Wia(F,y,q,i);h=lb;i=Wia(E,v,B,i);e=i+j|0;f=lb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=Wia(D,o,r,o);e=i+e|0;j=lb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=Wia(F,y,E,v);i=q+f|0;f=lb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;B=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=B+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=Wia(D,o,E,v);e=lb;r=Wia(F,y,r,o);d=r+j|0;f=lb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;v=d+q|0;e=f+h|0;e=v>>>0<d>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+v|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(C|0)&A>>>0>R>>>0|t>>>0>C>>>0;d=i+((t|0)==(u|0)&A>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=z;f=l<<1|g>>>31;z=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;wf(k+48|0,z,l,b,c,g);wf(k+32|0,d,e,h,i,g);Wl(k+16|0,z,l,b,c,f);Wl(k,d,e,h,i,f);z=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;l=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];f=x[k+8>>2];g=x[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|z):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|z|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=o;x[a+12>>2]=m;hb=k+96|0}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-144|0;hb=d;zc(c);a:{b:{c:{d:{if(!oo(c,d+128|0)){break d}if(Ob(d+128|0,13662,4)){break d}k=d+136|0;e:{if(!Ob(k,13360,4)){break e}if(!Ob(k,13418,4)){break e}if(Ob(k,14093,4)){break d}}j=hb-32|0;hb=j;g=Qb(d+112|0);f:{g:{h:{i:{j:{while(1){f=x[c+8>>2];e=x[c>>2];x[23420]=0;f=W(144,e|0,f|0,8)|0;e=x[23420];x[23420]=0;if((e|0)==1){break h}if(!f){break i}x[23420]=0;R(746,j|0,c|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;R(747,g|0,j|0);e=x[23420];x[23420]=0;if((e|0)==1){break j}Md(j);continue}break}a=P()|0;break g}a=P()|0;Md(j);break g}hb=j+32|0;break f}a=P()|0}_d(g);S(a|0);p()}x[23420]=0;j=T(162,d+88|0)|0;c=x[23420];x[23420]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=_c(d+80|0,8,1,1,0);if(Ob(k,14093,4)){break t}x[23420]=0;U(664,d+56|0,d+112|0,1296581714);c=x[23420];x[23420]=0;if((c|0)==1){break q}x[23420]=0;U(664,d+32|0,d+112|0,1296318804);c=x[23420];x[23420]=0;if((c|0)==1){break c}c=d+32|0;f=bd(j,c);zb(c);c=0;x[23420]=0;i=T(665,d+56|0)|0;e=x[23420];x[23420]=0;h=1;if((e|0)==1){break c}if(!i){break u}e=x[f>>2];x[23420]=0;i=T(166,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}if(!i){break u}x[23420]=0;m=T(266,d+56|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}x[23420]=0;g=T(258,d+56|0)|0;c=x[23420];x[23420]=0;w:{if((c|0)==1){break w}x[23420]=0;Q(176,d+56|0,2)|0;c=x[23420];x[23420]=0;if((c|0)==1){break w}x[23420]=0;c=T(266,d+56|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break v}}break c}h=P()|0;break a}x[23420]=0;R(580,d+32|0,d+56|0);e=x[23420];x[23420]=0;if((e|0)==1){break c}e=Lb(z[d+32>>1]);if(!e){break u}c=(c>>>0)/(e>>>0)|0;e=d+32|0;f=ic(e);i=Ue(e);e=Lb(y[f|0]|y[f+1|0]<<8);if((e|0)!=(Lb(y[i|0]|y[i+1|0]<<8)+1|0)){break u}if((e|0)==2){yo(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Lb(y[d+38|0]|y[d+39|0]<<8)|0){case 0:Rf(l,1);break x;case 2:Rf(l,17);break x;case 3:break y;default:break u}}Rf(l,16);break x}if(Lb(y[d+38|0]|y[d+39|0]<<8)){break u}Dh(l,16)}h=0}zb(d+56|0);if(!h){break s}h=0;break k}x[23420]=0;U(664,d+56|0,d+112|0,1447576658);c=x[23420];x[23420]=0;z:{A:{if((c|0)!=1){x[23420]=0;U(664,d+32|0,d+112|0,1128808782);c=x[23420];x[23420]=0;if((c|0)==1){break A}x[23420]=0;U(664,d+8|0,d+112|0,1112491097);c=x[23420];x[23420]=0;if((c|0)==1){break m}c=d+8|0;g=bd(j,c);zb(c);c=x[g>>2];x[23420]=0;f=T(166,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!f){break B}x[23420]=0;f=T(166,x[d+56>>2])|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}x[23420]=0;f=Q(666,d+56|0,d+8|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}m=Ob(k,13360,4);x[23420]=0;k=T(266,d+32|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break m}if(m){q=l,r=x[_c(d,16,1,0,0)>>2],x[q>>2]=r}if((k|0)==6){yo(l,3)}c=x[g>>2];x[23420]=0;n=x[d+24>>2];g=z[d+20>>1];o=x[d+12>>2];f=x[d+8>>2];e=T(148,c|0)|0;c=x[23420];x[23420]=0;i=1;if((c|0)==1){break m}c=e;e=D((k|0)==6?2:1,m?2:1);m=(c>>>0)/(e>>>0)|0;n=ac(n);c=Lb(g);o=(ac(o)>>>0)/(e>>>0)|0;e=(ac(f)>>>0)/(e>>>0)|0}zb(d+32|0);zb(d+56|0);if(i){break r}break k}h=P()|0;break b}h=P()|0;break l}break m}e=0}ct(a,b);x[23420]=0;f=D(b,104)+a|0;g=f+484380|0;R(264,g|0,0);i=x[23420];x[23420]=0;if((i|0)==1){break p}x[g>>2]=m;i=e+o|0;x[f+484388>>2]=i;x[f+484384>>2]=e;if(!(i>>>0<=e+4>>>0|i>>>0>m>>>0)){e=(D(b,104)+a|0)+484414|0;w[e>>1]=z[e>>1]|2}e=D(b,104)+a|0;x[e+484404>>2]=c?c:22050;c=n>>>8|0;w[e+484410>>1]=(n&16776960)>>>0>65536?256:c&65535?c:256;yz(g,x[a+480180>>2]);x[23420]=0;U(664,d+56|0,d+112|0,1312902469);c=x[23420];x[23420]=0;if((c|0)==1){break o}x[23420]=0;e=T(166,x[d+56>>2])|0;c=x[23420];x[23420]=0;if((c|0)==1){break n}C:{D:{if(e){x[23420]=0;e=T(148,x[d+56>>2])|0;c=x[23420];x[23420]=0;if((c|0)==1){break n}x[23420]=0;U(311,d+56|0,((b<<5)+a|0)+946304|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break D}break n}x[23420]=0;e=Q(54,d+32|0,21473)|0;c=x[23420];x[23420]=0;if((c|0)==1){break C}Dc(((b<<5)+a|0)+946304|0,e);xb(e)}x[23420]=0;W(207,l|0,g|0,j|0)|0;b=x[23420];x[23420]=0;h=1;if((b|0)==1){break n}lj(g,a);zb(d+56|0);break k}break n}h=P()|0;break b}h=P()|0;break b}h=P()|0;break b}h=P()|0;zb(d+56|0);break b}h=P()|0;zb(d+32|0)}zb(d+56|0);break b}zb(j);_d(d+112|0)}hb=d+144|0;return h|0}h=P()|0;zb(d+56|0)}zb(j)}_d(d+112|0);S(h|0);p()}function Pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=hb-144|0;hb=g;zc(b);a:{b:{c:{d:{e:{if(!bR(b,13979)){break e}k=Qb(g+128|0);j=Qb(g+112|0);x[23420]=0;x[g+104>>2]=0;x[g+108>>2]=0;R(234,a|0,32768);d=x[23420];x[23420]=0;if((d|0)==1){break b}x[23420]=0;d=Q(1,g+88|0,8087)|0;i=x[23420];x[23420]=0;if((i|0)==1){break c}Gb(a+1298344|0,d);yb(d);x[23420]=0;d=Q(1,g+72|0,6021)|0;i=x[23420];x[23420]=0;if((i|0)==1){break d}Gb(a+1298356|0,d);yb(d);x[a+1298404>>2]=13;m=a+484376|0;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[23420]=0;d=W(144,f|0,d|0,8)|0;f=x[23420];x[23420]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[23420]=0;d=Q(579,b|0,g- -64|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[23420]=0;U(178,g+16|0,b|0,ac(d)|0);d=x[23420];x[23420]=0;if((d|0)==1){break l}d=g+16|0;f=jc(g+40|0,d);zb(d);d=x[f>>2];x[23420]=0;d=T(166,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}if(d){break k}zb(f)}if(z[a+480188>>1]){break i}i=0;break g}a=P()|0;break a}a=P()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=ac(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[23420]=0;d=T(148,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[23420]=0;R(580,g+16|0,f|0);e=x[23420];x[23420]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=z[a+480188>>1];h=bc(g+16|0,d);v:{if(!Lb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Kb(h,e),q=1,v[o|0]=q;o=Kb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;Te(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Te(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[23420]=0;R(581,f|0,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[23420]=0;d=T(148,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23420]=0;d=T(258,f|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}o=a,q=Wd(d,1,255),x[o+480196>>2]=q;break f}d=x[f>>2];x[23420]=0;d=T(148,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[23420]=0;n=T(258,f|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break f}break j}d=y[m|0];e=x[a+484360>>2];h=x[f>>2];x[23420]=0;h=T(148,h|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break j}x[23420]=0;ea(326,Yb(e,d)|0,f|0,h|0,255,254);d=x[23420];x[23420]=0;if((d|0)==1){break j}break f}d=k;if(Ff(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Ff(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[23420]=0;e=T(148,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[23420]=0;R(582,d|0,f|0);d=x[23420];x[23420]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}zb(f);break g}a=P()|0;zb(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=y[a+484376|0];d=x[a+484360>>2];x[23420]=0;R(310,Yb(d,b)|0,n&65535);b=x[23420];x[23420]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[23420]=0;R(213,a+484344|0,Ff(i,b)&65535);b=x[23420];x[23420]=0;if((b|0)==1){break b}while(1){f=x[k>>2];b=d&65535;if(Ff(f,x[k+4>>2])>>>0<=b>>>0){break w}x[23420]=0;i=x[g+108>>2];e=x[g+104>>2];x[g+8>>2]=e;x[g+12>>2]=i;x[g>>2]=e;x[g+4>>2]=i;X(583,Bg(f,b)|0,b|0,a|0,g|0);b=x[23420];x[23420]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Ff(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;zo(c);x:{if(x[c>>2]){e=x[Bg(x[j>>2],b)>>2];x[23420]=0;e=T(148,e|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break h}xc(c,e);e=_c(g+40|0,8,1,1,0);h=x[j>>2];x[23420]=0;W(207,e|0,c|0,Bg(h,b)|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}kd(j);kd(k);break e}zb(f);continue}}hb=g+144|0;return i|0}a=P()|0;break a}a=P()|0;break a}a=P()|0}kd(j);kd(k);S(a|0);p()}function pV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-112|0;hb=f;zc(b);a:{if(!Hq(b,11632)){break a}if(!Ku(b,f+96|0)){break a}if(!eC(y[f+97|0])){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(dC(f+96|0),lb))){break a}if(!$b(b,y[f+105|0]|y[f+106|0]<<8)){break a}b:{if(!c){break b}Dd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[f+98|0]&31)+1;e=a+480190|0;w[e>>1]=y[f+99|0];wh(a,1);d=f+24|0;i=Vb(d,8394);Gb(a+1298344|0,i);yb(i);i=Vb(d,7011);Gb(a+1298356|0,i);yb(i);i=hb-16|0;hb=i;g=Vb(i,4208);Rc(f,g);yb(g);hb=i+16|0;x[23420]=0;X(217,d|0,f|0,y[f+97|0],f+96|0);d=x[23420];x[23420]=0;c:{if((d|0)!=1){d=f+24|0;Gb(a+1298368|0,d);yb(d);cc(f);x[a+1298404>>2]=5;d=y[f+99|0];i=f+80|0;x[i>>2]=0;x[i+4>>2]=0;Yj(i+8|0,0);if(d){Oq(i,d);RC(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>z[e>>1]){x[23420]=0;Q(218,b|0,a+1298308|0)|0;g=x[23420];x[23420]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>z[g>>1]){d=0;g=a+480188|0;f:{while(1){if(z[g>>1]<=d>>>0){d=0;x[23420]=0;g=a+484344|0;R(213,g|0,z[f+100>>1]);e=x[23420];x[23420]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;Te(e+480280|0);x[23420]=0;R(219,b|0,e+480289|0);e=x[23420];x[23420]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}g:{h:{i:{j:{while(1){if(z[f+100>>1]<=d>>>0){x[23420]=0;e=T(182,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break h}if(!e){break i}d=x[b+8>>2];g=x[b>>2];x[23420]=0;d=W(144,g|0,d|0,e|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break h}if(d){break j}break i}x[23420]=0;e=Q(220,b|0,f+24|0)|0;h=x[23420];x[23420]=0;k:{if((h|0)==1){break k}x[23420]=0;h=W(214,g|0,d&65535,64)|0;j=x[23420];x[23420]=0;if((j|0)==1){break k}if((e&h)==1){e=x[g>>2];x[23420]=0;R(221,_b(e,d)|0,f+24|0);e=x[23420];x[23420]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;break d}g=Qb(f+24|0);x[23420]=0;U(222,b|0,g|0,e|0);d=x[23420];x[23420]=0;l:{if((d|0)!=1){d=Jb(f);x[23420]=0;R(45,d|0,e|0);e=x[23420];x[23420]=0;m:{if((e|0)==1){break m}k=f,l=Db(x[g>>2]),x[k+48>>2]=l;h=Db(x[g+4>>2]);while(1){n:{e=x[f+48>>2];if(!Pb(e,h)){x[23420]=0;X(223,f+48|0,5,6,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break n}h=f+48|0;e=Ac(d,h);xb(h);h=Ic(e);j=Eb(e);x[23420]=0;ea(224,a+1298332|0,h|0,j|0,76,0);h=x[23420];x[23420]=0;if((h|0)==1){break m}xb(e);dc(g);break i}o:{e=v[e|0];if((e|0)<0){k=f,l=mh(d),x[k+64>>2]=l;j=x[Gf(f+72|0,f- -64|0)>>2];x[23420]=0;X(225,d|0,j|0,e&127,32);e=x[23420];x[23420]=0;if((e|0)!=1){break o}break m}x[23420]=0;R(46,d|0,e|0);e=x[23420];x[23420]=0;if((e|0)!=1){break o}break m}Be(f+48|0);continue}break}}b=P()|0;xb(d);break l}b=P()|0}dc(g);break d}d=y[a+484376|0];g=x[a+484360>>2];x[23420]=0;U(226,Yb(g,d)|0,b|0,z[f+102>>1]);d=x[23420];x[23420]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(z[f+100>>1]>d>>>0){g=x[b+8>>2];j=x[b>>2];x[23420]=0;g=W(144,j|0,g|0,4)|0;j=x[23420];x[23420]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>z[g>>1]){break g}e=D(c,104)+a|0;h=z[e+484414>>1];Ab(f+24|0,x[i>>2],c-1|0);c=_c(f,h&1?16:8,1,0,Bb(x[x[f+24>>2]>>2],x[f+28>>2])?6:0);x[23420]=0;W(207,c|0,e+484380|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}x[23420]=0;g=T(145,b|0)|0;j=x[23420];x[23420]=0;r:{s:{if((j|0)!=1){x[23420]=0;U(178,f|0,b|0,g|0);g=x[23420];x[23420]=0;if((g|0)==1){break s}g=jc(f+24|0,f);zb(f);if(!e){break r}j=x[a+484344>>2];if(!oe(j,x[h>>2],d&65535)){break r}x[23420]=0;U(227,_b(j,d)|0,0,g|0);j=x[23420];x[23420]=0;if((j|0)!=1){break r}b=P()|0;zb(g);break d}b=P()|0;break d}b=P()|0;break d}zb(g);d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}Je(i);break b}x[23420]=0;Q(228,b|0,((e<<5)+a|0)+946304|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;break d}b=P()|0;break d}x[23420]=0;R(229,b|0,f+24|0);h=x[23420];x[23420]=0;t:{if((h|0)==1){break t}x[23420]=0;R(230,f+24|0,(D(g,104)+a|0)+484380|0);h=x[23420];x[23420]=0;if((h|0)==1){break t}h=y[f+40|0];Ab(f,x[i>>2],g-1|0);vg(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0}Je(i);break c}b=P()|0;cc(f)}S(b|0);p()}d=1}hb=f+112|0;return d|0}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;e=hb-320|0;hb=e;d=-1;a:{b:{c:{if(!Fk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=El(e+216|0,b);x[23420]=0;d=Q(396,e+200|0,13810)|0;f=x[23420];x[23420]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[23420]=0;x[e+184>>2]=83886084;x[e+188>>2]=0;U(397,b|0,d|0,e+184|0);f=x[23420];x[23420]=0;if((f|0)==1){break A}Sb(d);v[e+199|0]=0;x[23420]=0;d=Q(396,e+184|0,14588)|0;f=x[23420];x[23420]=0;if((f|0)==1){break z}x[23420]=0;U(398,b|0,e+199|0,d|0);f=x[23420];x[23420]=0;if((f|0)==1){break y}Sb(d);x[23420]=0;f=y[e+199|0];d=Q(396,e+168|0,15625)|0;g=x[23420];x[23420]=0;if((g|0)==1){break x}x[23420]=0;f=f?0:c;X(835,b|0,a+40|0,d|0,f|0);c=x[23420];x[23420]=0;if((c|0)==1){break w}Sb(d);w[e+166>>1]=65535;x[23420]=0;c=Q(396,e+152|0,15227)|0;d=x[23420];x[23420]=0;if((d|0)==1){break v}x[23420]=0;W(426,b|0,e+166|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break u}Sb(c);w[e+150>>1]=0;x[23420]=0;c=Q(396,e+136|0,15126)|0;d=x[23420];x[23420]=0;if((d|0)==1){break t}x[23420]=0;W(426,b|0,e+150|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break s}Sb(c);w[a>>1]=z[e+150>>1];x[23420]=0;c=Q(396,e+120|0,14891)|0;d=x[23420];x[23420]=0;if((d|0)==1){break r}x[23420]=0;X(836,b|0,a+52|0,c|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break q}Sb(c);x[23420]=0;c=Q(396,e+104|0,14834)|0;d=x[23420];x[23420]=0;if((d|0)==1){break p}x[23420]=0;U(827,b|0,a+36|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break o}Sb(c);x[23420]=0;c=Q(396,e+88|0,15234)|0;d=x[23420];x[23420]=0;if((d|0)==1){break n}x[23420]=0;h=a+4|0;U(837,b|0,h|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break m}Sb(c);x[23420]=0;c=Q(396,e+72|0,15128)|0;d=x[23420];x[23420]=0;if((d|0)==1){break l}x[23420]=0;f=a+28|0;U(838,b|0,f|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break k}Sb(c);x[23420]=0;c=Q(396,e+56|0,15005)|0;d=x[23420];x[23420]=0;if((d|0)==1){break j}x[23420]=0;U(838,b|0,a+30|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}Sb(c);x[23420]=0;c=Q(396,e+40|0,14863)|0;d=x[23420];x[23420]=0;if((d|0)==1){break h}x[23420]=0;U(839,b|0,a+32|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}Sb(c);w[e+38>>1]=0;x[23420]=0;c=Q(396,e+24|0,14807)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}x[23420]=0;W(426,b|0,e+38|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}Sb(c);i=jL(B[a+32>>2]);B[a+32>>2]=i;d=-1;if(!Ul(i)){break d}k=e,l=Db(x[a+4>>2]),x[k+16>>2]=l;c=Db(x[a+8>>2]);while(1){g=x[e+16>>2];if(!Pb(g,c)){break e}if(!Ul(B[g>>2])){break d}Ce(e+16|0);continue}}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;break a}a=P()|0;Sb(c);break a}a=P()|0;Sb(c);break a}if(y[b+3|0]&64){break d}c=z[f>>1];if((c+300&65535)>>>0>600){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=e,l=vi(x[a+36>>2]),x[k+16>>2]=l;x[e+8>>2]=0;k=a,l=x[vj(e+16|0,e+8|0,43824)>>2],x[k+36>>2]=l;if(vc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[e+38>>1];if((f|0)<=0){break d}w[e+6>>1]=j;B[e+16>>2]=B[a+32>>2];x[23420]=0;w[e+8>>1]=c;w[e+10>>1]=(c+f|0)-1;a=fa(840,a|0,e+6|0,e+16|0,e+8|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;case 0:g=w[e+38>>1];if((g|0)<=0){break d}B[e+16>>2]=B[a+32>>2];x[23420]=0;w[e+8>>1]=c;w[e+10>>1]=(c+g|0)-1;a=ja(841,a|0,h|0,e+16|0,e+8|0,f|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;break a;default:break C}}x[23420]=0;Y(842,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}}d=1}Zg(b)}hb=e+320|0;return d|0}a=P()|0;break a}a=P()|0}Zg(b);S(a|0);p()}function AH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;i=hb-560|0;hb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+D(s,-24)|0;o=x[(e<<2)+72608>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+72624>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;A=k-25|0;g=o;b:{while(1){f=C[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Dj(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{v=(q|0)<=0;i:{if(!v){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;x[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;w=x[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(w){break k}h=0;break j}x[r>>2]=l-w;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(v){break l}c=8388607;m:{switch(A|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;x[l+476>>2]=x[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Dj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=x[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(s+g<<2)+72624>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Dj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}k=q}x[(i+480|0)+(g<<2)>>2]=c}f=Dj(1,k);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=C[(c<<3)+75392>>3]*C[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}C[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=C[h>>3];f=y+f;C[e+(c<<3)>>3]=m+(y-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=m+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}hb=i+560|0;return n&7}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-352|0;hb=e;zc(b);f=hb-16|0;hb=f;qT(f+8|0,e+128|0);h=x[f+12>>2];mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(h|0)){$b(b,x[f+12>>2])}hb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!sT(e+128|0)){break g}if(!Nb(x[b>>2],x[b+8>>2],Vc(rT(y[e+344|0],y[e+345|0]),lb))){break g}if(!c){d=1;break g}Dd(a,2);Cg(a);x[a+480188>>2]=524296;t=a,u=Ie(455e3),x[t+480204>>2]=u;Mb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;f=e+96|0;Ye(f,2,e+159|0);d=e+112|0;Fc(d,f);Ac(a+1298308|0,d);xb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Yb(x[a+484360>>2],y[a+484376|0]);o=y[e+344|0];n=o+1|0;no(d,b,n,65535,65535);f=Qb(e+112|0);x[23420]=0;U(222,b|0,f|0,n|0);d=x[23420];x[23420]=0;if((d|0)==1){break j}t=e,u=Db(x[f>>2]),x[t+96>>2]=u;d=Db(x[f+4>>2]);while(1){h=x[e+96>>2];q=Pb(h,d);if(q){if((y[h|0]-9&255)>>>0<248){break h}Be(e+96|0);continue}break}t=a,u=y[Kb(x[f>>2],0)|0],x[t+480196>>2]=u;d=y[e+343|0];i=y[e+345|0];h=Qb(e+96|0);x[23420]=0;m=i+1|0;U(222,b|0,h|0,m|0);i=x[23420];x[23420]=0;k:{if((i|0)==1){break k}x[23420]=0;i=a+484344|0;R(213,i|0,m|0);g=x[23420];x[23420]=0;if((g|0)==1){break k}r=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=y[Kb(x[h>>2],c)|0];x[23420]=0;d=W(214,i|0,d|0,r|0)|0;g=x[23420];x[23420]=0;l:{if((g|0)!=1){if(!d){break i}g=0;k=_b(x[i>>2],y[Kb(x[h>>2],c)|0]);m:while(1){s=g&65535;if(s>>>0>7){break l}g=g+1|0;d=0;while(1){if(A[k+12>>2]<=d>>>0){continue m}x[23420]=0;j=T(194,b|0)|0;l=x[23420];x[23420]=0;n:{o:{if((l|0)!=1){j=j<<24>>24;if((j|0)>=0){break o}d=(j&127)+d|0;break n}d=P()|0;break b}l=ed(x[k>>2],x[x[k+48>>2]+12>>2],d,s);if((j|0)==1){v[l|0]=254;break n}if((j-1&255)>>>0>96){break n}v[l+1|0]=g;v[l|0]=j+12}d=d+1|0;continue}}}d=P()|0;break b}c=c+1|0;continue}}d=P()|0;break b}}else{i=e+112|0;f=(e+128|0)+D(d,19)|0;bB(i,f+63|0);h=e+96|0;Fc(h,i);ym(((d<<5)+a|0)+480289|0,h);xb(h);d=d+1|0;g=D(d,104)+a|0;j=g+484380|0;pd(j,2);v[e+107|0]=0;h=y[f+78|0]|y[f+79|0]<<8|(y[f+80|0]<<16|y[f+81|0]<<24);v[e+103|0]=h;v[e+104|0]=h>>>8;v[e+105|0]=h>>>16;v[e+106|0]=h>>>24;h=y[f+75|0]|y[f+76|0]<<8|(y[f+77|0]<<16|y[f+78|0]<<24);f=y[f+71|0]|y[f+72|0]<<8|(y[f+73|0]<<16|y[f+74|0]<<24);x[e+8>>2]=x[e+104>>2];x[e+96>>2]=f;x[e+100>>2]=h;f=x[e+100>>2];x[e>>2]=x[e+96>>2];x[e+4>>2]=f;il(j,1,e);x[g+484404>>2]=8215;f=e+80|0;Fc(f,i);Dc(((d<<5)+a|0)+946304|0,f);xb(f);continue}break}d=P()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){x[23420]=0;b=Q(1,e+80|0,8518)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break p}d=P()|0;break b}b=y[c|0];g=x[a+484360>>2];x[23420]=0;k=d&65535;b=Q(297,Yb(g,b)|0,k|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){r:{s:{if(b){b=Yb(x[a+484360>>2],y[c|0]);break s}x[23420]=0;g=Q(345,i|0,r|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Yb(x[a+484360>>2],y[c|0]);t=bc(x[b>>2],d),u=g,w[t>>1]=u}b=aB(Db(x[_b(x[i>>2],z[bc(x[b>>2],d)>>1])+4>>2]),1);g=y[b+5|0];l=y[Kb(x[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(y[b+3|0]!=16){break t}g=y[c|0];m=x[a+484360>>2];x[23420]=0;g=Q(346,Yb(m,g)|0,k|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=aB(Db(x[_b(x[i>>2],g)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;break b}d=P()|0;break b}Gb(a+1298344|0,b);yb(b);x[23420]=0;b=Q(1,e- -64|0,6010)|0;c=x[23420];x[23420]=0;if((c|0)==1){break f}Gb(a+1298356|0,b);yb(b);b=e+16|0;tj(b,2,e+139|0);x[23420]=0;R(210,e+32|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;U(11,e+48|0,5,e+32|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}b=e+48|0;Gb(a+1298368|0,b);yb(b);xb(e+32|0);x[a+1298404>>2]=5;dc(h)}dc(f);d=q^1}hb=e+352|0;return d|0}d=P()|0;break b}d=P()|0;break b}d=P()|0;xb(e+32|0);break b}d=P()|0}dc(h)}dc(f);S(d|0);p()}function wx(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=hb-48|0;hb=l;x[l+44>>2]=0;a:{if(!(d|g|h)){j=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}Ib(j);x[k>>2]=0}x[23420]=0;Z(93);j=x[23420];x[23420]=0;c:{d:{if((j|0)==1){m=Ua(91780,48896,48952,61592,91968,92072,92020,91912,91900,92216,92184,92152,92140,92364,0)|0;e:{f:{n=ib;if((n|0)==(da(91780)|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=277;if((k|0)==1){break f}break c}if((da(48896)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=358;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(48952)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=359;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(61592)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=357;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(91968)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=300;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92072)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=299;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92020)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=298;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(91912)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=297;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(91900)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=296;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92216)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=289;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92184)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=288;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92152)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=287;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}if((da(92140)|0)==(n|0)){j=_(m|0)|0;x[23420]=0;R(1002,k|0,j|0);k=x[23420];x[23420]=0;j=286;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break e}o=da(92364)|0;j=257;m=_(m|0)|0;if((n|0)!=(o|0)){break c}x[23420]=0;R(1002,k|0,m|0);k=x[23420];x[23420]=0;j=267;if((k|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break e}break d}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break d}}V(0)|0;Ub()}p()}S(a|0);p()}$();k=j;m=!g;if(d){j=mb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=Wf(g?g:21473),x[q+20>>2]=r}if(h){x[h>>2]=k}if(!i){break a}g=x[l+44>>2];q=i,r=Wf(g?g:21473),x[q>>2]=r}g=x[l+44>>2];if(g){Ib(g);x[l+44>>2]=0}g:{if(!(j&1)){break g}x[23420]=0;R(1e3,l+32|0,a|0);g=x[23420];x[23420]=0;h:{i:{if((g|0)!=1){j:{if(f){g=x[f+24>>2];x[23420]=0;R(1001,g|0,l+32|0);g=x[23420];x[23420]=0;if((g|0)!=1){break j}break i}g=Ic(l+32|0);if(b){x[23420]=0;R(b|0,g|0,c|0);g=x[23420];x[23420]=0;if((g|0)==1){break i}break j}xs(g,l)}xb(l+32|0);break g}g=V(0)|0;break h}g=V(0)|0;xb(l+32|0)}_(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:21473;x[l+4>>2]=250;x[l>>2]=9076;UJ(17689,l);ws(92720);$()}hb=l+48|0}function MJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-272|0;hb=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Kk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Tk(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;Qd(g);h=x[f+96>>2];Qd(f+248|0);i=Jk(h,x[f+252>>2],b);Qd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=qc(f+264|0,21473);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Lc(h,g,f+8|0)){e=ba(8)|0;x[23420]=0;c=Ch(f+248|0,c,d);a=x[23420];x[23420]=0;f:{g:{h:{if((a|0)!=1){x[23420]=0;U(917,f+96|0,17452,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}a=0;b=rc(e,f+96|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}if(!e){break e}e=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23420]=0;g=Ch(f+216|0,b,a);a=x[23420];x[23420]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23420]=0;U(917,f+232|0,17488,g|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}x[23420]=0;R(919,f+248|0,f+232|0);b=x[23420];x[23420]=0;a=1;if((b|0)==1){break p}x[23420]=0;c=Ch(f+200|0,c,d);a=x[23420];x[23420]=0;if((a|0)==1){break o}x[23420]=0;U(921,f+96|0,f+248|0,c|0);b=x[23420];x[23420]=0;a=1;if((b|0)==1){break n}a=rc(e,f+96|0);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(f+96|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}xb(c)}xb(f+248|0)}xb(f+232|0)}xb(g);if(!a){break c}}ca(e|0);break c}b=qc(f+192|0,21473);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Lc(h,g,f+88|0)){e=ba(8)|0;x[23420]=0;c=Ch(f+248|0,c,d);a=x[23420];x[23420]=0;r:{s:{t:{if((a|0)!=1){x[23420]=0;U(917,f+96|0,17452,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break t}a=0;b=rc(e,f+96|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break s}b=P()|0;break r}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+184|0,12211);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Lc(h,g,f+80|0)){b=qc(f+176|0,5562);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;b=c;e=d;if(Lc(b,e,f+32|0)){x[a+52>>2]=0;break e}g=qc(f+168|0,11143);h=x[g+4>>2];x[f+24>>2]=x[g>>2];x[f+28>>2]=h;if(Lc(b,e,f+24|0)){x[a+52>>2]=1;break e}g=qc(f+160|0,9108);h=x[g+4>>2];x[f+16>>2]=x[g>>2];x[f+20>>2]=h;if(Lc(b,e,f+16|0)){x[a+52>>2]=2;break e}e=ba(8)|0;x[23420]=0;c=Ch(f+248|0,c,d);a=x[23420];x[23420]=0;u:{v:{w:{if((a|0)!=1){x[23420]=0;U(917,f+96|0,14466,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break w}a=0;b=rc(e,f+96|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+96|0);break v}b=P()|0;break u}b=P()|0;a=1}xb(c);if(!a){break c}}ca(e|0);break c}b=qc(f+152|0,11380);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Lc(h,g,f+72|0)){break e}b=qc(f+144|0,15408);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{e=c;c=d;if(Lc(e,c,f- -64|0)){break x}b=qc(f+136|0,15413);d=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=d;b=1;if(Lc(e,c,f+56|0)){break x}b=qc(f+128|0,12485);d=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=d;b=2;if(Lc(e,c,f+48|0)){break x}b=qc(f+120|0,9172);d=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=d;b=3;if(Lc(e,c,f+40|0)){break x}a=ba(8)|0;x[23420]=0;c=Q(54,f+96|0,11416)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=sJ(b),x[j+116>>2]=k;if(!tx(f+96|0,a+24648|0)){break e}ny(a,f+96|0)}hb=f+272|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function s_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb+-64|0;hb=h;x[h+56>>2]=b;x[e>>2]=0;ad(h,d);x[23420]=0;i=T(1086,h|0)|0;j=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;Zb(h);S(a|0);p()}VF(a,f+24|0,h+56|0,c,e,i);break b}UF(a,f+16|0,h+56|0,c,e,i);break b}g=a;i=b;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=sc(a);k=h,l=Jj(g,i,c,d,e,f,b,b+(Eb(a)<<2)|0),x[k+56>>2]=l;break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[20475];x[h+24>>2]=x[20474];x[h+28>>2]=g;g=x[20473];x[h+16>>2]=x[20472];x[h+20>>2]=g;g=x[20471];x[h+8>>2]=x[20470];x[h+12>>2]=g;g=x[20469];x[h>>2]=x[20468];x[h+4>>2]=g;k=h,l=Jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}g=x[20483];x[h+24>>2]=x[20482];x[h+28>>2]=g;g=x[20481];x[h+16>>2]=x[20480];x[h+20>>2]=g;g=x[20479];x[h+8>>2]=x[20478];x[h+12>>2]=g;g=x[20477];x[h>>2]=x[20476];x[h+4>>2]=g;k=h,l=Jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];F:{if(!(b&4|(a|0)>12)){x[f+16>>2]=a-1;break F}x[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+56|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(!Pr(a,b+8|0)){break H}if(!Ck(i,1,Dk(x[a>>2]))){break H}pn(a);continue}break}if(Lj(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+56|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Dr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=pc(h,81936,44);k=g,l=Jj(a,b,c,d,e,f,g,g+44|0),x[k+56>>2]=l;break b}x[h+16>>2]=x[20500];g=x[20499];x[h+8>>2]=x[20498];x[h+12>>2]=g;g=x[20497];x[h>>2]=x[20496];x[h+4>>2]=g;k=h,l=Jj(a,b,c,d,e,f,h,h+20|0),x[k+56>>2]=l;break b}a=Qi(h+56|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[20511];x[h+24>>2]=x[20510];x[h+28>>2]=g;g=x[20509];x[h+16>>2]=x[20508];x[h+20>>2]=g;g=x[20507];x[h+8>>2]=x[20506];x[h+12>>2]=g;g=x[20505];x[h>>2]=x[20504];x[h+4>>2]=g;k=h,l=Jj(a,b,c,d,e,f,h,h+32|0),x[k+56>>2]=l;break b}a=Qi(h+56|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=sc(a);k=h,l=Jj(g,i,c,d,e,f,b,b+(Eb(a)<<2)|0),x[k+56>>2]=l;break b}TF(f+20|0,h+56|0,c,e,i);break b}a=Qi(h+56|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(Lj(c,a+8|0)){break M}b=4;if((hn(i,Dk(x[c>>2]))|0)!=37){break M}b=2;if(!Lj(pn(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+56>>2]}hb=h- -64|0;return a|0}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=hb-752|0;hb=d;zc(b);e=hb-16|0;hb=e;g=d+144|0;HQ(e+8|0,g);f=x[e+12>>2];mc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(f|0)){$b(b,x[e+12>>2])}hb=e+16|0;e=(f|0)==(h|0);if(!e){GQ(g)}a:{if(!e){break a}if(!JQ(d+144|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(IQ(z[d+178>>1]),lb))){break a}if(!c){o=1;break a}Dd(a,262144);f=d+104|0;el(f,2,d+144|0);e=d+24|0;Fc(e,f);Ac(a+1298308|0,e);xb(e);g=Vb(e,8235);Gb(a+1298344|0,g);yb(g);e=Vb(e,10017);Gb(a+1298356|0,e);yb(e);e=hb-16|0;hb=e;i=f;f=Vb(e,4154);Rc(i,f);yb(f);hb=e+16|0;v[d+8|0]=y[d+174|0];x[23420]=0;v[d+127|0]=y[d+173|0];R(616,d+128|0,d+127|0);e=x[23420];x[23420]=0;b:{c:{d:{if((e|0)!=1){x[23420]=0;X(238,d+24|0,d+104|0,d+8|0,d+128|0);e=x[23420];x[23420]=0;if((e|0)!=1){e=d+24|0;Gb(a+1298368|0,e);yb(e);yb(d+128|0);f=d+104|0;cc(f);x[a+480208>>2]=12;x[a+1298404>>2]=5;g=a+480188|0;w[g>>1]=z[d+182>>1];w[d+24>>1]=z[d+178>>1];w[d+104>>1]=3999;B=a,C=z[Zc(e,f)>>1],w[B+480190>>1]=C;vT(Yb(x[a+484360>>2],y[a+484376|0]),d+240|0,z[d+176>>1]);e=0;while(1)if(z[g>>1]<=e>>>0){e=d+24|0;Xd(e,b,D(z[d+178>>1],80));g=c&2;l=jc(d+104|0,e);zb(e);h=d+72|0;e=0;e:{f:{while(1){if(z[a+480190>>1]<=e>>>0){o=1;if(c&1){break f}break b}x[23420]=0;R(617,l|0,d+24|0);f=x[23420];x[23420]=0;if((f|0)==1){break e}f=d+8|0;el(f,2,h);x[23420]=0;R(210,d+128|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break e}e=e+1|0;f=d+128|0;Dc(((e<<5)+a|0)+946304|0,f);xb(f);x[23420]=0;i=f;f=(D(e,104)+a|0)+484380|0;U(618,i|0,d+24|0,f|0);i=x[23420];x[23420]=0;g:{if((i|0)==1){break g}if(!g|!x[f>>2]){continue}x[23420]=0;i=Q(143,b|0,z[d+42>>1]|z[d+44>>1]<<16)|0;j=x[23420];x[23420]=0;if((j|0)==1){break g}if(!i){continue}x[23420]=0;W(207,d+128|0,f|0,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){continue}}break}break e}x[23420]=0;m=a+484344|0;R(213,m|0,z[d+180>>1]);c=x[23420];x[23420]=0;if((c|0)==1){break e}c=d+24|0;r=c|4;s=c|2;t=c|5;u=c|3;A=c|1;q=a+480188|0;e=0;while(1){if(z[d+180>>1]<=e>>>0){break b}x[23420]=0;a=W(214,m|0,e&65535,64)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}h:{if(!a){break h}a=(e<<1)+d|0;a=y[a+496|0]|y[a+497|0]<<8;if(!a){break h}x[23420]=0;a=Q(143,b|0,a<<4)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}if(!a){break h}c=0;a=_b(x[m>>2],e);j=ed(x[a>>2],x[x[a+48>>2]+12>>2],0,0);while(1){if(c>>>0>63){break h}a=x[b+8>>2];f=x[b>>2];x[23420]=0;a=W(144,f|0,a|0,1)|0;f=x[23420];x[23420]=0;i:{if((f|0)!=1){if(!a){break h}x[23420]=0;a=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}k=a<<24>>24;if(k){break i}c=c+1|0;j=D(z[q>>1],6)+j|0;continue}break e}w[d+28>>1]=0;x[d+24>>2]=0;a=k&31;f=D(a,6)+j|0;i=Sh(d+24|0);g=a>>>0<z[q>>1];n=g?f:i;h=k&255;j:{if(!(h&32)){break j}x[23420]=0;R(247,d+128|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}a=y[d+128|0];v[n|0]=a;B=g?f+1|0:A,C=y[jd(d+128|0)|0],v[B|0]=C;k:{if(a){if((a|0)==254){break k}if(a>>>0<121){break j}}a=0}v[n|0]=a}l:{if(!(h&64)){break l}x[23420]=0;R(247,d+128|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}h=g?f+3|0:u;a=y[d+128|0];v[h|0]=a;i=g?f+5|0:t;B=i,C=y[jd(d+128|0)|0],v[B|0]=C;m:{if(a>>>0>=16){if(a>>>0<=23){a=y[a+26839|0];v[h|0]=a;break m}v[h|0]=0;break l}Of(n);a=y[h|0]}if((a|0)!=23){if((a|0)!=9){break l}v[h|0]=20;v[d+8|0]=y[i|0]>>>3;v[d+127|0]=1;B=i,C=y[_e(d+8|0,d+127|0)|0]-1&15|128,v[B|0]=C;break l}v[d+8|0]=64;B=i,C=y[Wb(i,d+8|0)|0]<<1,v[B|0]=C}if((k|0)>=0){continue}v[(g?f+2|0:s)|0]=1;x[23420]=0;a=T(194,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break e}v[(g?f+4|0:r)|0]=a;continue}}e=e+1|0;continue}}b=P()|0;zb(l);break c}else{f=(e<<5)+a|0;Te(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;continue}}b=P()|0;yb(d+128|0);break d}b=P()|0}cc(d+104|0)}S(b|0);p()}zb(l)}hb=d+752|0;return o|0}function II(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=hb-48|0;hb=g;a:{b:{if(cs(c)){j=x[b+484344>>2];if(oe(j,x[b+484348>>2],c&65535)){break b}}c=a;a=Jb(g+32|0);b=Jb(g+16|0);ei(c,a,b);xb(b);xb(a);break a}c=_b(j,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Jb(g+32|0);b=Jb(g+16|0);ei(c,a,b);xb(b);xb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Jb(g+32|0);b=Jb(g+16|0);ei(c,a,b);xb(b);xb(a);break a}if(f>>>0>=6){c=a;a=Jb(g+32|0);b=Jb(g+16|0);ei(c,a,b);xb(b);xb(a);break a}c=ed(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!Uc(d)){if(!tp(d)){break k}}e=g+16|0;bM(e,b,d,y[c+1|0]);x[23420]=0;R(964,g+32|0,e|0);b=x[23420];x[23420]=0;d=1;if((b|0)!=1){break j}c=P()|0;break g}d=0;x[23420]=0;Q(54,g+32|0,16584)|0;b=x[23420];x[23420]=0;if((b|0)==1){break i}}b=9860;c=y[c|0];if(!Uc(c)){b=tp(c)?10170:16584}x[23420]=0;b=Q(54,g|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break h}c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);if(!d){break a}yb(g+16|0);break a}c=P()|0;break d}c=P()|0;xb(g+32|0);if(!d){break d}}yb(g+16|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){Nt(g+32|0,b);break l}Vb(g+32|0,16589)}b=y[b|0];x[23420]=0;b=Q(54,g+16|0,(b?10660:16589)|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);break a;case 2:m:{if(Rg(y[c|0])){Vb(g+32|0,17644);break m}d=y[c+2|0];if(d){Qe(g+32|0,1,BL(x[x[b+8>>2]+88>>2],d));break m}Vb(g+32|0,17644)}b=17644;if(!Rg(y[c|0])){b=y[c+2|0]?5466:17644}x[23420]=0;b=Q(54,g+16|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 4:n:{if(Rg(y[c|0])){k=g,l=Sj(y[c+2|0],y[c+4|0])&255,x[k>>2]=l;sA(g+32|0,g);break n}if(y[c+2|0]){Nt(g+32|0,c+4|0);break n}Vb(g+32|0,16589)}b=5450;if(!Rg(y[c|0])){b=y[c+2|0]?5450:16589}x[23420]=0;b=Q(54,g+16|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 3:o:{if(Rg(y[c|0])){k=g,l=(Sj(y[c+3|0],y[c+5|0])&3840)!=0,v[k|0]=l;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1058;x[d+12>>2]=1;j=g+32|0;b=hb+-64|0;hb=b;h=x[d+8>>2]&2?16:10;f=hb-32|0;hb=f;e=Qe(f+16|0,1,0);p:{q:{r:{while(1){i=sc(e);fx(f+8|0,i,Eb(e)+i|0,y[g|0],h);if(!x[f+12>>2]){break r}i=If(Eb(e));x[23420]=0;R(58,e|0,i|0);i=x[23420];x[23420]=0;if((i|0)!=1){continue}break}break q}h=x[f+8>>2];i=sc(e);x[23420]=0;R(59,e|0,h-i|0);h=x[23420];x[23420]=0;s:{if((h|0)!=1){x[23420]=0;R(60,b|0,e|0);h=x[23420];x[23420]=0;if((h|0)!=1){break s}break q}break q}xb(e);hb=f+32|0;break p}a=P()|0;xb(e);S(a|0);p()}e=b+16|0;ds(e,b,x[d+8>>2]);f=x[d+12>>2];h=x[d+8>>2];x[23420]=0;X(73,b+32|0,e|0,h|0,f|0);e=x[23420];x[23420]=0;t:{u:{v:{w:{x:{if((e|0)!=1){e=y[d+24|0];f=x[d+20>>2];x[23420]=0;X(74,b+48|0,b+32|0,f|0,e|0);e=x[23420];x[23420]=0;if((e|0)==1){break x}x[23420]=0;R(57,j|0,b+48|0);e=x[23420];x[23420]=0;if((e|0)==1){break w}xb(b+48|0);xb(b+32|0);xb(b+16|0);xb(b);hb=b- -64|0;break t}a=P()|0;break u}a=P()|0;break v}a=P()|0;xb(b+48|0)}xb(b+32|0)}xb(b+16|0);xb(b);S(a|0);p()}hb=d+32|0;break o}d=y[c+3|0];if(d){Qe(g+32|0,1,AL(x[x[b+8>>2]+84>>2],d));break o}Vb(g+32|0,16590)}b=12165;if(!Rg(y[c|0])){b=y[c+3|0]?12165:16590}x[23420]=0;b=Q(54,g+16|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d;case 5:break f;default:break c}}y:{if(Rg(y[c|0])){k=g,l=Sj(y[c+3|0],y[c+5|0])&255,x[k>>2]=l;sA(g+32|0,g);break y}if(y[c+3|0]){Nt(g+32|0,c+5|0);break y}Vb(g+32|0,16589)}b=11025;if(!Rg(y[c|0])){b=y[c+3|0]?11025:16589}x[23420]=0;b=Q(54,g+16|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){c=a;a=g+32|0;ei(c,a,b);xb(b);xb(a);break a}c=P()|0;xb(g+32|0);break d}c=P()|0;xb(g+32|0)}S(c|0);p()}c=a;a=Jb(g+32|0);b=Jb(g+16|0);ei(c,a,b);xb(b);xb(a)}hb=g+48|0}function C8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=hb-128|0;hb=d;g=-1;a:{b:{c:{d:{if(!Jg(x[x[b>>2]-12>>2]+b|0)){break d}e=d+112|0;ae(e,b);f=x[e+8>>2];k=x[e+12>>2];e=d+104|0;vl(e);b=zk(b,e,8);if(Ob(e,16560,8)){a=gh(d+88|0,f,k);c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;Hj(b,d+8|0);break d}w[d+86>>1]=0;Lf(b,d+86|0);k=w[d+86>>1];if((k-4&65535)>>>0<65534){break d}f=d+78|0;vl(f);e=zk(b,f,8);if(Ob(f,14140,8)){break d}w[d+76>>1]=0;Lf(e,d+76|0);f=w[d+76>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Jb(d+112|0);x[23420]=0;h=W(430,e|0,b|0,65535)|0;l=x[23420];x[23420]=0;if((l|0)==1){break b}if(!h){break i}x[23420]=0;U(11,d- -64|0,c|0,b|0);h=x[23420];x[23420]=0;if((h|0)!=1){break j}break b}b=Jb(d+112|0);x[23420]=0;h=Q(432,e|0,b|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break c}if(!h){break h}x[23420]=0;U(11,d- -64|0,c|0,b|0);h=x[23420];x[23420]=0;if((h|0)==1){break c}}h=d- -64|0;Gb(a+40|0,h);yb(h);xb(b);w[d+62>>1]=0;Lf(e,d+62|0);w[d+60>>1]=0;Lf(e,d+60|0);w[a>>1]=z[d+60>>1];w[d+58>>1]=0;k:{if((f|0)<=3){x[d+112>>2]=0;bk(e,d+112|0);b=x[d+112>>2];if(b>>>0>65535){break d}b=mu(b);w[d+58>>1]=b;break k}Lf(e,d+58|0);b=z[d+58>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Jb(d+112|0);x[23420]=0;w[d+40>>1]=0;R(846,e|0,d+40|0);i=x[23420];x[23420]=0;if((i|0)==1){break g}n:{if(!n){x[23420]=0;i=W(430,e|0,f|0,65535)|0;j=x[23420];x[23420]=0;if((j|0)==1){break g}if(i){break n}break e}x[23420]=0;i=Q(432,e|0,f|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break g}if(!i){break e}}x[23420]=0;U(11,d- -64|0,c|0,f|0);i=x[23420];x[23420]=0;if((i|0)!=1){x[23420]=0;i=Q(843,h|0,d+40|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break m}j=i;i=d- -64|0;Gb(j,i);yb(i);xb(f);b=b+1|0;continue}break}g=P()|0;break f}g=P()|0;yb(d- -64|0);break f}c=d- -64|0;vl(c);b=zk(e,c,8);if(Ob(c,14084,8)){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(hL(b,c)){break o}break d}if(!gL(b,c)){break d}}o=d,q=Db(x[a+4>>2]),x[o+112>>2]=q;c=Db(x[a+8>>2]);while(1){e=x[d+112>>2];if(Pb(e,c)){if(!Ul(B[e>>2])){break d}Ce(d+112|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(hL(b,c)){break p}break d}if(!gL(b,c)){break d}}o=d,q=Db(x[a+16>>2]),x[o+112>>2]=q;c=Db(x[a+20>>2]);while(1){e=x[d+112>>2];if(Pb(e,c)){if(!Ul(B[e>>2])){break d}Ce(d+112|0);continue}break}o=a,q=vc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+56>>1]=0;Lf(b,d+56|0);c=z[d+56>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+54>>1]=0;Lf(b,d+54|0);c=w[d+54>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+48>>2]=0;mp(b,d+48|0);m=jL(B[d+48>>2]);B[a+32>>2]=m;if(!Ul(m)){break d}c=d+40|0;vl(c);zk(b,c,8);if(Ob(c,16551,8)){break d}b=vc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=vi(b),x[o+112>>2]=q;x[d+32>>2]=0;o=a,q=x[vj(d+112|0,d+32|0,43824)>>2],x[o+36>>2]=q;np(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(pL(vc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Qb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+32>>1]=b;o=d,q=(vc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+34>>1]=q;x[23420]=0;w[d+30>>1]=0;ja(841,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=x[23420];x[23420]=0;g=1;if((a|0)==1){break r}tc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[23420]=0;R(847,e|0,Cb(f,b-c|0)|0);c=x[23420];x[23420]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=P()|0;tc(e);break a}xb(b);break d}xb(b);break d}g=P()|0}xb(f);break a}xb(f)}hb=d+128|0;return g|0}g=P()|0;xb(b);break a}g=P()|0;xb(b)}S(g|0);p()}function bM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=hb-16|0;hb=k;a:{b:{c:{if(!Uc(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}e=x[d+44>>2];if(!e){break c}w[k+14>>1]=c-61;c=hb+-64|0;hb=c;d:{e:{d=w[e+28>>1];h=k+14|0;b=w[h>>1];if((d|0)<=(b|0)){if((b|0)<=(vc(x[e+4>>2],x[e+8>>2])+d<<16)-65536>>16){break e}}Jb(a);break d}f:{d=z[e+30>>1];if(!d){b=e+52|0;d=Tx(b,h);if(!zg(d,yf(b))){break f}Om(a,ud(d)+4|0);break d}b=Sx(b,d<<16>>16);w[c+62>>1]=b;d=Jb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Tx(a,c+62|0);t:{if(zg(f,yf(a))){x[23420]=0;R(123,d|0,ud(f)+4|0);a=x[23420];x[23420]=0;if((a|0)==1){break t}a=w[e+30>>1];b=w[h>>1];x[23420]=0;l=c,m=Rx(b,a)+5|0,x[l+32>>2]=m;R(120,c+48|0,c+32|0);a=x[23420];x[23420]=0;u:{if((a|0)!=1){x[23420]=0;Q(87,d|0,c+48|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break u}yb(c+48|0);break d}a=P()|0;break g}a=P()|0;yb(c+48|0);break g}if(w[e+30>>1]>26){break q}x[23420]=0;b=W(477,c+32|0,1,(b<<24)+1090519040>>24)|0;a=x[23420];x[23420]=0;if((a|0)==1){break s}x[23420]=0;U(11,c+48|0,0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break r}a=c+48|0;f=Gb(d,a);yb(a);xb(b);x[23420]=0;Q(121,f|0,14489)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break p}}a=P()|0;break g}a=P()|0;break g}a=P()|0;xb(b);break g}x[23420]=0;a=b<<16>>16;x[c+28>>2]=(a|0)%16;R(795,c+32|0,c+28|0);f=x[23420];x[23420]=0;if((f|0)==1){break o}x[23420]=0;x[c+12>>2]=((a|0)/16<<16>>16)%16;R(795,c+16|0,c+12|0);a=x[23420];x[23420]=0;if((a|0)==1){break n}x[23420]=0;U(2,c+48|0,c+32|0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break m}a=c+48|0;f=Gb(d,a);yb(a);yb(c+16|0);yb(c+32|0);if(b<<16>>16<256){break p}x[23420]=0;U(8,c|0,0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break k}b=c+32|0;g=Yd(c);j=mh(c);i=Yd(c);a=hb-32|0;hb=a;x[a+16>>2]=j;x[a+24>>2]=g;x[a+8>>2]=i;while(1){if(Lh(a+24|0,a+16|0)){g=a+24|0;j=op(v[x[g>>2]]);i=a+8|0;v[x[i>>2]]=j;Be(g);Be(i);continue}break}hb=a+32|0;Rc(b,c);x[23420]=0;U(11,c+48|0,0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}a=c+48|0;Gb(f,a);yb(a);xb(c+32|0);xb(c)}a=w[e+30>>1];b=w[h>>1];x[23420]=0;l=c,m=Rx(b,a)+5|0,x[l+16>>2]=m;R(120,c+48|0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break i}x[23420]=0;Q(87,d|0,c+48|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break h}yb(c+48|0);break d}a=P()|0;break g}a=P()|0;break l}a=P()|0;yb(c+16|0)}yb(c+32|0);break g}a=P()|0;break g}a=P()|0;xb(c+32|0);xb(c);break g}a=P()|0;break g}a=P()|0;yb(c+48|0)}break a}d=hb-16|0;hb=d;f=hb-32|0;hb=f;e=Qe(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=sc(e);i=Eb(e)+b|0;g=w[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){v[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}jx(j,b,i,g&65535);if(!x[f+12>>2]){break x}b=If(Eb(e));x[23420]=0;R(58,e|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){continue}break}break w}b=x[f+8>>2];h=sc(e);x[23420]=0;R(59,e|0,b-h|0);b=x[23420];x[23420]=0;y:{if((b|0)!=1){x[23420]=0;R(71,d|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break y}break w}break w}xb(e);hb=f+32|0;break v}a=P()|0;xb(e);S(a|0);p()}x[23420]=0;R(70,a|0,d|0);a=x[23420];x[23420]=0;z:{if((a|0)!=1){yb(d);hb=d+16|0;break z}a=P()|0;break a}}hb=c- -64|0;break b}e=x[b>>2];b=hb-32|0;hb=b;A:{if(tp(c)){x[b+16>>2]=x[7984];d=x[7983];x[b+8>>2]=x[7982];x[b+12>>2]=d;d=x[7981];x[b>>2]=x[7980];x[b+4>>2]=d;Vb(a,(b+(c<<2)|0)-1004|0);break A}if(Uc(c)){d=Jb(b);x[23420]=0;c=c-1|0;f=(c|0)/12|0;c=Q(796,d|0,e+(D(f,-12)+c<<16>>16<<2)|0)|0;e=x[23420];x[23420]=0;B:{if((e|0)==1){break B}x[23420]=0;c=Q(797,c|0,(f<<24)+805306368>>24)|0;e=x[23420];x[23420]=0;if((e|0)==1){break B}x[23420]=0;Q(3,a|0,c|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break B}yb(c);break A}a=P()|0;break a}if(!c){Vb(a,16584);break A}Vb(a,14460)}hb=b+32|0}hb=k+16|0;return}yb(d);S(a|0);p()}function UU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-3056|0;hb=e;zc(b);f=hb-16|0;hb=f;h=e+1096|0;JB(f+8|0,h);i=x[f+12>>2];j=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(i|0)){$b(j,x[f+12>>2])}hb=f+16|0;b=(b|0)==(i|0);if(!b){IB(h)}a:{if(!b){break a}if(!KB(e+1096|0)){break a}b:{if(!c){break b}if(!Nb(x[j>>2],x[j+8>>2],Vc(1024,0))){break a}HB(j,e+576|0);HB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=x[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(fr(x[j>>2],(b+f|0)+2978|0)){continue}break a}break}Dd(a,2);Cg(a);b=e+40|0;d=Vb(b,13687);Gb(a+1298344|0,d);yb(d);d=Vb(b,14605);Gb(a+1298356|0,d);yb(d);b=Vb(b,15250);Gb(a+1298368|0,b);yb(b);x[a+1298404>>2]=5;b=y[e+1096|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;Ze(Yb(x[a+484360>>2],y[a+484376|0]),y[e+1097|0]);x[a+480188>>2]=4194317;Mb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=D(b,104)+a|0;i=g+484380|0;pd(i,2);h=e+16|0;Th(h,1,(D(d,13)+e|0)+1098|0);f=e+40|0;Fc(f,h);Dc(((b<<5)+a|0)+946304|0,f);xb(f);d=(e+1096|0)+(d<<4)|0;f=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[i>>2]=f;h=f;f=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(h>>>0>=f>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[g+484414>>1]=2;x[g+484388>>2]=f;x[g+484384>>2]=d}x[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(D(d,104)+a|0)+484380|0;pd(f,2);i=e+16|0;Th(i,1,(D(g,13)+e|0)+2026|0);b=e+40|0;Fc(b,i);Dc(((d<<5)+a|0)+946304|0,b);xb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(e+1096|0)+D(g,11)|0;o=Kb(b,0),q=y[d+1347|0],v[o|0]=q;o=Kb(b,1),q=y[d+1352|0],v[o|0]=q;o=Kb(b,2),q=y[d+1348|0],v[o|0]=q;o=Kb(b,3),q=y[d+1353|0],v[o|0]=q;o=Kb(b,4),q=y[d+1349|0],v[o|0]=q;o=Kb(b,5),q=y[d+1354|0],v[o|0]=q;o=Kb(b,6),q=y[d+1350|0],v[o|0]=q;o=Kb(b,7),q=y[d+1355|0],v[o|0]=q;o=Kb(b,8),q=y[d+1351|0],v[o|0]=q;o=Kb(b,9),q=y[d+1356|0],v[o|0]=q;o=Kb(b,10),q=y[d+1346|0],v[o|0]=q;x[e+8>>2]=x[e+48>>2];b=x[e+44>>2];x[e>>2]=x[e+40>>2];x[e+4>>2]=b;il(f,1,e);g=g+1|0;continue}break}Kq(Yb(x[a+484360>>2],y[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;lg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;$c(j,x[b+(e+576|0)>>2]+2978|0);d=e+16|0;Xd(d,j,x[b+(e- -64|0)>>2]);b=jc(e+40|0,d);zb(d);if(!m){break e}x[23420]=0;d=W(214,l|0,f&65535,64)|0;g=x[23420];x[23420]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=_b(x[l>>2],f);while(1){if(g>>>0>63){break e}d=x[b>>2];x[23420]=0;d=W(144,d|0,x[e+48>>2],1)|0;h=x[23420];x[23420]=0;g:{if((h|0)!=1){if(!d){break e}x[23420]=0;d=T(194,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=ed(x[i>>2],x[x[i+48>>2]+12>>2],g,d);x[23420]=0;R(247,e+16|0,b|0);k=x[23420];x[23420]=0;if((k|0)==1){break c}k=y[e+16|0];d=d>>>0>3;v[h|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=jd(e+16|0);v[h+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+16|0]>>>3&16);GB(h,y[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=ed(x[i>>2],x[x[i+48>>2]+12>>2],g,h&65535);x[23420]=0;k=T(194,b|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break c}GB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=ed(x[i>>2],x[x[i+48>>2]+12>>2],g-1|0,0),q=14,v[o+3|0]=q;break e}x[23420]=0;d=T(194,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}kg(_c(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}zb(b);d=0;break a}zb(b);f=f+1|0;continue}}}else{w[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;zb(b);S(a|0);p()}d=1}hb=e+3056|0;return d|0}function qfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=hb-224|0;hb=d;zc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!oo(b,d+208|0)){break l}if(!tR(d+208|0)){break l}g=zh(d+184|0);h=Jb(d+168|0);iu(d+104|0);x[23420]=0;f=Q(548,b|0,d+96|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=ac(ac(x[d+100>>2])-4|0),x[m+100>>2]=n;while(1){f=ac(ac(x[d+100>>2])-8|0);x[d+100>>2]=f;n:{if(c){break n}if((ac(x[d+96>>2])|0)!=1347699796){break n}j=1;break m}x[23420]=0;U(178,d+72|0,b|0,ac(f)|0);f=x[23420];x[23420]=0;if((f|0)==1){break d}e=d+72|0;f=jc(d+8|0,e);zb(e);e=x[f>>2];x[23420]=0;i=T(166,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=ac(x[d+96>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[23420]=0;Q(176,f|0,4)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}x[23420]=0;e=T(549,f|0)|0;k=x[23420];x[23420]=0;if((k|0)==1){break b}if(!e){break o}e=ac(x[d+100>>2]);if(e>>>0<7){break o}x[23420]=0;U(550,f|0,h|0,e-6|0);e=x[23420];x[23420]=0;if((e|0)==1){break b}break o}x[23420]=0;l=Q(551,f|0,d+104|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break o}break b}hv(g,f);break o}x[23420]=0;j=W(552,a|0,f|0,c|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}}zb(f);if(i){x[23420]=0;f=Q(548,b|0,d+96|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break i}if(f){continue}}break}if(eh(x[h+4>>2],y[h+11|0])){x[23420]=0;b=Q(1,d+72|0,14724)|0;c=x[23420];x[23420]=0;if((c|0)==1){break g}Gb(h,b);yb(b)}q:{if(!(j&l&1)){break q}b=z[d+146>>1];x[23420]=0;b=Lb(b)&256;W(251,a+1074312|0,5,!b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break f}c=Lb(z[d+142>>1]);if(c){w[d+8>>1]=64;w[d+56>>1]=c;m=a,n=z[Zc(d+8|0,d+56|0)>>1],x[m+480228>>2]=n}c=!b;b=Lb(z[d+144>>1]);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+104|0]){b=d+56|0;Ye(b,2,d+104|0);x[23420]=0;R(210,d+8|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}b=d+8|0;Ac(a+1298308|0,b);xb(b)}c=z[d+150>>1];if(!Qp(c,1,12)){break q}f=z[d+148>>1];if(!Qp(f,1,31)){break q}e=z[d+154>>1];if(!Qp(e,0,23)){break q}i=z[d+156>>1];if(!Qp(i,0,59)){break q}k=z[d+158>>1];if(!Qp(k,0,59)){break q}b=qq(d+8|0);m=b,n=Lb(z[d+152>>1]),x[m+20>>2]=n;m=b,n=Lb(c)-1|0,x[m+16>>2]=n;m=b,n=Lb(f),x[m+12>>2]=n;m=b,n=Lb(e),x[m+8>>2]=n;m=b,n=Lb(i),x[m+4>>2]=n;m=b,n=Lb(k),x[m>>2]=n;x[23420]=0;R(381,a+1298408|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break q}a=P()|0;break a}if(j&1){b=x[g>>2];x[23420]=0;b=T(166,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break h}if(b){b=Jb(d+8|0);x[23420]=0;U(255,g|0,b|0,32);c=x[23420];x[23420]=0;if((c|0)==1){break c}if(dq(b,13580)){x[23420]=0;U(11,d+56|0,13,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}c=d+56|0;Gb(a+1298320|0,c);yb(c)}c=x[g+8>>2];f=x[g>>2];x[23420]=0;c=Q(553,f|0,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}if(!c){x[23420]=0;c=T(190,g|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}x[23420]=0;ea(299,a+1298332|0,g|0,c|0,40,0);c=x[23420];x[23420]=0;if((c|0)==1){break c}}xb(b)}x[23420]=0;b=Q(1,d+56|0,17347)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}x[23420]=0;U(424,d+8|0,b|0,h|0);c=x[23420];x[23420]=0;if((c|0)==1){break j}c=d+8|0;Gb(a+1298368|0,c);yb(c);yb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[23420]=0;a=W(251,a+1074312|0,84,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break h}x[23420]=0;a=W(251,a|0,83,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break h}x[23420]=0;Q(252,a|0,85)|0;a=x[23420];x[23420]=0;if((a|0)==1){break h}}yb(h);zb(g)}hb=d+224|0;return j&1}a=P()|0;break a}a=P()|0;yb(b);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0;zb(f)}yb(h);zb(g);S(a|0);p()}function Gj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);g=j(1)|0;c=j(0)|0;a:{b:{m=g&2147483647;f=c;c:{if(!(m|c)){break c}o(+a);c=j(1)|0;t=j(0)|0;if(!t&(c|0)==1072693248){break c}q=c&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!f|(m|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(m>>>0>1128267775){break i}r=0;if(m>>>0<1072693248){break i}e=m>>>20|0;if(m>>>0<1094713344){break h}i=1075-e|0;e=f>>>i|0;r=0;if((f|0)!=e<<i){break i}r=2-(e&1)|0}i=r;if(f){break f}if((m|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(f){break f}f=1043-e|0;e=m>>>f|0;if((m|0)!=e<<f){break g}i=2-(e&1)|0}if((m|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}k=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|i)){a=k-k;return a/a}return(i|0)==1?-k:k}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(i|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}k=-1}m:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?O:0}return(g|0)>0?O:0}if(q>>>0<=1072693246){return(g|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;f=q>>>0<1048576;d=f?a:d;o(+a);c=j(1)|0;j(0)|0;i=f?c:q;e=i&1048575;c=e|1072693248;i=(i>>20)+(f?-1076:-1023)|0;f=0;n:{if(e>>>0<235663){break n}if(e>>>0<767610){f=1;break n}c=e|1071644672;i=i+1|0}e=f<<3;w=C[e+3536>>3];o(+d);j(1)|0;q=0;l(0,j(0)|q);l(1,c|0);p=+n();s=C[e+3520>>3];h=p-s;u=1/(s+p);d=h*u;o(+d);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((f<<18)+(c>>>1|0)|0)+537395200|0);v=a*a;y=h;h=+n();p=u*(y-a*h-a*(p-(h-s)));h=p*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=p*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;p=C[e+3552>>3];d=a*.9617967009544373;s=+(i|0);o(+(p+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-p-d)}l(0,0);l(1,g|0);p=+n();d=(b-p)*a+d*b;b=a*p;a=d+b;o(+a);g=j(1)|0;c=j(0)|0;o:{e=g;if((e|0)>=1083179008){if(c|e-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((e&2147482624)>>>0<1083231232){break o}if(c|e+1064252416){break a}if(!(d<=a-b)){break o}break a}f=0;i=e&2147483647;if(i>>>0>=1071644673){c=e+(1048576>>>(i>>>20|0)-1022|0)|0;e=c>>>20&2047;f=(c&1048575|1048576)>>>1043-e|0;f=(g|0)<0?0-f|0:f;l(0,0);l(1,c&-1048576>>e-1023);b=b-+n();o(+(d+b));g=j(1)|0;j(0)|0}l(0,0);l(1,g|0);a=+n();p=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-p);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(f<<20)+c|0;p:{if((c|0)<=1048575){a=Dj(a,f);break p}l(0,g|0);l(1,c|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;h=hb-736|0;hb=h;a:{b:{if(d>>>0<=511){a=hb-16|0;hb=a;e=h+56|0;hc(a+8|0,e,554);d=x[a+12>>2];mc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){$b(b,x[a+12>>2])}hb=a+16|0;a=(d|0)==(f|0);if(!a){Tb(e,0,554)}if(!a){break b}d=hb-32|0;hb=d;c:{a=h+56|0;if(Ob(a,13840,4)){break c}Rq(d,a+32|0);b=d+16|0;Fc(b,d);Dc(c+492|0,b);xb(b);Th(d,1,a+4|0);Fc(b,d);Dc(c+524|0,b);xb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;g=c+61|0;v[g|0]=y[a+18|0];i=c+62|0;v[i|0]=y[a+19|0];j=c+63|0;v[j|0]=y[a+20|0];k=c- -64|0;v[k|0]=y[a+21|0];f=c+48|0;bh(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Cb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}bh(f,b);e=x[f>>2]}b=_e(g,i);a=qe(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[_e(j,k)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=y[i- -64|0];o=bc(g,b),q=y[i+65|0],w[o>>1]=q;o=Kb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}hb=d+32|0;break b}i=x[b+8>>2];d=hb-32|0;hb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,g,f)){f=df(b)}j=d+8|0;e=h+56|0;fT(j,e);g=fc(d+16|0,x[d+8>>2],f);mc(d,x[b>>2],x[b+8>>2],x[g>>2],x[g+4>>2]);fT(j,e);Tb(x[d+8>>2]+f|0,0,674-f|0);$b(b,x[d+28>>2]);hb=d+32|0;f=x[a+480180>>2];a=0;d=hb-32|0;hb=d;if(!Ob(e,13840,4)){Rq(d,e+32|0);a=d+16|0;Fc(a,d);Dc(c+492|0,a);xb(a);Th(d,1,e+4|0);Fc(a,d);Dc(c+524|0,a);xb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;xc(c+4|0,64);g=y[e+25|0]&127;x[c+8>>2]=g>>>0>64?128:g<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+16|0]=y[e+26|0];v[d|0]=100;o=c,q=y[Wb(a,d)|0],v[o+20|0]=q;v[d+16|0]=y[e+27|0];v[d|0]=64;o=c,q=y[Wb(a,d)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];Em(c,a&127,a>>>7|0);a=y[e+59|0];Dm(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=v[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=f&16777216?240:25;cv(e+304|0,c+48|0,0,f);cv(e+386|0,c+68|0,32,f);cv(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=y[k- -64|0];o=bc(j,a),q=y[k+65|0],w[o>>1]=q;o=Kb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}hb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Ob(d,13365,4)){if(Ob(d,13672,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=bc(d,a);w[f>>1]=z[f>>1]|y[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}$c(b,d+i|0);if(!yh(b,13845)){break b}d=h+8|0;Xd(d,b,pg(b));a=jc(h+32|0,d);zb(d);b=x[a>>2];x[23420]=0;T(148,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;b=Q(348,a|0,13595)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(b){x[23420]=0;b=T(194,a|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}zb(a)}hb=h+736|0;return}b=P()|0;zb(a);S(b|0);p()}
function y_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=hb-32|0;hb=h;x[h+24>>2]=b;x[e>>2]=0;i=h+8|0;ad(i,d);x[23420]=0;i=T(18,i|0)|0;j=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;Zb(h+8|0);S(a|0);p()}YF(a,f+24|0,h+24|0,c,e,i);break b}XF(a,f+16|0,h+24|0,c,e,i);break b}g=a;i=b;a=mb[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Ic(a);k=h,l=Kj(g,i,c,d,e,f,b,Eb(a)+b|0),x[k+24>>2]=l;break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h+8>>2]=623865125;x[h+12>>2]=2032480100;k=h,l=Kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}x[h+8>>2]=623728933;x[h+12>>2]=1680158061;k=h,l=Kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];F:{if(!(b&4|(a|0)>12)){x[f+16>>2]=a-1;break F}x[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+24|0;b=hb-16|0;hb=b;x[b+8>>2]=c;while(1){H:{if(!dp(a,b+8|0)){break H}c=Ek(x[a>>2]);if(!jh(x[i+8>>2],1,c)){break H}Jl(a);continue}break}if(Yi(a,b+8|0)){x[e>>2]=x[e>>2]|2}hb=b+16|0;break b}b=h+24|0;a=mb[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Eb(a)|0)==(0-Eb(a+12|0)|0)){x[e>>2]=x[e>>2]|4;break I}c=Fr(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[81848]|y[81849]<<8|(y[81850]<<16|y[81851]<<24);v[h+15|0]=g;v[h+16|0]=g>>>8;v[h+17|0]=g>>>16;v[h+18|0]=g>>>24;g=y[81845]|y[81846]<<8|(y[81847]<<16|y[81848]<<24);x[h+8>>2]=y[81841]|y[81842]<<8|(y[81843]<<16|y[81844]<<24);x[h+12>>2]=g;k=h,l=Kj(a,b,c,d,e,f,h+8|0,h+19|0),x[k+24>>2]=l;break b}v[h+12|0]=y[81856];x[h+8>>2]=y[81852]|y[81853]<<8|(y[81854]<<16|y[81855]<<24);k=h,l=Kj(a,b,c,d,e,f,h+8|0,h+13|0),x[k+24>>2]=l;break b}a=Ri(h+24|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h+8>>2]=624576549;x[h+12>>2]=1394948685;k=h,l=Kj(a,b,c,d,e,f,h+8|0,h+16|0),x[k+24>>2]=l;break b}a=Ri(h+24|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=mb[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Ic(a);k=h,l=Kj(g,i,c,d,e,f,b,Eb(a)+b|0),x[k+24>>2]=l;break b}WF(f+20|0,h+24|0,c,e,i);break b}a=Ri(h+24|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=hb-16|0;hb=a;x[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(Yi(c,a+8|0)){break M}b=4;if((jn(i,Ek(x[c>>2]))|0)!=37){break M}b=2;if(!Yi(Jl(c),a+8|0)){break L}}x[e>>2]=x[e>>2]|b}hb=a+16|0}a=x[h+24>>2]}hb=h+32|0;return a|0}function LJ(){var a=0,b=0,c=0,d=0,e=0,f=0;if(y[467136]){return x[116783]}b=Od(468776);x[b>>2]=82056;c=b+8|0;x[c>>2]=0;x[c+4>>2]=0;e=Bc(c+8|0),f=0,v[e+128|0]=f;if(hh(1073741823)>>>0<=29){Tc();p()}a=AF(jw(c),30);x[c>>2]=a;x[c+4>>2]=a;e=Fb(c),f=a+120|0,x[e>>2]=f;EF(c,30);x[23420]=0;d=Q(54,b+152|0,14138)|0;a=x[23420];x[23420]=0;a:{b:{c:{if((a|0)!=1){Gc(c);Od(468448);x[117112]=84644;x[23420]=0;Y(1127,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468456);x[117114]=84676;x[23420]=0;Y(1128,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=Od(468464);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=82076;x[a+8>>2]=82128;x[23420]=0;Y(1129,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468480);x[117120]=83592;x[23420]=0;Y(1130,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468488);x[117122]=83740;x[23420]=0;Y(1131,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Z(1132);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Y(1133,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468512);x[117128]=83888;x[23420]=0;Y(1134,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468520);x[117130]=84120;x[23420]=0;Y(1135,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468528);x[117132]=84004;x[23420]=0;Y(1136,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468536);x[117134]=84236;x[23420]=0;Y(1137,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=Od(468544);w[a+8>>1]=11310;x[a>>2]=83208;Jb(a+12|0);x[23420]=0;Y(1138,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=Od(468568);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=83248;Jb(a+16|0);x[23420]=0;Y(1139,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468600);x[117150]=84708;x[23420]=0;Y(1140,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468608);x[117152]=84952;x[23420]=0;Y(1141,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468616);x[117154]=85164;x[23420]=0;Y(1142,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468624);x[117156]=85396;x[23420]=0;Y(1143,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468632);x[117158]=86380;x[23420]=0;Y(1144,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468640);x[117160]=86528;x[23420]=0;Y(1145,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468648);x[117162]=86644;x[23420]=0;Y(1146,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468656);x[117164]=86760;x[23420]=0;Y(1147,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468664);x[117166]=86876;x[23420]=0;Y(1148,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468672);x[117168]=87040;x[23420]=0;Y(1149,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468680);x[117170]=87204;x[23420]=0;Y(1150,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468688);x[117172]=87368;x[23420]=0;Y(1151,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468696);x[117176]=88624;x[117176]=85644;x[117174]=85596;x[23420]=0;Y(1152,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468712);x[117180]=88660;x[117180]=85908;x[117178]=85860;x[23420]=0;Y(1153,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Z(1154);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Y(1155,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Z(1156);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;Y(1157,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468760);x[117190]=87532;x[23420]=0;Y(1158,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}Od(468768);x[117192]=87652;x[23420]=0;Y(1159,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}break a}b=P()|0;break b}b=P()|0;xb(d)}FF(c);S(b|0);p()}x[116782]=468776;v[467136]=1;x[116783]=467128;return 467128}function KM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-16|0;hb=f;g=a+1074376|0;h=D(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(nj(x[e+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=d-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){b=D(b,872)+a|0;w[b+1075764>>1]=d<<28>>24;c=z[(d<<1)+33280>>1];x[b+1075696>>2]=c;e=b+1075692|0;if(!x[e>>2]){break a}k=e,l=Qg(a,y[b+1075789|0],d<<28>>24,c),x[k>>2]=l;break a}a=D(b,872)+a|0;b=x[a+1075096>>2];if(!b){break a}x[a+1075696>>2]=x[b+24>>2]+D(d,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Ab(f+8|0,a+1074312|0,21);if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Ab(f+8|0,a+1074312|0,21);if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=d>>>0<4?d:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+d;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(d>>>0<=2){d=z[a+480188>>1];h=d>>>0<=256?256:d;i=b+1|0;j=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=D(d,872)+a|0;c:{if(z[c+1075778>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:Pn(a,c+1074992|0);if(!(y[c+1075081|0]&2)){break d}e=x[a+1298300>>2];if(!wd(e)){break d}Tj(e,d&65535);break d;case 1:g=c+1075080|0;e=x[g>>2];x[g>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!wd(e)){break d}Tj(e,d&65535);break d;default:break e}}x[c+1075688>>2]=0;g=c+1075080|0;e=x[g>>2];x[g>>2]=e|4096;if(!(e&512)){break d}e=x[a+1298300>>2];if(!wd(e)){break d}ij(e,d&65535,1)}e=x[c+1075648>>2];if(!e){break c}g=y[e+34|0];if(!g){break c}g=x[(D(g,160)+a|0)+906140>>2];if(!g){break c}mb[x[x[g>>2]+92>>2]](g,e,y[c+1075789|0]+255|0,0,b)}d=d+1|0;continue}}gP(e,d,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}$l(a,e,d,4);break a;case 8:b=e;c=x[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:x[b+88>>2]=x[b+88>>2]&-257;break f;case 1:x[b+692>>2]=128;x[b+88>>2]=x[b+88>>2]|256;break f;case 8:x[b+88>>2]=x[b+88>>2]&-25165825|16777216;break f;case 9:x[b+88>>2]=x[b+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=c&-16385;break f;case 11:x[a+480208>>2]=c|16384;break f;case 12:x[a+480208>>2]=c&-8193;break f;case 13:x[a+480208>>2]=c|8192;break f;case 14:x[b+88>>2]=x[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[b>>2]|x[b+4>>2]){break h}a=x[b+76>>2];if(!a){break h}if(!(k=Uc(y[b+788|0]),l=1,m=y[b+88|0]&2,m?k:l)){break h}x[b>>2]=-1;x[b+4>>2]=a-1}x[b+88>>2]=x[b+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=d;Ab(f+8|0,a+1074312|0,35);if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!Uc(y[c+1075780|0])){break a}b=x[(D(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}x[e+4>>2]=a;break a;case 10:if(!(y[a+480209|0]&16)){break a}Ry(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=x[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Ab(f+8|0,a+1074312|0,30);Fy(a,b,d,Bb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=d}hb=f+16|0}function v5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-128|0;hb=f;a:{if(De(b)){break a}e=y[vJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+112|0;Fv(e,b,0,Eb(b)-1|0);Ac(b,e);xb(e)}g=f+112|0;Qd(g);e=x[f+112>>2];Qd(f+96|0);e=uJ(e,x[f+100>>2],b);Qd(g);b:{c:{d:{e:{if((e|0)==x[f+116>>2]){if(ne(b,21473)){a=ba(8)|0;x[23420]=0;U(908,f+112|0,17452,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,f+112|0);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(f+112|0);break c}if(!d){break e}a=ba(8)|0;x[23420]=0;U(908,f+80|0,17488,b|0);b=x[23420];x[23420]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[23420]=0;R(919,f+96|0,f+80|0);b=x[23420];x[23420]=0;if((b|0)==1){break j}x[23420]=0;U(479,f+112|0,f+96|0,c|0);b=x[23420];x[23420]=0;d=1;if((b|0)==1){break i}b=rc(a,f+112|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+112|0);d=0;break h}b=P()|0;break f}b=P()|0;d=1;break g}b=P()|0}xb(f+96|0)}xb(f+80|0);if(!d){break c}}ca(a|0);break c}k:{switch(x[e+4>>2]){case 0:ue(f+72|0,b);b=hb-192|0;hb=b;e=b+16|0;fi(e,c);x[23420]=0;R(77,b+32|0,e|0);c=x[23420];x[23420]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[23420]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break p}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23420]=0;g=ga(61)|0;h=x[23420];x[23420]=0;if((h|0)==1){break n}x[23420]=0;U(62,b+8|0,c+e|0,g|0);e=x[23420];x[23420]=0;if((e|0)==1){break n}Zb(b+8|0);x[23420]=0;e=Q(1017,c|0,b+32|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break n}c=Fk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=y[b+32|0];gf(e);hb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;break o}a=P()|0;xb(b+32|0)}xb(b+16|0);break m}a=P()|0;gf(c)}S(a|0);p()}c=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=c;PJ(a,f+8|0,b,d);break e;case 1:ue(f- -64|0,b);b=hb-192|0;hb=b;e=b+16|0;fi(e,c);x[23420]=0;R(77,b+32|0,e|0);c=x[23420];x[23420]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[23420]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break u}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23420]=0;g=ga(61)|0;h=x[23420];x[23420]=0;if((h|0)==1){break s}x[23420]=0;U(62,b+8|0,c+e|0,g|0);e=x[23420];x[23420]=0;if((e|0)==1){break s}Zb(b+8|0);x[23420]=0;e=Q(84,c|0,b+32|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break s}c=Fk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);g=x[b+32>>2];h=x[b+36>>2];gf(e);hb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;break t}a=P()|0;xb(b+32|0)}xb(b+16|0);break r}a=P()|0;gf(c)}S(a|0);p()}e=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=e;NJ(a,f+16|0,b,c,d);break e;case 2:ue(f+56|0,b);b=hb-192|0;hb=b;e=b+16|0;fi(e,c);x[23420]=0;R(77,b+32|0,e|0);c=x[23420];x[23420]=0;v:{w:{x:{y:{z:{if((c|0)!=1){x[23420]=0;c=Q(78,b+48|0,b+32|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break z}xb(b+32|0);xb(b+16|0);e=x[x[c>>2]-12>>2];x[23420]=0;g=ga(61)|0;h=x[23420];x[23420]=0;if((h|0)==1){break x}x[23420]=0;U(62,b+8|0,c+e|0,g|0);e=x[23420];x[23420]=0;if((e|0)==1){break x}Zb(b+8|0);x[23420]=0;e=Q(85,c|0,b+32|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break x}c=Fk(x[(e+x[x[e>>2]-12>>2]|0)+16>>2]);i=C[b+32>>3];gf(e);hb=b+192|0;i=c?0:i;break v}a=P()|0;break y}a=P()|0;xb(b+32|0)}xb(b+16|0);break w}a=P()|0;gf(c)}S(a|0);p()}b=x[f+60>>2];x[f+24>>2]=x[f+56>>2];x[f+28>>2]=b;OJ(a,f+24|0,i,d);break e;case 3:break k;default:break e}}ue(f+48|0,b);ue(f+40|0,c);b=x[f+52>>2];x[f+32>>2]=x[f+48>>2];x[f+36>>2]=b;MJ(a,f+32|0,x[f+40>>2],x[f+44>>2],d)}hb=f+128|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=hb-976|0;hb=e;zc(b);d=hb-16|0;hb=d;h=e+872|0;yT(d+8|0,h);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(f|0)==(g|0);if(!d){xT(h)}a:{if(!d){break a}if(!AT(e+872|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(zT(y[e+919|0]|y[e+920|0]<<8),lb))){break a}if(!c){l=1;break a}Dd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+947|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Mb(a+1074312|0,7,1);d=e+96|0;f=Vb(d,8142);Gb(a+1298344|0,f);yb(f);f=Vb(d,8814);Gb(a+1298356|0,f);yb(f);x[a+1298404>>2]=5;f=e+16|0;wT(f,e+872|4);Fc(d,f);Ac(a+1298308|0,d);xb(d);d=0;while(1){if((d|0)==16){b:{d=z[e+968>>1];if(d){uB(a+1298332|0,b,d,132,0)}d=hb-16|0;hb=d;h=e+96|0;hc(d+8|0,h,771);f=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){$b(b,x[d+12>>2])}hb=d+16|0;l=(f|0)==(g|0);if(!l){Tb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;vT(Yb(x[d>>2],y[f|0]),e+96|0,y[e+353|0]);Ze(Yb(x[d>>2],y[f|0]),y[e+354|0]);$c(b,y[e+919|0]|y[e+920|0]<<8);o=a+484344|0;q=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}FU(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!cB(b,e+16|0)){break a}d=d+1|0;w[a+480190>>1]=d;Ye(e,1,e+16|0);h=e+72|0;Fc(h,e);Dc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);xb(h);c=(D(d,104)+a|0)+484380|0;pd(c,0);i=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);x[c>>2]=i;f=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+4>>2]=f;g=y[e+58|0]|y[e+59|0]<<8|(y[e+60|0]<<16|y[e+61|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+53|0]<<4;if(v[e+62|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+63|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}_c(h,v[e+62|0]&1?16:8,1,0,0);kg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+355|0]|y[d+356|0]<<8;if(g){f=e+72|0;Xd(f,b,g);i=jc(e+16|0,f);zb(f);n=((y[d+355|0]|y[d+356|0]<<8)-2|0)/64|0;e:{if(!q){break e}x[23420]=0;d=W(214,o|0,h&65535,n|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}if(!d){break e}x[23420]=0;d=T(194,i|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break b}x[23420]=0;Q(176,i|0,1)|0;f=x[23420];x[23420]=0;if((f|0)==1){break b}r=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){g:{d=_b(x[o>>2],h);if((f|0)==(n|0)){break g}m=0;s=pf(x[d>>2],x[x[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}x[23420]=0;R(335,e+72|0,i|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}d=D(m,6)+s|0;j=e+72|0;g=Ue(j);j=Bi(j);k=y[e+72|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;t=d,u=y[jd(e+72|0)|0]+1|0,v[t+1|0]=u}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;h:{i:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break h;case 2:v[d+5|0]=g<<2;break h;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:v[d+5|0]=g<<3;break h;case 9:v[d+4|0]=(g<<2)+4;v[d+2|0]=1;break h;case 10:v[d+5|0]=g|128;break h;case 11:break i;default:break h}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+26224|0];m=m+1|0;continue}}break}ie(d,xh(Fe(ye(e+72|0,14,0),r)))}zb(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Te(h);g=h;h=(e+872|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;zb(i);S(a|0);p()}hb=e+976|0;return l|0}function FV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-576|0;hb=e;zc(b);d=hb-16|0;hb=d;f=e+72|0;GC(d+8|0,f);g=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(g|0)==(j|0);if(!d){EC(f)}a:{if(!d){break a}if(!IC(e+72|0)){break a}b:{if(!c){break b}if(!Nb(x[b>>2],x[b+8>>2],Vc(HC(y[e+182|0],y[e+183|0]),lb))){break a}Dd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Mb(a+1074312|0,7,1);d=e+40|0;g=Vb(d,14502);Gb(a+1298344|0,g);yb(g);d=Vb(d,14535);Gb(a+1298356|0,d);yb(d);xl(a+1298368|0,Ob(e+72|0,11012,2)?14530:14502);x[a+1298404>>2]=5;f=y[e+182|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=hb-16|0;hb=f;d=e+40|0;hc(f+8|0,d,25);l=x[f+12>>2];mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){$b(b,x[f+12>>2])}hb=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+53|0]|y[e+54|0]<<8|(y[e+55|0]<<16|y[e+56|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;pd(f,0);x[f+24>>2]=8363;l=e+40|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;x[f+8>>2]=d;if(d){w[f+34>>1]=2;kk(f)}f=e+8|0;Th(f,2,l);d=e+24|0;Fc(d,f);Dc(((j<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;Qf(g,3,h,36);d=e+40|0;Fc(d,g);Ac(a+1298308|0,d);xb(d);g=0;DC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;Tu(Yb(x[d>>2],y[h|0]),e+185|0,128);d=Yb(x[d>>2],y[h|0]);h=y[e+184|0];if(z[bc(x[d>>2],h)>>1]<y[e+183|0]){Ze(d,h)}while(1)if((g|0)==8){j=a+484344|0;lg(j,y[e+183|0]);n=c&1;f=0;while(1)if(y[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=_c(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}kg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(n){if($g(j,f&65535,64)){break d}}$b(b,1536);break c}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=y[d+369|0];if(g>>>0<63){ie(_b(x[j>>2],f),xh(Fe(ye(e+40|0,14,0),g)))}ie(_b(x[j>>2],f),xh(ye(e+40|0,16,y[d+241|0])));break c}g=0;d=_b(x[j>>2],f);h=pf(x[d>>2],x[x[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;Lq(d,b);i=jd(d);k=Ue(d);i=y[i|0];d=y[e+40|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+40|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(!(d&15)&(d|0)!=48){break g}k=y[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;v[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;v[h+3|0]=y[k+26008|0];i:{switch(k-3|0){case 0:v[h+5|0]=d|32;break g;case 1:v[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:v[h+5|0]=79;break f;case 1:break j;default:break h}}v[h+5|0]=244;break f}v[h+3|0]=0;break f}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Te(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}hb=e+576|0;return h|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-192|0;hb=f;a:{b:{if(Nb(x[c>>2],x[c+8>>2],8)){$b(c,4);while(1){if(Xt(x[c>>2],x[c+8>>2])){break b}m=hb-288|0;hb=m;e=BO(m);i=hb-384|0;hb=i;j=pc(e,BO(i+96|0),282);e=0;c:{d:{e:{f:{g:{if(yh(c,13486)){mg(c,4);h=he(i+72|0,c);x[23420]=0;k=Q(714,h|0,j|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}h:{if(!k){break h}k=x[h+8>>2];g=x[h>>2];l=y[j+26|0];x[23420]=0;k=W(144,g|0,k|0,l|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}if(!k){break h}k=0;i:{while(1){if(y[j+26|0]<=e>>>0){g=x[h+8>>2];l=x[h>>2];e=0;x[23420]=0;k=k&65535;g=W(144,l|0,g|0,k|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break e}if(!g){break h}x[23420]=0;Q(176,h|0,k|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break e}mg(h,DO(j));e=Bc(i- -64|0);g=i+96|0;jz(g);x[23420]=0;R(715,h|0,g|0);g=x[23420];x[23420]=0;if((g|0)!=1){w[i+118>>1]=0;w[i+120>>1]=0;e=kz(e,i+96|0,i+123|0);g=y[j+26|0];x[23420]=0;Q(176,h|0,g|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){break i}}e=P()|0;break d}x[23420]=0;g=T(186,h|0)|0;l=x[23420];x[23420]=0;if((l|0)!=1){v[(e+j|0)+27|0]=g;e=e+1|0;k=g+k|0;continue}break}e=P()|0;break d}l=e;e=j+27|0;l=kz(l,e,e+y[j+26|0]|0);x[23420]=0;U(178,i+16|0,h|0,k|0);e=x[23420];x[23420]=0;if((e|0)==1){break f}g=i+16|0;k=jc(i+40|0,g);zb(g);e=0;x[23420]=0;R(512,g|0,k|0);g=x[23420];x[23420]=0;if((g|0)==1){e=P()|0;zb(k);break d}g=i+16|0;_B(i+8|0,g);n=l;l=x[i+8>>2];l=kz(n,l,Kb(l,x[i+12>>2]));Oc(g);zb(k);if(x[l>>2]!=(y[j+22|0]|y[j+23|0]<<8|(y[j+24|0]<<16|y[j+25|0]<<24))){break h}e=DO(j);x[23420]=0;Q(176,c|0,e|0)|0;j=x[23420];x[23420]=0;e=1;if((j|0)==1){break e}}zb(h)}hb=i+384|0;break c}e=P()|0;break d}e=P()|0;break d}e=P()|0}zb(h);S(e|0);p()}hb=m+288|0;if(e){continue}break}}zc(c);kg(b,a,c);a=1;break a}v[d|0]=1;zc(c);e=pg(c);d=f+144|0;Xd(d,c,df(c));i=jc(f+168|0,d);zb(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=e>>>(c&1)>>>b;x[f+140>>2]=0;x[f+136>>2]=0;x[23420]=0;R(512,d|0,i|0);b=x[23420];x[23420]=0;j:{k:{l:{m:{if((b|0)!=1){c=xe(f+144|0);e=x[f+144>>2];j=qA(c,vi(e),f+140|0,f+136|0);x[23420]=0;b=x[f+140>>2];Q(176,i|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){if(!j){break j}Ag(a);d=b+c|0;b=e-b|0;e=x[f+136>>2];c=0;while(1){n:{if(e){if(!b|(e|0)!=1){break k}e=x[a>>2];if(e>>>0>c>>>0){break n}break k}e=x[a>>2];if(e>>>0<=c>>>0){break k}}if(!Td(e,x[a+20>>2])){break k}x[f+132>>2]=0;x[f+128>>2]=0;k=XR(j,d,vi(b),f+132|0,f+124|0,f+128|0);x[23420]=0;Q(176,i|0,k|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break m}Vh(f+128|0,vi(x[a>>2]-c|0));e=x[f+128>>2];o:{if((e|0)<=0){break o}h=x[f+132>>2];l=z[a+34>>1];if((Gd(l)|0)!=(h|0)){break o}m=D(c,h);g=x[a+20>>2];if(l&1){h=Vg(f+112|0,g+(m<<1)|0,h,e);m=Vg(f+96|0,x[f+124>>2],x[f+132>>2],e);x[23420]=0;x[f+56>>2]=x[h+8>>2];g=x[h+4>>2];x[f+48>>2]=x[h>>2];x[f+52>>2]=g;x[f+40>>2]=x[m+8>>2];h=x[m+4>>2];x[f+32>>2]=x[m>>2];x[f+36>>2]=h;R(513,f+48|0,f+32|0);h=x[23420];x[23420]=0;if((h|0)!=1){break o}break m}h=Vg(f+80|0,g+m|0,h,e);m=Vg(f- -64|0,x[f+124>>2],x[f+132>>2],e);x[23420]=0;x[f+24>>2]=x[h+8>>2];g=x[h+4>>2];x[f+16>>2]=x[h>>2];x[f+20>>2]=g;x[f+8>>2]=x[m+8>>2];h=x[m+4>>2];x[f>>2]=x[m>>2];x[f+4>>2]=h;R(514,f+16|0,f|0);h=x[23420];x[23420]=0;if((h|0)==1){break m}}b=b-k|0;d=d+k|0;c=c+e|0;e=WR(j);continue}}break m}c=P()|0;break l}c=P()|0;Oc(f+144|0)}zb(i);S(c|0);p()}VR(j)}Oc(f+144|0);zb(i);a=(j|0)!=0}hb=f+192|0;return a|0}function pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-336|0;hb=d;zc(b);a:{if(!oo(b,d+320|0)){break a}if(!RT(d+320|0)){break a}if(!Ob(d+320|0,14007,4)){$b(b,4)}if(!Yh(b,d+312|0)){break a}if(Ob(d+312|0,13983,4)){break a}if(!c){l=1;break a}NB(b,d+120|0,x[d+316>>2]);if(z[d+156>>1]>128|z[d+162>>1]>16|(z[d+160>>1]>256|z[d+154>>1]>128)){break a}Dd(a,8192);g=d+32|0;e=Vb(g,6500);Gb(a+1298344|0,e);yb(e);e=Vb(g,10033);Gb(a+1298356|0,e);yb(e);x[a+1298404>>2]=5;e=d+96|0;el(e,2,d+120|0);Fc(g,e);Ac(a+1298308|0,g);xb(g);w[d+32>>1]=z[d+162>>1];w[d+96>>1]=1;f=z[Ve(g,e)>>1];w[a+480188>>1]=f;x[a+480196>>2]=y[d+166|0];x[a+480204>>2]=D(y[d+167|0],1e4);v[d+32|0]=y[d+164|0];v[d+96|0]=64;e=y[Wb(g,e)|0];x[a+480200>>2]=e<<2;if(!e){x[a+480200>>2]=256}e=y[d+165|0];b:{if((e|0)==128){x[d+32>>2]=256/(f>>>0);x[d+96>>2]=128;e=x[Hb(d+32|0,d+96|0)>>2];break b}e=e&127}x[a+480228>>2]=e;g=0;while(1){if((g|0)==16){f=a+484376|0;Tu(Yb(x[a+484360>>2],y[f|0]),d+184|0,z[d+156>>1]);e=z[d+154>>1];if(e>>>0<z[d+156>>1]){Ze(Yb(x[a+484360>>2],y[f|0]),e)}o=c&2;m=a+484344|0;l=1;q=c&1;r=d+68|0;k=a+480190|0;s=a+480188|0;while(1){if(!Yh(b,d+312|0)){break a}c=d+32|0;Xd(c,b,x[d+316>>2]);i=jc(d+96|0,c);zb(c);c:{d:{if(!(Ob(d+312|0,13428,4)|!q)){x[23420]=0;g=n&65535;e=W(214,m|0,g|0,64)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}if(!e){break c}x[23420]=0;Q(176,i|0,2)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}Rh(d+32|0);j=0;e:{while(1){c=x[i>>2];x[23420]=0;e=W(144,c|0,x[d+104>>2],1)|0;c=x[23420];x[23420]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}x[23420]=0;e=T(194,i|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}f=e<<24>>24;if(f){break f}j=j+1|0;continue}break d}c=d+32|0;e=f&15;if(e>>>0<z[s>>1]){c=_b(x[m>>2],g);c=ed(x[c>>2],x[x[c+48>>2]+12>>2],j,e)}g:{if((f|0)>=0){break g}x[23420]=0;h=T(194,i|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}if(!h){break g}v[c|0]=h>>>0<109?h+12|0:h}h=f&255;if(h&64){x[23420]=0;f=T(194,i|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}v[c+1|0]=f}if(h&32){v[c+2|0]=1;x[23420]=0;f=T(194,i|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}v[d+16|0]=f;v[d|0]=64;t=c,u=y[Wb(d+16|0,d)|0],v[t+4|0]=u}if(!(h&16)){continue}x[23420]=0;R(247,d+16|0,i|0);e=x[23420];x[23420]=0;if((e|0)!=1){f=jd(d+16|0);h:{i:{j:{k:{l:{e=y[d+16|0];switch(e-17|0){case 2:break k;case 0:case 1:break l;default:break j}}e=e&15;break i}v[d+16|0]=33;v[f|0]=145;e=y[d+16|0];break h}if(e>>>0<17){break h}e=(e&240)==32?9:-1}v[d+16|0]=e}v[c+3|0]=e;v[c+5|0]=y[f|0];Of(c);continue}break}break d}n=n+1|0;break c}if(Ob(d+312|0,13433,4)){break c}c=z[k>>1];if(!Qh(c)){break c}e=c+1|0;w[k>>1]=e;x[23420]=0;R(305,i|0,d+32|0);c=x[23420];x[23420]=0;m:{if((c|0)==1){break m}x[23420]=0;f=(D(e&65535,104)+a|0)+484380|0;R(306,d+32|0,f|0);c=x[23420];x[23420]=0;if((c|0)==1){break m}el(d,2,r);x[23420]=0;R(210,d+16|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break m}c=d+16|0;Dc(((z[k>>1]<<5)+a|0)+946304|0,c);xb(c);if(!o){break c}h=y[d+45|0]|y[d+46|0]<<8;e=2;c=d+16|0;g=_c(c,8,1,0,1);n:{if(!(h&64)){e=0;if(!(h&2)){break n}}Rf(g,e)}if(h&4){Dh(g,16)}x[23420]=0;W(207,c|0,f|0,i|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break c}}}a=P()|0;zb(i);S(a|0);p()}zb(i);continue}}f=(g<<5)+a|0;Te(f+480280|0);e=y[(d+g|0)+168|0];if(e>>>0<=128){w[f+480284>>1]=e<<1}g=g+1|0;continue}}hb=d+336|0;return l|0}function Wn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=hb-96|0;hb=f;r=gz(x[a+24>>2],y[a+32|0]);t=kj(r);c=t;e=x[a>>2];d=vd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){i=hb-32|0;hb=i;c=c-d|0;d=x[Fb(a)>>2];e=x[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=hb-16|0;hb=e;c=zt(e,a,c);d=x[c+4>>2];h=x[c+8>>2];while(1){if((d|0)==(h|0)){kc(c);hb=e+16|0}else{_N(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}d=Fb(a);d=nk(i+8|0,Vm(a,vd(x[a>>2],e)+c|0),vd(x[a>>2],x[a+4>>2]),d);h=hb-16|0;hb=h;e=aQ(h,d+8|0,c);c=x[e>>2];while(1){if(x[e+4>>2]!=(c|0)){_N(c);c=x[e>>2]+12|0;x[e>>2]=c;continue}break}Id(e);hb=h+16|0;h=x[a>>2];c=x[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Xz(x[e>>2]-12|0,c);x[e>>2]=x[e>>2]-12;continue}break}nc(a,e);nc(a+4|0,d+8|0);nc(Fb(a),yc(d));x[d>>2]=x[d+4>>2];c=x[d+4>>2];while(1){e=x[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;x[d+8>>2]=e;Je(e);continue}break}c=x[d>>2];if(c){Po(d);Ib(c)}}hb=i+32|0;break a}if(d>>>0>c>>>0){eO(a,e+D(c,12)|0)}}if(b){c=a+12|0;Dp(c,Vd(c));A=Fb(c),B=0,x[A>>2]=B;d=c;c=ic(c);x[d>>2]=c;x[c>>2]=0;x[a+28>>2]=0}i=Qb(f+80|0);c=x[a+24>>2];c=et(x[c+484344>>2],x[c+484348>>2]);x[23420]=0;h=W(557,f- -64|0,c|0,30060)|0;c=x[23420];x[23420]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(t|0)){od(h);dc(i);hb=f+96|0;return}c=x[a+24>>2];m=z[bc(x[r>>2],k)>>1];d=kO(c,m);x[f+60>>2]=d;c=Hd(x[a>>2],k);e:{f:{if(b){x[23420]=0;v[f+40|0]=0;U(721,c|0,d|0,f+40|0);d=x[23420];x[23420]=0;if((d|0)!=1){break f}d=P()|0;break d}x[23420]=0;R(679,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break e}}x[23420]=0;d=Q(297,r|0,k&65535)|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}g:{if(!d){break g}x[f+40>>2]=b?0:x[c+4>>2];s=x[Hb(f+40|0,f+60|0)>>2];o=yf(e);c=z[bc(x[h>>2],m)>>1];if((c|0)!=65535){d=iO(e,z[cm(f+40|0,c,s)>>1],x[f+44>>2]);h:{if(zg(d,yf(e))){c=iO(e,z[cm(f+40|0,z[bc(x[h>>2],m)>>1],x[f+60>>2])>>1],x[f+44>>2]);break h}c=yf(e)}x[f+56>>2]=d;while(1){i:{if(!zg(d,c)){break g}g=Qb(f+40|0);d=Tm(ud(d)+8|0);x[23420]=0;R(722,g|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=Yj(f+24|0,o);j=cm(f+16|0,k,x[ud(x[f+56>>2])+4>>2]);d=x[d>>2];x[23420]=0;d=fa(723,e|0,d|0,j|0,g|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break i}x[f+32>>2]=d;o=x[Wg(f+32|0)>>2];je(g);d=x[Wg(f+56|0)>>2];continue}}break}d=P()|0;je(g);break d}q=_b(x[x[a+24>>2]+484344>>2],m);c=Dg(x[x[q+48>>2]+12>>2]);x[23420]=0;v[f+40|0]=0;U(703,i|0,c|0,f+40|0);c=x[23420];x[23420]=0;if((c|0)!=1){n=x[f+60>>2];j:while(1){k:{if((n|0)==(s|0)){if(s){break g}A=bc(x[h>>2],m),B=k,w[A>>1]=B;break g}g=1;j=0;c=x[x[q+48>>2]+12>>2];n=n-1|0;d=pf(x[q>>2],c,n);while(1){if(g>>>0<16&Dg(c)>>>0>j>>>0){u=Kb(x[i>>2],j);c=y[u|0];l:{m:{n:{switch(y[d+3|0]-19|0){case 1:l=y[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=y[d+5|0];if((l&240)!=96){break l}}v[u|0]=l&15;l=y[Kb(x[i>>2],j)|0];c=l?l:c}c=c&255;g=D(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=x[x[q+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Qb(f+40|0);x[23420]=0;R(722,c|0,g|0);d=x[23420];x[23420]=0;if((d|0)==1){break o}d=Yj(f+8|0,o);g=cm(f+16|0,k,n);d=x[d>>2];x[23420]=0;o=fa(723,e|0,d|0,g|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break k}je(c);continue j}}break}}break}d=P()|0;je(c);break d}d=P()|0;break d}k=k+1|0;continue}break}d=P()|0}od(h);break c}d=P()|0}dc(i);S(d|0);p()}function Dy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0,C=0,E=0;f=hb-16|0;hb=f;k=D(b,872)+a|0;m=k+1075800|0;i=y[m|0];l=a+1074312|0;Ab(f+8|0,l,23);h=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[m|0]=h;break i}e=y[m|0];if(e){g=e-1|0;v[m|0]=g;e=0;if(g&255){break c}}v[m|0]=h;e=1;break c}Ab(f+8|0,l,52);g=c&256;if(!(!g|!Bb(x[x[f+8>>2]>>2],x[f+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}e=D(b,872)+a|0;if(y[e+1075781|0]){i=gT(y[e+1075780|0])?1:i}if(y[(D(b,872)+a|0)+1075784|0]?y[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Uc(y[(D(b,872)+a|0)+1075780|0])){break c}break d}j=x[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}if((j|0)==16){break g}if((j|0)!=1){break f}e=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!e){if(Uc(y[(D(b,872)+a|0)+1075780|0])){break a}}if(h){break h}}e=0;break c}e=!((e>>>0)%(h>>>0)|0);break c}e=x[a+1074392>>2]==(h|0)&(h|0)!=0;break c}j:{if(!g){break j}e=D(b,872)+a|0;if(y[e+1075782|0]!=1){break j}h=(y[e+1075785|0]>15)+h|0}k:{if(x[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!x[a+1074416>>2]|g?e:!(A[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break k}e=0;i=j&1048580?0:i}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!g?x[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Ab(f+8|0,l,52);if(!Bb(x[x[f+8>>2]>>2],x[f+12>>2])|c){break c}e=!x[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(D(b,872)+a|0)+1075068|0;l:{if(x[n>>2]){break l}Ab(f+8|0,l,38);if(!Bb(x[x[f+8>>2]>>2],x[f+12>>2])){break l}if(!Rj(x[h+656>>2])){break a}}Ab(f+8|0,l,106);if(B=0,C=Bb(x[x[f+8>>2]>>2],x[f+12>>2]),E=x[(D(b,872)+a|0)+1075688>>2],E?B:C){break a}if(e){j=D(b,872)+a|0;q=j+1075680|0;g=x[q>>2];x[f+4>>2]=g;e=c>>>4&15;m:{if(!e){e=x[j+1075080>>2];break m}Ab(f+8|0,l,52);n:{if(B=Bb(x[x[f+8>>2]>>2],x[f+12>>2]),C=0,E=y[(D(b,872)+a|0)+1075782|0]==1,E?B:C){break n}if(!(16191>>>e&1)){x[f+4>>2]=(D(g,v[e+33696|0])|0)/16;break n}x[f+4>>2]=g+(v[e+33712|0]<<2)}ge(f+4|0,0,256);g=(D(b,872)+a|0)+1075080|0;e=x[g>>2]|2097152;x[g>>2]=e}k=D(b,872)+a|0;r=k+1075692|0;s=x[r>>2];g=y[k+1075794|0];j=0;if(e&512){Ab(f+8|0,l,108);j=Bb(x[x[f+8>>2]>>2],x[f+12>>2])}if(!((j^-1)&x[a+480180>>2]==2|(!x[n>>2]|(g-1&255)>>>0>119))){QM(a,b,0,g,1)}k=k+1075080|0;o:{if(!(x[a+480180>>2]&1048580)){break o}t=(c|0)<256;if((c|0)>255){break o}e=y[(D(b,872)+a|0)+1075781|0];if(!e){break o}t=1;Ap(a,h,e,0,0,1)}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];w=x[k>>2];x[p>>2]=0;Ab(f+8|0,l,23);e=1;p:{if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){break p}e=0;if(x[a+480180>>2]!=2){break p}e=(j^1)&x[n>>2]!=0}$s(a,h,g,e,t,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(w&4096)|x[a+480180>>2]!=4)){x[k>>2]=x[k>>2]|4096}j=o+1075780|0;x[q>>2]=x[f+4>>2];if(z[a+480192>>1]){v[j|0]=g;OM(a,b)}g=x[a+480180>>2];if(!(!(g&16777248)|(y[j|0]|!s))){x[r>>2]=s}if(e){x[h>>2]=0;x[h+4>>2]=0}e=g&16777250;q:{if(d-11>>>0<4294967286){break q}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break q}r:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break r}j=(D(b,872)+a|0)+1075656|0;b=x[Cb(g+68|0,d-2|0)>>2];x[j>>2]=b}Un(a,h,b)}i=e?i:0}a=f+8|0;Ab(a,l,52);b=x[x[f+8>>2]>>2];d=x[f+12>>2];Ab(a,l,23);if(Bb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}i=(Bb(b,d)&c>>>8)+i|0}v[m|0]=i}hb=f+16|0}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=hb-192|0;hb=e;zc(b);a:{if(!cB(b,e+144|0)){break a}if(!sQ(e+144|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(rQ(y[e+175|0],y[e+177|0]),lb))){break a}b:{if(!c){break b}Dd(a,256);g=e+32|0;tj(g,2,e+144|0);d=e- -64|0;Fc(d,g);Ac(a+1298308|0,d);xb(d);f=Vb(d,15111);Gb(a+1298344|0,f);yb(f);d=Vb(d,10012);Gb(a+1298356|0,d);yb(d);rg(g,4232);x[23420]=0;R(237,e+128|0,e+175|0);d=x[23420];x[23420]=0;c:{d:{if((d|0)!=1){x[23420]=0;X(625,e- -64|0,e+32|0,e+174|0,e+128|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=e- -64|0;Gb(a+1298368|0,d);yb(d);yb(e+128|0);cc(e+32|0);x[a+1298404>>2]=5;d=Mb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Mb(d,107,1);f=y[e+176|0];d=y[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=Tz(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;f=0;if(d>>>0>=11){v[e+64|0]=64;o=a,q=y[Wb(e+178|0,e- -64|0)|0]<<2,x[o+480200>>2]=q}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){Ht(b,e+32|0);d=y[e+44|0];if(d?(d|0)!=46:0){break c}h=hb-32|0;hb=h;d=(D(f,104)+a|0)+484380|0;pd(d,0);k=e+32|0;g=k;dk(h,2,g);i=h+16|0;Fc(i,h);ze(d+43|0,i);xb(i);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[h+16|0]=y[g+22|0];v[h|0]=64;o=d,q=y[Wb(i,h)|0]<<2,w[o+30>>1]=q;i=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=i;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(i>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Hb(d+8|0,d)>>2],x[o+8>>2]=q}hb=h+32|0;g=e+16|0;dk(g,2,k);d=e+128|0;Fc(d,g);Dc(((f<<5)+a|0)+946304|0,d);xb(d);w[((f<<1)+e|0)+62>>1]=z[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;no(Yb(x[d>>2],y[g|0]),b,y[e+175|0]?128:64,65535,65535);f=0;if(!pQ(Yb(x[d>>2],y[g|0]))){break a}m=c&1;if(m){lg(a+484344|0,y[e+177|0])}i=a+484344|0;while(1)if(y[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=_c(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!$c(b,d<<4)){break f}kg(c,g,b)}f=f+1|0;continue}}else{f=0;g:{h:{if(m){if($g(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Ee(b)+2&255)>>>0<=252){$b(b,3)}f=f+1|0;continue}}o=e,q=Db(x[_b(x[i>>2],l)>>2]),x[o+128>>2]=q;w[e+14>>1]=65535;x[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=z[e+14>>1];if((d|0)==65535){break g}ie(_b(x[i>>2],l),tm(Fe(ye(e+32|0,12,d&255),x[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Ee(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+128>>2]]=254;break j}d=e+32|0;Lq(d,b);j=y[Kb(d,0)|0];k=y[Kb(d,1)|0];n=y[Kb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+128>>2];v[d|0]=g;break k}h=h+1|0;continue i}d=x[e+128>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;v[d+3|0]=k&15;oQ(d,h,y[e+175|0],e+14|0,e+16|0)}f=f+1|0;dA(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Te(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;yb(e+128|0);break d}f=P()|0}cc(e+32|0);S(f|0);p()}f=0;break a}f=1}hb=e+192|0;return f|0}function mK(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=hb-16|0;hb=j;b=a+4208|0;i=Vj(E(B[Cb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[Cb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=me(E(10),E(E(lK(a)+E(E(B[Cb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Rl(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=me(E(10),E(E(E(E(B[Cb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=lp(E(E(kK(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=Xy(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=hb-16|0;hb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[Cb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[Cb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Ix(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[Cb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Rl(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=me(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){pK((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}hb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+46896>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=hb-16|0;hb=b;d=lh(a,5);e=lh(a,11);c=E(d*lh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*lh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=lh(a,3);l=lh(a,9);g=E(c*g);c=E(g*lh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*lh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}lh(a,12);g=B[a+4496>>2];l=lh(a,1);m=lh(a,7);q=lh(a,0);r=lh(a,6);t=b,u=me(E(10),E(E(lK(a)+E(E(B[Cb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Rl(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));hb=b+16|0;v[a+5046|0]=0;hb=j+16|0}function yaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-112|0;hb=e;g=a+140|0;sj(e+88|0,g,1296125513);x[23420]=0;f=T(166,x[e+88>>2])|0;h=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Jb(e+32|0);x[23420]=0;h=T(148,x[e+88>>2])|0;i=x[23420];x[23420]=0;if((i|0)==1){break p}x[23420]=0;U(731,e+88|0,f|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break p}h=z[a+174>>1];x[23420]=0;U(732,e+72|0,h|0,f|0);h=x[23420];x[23420]=0;if((h|0)==1){break o}x[23420]=0;U(8,e+8|0,c|0,e+72|0);c=x[23420];x[23420]=0;if((c|0)==1){break n}c=e+8|0;Dc(d,c);xb(c);yb(e+72|0);xb(f)}if(y[a+176|0]){x[23420]=0;R(733,e+32|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}c=e+32|0;ze(b+43|0,c);xb(c)}x[23420]=0;U(726,e+32|0,g|0,1413894985);c=x[23420];x[23420]=0;if((c|0)==1){break l}x[23420]=0;f=T(734,e+32|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}g=e+32|0;zb(g);c=a+40|0;zc(c);x[23420]=0;g=Q(735,c|0,g|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break j}if(g){q:{if(A[e+60>>2]<2){break q}x[23420]=0;g=Q(736,c|0,e+8|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break i}if(!g){break q}JL(e+8|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[23420]=0;c=Q(736,c|0,e+8|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break i}if(c){JL(e+8|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=x[e+44>>2];v[b+42|0]=c&128?0:c+1|0;kk(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[23420]=0;c=Q(604,c|0,7)|0;f=x[23420];x[23420]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;zc(c);x[23420]=0;c=Q(737,c|0,e+8|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+8|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[23420]=0;c=T(166,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break j}if(!c){break f}x[23420]=0;h=a+120|0;c=T(145,h|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}x[e+72>>2]=c;xc(e+72|0,9);f=b+68|0;g=x[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[23420]=0;R(738,h|0,e+8|0);i=x[23420];x[23420]=0;if((i|0)==1){break h}j=Cb(f,c),k=x[e+12>>2],x[j>>2]=k;c=c+1|0;continue}}a=P()|0;break a}a=P()|0;break m}a=P()|0;break m}a=P()|0;yb(e+72|0)}xb(f);break a}a=P()|0;break a}a=P()|0;zb(e+32|0);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}Gz(f+(g<<2)|0,$S(f),42680)}c=a+80|0;zc(c);x[23420]=0;f=Q(739,c|0,e+8|0)|0;g=x[23420];x[23420]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+8|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+72>>1]=z[e+12>>1];w[e+6>>1]=256;j=b,k=z[Zc(e+72|0,e+6|0)>>1],w[j+28>>1]=k;w[e+72>>1]=z[e+14>>1];w[e+6>>1]=256;j=b,k=z[Zc(e+72|0,e+6|0)>>1],w[j+30>>1]=k;w[e+72>>1]=z[e+16>>1];w[e+6>>1]=64;j=b,k=z[Zc(e+72|0,e+6|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+20|0];v[b+39|0]=y[e+21|0];v[b+40|0]=y[e+22|0];v[b+41|0]=y[e+23|0];f=x[a+88>>2];a=x[a+80>>2];x[23420]=0;a=W(144,a|0,f|0,32)|0;f=x[23420];x[23420]=0;if((f|0)==1){break s}if(!a){break b}x[23420]=0;R(740,c|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break s}x[23420]=0;a=T(190,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break s}x[23420]=0;U(741,c|0,b+43|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){break b}}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}a=P()|0;break a}zb(e+88|0);hb=e+112|0;return}zb(e+88|0);S(a|0);p()}function yM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){h=a+327720|0;c=hb-400|0;hb=c;zO(c+384|0,8);x[23420]=0;ra(716,c+368|0,9);i=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){x[23420]=0;i=Q(717,c+352|0,14)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}x[23420]=0;R(718,c+384|0,i|0);e=x[23420];x[23420]=0;if((e|0)==1){break k}x[23420]=0;R(718,c+368|0,i|0);e=x[23420];x[23420]=0;if((e|0)==1){break k}yO(c+280|0,4900);yO(c+208|0,32e3);pO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[23420]=0;e=Q(719,c+104|0,c+384|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break j}ht(c+120|0,c+280|0,e);je(e);x[23420]=0;e=Q(719,c+72|0,c+368|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break i}ht(c+88|0,c+208|0,e);je(e);x[23420]=0;e=Q(719,c+40|0,c+120|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break h}ht(c+56|0,c+136|0,e);je(e);x[23420]=0;e=Q(719,c+8|0,c+88|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break g}g=c+24|0;ht(g,c+136|0,e);je(e);e=c+120|0;Fp(e);l=c+56|0;Fp(l);m=c+88|0;Fp(m);Fp(g);q=c+368|0;Fp(q);Ep(x[c+120>>2],x[c+124>>2],Xn(h,0));Ep(x[c+56>>2],x[c+60>>2],Xn(h,1));Ep(x[c+88>>2],x[c+92>>2],Xn(h,2));Ep(x[c+24>>2],x[c+28>>2],Xn(h,3));Ep(x[c+368>>2],x[c+372>>2],Xn(h,4));je(g);je(l);je(m);je(e);dl(i);je(q);je(c+384|0);hb=c+400|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;je(c+56|0)}je(c+88|0)}je(c+120|0)}dl(i)}je(c+368|0)}je(c+384|0);S(a|0);p()}cy(a+131112|0,9.6377,.97);cy(a+196648|0,8.5,.5);cy(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(u=0,v=NL(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];h=hb+-64|0;hb=h;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=J(C[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:H(d,32768);n:{if(F(d)<2147483648){i=~~d;break n}i=-2147483648}w[m>>1]=i;b=b+1|0;continue}}else{j=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=Oe(d*.8975979010256552)*-.5+.5;break o;case 1:f=Oe(d*.8975979010256552)*-.46+.54;break o;case 2:f=Oe(d*1.7951958020513104)*.08+(Oe(d*.8975979010256552)*-.5+.42);break o;case 3:f=Oe(d*1.7951958020513104)*.05677+(Oe(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Oe(d*1.7951958020513104)*.07922+(Oe(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Oe(d*1.7951958020513104);k=Oe(d*.8975979010256552);f=Oe(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Oe(d*1.7951958020513104);k=Oe(d*.8975979010256552);f=Oe(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Oe(d*1.7951958020513104);k=Oe(d*.8975979010256552);f=Oe(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;j=si(d*j)/d}j=f*j;C[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}hb=h- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function PJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-256|0;hb=e;v[e+255|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Kk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tk(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;Qd(f);g=x[e+80>>2];Qd(e+224|0);h=Jk(g,x[e+228>>2],b);Qd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=qc(e+240|0,21473);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Lc(g,f,e)){d=ba(8)|0;x[23420]=0;R(910,e+224|0,e+255|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}x[23420]=0;U(917,e+80|0,17452,e+224|0);a=x[23420];x[23420]=0;if((a|0)==1){break f}a=0;b=rc(d,e+80|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);break e}if(!d){break h}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23420]=0;a=Ch(e+192|0,b,a);b=x[23420];x[23420]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23420]=0;U(917,e+208|0,17488,a|0);b=x[23420];x[23420]=0;if((b|0)==1){break p}x[23420]=0;R(919,e+224|0,e+208|0);b=x[23420];x[23420]=0;c=1;if((b|0)==1){break o}x[23420]=0;R(910,e+176|0,e+255|0);b=x[23420];x[23420]=0;if((b|0)==1){break n}x[23420]=0;U(921,e+80|0,e+224|0,e+176|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}b=rc(d,e+80|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);c=0;break l}b=P()|0;break d}b=P()|0;c=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}xb(e+176|0)}xb(e+224|0)}xb(e+208|0)}xb(a);if(c){break d}break c}b=qc(e+168|0,21473);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Lc(g,f,e+72|0)){d=ba(8)|0;x[23420]=0;R(910,e+224|0,e+255|0);a=x[23420];x[23420]=0;q:{r:{if((a|0)!=1){x[23420]=0;U(917,e+80|0,17452,e+224|0);a=x[23420];x[23420]=0;if((a|0)==1){break r}a=0;b=rc(d,e+80|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(e+80|0);break q}b=P()|0;break d}b=P()|0;a=1}xb(e+224|0);if(a){break d}break c}b=qc(e+160|0,7380);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Lc(g,f,e- -64|0)){b=qc(e+152|0,7362);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Lc(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=qc(e+144|0,6895);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Lc(g,f,e+48|0)){b=qc(e+136|0,6876);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Lc(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=qc(e+128|0,6979);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Lc(g,f,e+32|0)){v[a+62|0]=c;break h}b=qc(e+120|0,6025);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Lc(g,f,e+24|0)){v[a+63|0]=c;break h}b=qc(e+112|0,7429);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Lc(g,f,e+16|0)){v[a+64|0]=c;break h}b=qc(e+104|0,13234);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Lc(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=sJ(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!tx(e+80|0,b+24648|0)){break h}ny(b,e+80|0)}hb=e+256|0;return}b=P()|0;break d}b=P()|0;a=1}xb(e+224|0);if(!a){break c}}ca(d|0)}S(b|0)}p()}function Sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-224|0;hb=f;ae(f+208|0,b);g=hb-48|0;hb=g;x[g+44>>2]=0;bk(b,g+44|0);a:{b:{c:{if(x[g+44>>2]!=(Bm(13947)|0)){break c}x[g+40>>2]=0;e=hb-32|0;hb=e;x[e+24>>2]=0;Kv(e+8|0,e+24|0);kn(e+16|0,b,x[e+8>>2],x[e+12>>2]);x[g+40>>2]=x[e+24>>2];hb=e+32|0;e=-1;i=x[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Jb(g+24|0);x[23420]=0;h=W(430,b|0,i|0,256)|0;j=x[23420];x[23420]=0;if((j|0)==1){break b}if(!h){break e}x[23420]=0;U(11,g+8|0,d|0,i|0);h=x[23420];x[23420]=0;if((h|0)!=1){break f}break b}i=Jb(g+24|0);x[23420]=0;h=Q(432,b|0,i|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break b}if(!h){break d}x[23420]=0;U(11,g+8|0,d|0,i|0);h=x[23420];x[23420]=0;if((h|0)==1){break b}}h=g+8|0;Gb(c,h);yb(h);xb(i);Lf(b,h);i=0;x[g+24>>2]=0;bk(b,g+24|0);h=x[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(fL(a,b,d)){continue}break}break c}x[g+24>>2]=0;bk(b,g+24|0);e=x[g+24>>2]==(Bm(13993)|0)?1:-1;break c}xb(i);break c}xb(i)}hb=g+48|0;break a}a=P()|0;xb(i);S(a|0);p()}h:{if(e){break h}Ym(x[x[b>>2]-12>>2]+b|0,0);e=x[f+220>>2];x[f+8>>2]=x[f+216>>2];x[f+12>>2]=e;e=x[f+212>>2];x[f>>2]=x[f+208>>2];x[f+4>>2]=e;b=El(f+104|0,Hj(b,f));x[23420]=0;e=Q(396,f+88|0,14132)|0;g=x[23420];x[23420]=0;i:{if((g|0)!=1){x[23420]=0;x[f+72>>2]=3;x[f+76>>2]=0;U(397,b|0,e|0,f+72|0);g=x[23420];x[23420]=0;if((g|0)!=1){Sb(e);v[f+87|0]=0;x[23420]=0;e=Q(396,f+72|0,14588)|0;g=x[23420];x[23420]=0;if((g|0)!=1){x[23420]=0;U(398,b|0,f+87|0,e|0);g=x[23420];x[23420]=0;if((g|0)!=1){Sb(e);x[23420]=0;g=y[f+87|0];e=T(411,b|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){x[23420]=0;i=T(412,b|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){g=g?0:d;x[f+64>>2]=e;j:{k:{l:{m:{while(1){if(!Pb(e,i)){a=x[b>>2];Zg(b);e=a&1073741824?-1:1;break h}x[23420]=0;d=Q(396,f+48|0,15625)|0;e=x[23420];x[23420]=0;if((e|0)==1){break l}e=x[b+36>>2];h=x[b+32>>2];x[23420]=0;e=fa(413,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break k}Sb(d);n:{o:{if(!e){x[23420]=0;X(414,b|0,f- -64|0,c|0,g|0);d=x[23420];x[23420]=0;if((d|0)!=1){break o}break j}x[23420]=0;d=Q(396,f+32|0,15227)|0;e=x[23420];x[23420]=0;p:{q:{if((e|0)!=1){e=x[b+36>>2];h=x[b+32>>2];x[23420]=0;e=fa(413,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break q}Sb(d);if(e){break p}x[23420]=0;U(415,b|0,f- -64|0,f+62|0);d=x[23420];x[23420]=0;if((d|0)==1){break j}break o}a=P()|0;break i}a=P()|0;Sb(d);break i}x[23420]=0;d=Q(396,f+16|0,15126)|0;e=x[23420];x[23420]=0;if((e|0)==1){break n}e=x[b+36>>2];h=x[b+32>>2];x[23420]=0;e=fa(413,h|0,e|0,x[f+64>>2],d|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break m}Sb(d);if(e){break o}x[23420]=0;X(416,b|0,f- -64|0,a|0,g|0);d=x[23420];x[23420]=0;if((d|0)==1){break j}}co(f- -64|0);e=x[f+64>>2];continue}break}a=P()|0;break i}a=P()|0;Sb(d);break i}a=P()|0;break i}a=P()|0;Sb(d);break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;break i}a=P()|0;Sb(e);break i}a=P()|0;break i}a=P()|0;Sb(e);break i}a=P()|0}Zg(b);S(a|0);p()}hb=f+224|0;return e|0}function OJ(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-176|0;hb=e;C[e+168>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[Kk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tk(e+144|0,g,f,f-1|0);f=x[e+148>>2];x[b>>2]=x[e+144>>2];x[b+4>>2]=f}f=e+144|0;Qd(f);g=x[e+144>>2];Qd(e+128|0);h=Jk(g,x[e+132>>2],b);Qd(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+148>>2]){a=qc(e+160|0,21473);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Lc(g,f,e+8|0)){d=ba(8)|0;x[23420]=0;R(914,e+128|0,e+168|0);a=x[23420];x[23420]=0;f:{g:{h:{if((a|0)!=1){x[23420]=0;U(917,e+144|0,17452,e+128|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}a=0;b=rc(d,e+144|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(e+144|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(e+128|0);if(!a){break c}}ca(d|0);break c}if(!d){break e}d=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23420]=0;f=Ch(e+96|0,b,a);a=x[23420];x[23420]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23420]=0;U(917,e+112|0,17488,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}x[23420]=0;R(919,e+128|0,e+112|0);b=x[23420];x[23420]=0;a=1;if((b|0)==1){break p}x[23420]=0;R(914,e+80|0,e+168|0);a=x[23420];x[23420]=0;if((a|0)==1){break o}x[23420]=0;U(921,e+144|0,e+128|0,e+80|0);b=x[23420];x[23420]=0;a=1;if((b|0)==1){break n}a=rc(d,e+144|0);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(e+144|0);a=0;break m}b=P()|0;break i}b=P()|0;a=1;break j}b=P()|0;break k}b=P()|0;a=1;break l}b=P()|0}xb(e+80|0)}xb(e+128|0)}xb(e+112|0)}xb(f);if(!a){break c}}ca(d|0);break c}b=qc(e+72|0,21473);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Lc(g,f,e+40|0)){d=ba(8)|0;x[23420]=0;R(914,e+128|0,e+168|0);a=x[23420];x[23420]=0;r:{s:{t:{if((a|0)!=1){x[23420]=0;U(917,e+144|0,17452,e+128|0);a=x[23420];x[23420]=0;if((a|0)==1){break t}a=0;b=rc(d,e+144|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(e+144|0);break s}b=P()|0;break r}b=P()|0;a=1}xb(e+128|0);if(!a){break c}}ca(d|0);break c}b=qc(e- -64|0,7677);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Lc(g,f,e+32|0)){if(!Rd(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[23420]=0;d=Q(54,e+144|0,7772)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(d);break c}a=x[a+24>>2];i=a,j=Ie(65536/c),x[i+480244>>2]=j;up(a);break e}b=qc(e+56|0,7729);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Lc(g,f,e+24|0)){if(!Rd(y[a+28|0])){break e}if(c<=0|c>4){a=ba(8)|0;x[23420]=0;d=Q(54,e+144|0,7793)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(d);break c}b=P()|0;ca(a|0);break c}a=x[a+24>>2];i=a,j=Ie(c*65536),x[i+480240>>2]=j;up(a);break e}b=qc(e+48|0,7747);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Lc(g,f,e+16|0)){break e}i=x[a+24>>2],j=fm(c*65536),x[i+480236>>2]=j}hb=e+176|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function Ib(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[23300]){break a}a=a+b|0;if(x[23301]!=(d|0)){if(b>>>0<=255){e=x[d+8>>2];b=b>>>3|0;c=x[d+12>>2];if((c|0)==(e|0)){i=93184,j=x[23296]&_ia(-2,b),x[i>>2]=j;break b}x[e+12>>2]=c;x[c+8>>2]=e;break b}h=x[d+24>>2];b=x[d+12>>2];c:{if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}d:{e=d+20|0;c=x[e>>2];if(c){break d}e=d+16|0;c=x[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break b}e=x[d+28>>2];c=(e<<2)+93488|0;e:{if(x[c>>2]==(d|0)){x[c>>2]=b;if(b){break e}i=93188,j=x[23297]&_ia(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b;break b}b=x[f+4>>2];if((b&3)!=3){break b}x[23298]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(x[23302]==(f|0)){x[23302]=d;a=x[23299]+a|0;x[23299]=a;x[d+4>>2]=a|1;if(x[23301]!=(d|0)){break a}x[23298]=0;x[23301]=0;return}if(x[23301]==(f|0)){x[23301]=d;a=x[23298]+a|0;x[23298]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=x[f+8>>2];b=b>>>3|0;c=x[f+12>>2];if((c|0)==(e|0)){i=93184,j=x[23296]&_ia(-2,b),x[i>>2]=j;break g}x[e+12>>2]=c;x[c+8>>2]=e;break g}h=x[f+24>>2];b=x[f+12>>2];h:{if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}i:{e=f+20|0;c=x[e>>2];if(c){break i}e=f+16|0;c=x[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break g}e=x[f+28>>2];c=(e<<2)+93488|0;j:{if(x[c>>2]==(f|0)){x[c>>2]=b;if(b){break j}i=93188,j=x[23297]&_ia(-2,e),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[23301]!=(d|0)){break f}x[23298]=a;return}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+93224|0;c=x[23296];a=1<<(a>>>3);k:{if(!(c&a)){x[23296]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}x[d+28>>2]=e;x[d+16>>2]=0;x[d+20>>2]=0;g=(e<<2)+93488|0;l:{m:{c=x[23297];b=1<<e;n:{if(!(c&b)){x[23297]=b|c;x[g>>2]=d;x[d+24>>2]=g;break n}e=a<<((e|0)!=31?25-(e>>>1|0)|0:0);b=x[g>>2];while(1){c=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=c}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[c+8>>2];x[a+12>>2]=d;x[c+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=c;x[d+8>>2]=a}a=x[23304]-1|0;x[23304]=a?a:-1}}function xg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=hb-112|0;hb=k;l=i&2147483647;j=e&2147483647;m=j;a:{b:{o=!(b|c);if(!(d|j?j-2147418112>>>0<2147549184:o)){n=l-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?o:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(l|0)==2147418112?!(f|g):l>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(l^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|l)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|l)){break b}f=b;g=c;h=d;i=e;break a}j=(l|0)==(m|0);j=j&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:j&d>>>0<h>>>0|l>>>0>m>>>0;p=j?f:b;m=j?g:c;l=j?i:e;s=l;q=j?h:d;o=l&65535;e=j?e:i;r=e;h=j?d:h;l=e>>>16&32767;n=s>>>16&32767;if(!n){d=!(o|q);e=d<<6;i=G(d?p:q)+32|0;d=G(d?m:o);d=e+((d|0)==32?i:d)|0;wf(k+96|0,p,m,q,o,d-15|0);q=x[k+104>>2];o=x[k+108>>2];p=x[k+96>>2];n=16-d|0;m=x[k+100>>2]}f=j?b:f;g=j?c:g;i=r&65535;if(!l){b=!(h|i);c=b<<6;d=G(b?f:h)+32|0;b=G(b?g:i);b=c+((b|0)==32?d:b)|0;wf(k+80|0,f,g,h,i,b-15|0);l=16-b|0;h=x[k+88>>2];i=x[k+92>>2];g=x[k+84>>2];f=x[k+80>>2]}c=h;b=i<<3|c>>>29;d=c<<3;c=b;b=g>>>29|d;c=c|524288;d=q;j=o<<3|d>>>29;h=d<<3|m>>>29;i=j;r=r^s;d=f;e=g<<3|d>>>29;d=d<<3;c:{if((l|0)==(n|0)){break c}f=n-l|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}wf(k- -64|0,d,e,b,c,128-f|0);Wl(k+48|0,d,e,b,c,f);b=x[k+56>>2];c=x[k+60>>2];e=x[k+52>>2];d=x[k+48>>2]|(x[k+64>>2]|x[k+72>>2]|(x[k+68>>2]|x[k+76>>2]))!=0}l=d;o=e;j=h;q=i|524288;d=p;e=m<<3|d>>>29;m=d<<3;p=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(l^m|b^j|(o^p|c^q))){break a}d=m-l|0;e=p-((l>>>0>m>>>0)+o|0)|0;c=q-((b>>>0>j>>>0)+c|0)|0;f=j-b|0;b=(o|0)==(p|0)&l>>>0>m>>>0|o>>>0>p>>>0;i=c-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;f=G(b?d:h)+32|0;b=G(b?e:i);b=c+((b|0)==32?f:b)|0;b=b-12|0;wf(k+32|0,d,e,h,i,b);n=n-b|0;h=x[k+40>>2];i=x[k+44>>2];d=x[k+32>>2];e=x[k+36>>2];break d}e=o+p|0;d=l+m|0;e=d>>>0<m>>>0?e+1|0:e;f=b;b=j;f=f+b|0;j=c+q|0;j=b>>>0>f>>>0?j+1|0:j;c=f;b=c+((e|0)==(o|0)&d>>>0<l>>>0|e>>>0<o>>>0)|0;h=b;i=b>>>0<c>>>0?j+1|0:j;if(!(i&1048576)){break d}c=h;j=c<<31;d=l&1|((e&1)<<31|d>>>1);e=j|e>>>1;n=n+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}c=0;m=s&-2147483648;if((n|0)>=32767){h=c;i=m|2147418112;f=0;g=0;break a}l=0;e:{if((n|0)>0){l=n;break e}wf(k+16|0,d,e,h,i,n+127|0);Wl(k,d,e,h,i,1-n|0);d=x[k>>2]|(x[k+16>>2]|x[k+24>>2]|(x[k+20>>2]|x[k+28>>2]))!=0;e=x[k+4>>2];h=x[k+8>>2];i=x[k+12>>2]}j=h<<29;o=(e&7)<<29|d>>>3;f=o;n=d&7;d=f+(n>>>0>4)|0;b=e>>>3|j;e=d>>>0<f>>>0?b+1|0:b;f=d;c=c|((i&7)<<29|h>>>3);g=e;b=c+((b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0)|0;i=m|(i>>>3&65535|l<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((n|0)==4){c=0;j=g+c|0;d=f&1;b=f+d|0;j=b>>>0<f>>>0?j+1|0:j;f=b;g=j;c=(c|0)==(j|0)&b>>>0<d>>>0|c>>>0>j>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!n){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;hb=k+112|0}function dha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-400|0;hb=e;g=hb-32|0;hb=g;d=g+8|0;PA(d,b);Eu(g,d);x[23420]=0;U(410,e+240|0,x[g>>2],x[g+4>>2]);b=x[23420];x[23420]=0;a:{if((b|0)!=1){Oc(g+8|0);hb=g+32|0;break a}a=P()|0;Oc(g+8|0);S(a|0);p()}x[23420]=0;U(393,e+136|0,x[e+240>>2],x[e+244>>2]);b=x[23420];x[23420]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[23420]=0;g=Q(78,e+256|0,e+136|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break z}xb(e+136|0);dc(e+240|0);if(c>>>0<2189){break g}b=El(e+136|0,g);x[23420]=0;c=Q(396,e+120|0,10016)|0;d=x[23420];x[23420]=0;if((d|0)==1){break x}x[23420]=0;x[e+104>>2]=19924737;x[e+108>>2]=0;U(397,b|0,c|0,e+104|0);d=x[23420];x[23420]=0;if((d|0)==1){break w}Sb(c);v[e+119|0]=0;x[23420]=0;c=Q(396,e+104|0,10906)|0;d=x[23420];x[23420]=0;if((d|0)==1){break i}x[23420]=0;U(398,b|0,e+119|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break v}Sb(c);c=0;c=y[e+119|0]?c:x[a+1298404>>2];f=x[a+4>>2];x[23420]=0;d=Q(396,e+88|0,15625)|0;h=x[23420];x[23420]=0;if((h|0)==1){break u}x[23420]=0;X(399,b|0,f|0,d|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break t}Sb(d);x[23420]=0;d=Q(396,e+72|0,15227)|0;f=x[23420];x[23420]=0;if((f|0)==1){break s}x[23420]=0;X(400,b|0,a|0,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break r}Sb(d);x[23420]=0;c=Q(396,e+56|0,15126)|0;d=x[23420];x[23420]=0;if((d|0)==1){break q}x[23420]=0;d=a+484360|0;U(401,b|0,d|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break p}Sb(c);x[23420]=0;c=Q(396,e+40|0,26486)|0;f=x[23420];x[23420]=0;if((f|0)==1){break o}x[23420]=0;U(402,b|0,a+484344|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break n}Sb(c);f=x[a+1298404>>2];x[23420]=0;c=Q(396,e+24|0,26492)|0;h=x[23420];x[23420]=0;if((h|0)==1){break m}x[23420]=0;X(403,b|0,d|0,c|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break l}Sb(c);if(y[b+3|0]&64){x[23420]=0;c=Q(1,e+8|0,16104)|0;d=x[23420];x[23420]=0;if((d|0)==1){break k}a=x[a+1298464>>2];x[23420]=0;U(353,a|0,1,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}yb(c)}Zg(b);break f}a=P()|0;break y}a=P()|0;xb(e+136|0)}dc(e+240|0);break b}a=P()|0;break h}a=P()|0;Sb(c);break h}a=P()|0;Sb(c);break h}a=P()|0;break h}a=P()|0;Sb(d);break h}a=P()|0;break h}a=P()|0;Sb(d);break h}a=P()|0;break h}a=P()|0;Sb(c);break h}a=P()|0;break h}a=P()|0;Sb(c);break h}a=P()|0;break h}a=P()|0;Sb(c);break h}a=P()|0;break h}a=P()|0;yb(c);break h}a=P()|0}Zg(b);break c}b=Jb(e+136|0);d=x[a+1298404>>2];f=x[a+4>>2];x[23420]=0;d=fa(404,f|0,g|0,b|0,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[23420]=0;c=Q(1,e+120|0,16410)|0;d=x[23420];x[23420]=0;B:{if((d|0)!=1){a=x[a+1298464>>2];x[23420]=0;U(353,a|0,1,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break B}yb(c);break A}a=P()|0;break d}a=P()|0;yb(c);break d}d=x[a+1298404>>2];x[23420]=0;X(405,g|0,a|0,d|0,c>>>0<2188|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}}yb(b)}gf(g);hb=e+400|0;return}a=P()|0}yb(b)}gf(g)}S(a|0);p()}function Ida(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=hb-4144|0;hb=h;g=Lb(y[a+14|0]|y[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(z[j>>1]<=y[a+23|0]){break a}pd(d,32);w[d+34>>1]=1;f=h+24|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;TP(h+4136|0,x[h+24>>2],x[h+28>>2],Lb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4136>>2];k=y[Cb(g,0)+3|0];x[h+24>>2]=1;k=x[Yc(_j(b,k+1|0)+24|0,f)>>2];i=f;f=x[h+4140>>2];TP(i,g,f,c?f:1);r=1/+(k>>>0);f=x[h+24>>2];g=Cb(f,x[h+28>>2]);k=x[h+4136>>2];j=z[j>>1];while(1){if((f|0)==(g|0)){b:{s=Ag(d);if(!s){break b}g=x[h+4140>>2];k=h+4120|0;x[k>>2]=0;x[k+4>>2]=0;Bc(k+8|0);if(g){f=hb-16|0;hb=f;x[f+12>>2]=4925421;x[f+8>>2]=2147483647;j=x[Hb(f+12|0,f+8|0)>>2];hb=f+16|0;if(g>>>0>j>>>0){Tc();p()}if(g>>>0>=4925422){ig();p()}g=D(g,872);f=wc(g);x[k>>2]=f;x[k+4>>2]=f;C=Fb(k),E=f+g|0,x[C>>2]=E;f=hb-16|0;hb=f;x[f>>2]=k;j=x[k+4>>2];x[f+4>>2]=j;x[f+8>>2]=g+j;i=x[f+4>>2];g=x[f+8>>2];while(1){if((g|0)==(i|0)){kc(f);hb=f+16|0}else{HP(Tb(i,0,872));i=i+872|0;x[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;t=x[k>>2];n=x[h+4136>>2];u=x[h+4140>>2];B=b+480190|0;f=0;i=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=Cb(n,f);e=SP(t,f);l=y[g+3|0];c:{if(l>>>0>=z[B>>1]){break c}o=v[g+1|0];if((o|0)<0){break c}m=0;g=y[g+2|0];if((g+14&255)>>>0<=5){m=v[g+26638|0]}g=_j(b,l+1|0);l=x[g+24>>2];q=r*(Ej(+(m<<24>>24)/96+ +(o-v[Cb(n,0)+1|0]|0)/12)*+(l>>>0));if(q<=0){break c}m=RP(q);x[e+8>>2]=m;l=lb;x[e+12>>2]=l;x[e+16>>2]=x[g+20>>2];o=x[g>>2];x[e+76>>2]=o;x[e+88>>2]=z[g+34>>1]&1023;d:{if(c){x[e+664>>2]=i;i=Ie(+(o>>>0)/Nz(m,l))+i|0;g=j;break d}g=(j>>>0)/(Lb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=x[d>>2];if(a>>>0>b>>>0){Tb(h+24|0,0,4096);x[h+16>>2]=512;x[h+12>>2]=a-b;c=x[Hb(h+16|0,h+12|0)>>2];C=h,E=Db(x[k>>2]),x[C+16>>2]=E;j=Db(x[k+4>>2]);while(1){a=x[h+16>>2];if(!Pb(a,j)){break e}f:{g:{if(!x[a+16>>2]){break g}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break g}f=x[a+88>>2];x[h+12>>2]=c-e;C=h,E=Ie((+A[a+76>>2]-Nz(x[a>>2],x[a+4>>2]))/Nz(x[a+8>>2],x[a+12>>2])),x[C+8>>2]=E;i=x[Hb(h+12|0,h+8|0)>>2];x[23420]=0;X(x[((f&1|(f&64?18:16))<<2)+27232>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=x[23420];x[23420]=0;if((e|0)==1){break f}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break g}x[a+16>>2]=0}x[h+16>>2]=x[h+16>>2]+872;continue}break}a=P()|0;At(k);S(a|0);p()}At(k);break b}e=x[d+20>>2]+(b<<1)|0;f=h+24|0;a=hb-16|0;hb=a;x[a+12>>2]=c;xc(a+12|0,512);i=x[a+12>>2];while(1){if(i){j=hd(x[f>>2]+2048|0,12);j=(j|0)>=32767?32767:j;w[e>>1]=(j|0)<=-32768?-32768:j;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}hb=a+16|0;b=b+c|0;continue}}f=(s|0)!=0}else{i=y[f+3|0];h:{if(i>>>0>=j>>>0){break h}n=v[f+1|0];if((n|0)<0){break h}i=_j(b,i+1|0);m=x[i>>2];q=Ej(+(n-v[Cb(k,0)+1|0]|0)/-12);C=d,E=x[d>>2]+Ie(r*(q*+(m>>>0)*+A[i+24>>2]))|0,x[C>>2]=E}f=f+4|0;continue}break}}hb=h+4144|0;return f|0}function mR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=x[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=x[23301]){if(c>>>0<=255){e=x[a+8>>2];c=c>>>3|0;d=x[a+12>>2];if((d|0)!=(e|0)){break c}i=93184,j=x[23296]&_ia(-2,c),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];d:{if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break d}e:{e=a+20|0;d=x[e>>2];if(d){break e}e=a+16|0;d=x[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0}if(!h){break b}e=x[a+28>>2];d=(e<<2)+93488|0;f:{if(x[d>>2]==(a|0)){x[d>>2]=c;if(c){break f}i=93188,j=x[23297]&_ia(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c;break b}c=x[f+4>>2];if((c&3)!=3){break b}x[23298]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[e+12>>2]=d;x[d+8>>2]=e}c=x[f+4>>2];g:{if(!(c&2)){if(x[23302]==(f|0)){x[23302]=a;b=x[23299]+b|0;x[23299]=b;x[a+4>>2]=b|1;if(x[23301]!=(a|0)){break a}x[23298]=0;x[23301]=0;return}if(x[23301]==(f|0)){x[23301]=a;b=x[23298]+b|0;x[23298]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=x[f+8>>2];c=c>>>3|0;d=x[f+12>>2];if((d|0)==(e|0)){i=93184,j=x[23296]&_ia(-2,c),x[i>>2]=j;break h}x[e+12>>2]=d;x[d+8>>2]=e;break h}h=x[f+24>>2];c=x[f+12>>2];i:{if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}j:{d=f+20|0;e=x[d>>2];if(e){break j}d=f+16|0;e=x[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=x[d>>2];if(e){continue}d=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0}if(!h){break h}e=x[f+28>>2];d=(e<<2)+93488|0;k:{if(x[d>>2]==(f|0)){x[d>>2]=c;if(c){break k}i=93188,j=x[23297]&_ia(-2,e),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[23301]!=(a|0)){break g}x[23298]=b;return}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+93224|0;d=x[23296];b=1<<(b>>>3);l:{if(!(d&b)){x[23296]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}x[a+28>>2]=e;x[a+16>>2]=0;x[a+20>>2]=0;g=(e<<2)+93488|0;m:{d=x[23297];c=1<<e;n:{if(!(d&c)){x[23297]=c|d;x[g>>2]=a;x[a+24>>2]=g;break n}e=b<<((e|0)!=31?25-(e>>>1|0)|0:0);c=x[g>>2];while(1){d=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=d}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[d+8>>2];x[b+12>>2]=a;x[d+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=d;x[a+8>>2]=b}}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=hb-736|0;hb=e;zc(b);f=hb-16|0;hb=f;h=e+120|0;qU(f+8|0,h);g=x[f+12>>2];j=b;mc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){$b(j,x[f+12>>2])}hb=f+16|0;b=(b|0)==(g|0);if(!b){pU(h)}a:{if(!b){break a}if(!rU(e+120|0)){break a}b:{if(!c){break b}Dd(a,67108864);Cg(a);b=y[e+145|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=Vb(e,8097);Gb(a+1298344|0,b);yb(b);b=Vb(e,10663);Gb(a+1298356|0,b);yb(b);d=e+96|0;rg(d,4135);f=y[e+144|0];x[e+72>>2]=f>>>4;b=0;x[23420]=0;x[e+116>>2]=f&15;X(288,e|0,d|0,e+72|0,e+116|0);d=x[23420];x[23420]=0;c:{d:{if((d|0)!=1){Gb(a+1298368|0,e);yb(e);cc(e+96|0);x[a+1298404>>2]=13;rq(Yb(x[a+484360>>2],y[a+484376|0]),e+168|0,y[e+167|0]+1|0);while(1){e:{if((b|0)==31){vu(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=D(d,104)+a|0;h=g+484380|0;pd(h,1);f=(e+120|0)+(b<<2)|0;q=h,r=ac(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[q>>2]=r;k=ac(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=ac(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}kk(h);b=(e+120|0)+b|0;v[e|0]=y[b+548|0];v[e+96|0]=64;q=g+484410|0,r=y[Wb(e,e+96|0)|0]<<2,w[q>>1]=r;v[g+484417|0]=y[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){oU(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){lg(a+484344|0,y[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(y[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=_c(e,8,1,1,0);while(1){if((d|0)==32){break b}kg(b,(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=zh(e+96|0);f:{g:{if(y[e+146|0]){x[23420]=0;b=T(258,j|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}x[23420]=0;U(178,e+72|0,j|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break f}break g}b=z[m>>1];x[23420]=0;U(178,e+72|0,j|0,b<<8);b=x[23420];x[23420]=0;if((b|0)==1){break d}}b=e+72|0;d=jc(e,b);bd(g,d);zb(d);zb(b);h:{if(!n){break h}x[23420]=0;b=W(214,k|0,f&65535,64)|0;d=x[23420];x[23420]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(y[e+146|0]){h=0;x[23420]=0;R(289,g|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=_b(x[k>>2],f);l=pf(x[l>>2],x[x[l+48>>2]+12>>2],h);while(1){if(z[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(y[i|0]&b)){break j}x[23420]=0;R(290,g|0,l+D(d,6)|0);o=x[23420];x[23420]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=z[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=_b(x[k>>2],f);i=ed(x[i>>2],x[x[i+48>>2]+12>>2],d,h);x[23420]=0;R(290,g|0,i|0);i=x[23420];x[23420]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}zb(g);f=f+1|0;continue}break}break d}d=P()|0;cc(e+96|0);break c}d=P()|0;zb(g)}S(d|0);p()}d=1}hb=e+736|0;return d|0}function _L(a,b){var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=E(0),t=0;if(b){oy(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;dM(a)}ZL(a+24648|0);o=x[a+24620>>2];f=hb-144|0;hb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}h=D(c,44)+47472|0;if(!((h|0)==x[e+8>>2]&d)){x[e+8>>2]=h;m=E(o>>>0);c=f+8|0;d=x[h+24>>2];x[c>>2]=d;j=x[h+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;x[c+4>>2]=i-j;x[c>>2]=d-j}g=E(B[h+36>>2]*E(79.30999755859375));a:{if(E(F(g))<E(2147483648)){d=~~g;break a}d=-2147483648}x[c+16>>2]=d- -8192;g=E(E(E(B[h+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(g))<E(2147483648)){d=~~g;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;g=B[h+8>>2];l=E(E(H(B[h+20>>2],E(.10000000149011612)))*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;i=k-7500|0;n=k>>>0>=i>>>0?i:0;l=E(B[h+28>>2]*m);d:{if(E(F(l))<E(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)<=128?128:d;p=i>>>0>=3800?3800:i;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=E(g*m);e:{if(E(F(g))<E(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0<=i>>>0?d:0)|0;x[c+32>>2]=i;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){g=E(i|0);l=E(me(E(.0010000000474974513),(i|0)<4721?E(1):E(E(4720)/g))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;g=E(B[h+12>>2]*g);r=c,s=me(E(.0010000000474974513),g<=E(4720)?E(1):E(E(4720)/g)),B[r+28>>2]=s}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+48762>>1];w[k+36>>1]=z[d+48756>>1];w[k+40>>1]=z[d+48760>>1];w[k+38>>1]=z[d+48758>>1];x[k+44>>2]=n+((D(x[d+48752>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+40>>2];c=aK(bK(x[f+16>>2]),m);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+24>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+32>>2];c=x[f+12>>2];if((c|0)>-9e3){c=$J(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+8>>2];if((c|0)>=-8999){c=$J(c)}else{c=0}x[d>>2]=c;c=x[f+28>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+4>>2]=x[f+20>>2];ge(f+4|0,0,32752);c=z[f+4>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;g=B[f+36>>2];r=f,t=aK(E(g*g),m),x[r>>2]=t;ge(f,256,32512);c=z[f>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+D(c,12)|0;j=x[h+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[h+36>>1];w[d+110>>1]=z[h+42>>1];w[d+112>>1]=z[h+40>>1];w[d+114>>1]=z[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){x[e+16>>2]=0;dK(e,c,d)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}hb=f+144|0;b=x[a+1298300>>2];if(wd(b)){IO(b,x[a+24620>>2])}}function RV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=hb-32|0;hb=e;x[e+28>>2]=b;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+16>>2]=214748364;u=e,w=D(x[Hb(e+28|0,e+16|0)>>2],20),x[u+20>>2]=w;en(c,x[Hb(e+8|0,e+20|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=ch(a,b,i);h=ch(a,b,i+4|0);f=ch(a,b,i+5|0);u=e,w=ch(a,b,i+6|0)<<8|ch(a,b,i+7|0),x[u+24>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ba(8)|0;x[23420]=0;a=T(181,i|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=ch(a,b,i+t|0),v[u+20|0]=w;dn(c,e+20|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}Vh(e+24|0,d);s=x[e+24>>2];o=ch(a,b,i+10|0);v[e+20|0]=o;dn(c,e+20|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=og(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!og(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!og(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!og(j,f,1,e+8|0)){break o}k=og(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ba(8)|0;x[23420]=0;b=T(181,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ba(8)|0;x[23420]=0;b=T(181,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break q}}b=P()|0;ca(a|0);S(b|0);p()}ha(b|0,25912,156);p()}ha(b|0,25912,156);p()}m=y[h+25952|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=ch(x[e+8>>2],x[e+12>>2],h);o=o-hd((ch(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|ch(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+20|0]=o;dn(c,e+20|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!og(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!og(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!og(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!og(j,g+4|0,1,e+8|0)){g=g+8|0;f=og(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=og(j,f,5,e+8|0);break u}g=f+2|0;f=og(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(og(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=og(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=og(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Wc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[Kb(x[c>>2],g)|0];v[e+20|0]=o;dn(c,e+20|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ba(8)|0;x[23420]=0;a=T(181,i|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}ha(a|0,25912,156);p()}q=q-(q>>3)|0;continue}}ha(a|0,25912,156);p()}i=uc(x[c>>2],x[c+4>>2])^1;break a}a=P()|0;ca(i|0);S(a|0);p()}x[e+24>>2]=i}d=d-s|0;i=n+t|0;continue}}hb=e+32|0;return i|0}function XS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-176|0;hb=g;i=gg(g+160|0);a:{b:{c:{if(d){x[23420]=0;U(417,a|0,i|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){break c}break b}x[23420]=0;U(418,a|0,i|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}}k=Qb(g+144|0);m=b+480192|0;n=b+1298464|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[m>>1]){x[23420]=0;w[g+142>>1]=0;R(419,a|0,g+142|0);d=x[23420];x[23420]=0;t:{u:{v:{w:{if((d|0)!=1){j=hb-16|0;hb=j;o=z[g+142>>1];d=Vd(i);e=ic(i);f=hb-16|0;hb=f;while(1){if(d){l=lo(z[d+16>>1],o);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[gc(f+8|0,e)>>2];hb=f+16|0;x:{if(Pb(d,Kf(i))){if(!lo(z[g+142>>1],z[ud(d)>>1])){break x}}d=Kf(i)}d=gc(j+8|0,d);hb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!zg(d,yf(i))){break u}x[23420]=0;d=Q(3,g+128|0,ud(d)+4|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break t}x[23420]=0;e=Q(1,g+112|0,16600)|0;f=x[23420];x[23420]=0;if((f|0)==1){break v}f=$p(d,e);yb(e);if(f){break p}e=x[b+4>>2];x[23420]=0;e=Q(420,e|0,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=P()|0;break f}x[23420]=0;e=Q(1,g+96|0,13265)|0;f=x[23420];x[23420]=0;y:{z:{A:{if((f|0)!=1){B:{if(!$p(d,e)){x[23420]=0;f=Q(1,g+80|0,13470)|0;h=x[23420];x[23420]=0;if((h|0)==1){break A}h=$p(d,f);yb(f);yb(e);if(h){break B}break s}yb(e)}x[23420]=0;e=T(421,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break z}x[g+56>>2]=e;e=x[b+4>>2];f=x[Tf(g+72|0,g+56|0)>>2];x[23420]=0;e=Q(422,e|0,f|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break y}hg(g+56|0);if(e){break e}break s}c=P()|0;break g}c=P()|0;yb(e);break g}c=P()|0;break g}c=P()|0;hg(g+56|0);break g}c=P()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=P()|0;break f}yl(k);VS(i);hb=g+176|0;return}e=Db(x[k>>2]);h=Db(x[k+4>>2]);f=hb-16|0;hb=f;x[f+8>>2]=e;while(1){C:{if(!Pb(e,h)){break C}if($p(e,d)){break C}e=x[_p(f+8|0)>>2];continue}break}hb=f+16|0;if(Pb(e,Db(x[k+4>>2]))){break p}x[23420]=0;R(423,k|0,d|0);e=x[23420];x[23420]=0;if((e|0)!=1){break q}}c=P()|0;break g}x[23420]=0;e=Q(1,g+24|0,17301)|0;f=x[23420];x[23420]=0;if((f|0)==1){break o}x[23420]=0;U(424,g+40|0,e|0,d|0);f=x[23420];x[23420]=0;if((f|0)==1){break n}x[23420]=0;f=Q(1,g+8|0,16153)|0;h=x[23420];x[23420]=0;if((h|0)==1){break m}x[23420]=0;U(2,g+56|0,g+40|0,f|0);h=x[23420];x[23420]=0;if((h|0)==1){break l}h=x[n>>2];x[23420]=0;U(353,h|0,2,g+56|0);h=x[23420];x[23420]=0;if((h|0)==1){break k}yb(g+56|0);yb(f);yb(g+40|0);yb(e)}x[x[j>>2]+44>>2]=0;break e}c=P()|0;break g}c=P()|0;break h}c=P()|0;break i}c=P()|0;break j}c=P()|0;yb(g+56|0)}yb(f)}yb(g+40|0)}yb(e)}yb(d)}yl(k);break a}yb(d)}c=c+1|0;continue}}c=P()|0}VS(i);S(c|0);p()}function jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-32|0;hb=j;a:{b:{if(pt(a)>>>0<b>>>0){if((b|0)<0){break b}n=ao(j+16|0);x[23420]=0;R(683,n|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}$k(j+8|0,x[a>>2]);lm(j,x[a>>2],x[a+4>>2]);m=hb-48|0;hb=m;c=x[n+4>>2];e=fc(m+40|0,x[j+8>>2],x[j+12>>2]);f=fc(m+32|0,x[j>>2],x[j+4>>2]);b=hb-16|0;hb=b;e=fc(b+8|0,x[e>>2],x[e+4>>2]);f=fc(b,x[f>>2],x[f+4>>2]);e=OQ(x[e>>2],x[e+4>>2],x[f>>2],x[f+4>>2]);hb=b+16|0;e=c+e|0;x[n+4>>2]=e;c:{d:{if(!c){b=e-1|0;break d}b=e-1|0;if((b^c-1)>>>0<32){break c}}x[x[n>>2]+((e>>>0>=33?b>>>5|0:0)<<2)>>2]=0}f=fc(m+24|0,x[j+8>>2],x[j+12>>2]);e=fc(m+16|0,x[j>>2],x[j+4>>2]);b=m+8|0;Ao(b,x[n>>2],c);c=x[f>>2];o=hb-48|0;hb=o;f=x[f+4>>2];e:{if((f|0)==x[b+4>>2]){f=fc(o+40|0,c,f);c=fc(o+32|0,x[e>>2],x[e+4>>2]);b=fc(o+24|0,x[b>>2],x[b+4>>2]);e=hb-16|0;hb=e;g=x[f>>2];d=x[f+4>>2];c=_k(x[c>>2],x[c+4>>2],g,d);x[e+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(d){i=32-d|0;x[e+8>>2]=i;k=c;c=x[td(e+8|0,e+12|0)>>2];x[e+12>>2]=k-c;h=x[b>>2];d=-1<<d&-1>>>i-c;x[h>>2]=x[h>>2]&(d^-1)|d&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);g=x[f>>2]+4|0;x[f>>2]=g;c=x[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;Ji(x[b>>2],k,g);d=c-(d<<5)|0;x[e+12>>2]=d;c=g+x[b>>2]|0;x[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+x[f>>2]|0;x[c>>2]=f;c=x[b>>2];g=-1>>>32-d|0;x[c>>2]=x[c>>2]&(g^-1)|g&x[f>>2];x[b+4>>2]=x[e+12>>2]}fc(m,c,x[b+4>>2]);break e}g=fc(o+16|0,c,f);c=fc(o+8|0,x[e>>2],x[e+4>>2]);f=fc(o,x[b>>2],x[b+4>>2]);e=hb-16|0;hb=e;k=x[c>>2];d=x[c+4>>2];b=x[g>>2];c=x[g+4>>2];d=_k(k,d,b,c);x[e+12>>2]=d;g:{if((d|0)<=0){c=x[f+4>>2];break g}h:{if(!c){c=x[f+4>>2];break h}l=32-c|0;x[e+8>>2]=l;i=e+8|0;h=x[td(i,e+12|0)>>2];x[e+12>>2]=d-h;d=x[f+4>>2];q=x[b>>2];x[e+8>>2]=h;k=32-d|0;x[e+4>>2]=k;b=x[f>>2];r=x[b>>2];i=x[Hb(i,e+4|0)>>2];l=q&(-1<<c&-1>>>l-h);x[b>>2]=(-1<<d&-1>>>k-i^-1)&r|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;x[f+4>>2]=c;d=b+(d>>>3&536870908)|0;x[f>>2]=d;b=h-i|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|l>>>i+x[g+4>>2];x[f+4>>2]=b;c=b}b=x[g>>2]+4|0;x[g>>2]=b;d=x[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=x[f>>2];b=x[b>>2];x[d>>2]=l&x[d>>2]|b<<c;x[f>>2]=d+4;x[d+4>>2]=i&x[d+4>>2]|b>>>h;d=x[e+12>>2]-32|0;x[e+12>>2]=d;b=x[g>>2]+4|0;x[g>>2]=b;continue}break}if((d|0)<=0){break g}l=x[b>>2];x[e+8>>2]=h;g=x[f>>2];b=x[g>>2];k=b;b=x[td(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;x[g>>2]=k|h<<c;d=b+c|0;c=d&31;x[f+4>>2]=c;g=g+(d>>>3&536870908)|0;x[f>>2]=g;d=x[e+12>>2]-b|0;x[e+12>>2]=d;if((d|0)<=0){break g}x[g>>2]=x[g>>2]&(-1>>>32-d^-1)|h>>>b;c=x[e+12>>2];x[f+4>>2]=c}fc(m,x[f>>2],c)}hb=e+16|0;hb=o+48|0;hb=m+48|0;wt(a,n);Je(n)}hb=j+32|0;return}Tc();p()}a=P()|0;Je(n);S(a|0);p()}function jK(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=0,t=E(0),u=0,v=E(0),w=E(0);d=a+4208|0;IN(Cb(d,0),B[a+4272>>2]);b=E(E(B[Cb(d,0)>>2]*E(15920))+E(80));t=me(E(10),E(E(E(B[Cb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=EK(c);v=lp(c);w=b;f=E(E(c*E(E(E(B[Cb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());g=(q(f),j(2))&2147483647;c=(l(2,g),r());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(!(c>E(88.7216796875))){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Tw(b)&2047;j:{k:{if(Tw(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Tw(E(O))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=uD(0);break j}if(!(b<E(-103.97207641601562))){break k}c=WC(0);break j}k=C[165]*+b;s=C[164];u=k+s;k=k-(u-s);s=(C[166]*k+C[167])*(k*k)+(C[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=x[d>>2];d=x[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=E(s*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/t);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*t);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-160|0;hb=d;zc(b);Lo(a);a:{if(!jv(b,d+120|0)){break a}if(!gD(d+120|0)){break a}j=x[b+8>>2];b:{if(!$c(b,y[d+136|0]|y[d+137|0]<<8|(y[d+138|0]<<16|y[d+139|0]<<24))){break b}while(1){c:{if((y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))>>>0>h>>>0){if(Nb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((y[d+124|0]|y[d+125|0]<<8)>>>0>=64){if((mi(b)|0)<=0){break d}}while(1){l=Ee(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(op(l<<24>>24)&255)==y[f+12955|0]}g=e;f=f+1|0;continue}break}$b(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}$c(b,j);if(!f){break a}if(!Nb(x[b>>2],x[b+8>>2],fD(d+120|0))){break a}if(!c){k=1;break a}g=hb-16|0;hb=g;e=d+120|0;$c(b,y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24));i=d+104|0;f=Qb(i);c=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);x[23420]=0;R(169,f|0,c|0);c=x[23420];x[23420]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24))>>>0<=c>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[23420]=0;h=W(144,j|0,h|0,5)|0;j=x[23420];x[23420]=0;if((j|0)==1){break g}if(!h){break h}h=y[e+4|0]|y[e+5|0]<<8;x[23420]=0;U(170,g|0,b|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;R(171,f|0,g|0);h=x[23420];x[23420]=0;if((h|0)==1){break i}c=c+1|0;xb(g);continue}break}c=P()|0;break f}c=P()|0;xb(g);break f}hb=g+16|0;break e}c=P()|0;break f}c=P()|0}Ke(f);S(c|0);p()}x[23420]=0;X(164,d+88|0,b|0,e|0,i|0);c=x[23420];x[23420]=0;j:{if((c|0)!=1){x[23420]=0;Q(143,b|0,x[d+144>>2])|0;c=x[23420];x[23420]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(A[d+140>>2]>k>>>0){c=x[b+8>>2];e=x[b>>2];x[23420]=0;c=W(144,e|0,c|0,8)|0;e=x[23420];x[23420]=0;if((e|0)==1){break q}if(c){break p}}k=uc(x[a>>2],x[a+4>>2])^1;tc(d+88|0);Ke(d+104|0);break a}b=P()|0;break k}x[23420]=0;ea(165,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=x[23420];x[23420]=0;if((c|0)!=1){e=Mo(d- -64|0);x[23420]=0;c=T(166,x[d+64>>2])|0;f=x[23420];x[23420]=0;if((f|0)==1){break o}if(c){x[23420]=0;c=T(167,d+24|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+104>>2];if(vd(f,x[d+108>>2])>>>0<=e>>>0){break r}x[23420]=0;U(11,d+8|0,8,Hd(f,e)|0);e=x[23420];x[23420]=0;if((e|0)==1){break m}e=d+8|0;Gb(c,e);yb(e)}hv(g,d- -64|0);x[23420]=0;R(168,a|0,c|0);e=x[23420];x[23420]=0;if((e|0)==1){break m}Yq(c)}k=k+1|0;zb(d- -64|0);continue}break}b=P()|0;break k}b=P()|0;break l}b=P()|0;break l}b=P()|0;Yq(c)}zb(d- -64|0);break k}b=P()|0}tc(d+88|0);break j}b=P()|0}Ke(d+104|0);S(b|0);p()}hb=d+160|0;return k|0}function NJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=hb-160|0;hb=f;x[f+152>>2]=c;x[f+156>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[Kk(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Tk(f+128|0,h,g,g-1|0);g=x[f+132>>2];x[b>>2]=x[f+128>>2];x[b+4>>2]=g}g=f+128|0;Qd(g);h=x[f+128>>2];Qd(f+112|0);i=Jk(h,x[f+116>>2],b);Qd(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+132>>2]){a=qc(f+144|0,21473);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Lc(h,g,f+8|0)){a=ba(8)|0;x[23420]=0;R(912,f+112|0,f+152|0);b=x[23420];x[23420]=0;if((b|0)==1){break g}x[23420]=0;U(917,f+128|0,17452,f+112|0);b=x[23420];x[23420]=0;if((b|0)==1){break f}e=0;b=rc(a,f+128|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);break e}if(!e){break h}a=ba(8)|0;c=x[b>>2];b=x[b+4>>2];x[23420]=0;c=Ch(f+80|0,c,b);b=x[23420];x[23420]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[23420]=0;U(917,f+96|0,17488,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break p}x[23420]=0;R(919,f+112|0,f+96|0);b=x[23420];x[23420]=0;e=1;if((b|0)==1){break o}x[23420]=0;R(912,f- -64|0,f+152|0);b=x[23420];x[23420]=0;if((b|0)==1){break n}x[23420]=0;U(921,f+128|0,f+112|0,f- -64|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}b=rc(a,f+128|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);e=0;break l}b=P()|0;break d}b=P()|0;e=1;break i}b=P()|0;break j}b=P()|0;break k}b=P()|0}xb(f- -64|0)}xb(f+112|0)}xb(f+96|0)}xb(c);if(e){break d}break c}b=qc(f+56|0,21473);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Lc(h,g,f+32|0)){a=ba(8)|0;x[23420]=0;R(912,f+112|0,f+152|0);b=x[23420];x[23420]=0;q:{r:{if((b|0)!=1){x[23420]=0;U(917,f+128|0,17452,f+112|0);b=x[23420];x[23420]=0;if((b|0)==1){break r}e=0;b=rc(a,f+128|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(f+128|0);break q}b=P()|0;break d}b=P()|0;e=1}xb(f+112|0);if(e){break d}break c}b=qc(f+48|0,10833);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Lc(h,g,f+24|0)){KJ(a,Hc(c,d));break h}b=qc(f+40|0,8529);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Lc(h,g,f+16|0)){break h}a=x[a+32>>2];b=Zy(c,d);b=b>>>0>=4?1:b;c=hb-16|0;hb=c;s:{if((Nj(y[a+140|0])|0)==(b|0)){d=a+120|0;ms(y[d+20|0]);b=hb-16|0;hb=b;x[b+8>>2]=c+8;a=hb-16|0;hb=a;e=x[15326];x[a+8>>2]=x[15325];x[a+12>>2]=e;e=x[15324];x[a>>2]=x[15323];x[a+4>>2]=e;mb[x[hp(a,Nj(y[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break s}qJ(a,b,rJ(a))}hb=c+16|0}hb=f+160|0;return}b=P()|0;break d}b=P()|0;e=1}xb(f+112|0);if(!e){break c}}ca(a|0)}S(b|0)}p()}function ID(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=hb-176|0;hb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((c|0)<=5){sv(a+128|0,c);x[23420]=0;c=Q(1,a+112|0,17588)|0;d=x[23420];x[23420]=0;if((d|0)==1){break E}x[23420]=0;U(2,a+144|0,a+128|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break D}x[23420]=0;d=Q(3,a+80|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break C}x[23420]=0;e=Q(1,a- -64|0,19416)|0;f=x[23420];x[23420]=0;if((f|0)==1){break B}x[23420]=0;U(4,a+96|0,d|0,e|0);f=x[23420];x[23420]=0;if((f|0)==1){break A}x[23420]=0;U(2,a+160|0,a+144|0,a+96|0);f=x[23420];x[23420]=0;if((f|0)==1){break z}yb(a+96|0);yb(e);yb(d);d=a+144|0;yb(d);yb(c);yb(a+128|0);c=x[b>>2];x[23420]=0;U(5,d|0,1,(c?c:21473)|0);c=x[23420];x[23420]=0;if((c|0)==1){break t}c=x[b+4>>2];x[23420]=0;U(5,a+128|0,1,(c?c:21473)|0);c=x[23420];x[23420]=0;if((c|0)==1){break s}b=x[b+8>>2];x[23420]=0;x[a+48>>2]=b;R(6,a+96|0,a+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break r}x[23420]=0;Y(7,17467);b=x[23420];x[23420]=0;if((b|0)==1){break q}x[23420]=0;U(8,a+48|0,0,a+144|0);b=x[23420];x[23420]=0;if((b|0)==1){break p}x[23420]=0;Y(9,a+48|0);b=x[23420];x[23420]=0;if((b|0)==1){break o}x[23420]=0;Y(7,17261);b=x[23420];x[23420]=0;if((b|0)==1){break o}x[23420]=0;U(8,a+32|0,0,a+96|0);b=x[23420];x[23420]=0;if((b|0)==1){break n}x[23420]=0;Y(9,a+32|0);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;Y(7,17259);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;Y(7,17588);b=x[23420];x[23420]=0;if((b|0)==1){break m}x[23420]=0;U(8,a+16|0,0,a+160|0);b=x[23420];x[23420]=0;if((b|0)==1){break l}x[23420]=0;Y(9,a+16|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}x[23420]=0;Y(7,13291);b=x[23420];x[23420]=0;if((b|0)==1){break k}x[23420]=0;U(8,a|0,0,a+128|0);b=x[23420];x[23420]=0;if((b|0)==1){break j}x[23420]=0;Y(9,a|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;Y(7,13289);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;Z(10);b=x[23420];x[23420]=0;if((b|0)==1){break i}xb(a);xb(a+16|0);xb(a+32|0);xb(a+48|0);yb(a+96|0);yb(a+128|0);yb(a+144|0);yb(a+160|0)}hb=a+176|0;return}b=P()|0;break u}b=P()|0;break v}b=P()|0;break w}b=P()|0;break x}b=P()|0;break y}b=P()|0;yb(a+96|0)}yb(e)}yb(d)}yb(a+144|0)}yb(c)}yb(a+128|0);break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;break e}b=P()|0;break e}b=P()|0;break f}b=P()|0;break f}b=P()|0;break g}b=P()|0;break g}b=P()|0;break h}b=P()|0;break h}b=P()|0;xb(a)}xb(a+16|0)}xb(a+32|0)}xb(a+48|0)}yb(a+96|0)}yb(a+128|0)}yb(a+144|0)}yb(a+160|0)}S(b|0);p()}function aF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=hb-48|0;hb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}C[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(C[(i+16|0)+(h<<3)>>3]==0){continue}break}d=AH(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=C[i>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[i+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[i+8>>3]}hb=i+48|0;return d}function Ov(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-96|0;hb=f;a:{if(gd(a,11)|x[a+4>>2]){e=x[a+28>>2];d=x[a+12>>2];b=x[a+64>>2];g=b+x[a+8>>2]|0;g=gh(f+80|0,g,b>>>0>g>>>0?d+1|0:d);b=x[g+12>>2];x[f+32>>2]=x[g+8>>2];x[f+36>>2]=b;b=x[g+4>>2];x[f+24>>2]=x[g>>2];x[f+28>>2]=b;Hj(e,f+24|0);b=x[a+28>>2];if(Fk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){ih(a,1073741826);break a}c=x[a+92>>2];h=a+44|0;b=x[h>>2];d=fh(b,x[h+4>>2]);b:{if(c>>>0>d>>>0){g=hb-32|0;hb=g;c=c-d|0;b=x[Fb(h)>>2];e=x[h+4>>2];c:{if(c>>>0<=b-e>>4>>>0){e=hb-16|0;hb=e;d=Ro(e,h,c);c=x[d+4>>2];b=x[d+8>>2];while(1){if((b|0)==(c|0)){kc(d);hb=e+16|0}else{eE(c);c=c+16|0;x[d+4>>2]=c;continue}break}break c}b=Fb(h);d=Lv(g+8|0,Mv(h,fh(x[h>>2],e)+c|0),fh(x[h>>2],x[h+4>>2]),b);b=hb-16|0;hb=b;c=dE(b,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){eE(e);e=x[c>>2]+16|0;x[c>>2]=e;continue}break}Id(c);hb=b+16|0;zd(h,d);gE(d)}hb=g+32|0;break b}if(d>>>0>c>>>0){Nd(h,b+(c<<4)|0)}}g=a+32|0;en(g,x[a+92>>2]<<2);d=0;while(1){if(A[a+92>>2]>d>>>0){b=x[a+28>>2];if(Fk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){ih(a,1073741828);break a}c=z[a+16>>1];w[f+78>>1]=c;if((c|0)==65535){Pv(b,f+78|0);c=z[f+78>>1]}e=Wc(x[a+32>>2],x[a+36>>2]);b=c&65535;d:{if(!b){c=0;break d}if(b>>>0>(e^-1)>>>0){break d}Ki(g,b+e|0);zk(x[a+28>>2],Kb(x[a+32>>2],e),b)}b=dd(x[a+44>>2],d);x[b>>2]=e;w[b+12>>1]=c;if(gd(a,6)){pk(x[a+28>>2],f+56|0);b=x[f+56>>2];if(x[f+60>>2]<0){ih(a,1073741829);break a}i=dd(x[a+44>>2],d),j=b,x[i+4>>2]=j}b=x[a+4>>2];e:{if(b){c=dd(x[a+44>>2],d);x[c+8>>2]=b;break e}if(!gd(a,7)){c=dd(x[a+44>>2],d);break e}pk(x[a+28>>2],f+56|0);b=x[f+56>>2];if(x[f+60>>2]<0){ih(a,1073741829);break a}c=dd(x[a+44>>2],d);x[c+8>>2]=b}f:{if(x[c+8>>2]==-1){break f}if(gd(a,6)){break f}g:{if(!d){c=0;b=dd(x[a+44>>2],0);break g}e=x[a+44>>2];b=dd(e,d-1|0);c=x[b+8>>2]+x[b+4>>2]|0;b=dd(e,d)}x[b+4>>2]=c}if(gd(a,8)){w[f+56>>1]=0;Pv(x[a+28>>2],f+56|0);b=gd(a,9);Gl(x[a+28>>2],z[f+56>>1]<<b)}d=d+1|0;continue}break}ae(f+56|0,x[a+28>>2]);b=x[f+68>>2];x[a+72>>2]=x[f+64>>2];x[a+76>>2]=b}rk(a,4,1);e=x[a+76>>2];b=x[a+88>>2];g=b+x[a+8>>2]|0;d=x[a+12>>2];d=b>>>0>g>>>0?d+1|0:d;b=(b|0)==x[a+64>>2];g=b?x[a+72>>2]:g;x[a+80>>2]=g;b=b?e:d;x[a+84>>2]=b;e=x[a+28>>2];g=gh(f+40|0,g,b);b=x[g+12>>2];x[f+16>>2]=x[g+8>>2];x[f+20>>2]=b;b=x[g+4>>2];x[f+8>>2]=x[g>>2];x[f+12>>2]=b;Hj(e,f+8|0);if(gd(a,6)){break a}if(!(gd(a,7)|x[a+4>>2])){break a}e=x[a+80>>2];b=x[a+8>>2];d=e-b|0;g=x[a+44>>2];e=x[a+92>>2];a=0;while(1){if((a|0)==(e|0)){break a}b=dd(g,a);x[b+4>>2]=d+x[b+4>>2];a=a+1|0;continue}}hb=f+96|0}function U9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=43568;x[a+4>>2]=0;x[a>>2]=32e3;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Kp(a+24604|0);DM(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Tb(b+28|0,0,40);Tb(b+68|0,0,49824);Tb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;i=Qb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;BC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Qb(c);x[f+12>>2]=a;x[23420]=0;j=Q(763,a+484360|0,a|0)|0;b=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){d=a+900380|0;b=a+484380|0;while(1){x[23420]=0;b=T(634,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break i}b=b+104|0;if((d|0)!=(b|0)){continue}break}x[23420]=0;T(764,a+901404|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break h}c=a+946300|0;g=a+906300|0;b=g;while(1){b=CM(b)+160|0;if((c|0)!=(b|0)){continue}break}x[a+946300>>2]=0;e=a+1074304|0;h=a+946304|0;b=h;while(1){b=mt(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;Xq(a+1074312|0);x[23420]=0;Z(765);b=x[23420];x[23420]=0;if((b|0)==1){break g}t=a,u=xM(),x[t+1074328>>2]=u;b=a+1074332|0;x[b+12>>2]=1065353216;oM(b,4);x[23420]=0;e=T(766,a+1074376|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break g}x[23420]=0;k=W(534,a+1298264|0,a|0,255)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}l=Bc(a+1298300|0);m=Bc(a+1298304|0);n=Jb(a+1298308|0);o=Jb(a+1298320|0);q=Jb(a+1298332|0);r=BM(a+1298344|0);s=Qb(a+1298408|0);v[a+1298420|0]=0;b=a+1298424|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298464>>2]=0;vp(a+12|0);wy(a+8204|0);wy(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Tb(d,0,1024);wM(h);x[23420]=0;b=T(767,12)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;t=a,u=Qb(b),x[t+4>>2]=u;return a|0}b=P()|0;break a}b=P()|0;break b}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;AM(s);zy(r);xb(q);yb(o);xb(n);yy(m);xy(l);_s(k)}My(e)}while(1){c=Rs(c-160|0);if((g|0)!=(c|0)){continue}break}}tz(j)}tM(f);tc(i);S(b|0);p()}function C5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Kk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Tk(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;Qd(f);e=x[d+168>>2];Qd(d+152|0);e=Jk(e,x[d+156>>2],b);Qd(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+184|0,21473);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Lc(e,a,d)){a=ba(8)|0;x[23420]=0;c=Q(54,d+168|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}e=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[23420]=0;e=Ch(d+152|0,b,c);b=x[23420];x[23420]=0;f:{g:{h:{if((b|0)!=1){x[23420]=0;U(917,d+168|0,17488,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break h}c=0;b=rc(a,d+168|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(d+168|0);break g}b=P()|0;break f}b=P()|0;c=1}xb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]){a=ba(8)|0;x[23420]=0;c=Q(54,d+168|0,11442)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d+144|0,21473);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Lc(b,c,d+72|0)){a=ba(8)|0;x[23420]=0;c=Q(54,d+168|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+136|0,7380);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Lc(b,c,d- -64|0)){e=qc(d+128|0,7362);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Lc(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=qc(d+120|0,6895);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Lc(b,c,d+48|0)){e=qc(d+112|0,6876);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Lc(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=qc(d+104|0,6979);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Lc(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=qc(d+96|0,6025);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Lc(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=qc(d+88|0,7429);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Lc(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=qc(d+80|0,13234);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Lc(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}hb=d+192|0;return e|0}b=P()|0;ca(a|0)}S(b|0)}p()}function sfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=hb-560|0;hb=f;a:{if(!$c(b,1464)){break a}if(!mo(b,f+556|0)){break a}Dd(a,1);Mb(Mb(Cf(a+1074312|0,83),84,1),85,1);b:{if(ee(f+556|0,26729)){d=f+32|0;e=Vb(d,8348);Gb(a+1298344|0,e);yb(e);e=Vb(d,14663);Gb(a+1298356|0,e);yb(e);d=Vb(d,14728);Gb(a+1298368|0,d);break b}if(!ee(f+556|0,15344)){break a}d=f+32|0;e=Vb(d,8506);Gb(a+1298344|0,e);yb(e);e=Vb(d,12130);Gb(a+1298356|0,e);yb(e);d=Vb(d,15190);Gb(a+1298368|0,d)}yb(d);x[a+1298404>>2]=13;$c(b,0);SA(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;Qu(d,b);m=jd(d);if(y[f+552|0]>128){break a}e=f+32|0;d=hb-16|0;hb=d;c:{if(!Nb(x[b>>2],x[b+8>>2],512)){uR(e);break c}wu(d+8|0,e);qd(d,b,x[d+8>>2],x[d+12>>2])}hb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){i=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[i|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;wh(a,0);o=a+484376|0;jg(Yb(x[a+484360>>2],y[o|0]),y[f+552|0]);k=a+484344|0;lg(k,y[f+552|0]);e=0;while(1)if(y[f+552|0]<=e>>>0){if(!(c&2)){break a}$c(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){kg(_c(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{r=bc(x[Yb(x[a+484360>>2],y[o|0])>>2],e),s=e,w[r>>1]=s;d:{if(!$g(k,e&65535,64)){break d}l=e<<2;i=0;e:while(1){if((i|0)==4){r=f,s=Db(x[_b(x[k>>2],e)>>2]),x[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;l=h;h=j&15;g=(l|0)==(h|0)|!h;p=g?p:l;q=g?q:h;h=!g}d=d+1|0;dA(f+24|0);continue}break}ie(_b(x[k>>2],e),Fe(ye(f+8|0,16,y[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}$c(b,(y[f+32+(i+l)|0]<<8)+1468|0);g=0;d=_b(x[k>>2],e);d=ed(x[d>>2],x[x[d+48>>2]+12>>2],0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue e}else{pu(b,d);i:{j:{j=y[d+3|0];k:{if((j|0)!=14){if(!j){if(y[d+5|0]){break j}break k}if((j-5&255)>>>0<5){break k}break j}if(y[d+5|0]<=15){break j}}v[d+3|0]=0;break i}Of(d)}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}else{g=lA(b,f+32|0,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}hb=f+560|0;return n|0}function jm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-80|0;hb=e;h=Qb(a);x[23420]=0;a=T(266,b|0)|0;c=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[23420]=0;c=W(144,d|0,c|0,a|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}if(c){break d}x[23420]=0;a=T(190,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;Q(176,b|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break c}}a=P()|0;break a}x[23420]=0;U(178,e+32|0,b|0,a|0);b=x[23420];x[23420]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=jc(e+56|0,b);zb(b);if(a>>>0<10){break g}x[23420]=0;b=T(660,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}if(!b){break g}x[23420]=0;b=T(266,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}x[e+28>>2]=b;a=a-10|0;xc(e+28|0,a>>>0>25264513?-1:D(a,170));x[23420]=0;d=x[e+28>>2];R(272,h|0,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){break h}break b}a=P()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[23420]=0;a=Q(661,f|0,a|0)|0;f=x[23420];x[23420]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[23420]=0;a=T(469,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[23420]=0;a=T(194,c|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[23420]=0;g=W(144,i|0,g|0,a|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}if(!g){continue}ke(e+32|0,x[h>>2],x[h+4>>2]);iq(e+16|0,x[e+32>>2],x[e+36>>2],b,a);x[23420]=0;bn(406,e+8|0,c,x[e+16>>2],x[e+20>>2]);f=x[23420];x[23420]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[23420]=0;a=T(194,c|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[23420]=0;i=Q(662,c|0,e+24|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=ic(f);ah(f,i,_g(Db(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[23420]=0;a=Q(662,c|0,e+24|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=ic(a);ah(a,f,_g(Db(x[h>>2]),b));ah(a,f,_g(_g(Db(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[23420]=0;a=T(194,c|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Qb(e+32|0);wt(a,h);dc(a);break f}x[23420]=0;U(313,c|0,h|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}}zb(c)}hb=e+80|0;return}a=P()|0;zb(c)}dc(h);S(a|0);p()}function caa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;j=hb-32|0;hb=j;r=x[a+4>>2];e=Pe(x[a+8>>2],b);t=x[e>>2];a:{if(t+1>>>0<2){break a}i=(D(b,872)+r|0)+616|0;if(!(pi(x[i+8>>2],x[i+12>>2])|y[e+4|0])){break a}f=D(b,872)+r|0;if(!x[f+720>>2]){break a}h=x[f+704>>2]&2;e=x[(h?f+700|0:f+692|0)>>2];l=x[f+700>>2];g=x[f+696>>2];Ab(j+8|0,x[a>>2]+1074312|0,31);u=Bb(x[x[j+8>>2]>>2],x[j+12>>2]);n=$e(x[f+624>>2],x[f+628>>2],c);p=n;m=y[f+704|0]&128;n=m?0-n|0:n;k=lb;m=m?0-(k+((p|0)!=0)|0)|0:k;k=0;B=k;p=e;w=h?k:0;e=g;q=h?e:0;k=l-e|0;C=k<<1;F=f+1316|0;o=f+1467|0;A=f+1362|0;G=(y[A|0]&17)!=1;b:{while(1){if((s|0)==(t|0)){break b}c:{if(d>>>0>s>>>0){g=(y[A|0]&17)==1;break c}v[o|0]=y[o|0]&254;g=x[a>>2];e=x[a+4>>2];h=_b(x[g+484344>>2],z[e+70>>1]);e=ed(x[h>>2],x[x[h+48>>2]+12>>2],x[e+48>>2],b);h=y[e+3|0];if(y[e+2|0]==11){l=j+8|0;Sy(l,g,h,y[e+4|0],0);l=Ue(l);Nn(x[a>>2],i,z[j+8>>1]);g=1;if(y[l|0]){break c}}g=1;d:{switch(h-4|0){case 0:Nn(x[a>>2],i,y[e+5|0]);break c;case 2:break d;default:break c}}Nn(x[a>>2],i,0)}x[j+28>>2]=x[F>>2];if(u){Ys(x[a>>2],i)}if(!G){eN(x[a>>2],i,j+28|0);g=1}if(!u){Ys(x[a>>2],i)}x[j+24>>2]=0;dN(i,j+24|0);e:{f:{if(y[f+705|0]&2){break f}g:{if(!g){if(!y[Pe(x[a+8>>2],b)+4|0]){break g}}if(y[o|0]&96){hP(i,E(1),0,x[a>>2]);e=y[o|0];v[o|0]=(e&64?-65:-33)&e}Uy(j+8|0,x[a>>2],i,x[j+28>>2],0);e=x[j+12>>2];x[f+624>>2]=x[j+8>>2];x[f+628>>2]=e;H=Pe(x[a+8>>2],b),I=0,v[H+4|0]=I;e=$e(x[f+624>>2],x[f+628>>2],c);g=y[f+704|0]&128;n=g?0-e|0:e;h=lb;m=g?0-(h+((e|0)!=0)|0)|0:h}Rb(i,n,m);l=x[i>>2];e=x[i+4>>2];if((l>>>0<B>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&l>>>0>=w>>>0|(e|0)>(q|0)|((m|0)>0|(m|0)>=0))){break f}h=x[f+704>>2];if(!(h&2)){break e}if(h&4){g=x[f+696>>2];if(l>>>0<w>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){H=i,I=Fg(0,g<<1,l,e),x[H>>2]=I;e=lb;x[i+4>>2]=e;x[f+704>>2]=h^128;h=n;n=0-h|0;m=0-(((h|0)!=0)+m|0)|0}Ab(j+8|0,x[a>>2]+1074312|0,33);e=(e-g>>>0)%(C-Bb(x[x[j+8>>2]>>2],x[j+12>>2])>>>0)|0;h:{if(e>>>0<k>>>0){g=e+x[f+696>>2]|0;break h}g=x[f+700>>2]+(k-e|0)|0}x[i+4>>2]=g;g=x[f+704>>2];if((g&128)>>>7^e>>>0<k>>>0){break f}x[f+704>>2]=g^128;e=n;n=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break f}g=e;h=x[f+700>>2];if(e>>>0>=h+k>>>0){g=h+((g-h>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=h>>>0){continue}break}x[i>>2]=l;x[i+4>>2]=e}s=s+1|0;continue}break}kP(i);x[(D(b,872)+r|0)+1324>>2]=0}H=Pe(x[a+8>>2],b),I=0,x[H>>2]=I}hb=j+32|0}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb+-64|0;hb=d;w[d+62>>1]=c;tg(d+62|0,32);j=Qb(a);x[23420]=0;o=z[d+62>>1];R(473,j|0,o|0);a=x[23420];x[23420]=0;a:{b:{if((a|0)!=1){k=b+480190|0;q=b+480192|0;c:{d:{while(1){if((r&65535)>>>0>=o>>>0){break d}e=1;c=z[k>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=_j(b,f);if(!Td(x[g>>2],x[g+20>>2])){if(!Pb(eA(Db(x[j>>2]),Db(x[j+4>>2]),e),Db(x[j+4>>2]))){break i}c=z[k>>1]}e=e+1|0;continue}break}w[d+60>>1]=e;a=1;while(1){if(z[q>>1]<a>>>0){a=e}else{j:{c=x[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=fq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}e=ao(d+48|0);x[23420]=0;a=Q(700,b|0,e|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break b}if(!a){break e}x[23420]=0;R(701,b|0,e|0);c=x[23420];x[23420]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[q>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=fq(c);while(1){if((c|0)==(f|0)){break k}g=z[c>>1];l:{if(g>>>0>=A[d+52>>2]){break l}Ab(d+40|0,x[e>>2],g);if(Bb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}$k(d+24|0,x[e>>2]);tP(d+32|0,x[d+24>>2],x[d+28>>2],1);lm(d+16|0,x[e>>2],x[d+52>>2]);m=hb-16|0;hb=m;g=d+40|0;c=fc(m,x[d+32>>2],x[d+36>>2]);a=_k(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);f=hb-16|0;hb=f;x[f+12>>2]=a;h=x[c+4>>2];m:{if(h){i=32-h|0;x[f+8>>2]=i;n=x[Hb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=x[c>>2];l=l&(x[i>>2]^-1);if(l){fc(g,i,Via(l));break m}if((a|0)==(n|0)){tP(g,i,h,a);break m}a=a-n|0;x[f+12>>2]=a;x[c>>2]=i+4}while(1){if(a>>>0>=32){h=x[c>>2];i=x[h>>2];if((i|0)!=-1){fc(g,h,Via(i^-1));break m}else{x[c>>2]=h+4;a=a-32|0;x[f+12>>2]=a;continue}}break}if(!a){fc(g,x[c>>2],0);break m}c=x[c>>2];h=(x[c>>2]^-1)&-1>>>32-a;if(!h){fc(g,c,a);break m}fc(g,c,Via(h))}hb=f+16|0;hb=m+16|0;$k(d+8|0,x[e>>2]);a=_k(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;Je(e);if((a&65535)>>>0>3999){break f}}x[23420]=0;R(245,j|0,d+60|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}if(z[k>>1]>=(a&65535)>>>0){break f}w[k>>1]=a}r=r+1|0;continue}break}Je(e)}hb=d- -64|0;return}c=P()|0;break a}c=P()|0;break a}c=P()|0;Je(e)}od(j);S(c|0);p()}function Y1(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=hb-192|0;hb=d;x[d+184>>2]=c;a:{b:{c:{if(b>=.8){x[23420]=0;e=ga(1027)|0;f=x[23420];x[23420]=0;d:{e:{f:{if((f|0)!=1){x[d+80>>2]=e;x[23420]=0;c=T(1028,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break e}x[d+176>>2]=c;Bn(e,c);a=he(d+152|0,a);x[23420]=0;f=x[a+12>>2];c=d- -64|0;x[c>>2]=x[a+8>>2];x[c+4>>2]=f;x[d+72>>2]=x[a+16>>2];c=x[a+4>>2];x[d+56>>2]=x[a>>2];x[d+60>>2]=c;a=W(1020,e|0,d+56|0,15)|0;c=x[23420];x[23420]=0;if((c|0)==1){break f}if(a){x[23420]=0;Y(768,e|0);a=x[23420];x[23420]=0;g=1;if((a|0)==1){break f}}bj(d+176|0);cj(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;bj(d+176|0);break d}c=V(0)|0}cj(d+80|0);break c}if(b>=.6){x[23420]=0;e=ga(1027)|0;f=x[23420];x[23420]=0;g:{h:{i:{if((f|0)!=1){x[d+80>>2]=e;x[23420]=0;c=T(1028,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}x[d+176>>2]=c;Bn(e,c);a=he(d+128|0,a);x[23420]=0;c=x[a+12>>2];x[d+40>>2]=x[a+8>>2];x[d+44>>2]=c;x[d+48>>2]=x[a+16>>2];c=x[a+4>>2];x[d+32>>2]=x[a>>2];x[d+36>>2]=c;a=W(1020,e|0,d+32|0,2)|0;c=x[23420];x[23420]=0;if((c|0)==1){break i}if(a){x[23420]=0;Y(768,e|0);a=x[23420];x[23420]=0;g=.8;if((a|0)==1){break i}}bj(d+176|0);cj(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;bj(d+176|0);break g}c=V(0)|0}cj(d+80|0);break c}g=.2;if(b>=.2){x[23420]=0;e=ga(1027)|0;f=x[23420];x[23420]=0;j:{k:{l:{if((f|0)!=1){x[d+80>>2]=e;x[23420]=0;c=T(1028,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break k}x[d+176>>2]=c;Bn(e,c);a=he(d+104|0,a);x[23420]=0;c=x[a+12>>2];x[d+16>>2]=x[a+8>>2];x[d+20>>2]=c;x[d+24>>2]=x[a+16>>2];c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;a=W(1020,e|0,d+8|0,0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break l}g=0;if(a){x[23420]=0;Y(768,e|0);a=x[23420];x[23420]=0;g=.6;if((a|0)==1){break l}}bj(d+176|0);cj(d+80|0);break b}c=V(0)|0;break c}c=V(0)|0;bj(d+176|0);break j}c=V(0)|0}cj(d+80|0);break c}if(!(b>=.1)){break b}x[23420]=0;U(191,d+80|0,a|0,2048);c=x[23420];x[23420]=0;if((c|0)!=1){c=xe(d+80|0);a=x[a>>2];x[23420]=0;e=x[d+80>>2];a=T(148,a|0)|0;f=x[23420];x[23420]=0;m:{if((f|0)==1){break m}x[23420]=0;a=XE(1029,c,e,a,0);c=x[23420];x[23420]=0;if((c|0)==1){break m}g=C[(a<<3)+61320>>3];Oc(d+80|0);break b}c=V(0)|0;Oc(d+80|0);break c}c=V(0)|0}_(c|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;g=0;if((a|0)==1){break a}}se(d+184|0);hb=d+192|0;return+g}a=P()|0;se(d+184|0);S(a|0);p()}function nX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-320|0;hb=d;e=hb-16|0;hb=e;x[a>>2]=0;f=a+32|0;en(f,32);v[e+15|0]=0;dn(f,e+15|0);hb=e+16|0;e=x[a+28>>2];a:{if(!Jg(x[x[e>>2]-12>>2]+e|0)){ih(a,1073741825);break a}f=d+56|0;ae(f,e);e=x[f+12>>2];x[a+8>>2]=x[f+8>>2];x[a+12>>2]=e;x[f>>2]=3;h=x[a+28>>2];g=d+16|0;e=0;while(1){if(A[f>>2]>e>>>0){bi(h,e+g|0);e=e+1|0;continue}break}if(Ob(g,25808,3)){ih(a,1073741827);break a}v[d+319|0]=0;bi(x[a+28>>2],d+319|0);Tb(d+56|0,0,256);e=y[d+319|0];if(e){zk(x[a+28>>2],d+56|0,e)}f=b;b=Zm(d+16|0,d+56|0,e);e=Vv(f,b);Sb(b);if(!e){ih(a,1073741830)}if(y[a+3|0]&64){break a}bi(x[a+28>>2],d+55|0);b=y[d+55|0];e=b&3;w[a+16>>1]=(e|0)==3?4:e;if(Li(b,6)){rk(a,9,1)}x[d+48>>2]=0;jE(x[a+28>>2],d+48|0);f=x[d+48>>2];v[d+47|0]=0;if(f>>>0>=2){bi(x[a+28>>2],d+55|0);e=-1;if(!y[d+55|0]){bi(x[a+28>>2],d+47|0);e=-2}Gl(x[a+28>>2],e+f|0)}x[d+32>>2]=0;x[d+36>>2]=0;b:{if(!Li(b,4)){break b}pk(x[a+28>>2],d+32|0);e=x[d+36>>2];f=x[d+32>>2];x[a+56>>2]=f;x[a+60>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}ih(a,536871424)}if(Li(b,5)){bi(x[a+28>>2],d+55|0);Gl(x[a+28>>2],y[d+55|0])}e=y[d+47|0];c:{if(!Li(e,0)){break c}bi(x[a+28>>2],d+55|0);c=y[d+55|0];c=c&1?-1:c>>>1|0;w[a+16>>1]=c;if(c){break c}ih(a,536871168)}x[a+4>>2]=0;c=1;if(Li(e,1)){jE(x[a+28>>2],a+4|0)}rk(a,6,Li(b,2));rk(a,7,Li(b,3));rk(a,5,z[a+16>>1]!=0);rk(a,8,Li(b,7));d:{if(gd(a,5)){break d}if(gd(a,6)){break d}if(gd(a,7)){break d}c=gd(a,8)}rk(a,11,c);gd(a,11);if(Li(e,2)){w[d+16>>1]=0;Pv(x[a+28>>2],d+16|0);Gl(x[a+28>>2],D(z[d+16>>1],gd(a,9)?2:1))}if(Li(e,3)){Gl(x[a+28>>2],5)}pk(x[a+28>>2],d+32|0);c=x[d+36>>2];b=x[d+32>>2];if(!c&b>>>0>=16001|c){ih(a,1073741831);break a}x[a+92>>2]=b;if(!b){ih(a,536871040)}e:{if(!gd(a,11)){break e}pk(x[a+28>>2],d+32|0);b=x[d+32>>2];c=x[d+36>>2];if((c|0)>0|(c|0)>=0){break e}ih(a,1073741829);break a}ae(d,x[a+28>>2]);c=x[a+8>>2];e=x[a+12>>2];f=x[d+4>>2];x[d+16>>2]=x[d>>2];x[d+20>>2]=f;f=x[d+12>>2];x[d+24>>2]=x[d+8>>2];x[d+28>>2]=f;f=x[d+24>>2];e=x[d+28>>2]-(e+(c>>>0>f>>>0)|0)|0;x[d+24>>2]=f-c;x[d+28>>2]=e;c=x[d+24>>2];e=x[d+28>>2];if((e|0)==1|e>>>0>1){ih(a,1073741832);break a}x[a+88>>2]=c;c=gd(a,11);x[a+64>>2]=c?b:x[a+88>>2];if(!gd(a,11)){b=x[a+12>>2];e=x[a+88>>2];c=e+x[a+8>>2]|0;x[a+72>>2]=c;x[a+76>>2]=c>>>0<e>>>0?b+1|0:b}rk(a,10,1)}hb=d+320|0}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=hb-16|0;hb=g;a:{if(!Nb(x[a>>2],x[a+8>>2],2)){$g(c+484344|0,b,64);break a}l=c+484344|0;m=Wd(wq(a),1,1024);if(!$g(l,b,m)){break a}p=z[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=_b(x[l>>2],b);n=pf(x[e>>2],x[x[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+8|0;Am(f,a);e=D(i,6)+n|0;r=Ue(f);f=Bi(f);h=y[g+8|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;o=y[jd(g+8|0)|0];h=o+1|0;v[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>z[q>>1]){break c}h=_j(c,h);j=Kb(d,i);if(!(!y[j|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=x[Cb(h+68|0,0)>>2];if(!(y[j|0]|h?y[j|0]?(h|0)==1:0:1)){break c}v[e+1|0]=o+101}d:{e:{switch(y[r|0]){case 1:if(!y[f|0]){break d}v[e+3|0]=2;v[e+5|0]=y[f|0];break d;case 2:if(!y[f|0]){break d}v[e+3|0]=3;v[e+5|0]=y[f|0];break d;case 12:if(!y[f|0]){break d}v[e+3|0]=1;v[e+5|0]=y[f|0];break d;case 13:if(!y[f|0]){break d}v[e+3|0]=39;v[g+7|0]=15;s=e,t=y[Wb(g+7|0,f)|0]|16,v[s+5|0]=t;break d;case 30:if(!y[f|0]){break d}v[e+3|0]=38;v[g+6|0]=15;s=e,t=y[Wb(g+6|0,f)|0]|16,v[s+5|0]=t;break d;case 21:if(!y[f|0]){break d}v[e+3|0]=39;v[g+5|0]=15;s=e,t=y[Wb(g+5|0,f)|0]|80,v[s+5|0]=t;break d;case 17:if(!y[f|0]){break d}v[e+3|0]=38;v[g+4|0]=15;s=e,t=y[Wb(g+4|0,f)|0]|80,v[s+5|0]=t;break d;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break d;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break d;case 27:eo(e);v[e|0]=255;break d;case 28:if(y[f|0]>31){break d}v[e+3|0]=16;v[e+5|0]=y[f|0];break d;case 31:h=y[f|0];if(h&15){s=e,t=y[Kb(d,i)|0]?22:11,v[s+3|0]=t;v[e+5|0]=y[f|0]&15;h=y[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(y[Kb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break f}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break f;case 5:v[e+5|0]=y[e+5|0]<<4;break f;case 6:v[g+3|0]=y[e+5|0];v[g+2|0]=14;s=e,t=y[Wb(g+3|0,g+2|0)|0]|240,v[s+5|0]=t;break f;case 7:v[g+1|0]=y[e+5|0];v[g|0]=14;s=e,t=y[Wb(g+1|0,g)|0]<<4|15,v[s+5|0]=t;break f;default:break g}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break d}f=D(v[Kb(d,i)|0]+i|0,6)+n|0;if(Dq(f+3|0,f+5|0,1)){v[f+2|0]=y[f+3|0];v[f+4|0]=y[f+5|0]}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break d;case 0:break d;default:break e}}v[e+3|0]=0}i=i+1|0;continue}}}hb=g+16|0}function W8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-48|0;hb=c;a:{b:{if(!Pb(x[b>>2],x[b+4>>2])){break b}l=x[b+12>>2];k=Dg(x[x[b+48>>2]+12>>2]);d=k;f=c+32|0;x[f>>2]=0;x[f+4>>2]=0;Bc(f+8|0);if(d){au(f,d);g=hb-16|0;hb=g;e=mq(g,f,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);hb=g+16|0}else{Rh(d);d=d+6|0;x[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(j>>>0>=l>>>0){break r}if(!Jg(x[x[a>>2]-12>>2]+a|0)){break r}x[23420]=0;v[c+31|0]=0;Q(830,a|0,c+31|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}d=v[c+31|0];if(!d){j=j+1|0;continue}v[c+30|0]=0;s:{if((d|0)>=0){break s}x[23420]=0;Q(830,a|0,c+30|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break s}break a}v[c+29|0]=0;Rh(c+16|0);t:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;u:{v:{if(!i){h=ed(x[b>>2],x[x[b+48>>2]+12>>2],j,g);d=y[c+30|0];if(d&1){break v}e=Cd(x[f>>2],g);break u}h=c+16|0;d=y[c+30|0];if(!(d&1)){break t}}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break t}e=Cd(x[f>>2],g);v[e|0]=y[c+29|0]}v[h|0]=y[e|0];d=y[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}ek(f);break b}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break o}e=Cd(x[f>>2],g);v[e+1|0]=y[c+29|0]}v[h+1|0]=y[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break l}e=Cd(x[f>>2],g);v[e+2|0]=y[c+29|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break i}e=Cd(x[f>>2],g);v[e+4|0]=y[c+29|0]}v[h+4|0]=y[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break f}e=Cd(x[f>>2],g);v[e+3|0]=y[c+29|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}x[23420]=0;Q(830,a|0,c+29|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break c}e=Cd(x[f>>2],g);v[e+5|0]=y[c+29|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[23420]=0;Q(830,a|0,c+15|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;Q(831,a|0,y[c+15|0])|0;d=x[23420];x[23420]=0;if((d|0)!=1){continue}}break}break a}hb=c+48|0;return}a=P()|0;ek(f);S(a|0);p()}function v2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=hb-192|0;hb=d;h=jJ(d+176|0);x[h>>2]=49284;Qb(h+4|0);Bn(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=he(d+152|0,b);x[23420]=0;j=x[b+12>>2];x[d+16>>2]=x[b+8>>2];x[d+20>>2]=j;x[d+24>>2]=x[b+16>>2];j=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1020,e|0,d+8|0,(i?b&3:b)|0)|0;e=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;x[23420]=0;c=Q(54,d+136|0,11868)|0;a=x[23420];x[23420]=0;if((a|0)!=1){a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0);break b}if(!y[a+63|0]){x[23420]=0;R(1021,a|0,a+36|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}}v[a+28|0]=1;Bn(x[a+24>>2],x[a+4>>2]);x[23420]=0;R(1022,d+136|0,h|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}k=d,l=Db(x[d+136>>2]),x[k+128>>2]=l;e=a+68|0;i=Db(x[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+128>>2];if(!Pb(b,i)){k=d,l=qj(x[c>>2]),x[k+112>>2]=l;c=yf(c);while(1){b=x[d+112>>2];if(!zg(b,c)){break d}x[23420]=0;e=ud(b);b=Q(53,d+32|0,e|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break h}x[23420]=0;X(918,a|0,b|0,e+12|0,0);e=x[23420];x[23420]=0;if((e|0)==1){break g}xb(b);Wg(d+112|0);continue}}f=x[a+24>>2];g=x[b>>2];x[23420]=0;j=f;f=b+4|0;U(1023,j|0,g|0,f|0);g=x[23420];x[23420]=0;if((g|0)!=1){b=x[b>>2];x[23420]=0;R(1024,d- -64|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break r}x[23420]=0;R(964,d+80|0,d- -64|0);b=x[23420];x[23420]=0;if((b|0)==1){break q}x[23420]=0;b=Q(54,d+48|0,17588)|0;g=x[23420];x[23420]=0;if((g|0)==1){break p}x[23420]=0;U(921,d+96|0,d+80|0,b|0);g=x[23420];x[23420]=0;if((g|0)==1){break o}x[23420]=0;U(479,d+112|0,d+96|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break n}x[23420]=0;R(171,e|0,d+112|0);f=x[23420];x[23420]=0;if((f|0)==1){break m}xb(d+112|0);xb(d+96|0);xb(b);xb(d+80|0);yb(d- -64|0);co(d+128|0);continue}break}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;break j}a=P()|0;break k}a=P()|0;break l}a=P()|0;xb(d+112|0)}xb(d+96|0)}xb(b)}xb(d+80|0)}yb(d- -64|0);break f}a=P()|0;break f}a=P()|0;xb(b)}rx(d+136|0);break b}a=P()|0;break b}rx(d+136|0);js(h);hb=d+192|0;return}a=P()|0}js(h);S(a|0)}p()}function DV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-384|0;hb=f;zc(b);d=hb-16|0;hb=d;h=f+344|0;xC(d+8|0,h);e=x[d+12>>2];mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(e|0)){$b(b,x[d+12>>2])}hb=d+16|0;d=(e|0)==(i|0);if(!d){wC(h)}a:{if(!d){break a}if(!zC(f+344|0)){break a}if(!Nb(x[b>>2],x[b+8>>2],Vc(yC(y[f+379|0]),lb))){break a}b:{if(!c){break b}Dd(a,2097152);Cg(a);wh(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[f+376|0];x[a+480204>>2]=D(y[f+377|0],1e4);j=a+480190|0;w[j>>1]=y[f+378|0];d=y[f+381|0];if(d>>>0<y[f+380|0]){Ze(Yb(x[a+484360>>2],y[a+484376|0]),d)}d=f+80|0;g=Vb(d,6480);Gb(a+1298344|0,g);yb(g);g=Vb(d,11008);Gb(a+1298356|0,g);yb(g);x[a+1298404>>2]=5;Ru(b,d);Kq(Yb(x[a+484360>>2],y[a+484376|0]),d,y[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>z[j>>1]){$b(b,D(64-y[f+378|0]|0,37));h=a+484344|0;lg(h,y[f+379|0]);i=c&1;g=0;while(1)if(y[f+379|0]<=g>>>0){if(!(c&2)){break b}c=_c(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>z[d>>1]){break b}kg(c,(D(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(i){if($g(h,g&65535,64)){break d}}$b(b,2048);break c}d=_b(x[h>>2],g);n=f,o=Db(x[d>>2]),x[n+40>>2]=o;j=Db(x[d+4>>2]);while(1){d=x[f+40>>2];if(!Pb(d,j)){break c}e=f+24|0;Am(e,b);k=jd(e);m=Ue(e);e=Bi(e);l=y[f+24|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[k|0];v[d+3|0]=y[m|0];v[d+5|0]=y[e|0];Of(d);jk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;uC(b,d);h=hb-16|0;hb=h;e=(D(i,104)+a|0)+484380|0;pd(e,0);v[e+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=e,o=y[Wb(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[e+36|0]=y[d+24|0];x[e>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[e+34>>1]=z[e+34>>1]|2;x[e+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[e+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}hb=h+16|0;e=f+8|0;ml(e,2,d);d=f+24|0;Fc(d,e);Dc(((i<<5)+a|0)+946304|0,d);g=g+1|0;xb(d);continue}}}g=1}hb=f+384|0;return g|0}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,B=0,C=0,E=0;f=hb-32|0;hb=f;k=Sh(f+24|0);o=k+3|0;p=k+5|0;q=k+4|0;r=k+2|0;s=k+1|0;d=f+16|0;t=d|5;u=d|3;while(1){a:{if(A[a+12>>2]>l>>>0){z=pf(x[a>>2],x[x[a+48>>2]+12>>2],l);b:while(1){if(!Nb(x[c>>2],x[c+8>>2],1)){break a}d=Ee(c);if((d|0)==255){break a}m=d<<24>>24;d=m&31;h=D(d,6)+z|0;i=Dg(x[x[a+48>>2]+12>>2])>>>0>d>>>0;j=i?h:k;e=1;if(!(m&64)){d=Ee(c);g=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}v[j|0]=e}C=i?h+1|0:s,E=Ee(c),v[C|0]=E;e=(g|0)<0}g=i?h+3|0:o;d=i?h+5|0:p;n=i?h+4|0:q;i=i?h+2|0:r;while(1){e:{f:{g:{if(e&1){x[f+16>>2]=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);w[f+20>>1]=y[j+4|0]|y[j+5|0]<<8;e=Ee(c);h=e&63;B=e<<24>>24;if(e&64){v[i|0]=1;v[n|0]=h;break e}e=Ee(c);v[d|0]=e;if(h>>>0<=15){v[g|0]=h;Of(j);h:{i:{j:{e=y[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[g|0]=9;v[d|0]=D(y[d|0]&15,17);break f}v[g|0]=0;v[i|0]=1;x[f+12>>2]=y[d|0]+1>>>1;x[f+8>>2]=64;C=n,E=x[td(f+12|0,f+8|0)>>2],v[C|0]=E;break f}if((e|0)!=19){break f}if(y[d|0]==128){break g}Gu(j);break f}if(h>>>0>44){break f}v[g|0]=y[h+26064|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}v[d|0]=e|158;break f;case 1:case 2:v[f+12|0]=15;C=d,E=y[Wb(f+12|0,d)|0]|224,v[C|0]=E;break f;case 5:case 6:x[f+12>>2]=16;x[f+8>>2]=e+1;C=d,E=x[td(f+12|0,f+8|0)>>2]/2|240,v[C|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[g|0]=2;v[d|0]=e|240;break f}v[g|0]=3;v[d|0]=e|240;break f}v[g|0]=11;v[d|0]=(e<<3&120)+8|15;break f}v[g|0]=11;v[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+12>>2]=e+1>>>1;x[f+8>>2]=64;C=d,E=x[td(f+12|0,f+8|0)>>2],v[C|0]=E;break f}if((m|0)>=0){continue b}break a}v[g|0]=0}Fu(g,d,u,t);e=y[f+19|0];if(Ai(e)>>>0<=Ai(y[g|0])>>>0){break e}q:{if(y[i|0]){break q}if(!Dq(g,d,1)){break q}v[i|0]=y[g|0];v[n|0]=y[d|0]}v[g|0]=e;v[d|0]=y[f+21|0]}e=(B|0)<0;continue}}}hb=f+32|0;return}l=l+1|0;continue}}function k9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=hb-16|0;hb=h;f=x[a+8>>2];e=x[a>>2];x[23420]=0;f=Q(553,e|0,f|0)|0;e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){if(f){break b}x[23420]=0;f=T(194,a|0)|0;e=x[23420];x[23420]=0;c:{if((e|0)==1){break c}x[23420]=0;j=d+484344|0;k=Wd(f+1|0,1,1024);f=W(214,j|0,b|0,k|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[23420]=0;f=W(144,e|0,f|0,1)|0;e=x[23420];x[23420]=0;d:{if((e|0)!=1){if(!f){break b}x[23420]=0;i=T(194,a|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=_b(e,b);e=ed(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Zc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[23420]=0;g=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break a}v[e+5|0]=g;x[23420]=0;g=T(194,a|0)|0;f=x[23420];x[23420]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+42688|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Wd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=xi(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:Gu(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[23420]=0;R(247,h+8|0,a|0);f=x[23420];x[23420]=0;if((f|0)==1){break j}v[e+1|0]=y[h+8|0];g=y[jd(h+8|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[23420]=0;g=T(194,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}zb(a);hb=h+16|0;return}b=P()|0;zb(a);S(b|0);p()}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;s=x[a+16>>2];t=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){e=x[a+8>>2];k=x[a+12>>2];p=cg(e,k,o);q=lb;i=x[a+76>>2];Hf(x[a>>2],x[a+4>>2],$e(e,k,d),lb);k=i>>>0<lb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];w=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Rb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}e=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Kd(j,(g|0)/8<<16>>16);Jd(j,4);Rb(f+40|0,p,q);e=e-1|0;continue b}else{g=(v[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Kd(j,(g|0)/8<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=_f(j,t);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=x[r>>2];i=(f+16|0)+(b<<3)|0;G=x[i+8>>2];g=x[i+4>>2];x[i+8>>2]=g;n=e<<8;e=n;e=Wia(E,F,e,e>>31);h=lb;H=i;i=e;e=Xb(g,-16777216,16776704);e=Wia(B,C,e,e>>31);g=i+e|0;i=lb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Xb(G,-16777216,16776704);h=Wia(z,A,e,e>>31);g=h+g|0;e=lb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Qc(h,e,24);x[H+4>>2]=e-(n&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];m=x[a+28>>2]+m|0;x[c>>2]=x[c>>2]+D(x[f>>2],m>>12);l=b+l|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],l>>12);Rb(f+8|0,u,w);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Jb(a);x[23420]=0;Z(93);c=x[23420];x[23420]=0;a:{b:{if((c|0)==1){c=Ta(61592,91780,92364,0)|0;d=ib;c:{d:{e:{if((da(61592)|0)==(d|0)){c=_(c|0)|0;x[23420]=0;b=Q(891,a|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}x[23420]=0;b=Q(891,b|0,17588)|0;d=x[23420];x[23420]=0;if((d|0)==1){break e}x[23420]=0;d=Q(891,b|0,17564)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23420]=0;Q(891,d|0,(b?b:21473)|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;break a}f:{if((da(91780)|0)==(d|0)){c=_(c|0)|0;x[23420]=0;b=Q(891,a|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}x[23420]=0;b=Q(891,b|0,17588)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}x[23420]=0;d=Q(891,b|0,17539)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23420]=0;Q(891,d|0,(b?b:21473)|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;break a}e=da(92364)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){x[23420]=0;b=Q(891,a|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;b=Q(891,b|0,17588)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;d=Q(891,b|0,17555)|0;b=x[23420];x[23420]=0;if((b|0)==1){break g}b=mb[x[x[c>>2]+8>>2]](c)|0;x[23420]=0;Q(891,d|0,(b?b:21473)|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break g}x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;break a}x[23420]=0;b=Q(891,a|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}x[23420]=0;b=Q(891,b|0,17588)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}x[23420]=0;Q(891,b|0,13557)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;break a}b=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){break a}break c}b=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){break a}break c}b=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)==1){break c}break a}b=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){break a}}V(0)|0;Ub()}p()}return}xb(a);S(b|0);p()}function dt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=hb-16|0;hb=i;f=x[a+24>>2];h=gz(f,y[a+32|0]);j=x[h>>2];a:{if(Mc(j,x[h+4>>2])>>>0<=b>>>0){break a}if(kO(f,z[bc(j,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(vd(h,x[a+4>>2])>>>0>b>>>0){if(A[Hd(h,b)+4>>2]>c>>>0){break b}}Wn(a,0);if(vd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}f=x[a+24>>2]}hc(i,x[d>>2],z[f+480188>>1]);d=i+8|0;h=x[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=x[i+4>>2];while(1){if(!g&(k|0)==(j|0)){x[d>>2]=f;x[d+4>>2]=e}else{l=y[SP(h,k)+841|0];m=l^Wia(f^k,e^g,435,256);l=!l;f=(q=f,r=Wia(m,lb,435,256),s=l,s?q:r);e=l?e:lb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=cm(i,b,c);h=hb-16|0;hb=h;k=a+12|0;g=$N(z[f>>1],x[f+4>>2],Vd(k),ic(k));c:{if(Pb(g,Kf(k))){j=z[f>>1];l=x[f+4>>2];f=ud(g);if(!Vk(j,l,z[f>>1],x[f+4>>2])){break c}}g=Kf(k)}f=x[gc(h+8|0,g)>>2];hb=h+16|0;if(zg(f,yf(k))){d=ud(f);d=uc(x[d+8>>2],x[d+12>>2])^1}h=x[e>>2]!=-2078137563|x[e+4>>2]!=-873292572;Ab(i,x[Hd(x[a>>2],b)>>2],c);g=1;m=Bb(x[x[i>>2]>>2],x[i+4>>2])^1;j=d|h;if(!(m|j)){break a}d:{e:{f:{g:{if(d){l=ud(f);f=Db(x[l+8>>2]);n=Db(x[l+12>>2]);o=x[e>>2];p=x[e+4>>2];j=hb-16|0;hb=j;x[j+8>>2]=f;while(1){if(!(!Pb(f,n)|x[f>>2]==(o|0)&x[f+4>>2]==(p|0))){f=x[ft(j+8|0)>>2];continue}break}hb=j+16|0;if(Pb(f,Db(x[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(d|m){break e}d=ZN(k,cm(i,b,c));h:{if(A[d+4>>2]<A[Fb(d)>>2]){g=hb-16|0;hb=g;d=YN(g,d);XN(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;kc(d);hb=g+16|0;break h}f=hb-32|0;hb=f;g=Fb(d);g=ar(f+8|0,br(d,Gg(x[d>>2],x[d+4>>2])+1|0),Gg(x[d>>2],x[d+4>>2]),g);XN(x[g+8>>2]);x[g+8>>2]=x[g+8>>2]+8;zd(d,g);$q(g);hb=f+32|0}}d=ZN(k,cm(i,b,c));i:{if(A[d+4>>2]<A[Fb(d)>>2]){g=hb-16|0;hb=g;d=YN(g,d);TM(x[d+4>>2],x[e>>2],x[e+4>>2]);x[d+4>>2]=x[d+4>>2]+8;kc(d);hb=g+16|0;break i}f=hb-32|0;hb=f;g=Fb(d);g=ar(f+8|0,br(d,Gg(x[d>>2],x[d+4>>2])+1|0),Gg(x[d>>2],x[d+4>>2]),g);TM(x[g+8>>2],x[e>>2],x[e+4>>2]);x[g+8>>2]=x[g+8>>2]+8;zd(d,g);$q(g);hb=f+32|0}}Ab(i,x[Hd(x[a>>2],b)>>2],c);vg(i,1);g=0}hb=i+16|0;return g|0}function Bx(a){a=a|0;var b=0,c=0,d=E(0),e=0;Tb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[23420]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}ea(879,e|0,67,5,c|0,b|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[23420]=0;ea(879,a+4528|0,62,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[23420]=0;ea(879,a+4552|0,53,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[23420]=0;ea(879,a+4576|0,43,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[23420]=0;ea(879,a+4600|0,32,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[23420]=0;ea(879,a+4624|0,22,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[23420]=0;ea(879,a+4648|0,75,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[23420]=0;ea(879,a+4672|0,69,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[23420]=0;ea(879,a+4696|0,60,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[23420]=0;ea(879,a+4720|0,48,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[23420]=0;ea(879,a+4744|0,36,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[23420]=0;ea(879,a+4768|0,25,5,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;ea(879,a+4792|0,0,0,0,0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[23420]=0;ea(879,a+4816|0,3,0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[23420]=0;ea(879,a+4840|0,3,0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;ea(879,a+4864|0,407,1,c|0,0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;ea(879,a+4888|0,400,1,c|0,0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;ea(879,a+4912|0,10,0,c|0,-1);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;ea(879,a+4936|0,10,0,c|0,-1);c=x[23420];x[23420]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=V(91780)|0;if((ib|0)==(da(91780)|0)){_(c|0)|0;v[a+5045|0]=0;$();return}S(c|0);p()}function _fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-32|0;hb=e;a:{b:{if(!c){break b}n=e,o=Ee(a),v[n+16|0]=o;dn(b,e+16|0);k=c-1|0;c=0;while(1){f=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!cf(a,e+16|0)){break b}g=1;d=y[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}g=1;break c}if(!cf(a,e+16|0)){break b}FT(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!cf(a,e+16|0)){break g}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=Sp(g,1)+c|0;c=d<<1&254;if(c){break f}if(!cf(a,e+16|0)){break g}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((g|0)<=2){j=0;h=g-2|0;break h}if(!cf(a,e+16|0)){break b}d=Sp(g-3|0,8)|y[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!cf(a,e+16|0)){break b}c=y[e+16|0]<<1|1;d=c&255;f=c>>>0>255}l=Sp(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!cf(a,e+16|0)){break b}d=y[e+16|0]<<1|1;c=d&255;d=d>>>0>255}g=1;h=k;d=Sp(f+l|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!cf(a,e+16|0)){break k}c=y[e+16|0]<<1|1;d=c&255;c=c>>>0>255}g=Sp(g,1)+c|0;c=d<<1&254;if(c){break j}if(!cf(a,e+16|0)){break k}d=y[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=g+2|0}g=h;h=d+j|0;f=0;if(g>>>0<h>>>0|(h|0)<=0|(m|0)>=0){break a}d=x[b+4>>2];f=0;if((0-Wc(x[b>>2],d)|0)>(m|0)){break a}d=gc(e+24|0,Db(d));v[e+16|0]=0;g=e+16|0;l=hb-32|0;hb=l;f=x[d>>2];d=x[b>>2];i=We(f,Db(d))+d|0;d=x[Fb(b)>>2];j=x[b+4>>2];l:{if(h>>>0<=d-j>>>0){d=h;f=j-i|0;if(d>>>0>f>>>0){Bo(b,h-f|0,g);d=f;if(!d){break l}}HT(b,i,j,h+i|0);Xh(i,d,g+(g>>>0>=i>>>0?g>>>0<A[b+4>>2]?h:0:0)|0);break l}d=Fb(b);d=Dl(l+8|0,Al(b,Wc(x[b>>2],j)+h|0),i-x[b>>2]|0,d);HS(d,h,g);i=GT(b,d,i);Cl(d)}Db(i);hb=l+32|0;n=e,o=_g(TR(Db(x[b+4>>2]),h),m),x[n+16>>2]=o;n=e,o=TR(Db(x[b+4>>2]),h),x[n+8>>2]=o;d=h;while(1){f=y[SR(e+16|0)|0];n=SR(e+8|0),o=f,v[n|0]=o;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}f=0}hb=e+32|0;return f|0}function A5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-112|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[Kk(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Tk(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;Qd(f);e=x[d+88>>2];Qd(d+72|0);e=Jk(e,x[d+76>>2],b);Qd(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+104|0,21473);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Lc(e,a,d)){a=ba(8)|0;x[23420]=0;c=Q(54,d+88|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}g=0;if(!c){break e}a=ba(8)|0;c=x[b+4>>2];b=x[b>>2];x[23420]=0;e=Ch(d+72|0,b,c);b=x[23420];x[23420]=0;f:{g:{h:{if((b|0)!=1){x[23420]=0;U(917,d+88|0,17488,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break h}c=0;b=rc(a,d+88|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(d+88|0);break g}b=P()|0;break f}b=P()|0;c=1}xb(e);if(!c){break c}}ca(a|0);break c}if(x[e+4>>2]!=2){a=ba(8)|0;x[23420]=0;c=Q(54,d+88|0,11442)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d- -64|0,21473);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Lc(b,c,d+32|0)){a=ba(8)|0;x[23420]=0;c=Q(54,d+88|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+56|0,7677);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Lc(b,c,d+24|0)){g=1;if(!Rd(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=qc(d+48|0,7729);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Lc(b,c,d+16|0)){g=1;if(!Rd(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=qc(d+40|0,7747);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Lc(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}hb=d+112|0;return+g}b=P()|0;ca(a|0)}S(b|0)}p()}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;s=x[a+16>>2];t=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){e=x[a+8>>2];j=x[a+12>>2];p=cg(e,j,o);q=lb;g=x[a+76>>2];Hf(x[a>>2],x[a+4>>2],$e(e,j,d),lb);j=g>>>0<lb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];v=x[a+12>>2];a:while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Rb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Kd(i,(w[(b<<1|2)+l>>1]+w[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=_f(i,t);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=x[r>>2];g=(f+16|0)+(b<<3)|0;G=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;l=e<<8;e=l;e=Wia(E,F,e,e>>31);h=lb;H=g;g=e;e=Xb(k,-16777216,16776704);e=Wia(B,C,e,e>>31);k=g+e|0;g=lb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Xb(G,-16777216,16776704);h=Wia(z,A,e,e>>31);k=h+k|0;e=lb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Qc(h,e,24);x[H+4>>2]=e-(l&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];n=x[a+28>>2]+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],n>>12);m=b+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],m>>12);Rb(f+8|0,u,v);c=c+8|0;continue a}else{e=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Kd(i,(w[(e<<1|2)+l>>1]+w[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(i,4);Rb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function m7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=0,Q=E(0);a:{if(!x[a+4316>>2]){break a}if(!Uh(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=x[a+44>>2];s=Ec(e,0);t=Ec(e,1);e=x[a+56>>2];u=Ec(e,0);v=Ec(e,1);L=mb[x[x[a>>2]+192>>2]](a)|0;w=E(E(mb[x[x[a>>2]+200>>2]](a))/E(100));I=E(mb[x[x[a>>2]+188>>2]](a));z=mb[x[x[a>>2]+212>>2]](a)|0;M=z&1;o=x[a+4324>>2];i=x[a+4320>>2];m=x[a+4328>>2];k=x[a+4312>>2];N=x[a+4276>>2];p=x[a+4264>>2];A=x[a+4256>>2];C=y[a+4260|0];r=a+4316|0;D=d;while(1){if(D){h=B[t>>2];l=B[s>>2];j=x[r>>2];e=Fn(j,k+A|0);j=Fn(j,k);b:{if(C){P=Cb(H,m),Q=l,B[P>>2]=Q;P=Cb(G,m),Q=h,B[P>>2]=Q;q=Cb(p,e);P=Cb(p,j),Q=E(E(B[q>>2]*w)+l),B[P>>2]=Q;g=E(E(B[Cb(N,e)>>2]*w)+h);e=K;break b}g=E(E(B[Cb(p,e)>>2]*w)+E(E(l+h)*E(.5)));e=J}P=Cb(x[e>>2],j),Q=g,B[P>>2]=Q;c:{if(L){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(C){e=(m+2|0)%3|0;l=B[Cb(H,e)>>2];h=B[Cb(G,e)>>2]}e=x[r>>2];j=Cb(p,Fn(e,i+k|0));q=e;e=k+4096|0;O=B[Cb(p,Fn(q,e+i|0))>>2];n=B[j>>2];B[u>>2]=E(E(E(E(E(O-n)*E(E(i&4095)*E(.000244140625)))+n)-l)*I)+l;i=x[(C?4276:4264)+a>>2];j=x[r>>2];q=Cb(i,Fn(j,k+o|0));n=B[Cb(i,Fn(j,e+o|0))>>2];l=B[q>>2];B[v>>2]=E(E(E(E(E(n-l)*E(E(o&4095)*E(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;k=(((k|0)<=0?x[r>>2]<<12:0)+k|0)-4096|0;x[a+4312>>2]=k;h=M?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(z>>>0>1?e:0-e|0)+A|0;x[a+4324>>2]=o;i=z>>>0<4;t=t+4|0;s=s+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+A|0;x[a+4320>>2]=i;D=D-1|0;v=v+4|0;u=u+4|0;continue}else{e=a;a=x[a+56>>2];ji(e,b,c,Ec(a,0),Ec(a,1),d)}break}}}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;q=x[a+16>>2];r=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;m=x[a+128>>2];if(m){e=x[a+8>>2];k=x[a+12>>2];n=cg(e,k,m);o=lb;i=x[a+76>>2];Hf(x[a>>2],x[a+4>>2],$e(e,k,d),lb);k=i>>>0<lb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];w=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Rb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}e=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Kd(j,(g|0)/8<<16>>16);Jd(j,4);Rb(f+40|0,n,o);e=e-1|0;continue b}else{g=(v[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Kd(j,(g|0)/8<<16>>16);Jd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=_f(j,r);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=x[p>>2];i=(f+16|0)+(b<<3)|0;G=x[i+8>>2];g=x[i+4>>2];x[i+8>>2]=g;l=e<<8;e=l;e=Wia(E,F,e,e>>31);h=lb;H=i;i=e;e=Xb(g,-16777216,16776704);e=Wia(B,C,e,e>>31);g=i+e|0;i=lb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Xb(G,-16777216,16776704);h=Wia(z,A,e,e>>31);g=h+g|0;e=lb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Qc(h,e,24);x[H+4>>2]=e-(l&y);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],s);Rb(f+8|0,u,w);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function $5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=E(0),n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=E(0),A=0,C=0,D=0,F=0,G=E(0),H=0,I=0,J=0,K=0,L=0,M=0,N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=E(0);if(Uh(a+44|0)){f=x[a+44>>2];A=Ec(f,0);C=Ec(f,1);f=x[a+56>>2];D=Ec(f,0);F=Ec(f,1);t=x[a+4296>>2];g=t+1|0;k=a+4304|0;f=a+4272|0;u=g+x[Cb(f,0)>>2]&4095;o=k+(u<<4)|0;v=g+x[Cb(f,1)>>2]&4095;p=((v<<4)+k|0)+4|0;w=g+x[Cb(f,2)>>2]&4095;q=((w<<4)+k|0)+8|0;h=Cb(f,3);i=x[Cb(f,4)>>2];r=x[a+4300>>2];i=i+r|0;y=g+x[h>>2]&4095;s=((y<<4)+k|0)+12|0;h=x[Cb(f,5)>>2]+r|0;g=a+4232|0;I=a+69840|0;J=a+78032|0;f=d;while(1){if(f){N=B[s>>2];O=B[q>>2];P=B[p>>2];Q=B[o>>2];z=B[C>>2];R=B[A>>2];K=i&1023;i=(K<<3)+I|0;j=B[i+4>>2];u=u-1&4095;o=(u<<4)+k|0;e=B[o>>2];s=r<<3;q=s+I|0;v=v-1&4095;p=((v<<4)+k|0)+4|0;l=B[p>>2];m=l;n=E(l*E(.6180340051651001));G=B[i>>2];l=B[Cb(g,0)>>2];n=E(n+E(G*l));B[q+4>>2]=m+E(n*E(-.6180340051651001));m=e;e=E(E(j*l)+E(e*E(-.6180340051651001)));B[q>>2]=m+E(e*E(.6180340051651001));B[o>>2]=n;B[p>>2]=e;L=h&1023;h=(L<<3)+J|0;l=B[h+4>>2];w=w-1&4095;H=(w<<4)+k|0;q=H+8|0;e=B[q>>2];M=s+J|0;y=y-1&4095;i=(y<<4)+k|0;s=i+12|0;j=B[s>>2];m=j;G=B[h>>2];n=B[Cb(g,1)>>2];j=E(E(j*E(.6180340051651001))+E(G*n));B[M+4>>2]=m+E(j*E(-.6180340051651001));m=e;e=E(E(l*n)+E(e*E(-.6180340051651001)));B[M>>2]=m+E(e*E(.6180340051651001));B[H+8>>2]=j;B[i+12>>2]=e;e=E(R+E(1.0000000031710769e-30));B[D>>2]=j+E(E(e*B[a+4224>>2])+B[o>>2]);j=E(z+E(1.0000000031710769e-30));B[F>>2]=E(E(j*B[a+4224>>2])+B[p>>2])+B[i+12>>2];h=(t<<4)+k|0;l=e;e=B[a+4228>>2];z=E(l*e);S=h,T=E(z+E(E(B[o>>2]*B[Cb(g,2)>>2])+E(Q*B[Cb(g,3)>>2]))),B[S>>2]=T;e=E(j*e);S=h,T=E(e+E(E(B[p>>2]*B[Cb(g,4)>>2])+E(P*B[Cb(g,5)>>2]))),B[S+4>>2]=T;S=h,T=E(E(E(B[H+8>>2]*B[Cb(g,6)>>2])+E(O*B[Cb(g,7)>>2]))-e),B[S+8>>2]=T;S=h,T=E(z+E(E(B[i+12>>2]*B[Cb(g,8)>>2])+E(N*B[Cb(g,9)>>2]))),B[S+12>>2]=T;f=f-1|0;F=F+4|0;D=D+4|0;C=C+4|0;A=A+4|0;h=L-1|0;i=K-1|0;r=r-1&1023;t=t-1&4095;continue}else{x[a+4300>>2]=r;x[a+4296>>2]=t;f=a;a=x[a+56>>2];ji(f,b,c,Ec(a,0),Ec(a,1),d)}break}}}function SJ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=hb-128|0;hb=j;a:{b:{c:{if(!dm(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Ed(j+16|0,b,c,d,e,f,g,h,i);e=x[j+16>>2];d=x[j+20>>2];c=x[j+24>>2];b=x[j+28>>2];uK(j,e,d,c,b,e,d,c,b);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((dm(b,c,l,p,f,g,h,k)|0)<=0){if(dm(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Ed(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}if(o){i=c;h=b}else{Ed(j+96|0,b,c,l,p,0,0,0,1081540608);h=x[j+108>>2];p=h;l=x[j+104>>2];o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Ed(j+80|0,f,g,m,k,0,0,0,1081540608);f=x[j+92>>2];k=f;m=x[j+88>>2];q=(k>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Ed(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Ed(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Ed(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;hb=j+128|0}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;e=hb-48|0;hb=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;while(1){if(d){b=x[e+16>>2];G=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=w[b+14>>1];g=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;x[(e+8|0)+(p<<2)>>2]=(((((((D(w[i-8>>1],f)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)+D(w[i+4>>1],r)|0)+D(w[i+8>>1],q)|0)+D(g,w[i+12>>1])|0)+D(H,w[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=x[q>>2];g=(e+24|0)+(o<<3)|0;r=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=Wia(E,F,b,b>>31);f=lb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Wia(B,C,b,b>>31);h=g+b|0;g=lb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(r,-16777216,16776704);f=Wia(z,A,b,b>>31);h=f+h|0;b=lb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);x[i+4>>2]=b-(k&y);x[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[e+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m>>12);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function Cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-128|0;hb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=lR(c,+y[a+2|0]*1e4/240),v[f|0]=g;x[d+96>>2]=127;x[d+80>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[td(d+96|0,d+80|0)>>2],v[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:ru(d+80|0,15419);x[23420]=0;R(495,d- -64|0,d|0);a=x[23420];x[23420]=0;f:{g:{h:{i:{if((a|0)!=1){x[23420]=0;R(495,d+48|0,d+127|0);a=x[23420];x[23420]=0;if((a|0)==1){break i}x[23420]=0;X(496,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}a=d+96|0;ue(d+112|0,a);Xe(b,x[d+112>>2],x[d+116>>2]);xb(a);xb(d+48|0);xb(d- -64|0);Sb(d+80|0);break b}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(d+48|0)}xb(d- -64|0)}break c;case 1:ru(d+80|0,15359);x[23420]=0;R(495,d- -64|0,d|0);a=x[23420];x[23420]=0;j:{k:{l:{m:{if((a|0)!=1){x[23420]=0;R(495,d+48|0,d+127|0);a=x[23420];x[23420]=0;if((a|0)==1){break m}x[23420]=0;X(496,d+96|0,d+80|0,d- -64|0,d+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break l}a=d+96|0;ue(d+40|0,a);Xe(b,x[d+40>>2],x[d+44>>2]);xb(a);xb(d+48|0);xb(d- -64|0);Sb(d+80|0);break b}a=P()|0;break j}a=P()|0;break k}a=P()|0;xb(d+48|0)}xb(d- -64|0)}break c;default:break e}}a=qc(d+32|0,15446);Xe(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+127|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+31|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+30|0]=(a|0)<0?127:a;a=hb-16|0;hb=a;c=Vb(a,4009);Rc(d+80|0,c);xb(c);hb=a+16|0;x[23420]=0;R(495,d- -64|0,d+127|0);a=x[23420];x[23420]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[23420]=0;R(495,d+48|0,d+31|0);a=x[23420];x[23420]=0;if((a|0)==1){break s}x[23420]=0;R(495,d|0,d+30|0);a=x[23420];x[23420]=0;if((a|0)==1){break r}x[23420]=0;ea(663,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}a=d+96|0;ue(d+16|0,a);Xe(b,x[d+16>>2],x[d+20>>2]);xb(a);xb(d);xb(d+48|0);xb(d- -64|0);Sb(d+80|0);break b}a=P()|0;break n}a=P()|0;break o}a=P()|0;break p}a=P()|0;xb(d)}xb(d+48|0)}xb(d- -64|0)}}Sb(d+80|0);S(a|0);p()}e=1}hb=d+128|0;return e|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=hb-48|0;hb=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];b=x[a+68>>2];A=b;B=b>>31;b=x[a+64>>2];C=b;E=b>>31;b=x[a+60>>2];F=b;G=b>>31;while(1){if(d){b=x[e+16>>2];H=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(b>>>16&65520)+s|0;I=w[b+14>>1];g=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;x[(e+8|0)+(p<<2)>>2]=(((((((D(v[i-4|0],f)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)|0)+D(v[i+2|0],r)|0)+D(v[i+4|0],q)|0)+D(g,v[i+6|0])|0)+D(I,v[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=x[q>>2];g=(e+24|0)+(o<<3)|0;r=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=Wia(F,G,b,b>>31);f=lb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Wia(C,E,b,b>>31);h=g+b|0;g=lb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(r,-16777216,16776704);f=Wia(A,B,b,b>>31);h=f+h|0;b=lb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);x[i+4>>2]=b-(k&z);x[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[e+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],m>>12);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=E(0);d=hb-112|0;hb=d;c=hb-16|0;hb=c;e=b+16|0;DS(c+8|0,e);f=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((h|0)==(f|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((f|0)!=(h|0)){Tb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d- -64|0;Xd(c,a,pg(a));f=jc(d+88|0,c);zb(c);x[23420]=0;c=T(190,f|0)|0;e=x[23420];x[23420]=0;a:{b:{if((e|0)==1){break b}x[23420]=0;R(272,b+4|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}ke(d+56|0,x[b+4>>2],x[b+8>>2]);x[23420]=0;bn(406,d- -64|0,f,x[d+56>>2],x[d+60>>2]);c=x[23420];x[23420]=0;if((c|0)!=1){x[23420]=0;c=T(145,a|0)|0;e=x[23420];x[23420]=0;c:{if((e|0)==1){break c}x[23420]=0;U(178,d+32|0,a|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=d+32|0;c=jc(d- -64|0,a);zb(a);a=x[c>>2];x[23420]=0;a=T(166,a|0)|0;e=x[23420];x[23420]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=x[c+8>>2];e=x[c>>2];x[23420]=0;a=W(144,e|0,a|0,5)|0;e=x[23420];x[23420]=0;if((e|0)==1){break e}if(!a){break f}x[23420]=0;Q(407,c|0,d+28|0)|0;a=x[23420];x[23420]=0;h:{if((a|0)!=1){a=4;if(!Ob(d+28|0,13448,4)){break h}if(!Ob(d+28|0,13960,4)){break h}x[23420]=0;a=T(145,c|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break h}a=P()|0;break d}a=P()|0;break d}x[23420]=0;U(178,d+8|0,c|0,a|0);a=x[23420];x[23420]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=jc(d+32|0,a);zb(a);if(Ob(d+28|0,13448,4)){break k}x[23420]=0;g=E(za(408,e|0));a=x[23420];x[23420]=0;if((a|0)==1){break g}B[d+8>>2]=g;x[d+4>>2]=0;x[d>>2]=1065353216;g=B[Xp(d+8|0,d+4|0,d)>>2];B[b+144>>2]=g;i=E(F(g));if((i<E(11754943508222875e-54)^-1)&(!(i>=E(O))&g==g)){break j}x[b+144>>2]=0;break j}a=P()|0;break d}if(Ob(d+28|0,13960,4)){break j}x[23420]=0;a=T(145,e|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break i}x[b+148>>2]=a}zb(e);continue}}break}a=P()|0;zb(e);break d}zb(c);zb(f);hb=d+112|0;return}a=P()|0;break d}a=P()|0}zb(c);break a}a=P()|0;break a}a=P()|0;break a}a=P()|0}zb(f);S(a|0);p()}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=hb-176|0;hb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=dd(d,h<<1);LL(c+160|0,C[e>>3],C[e+8>>3]);d=dd(d,h);LL(c+144|0,C[d>>3],C[d+8>>3]);ni(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=dd(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=dd(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=dd(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=dd(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Ok(g,f,o,n);j=c- -64|0;dj(j,f,o,n);l=c+96|0;Ok(c+48|0,l,u,t);f=c+16|0;dj(f,l,u,t);ni(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Ok(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Ok(c,j,C[c+32>>3],C[c+40>>3]);ni(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=dd(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;dj(c,g,C[c+48>>3],C[c+56>>3]);ni(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=dd(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;dj(c,j,C[c+32>>3],C[c+40>>3]);ni(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=dd(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=dd(h,d+i|0);m=dd(h,d);n=C[a>>3];o=C[a+8>>3];dj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;ay(dd(x[b>>2],d),n,o);d=d+1|0;continue}}hb=c+176|0}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=hb-48|0;hb=f;q=x[a+16>>2];r=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;m=x[a+128>>2];if(m){e=x[a+8>>2];j=x[a+12>>2];n=cg(e,j,m);o=lb;g=x[a+76>>2];Hf(x[a>>2],x[a+4>>2],$e(e,j,d),lb);j=g>>>0<lb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;u=x[a+8>>2];v=x[a+12>>2];a:while(1){if(d){d=d-1|0;b=x[f+12>>2];e=x[f+8>>2];x[f+40>>2]=e;x[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Rb(i,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Kd(i,(w[(b<<1|2)+l>>1]+w[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(i,h);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=_f(i,r);x[f+4>>2]=b;x[f>>2]=b;y=x[a+72>>2];b=x[a+68>>2];z=b;A=b>>31;b=x[a+64>>2];B=b;C=b>>31;b=x[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=x[p>>2];g=(f+16|0)+(b<<3)|0;G=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;l=e<<8;e=l;e=Wia(E,F,e,e>>31);h=lb;H=g;g=e;e=Xb(k,-16777216,16776704);e=Wia(B,C,e,e>>31);k=g+e|0;g=lb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Xb(G,-16777216,16776704);h=Wia(z,A,e,e>>31);k=h+k|0;e=lb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Qc(h,e,24);x[H+4>>2]=e-(l&y);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+4>>2]);Rb(f+8|0,u,v);c=c+8|0;continue a}else{e=(x[f+44>>2]&2147483647)<<1|x[f+40>>2]>>>31;Kd(i,(w[(e<<1|2)+l>>1]+w[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(i,4);Rb(f+40|0,n,o);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=f+48|0}function ie(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;e=x[a>>2];a:{if(uc(e,x[a+4>>2])){break a}f=x[b+4>>2];if(f>>>0>=A[a+12>>2]){break a}c=z[b+8>>1];i=x[x[a+48>>2]+12>>2];g=Dg(i);if(c>>>0>=g>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?g-1|0:c;g=f;f=d?0:c;c=ed(e,i,g,f);g=y[b+12|0];j=g&4;b:{c:{if(g&2){break c}k=y[b+10|0];e=c;d=f;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=y[e+3|0]){break d}break b}if((k|0)==y[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=f;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(g&1)){break f}d=x[i+480180>>2]&2;g:{h:{if(!j){while(1){if((f&65535)>>>0<=(l&65535)>>>0){i:{j:{switch(y[c+3|0]-9|0){case 4:if(!lT(x[x[i+8>>2]+88>>2])){break i}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break j;default:break i}}k:{if(d){e=y[c+5|0];if(e>>>0>128){break i}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break k}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break b}c=c+6|0;f=f+1|0;continue}break}if(!j){break h}}e=y[b+11|0];f=13;l:{switch(y[b+10|0]-1|0){case 1:f=9;e=Cm(D(d?2:4,e));break;case 0:break l;default:break g}}v[b+11|0]=e;v[b+10|0]=f;g=g&254;v[b+12|0]=g;break g}c=y[b+11|0];v[h+14|0]=c;f=!d;d=y[b+10|0];m:{n:{if(!(f|(d|0)!=9)){if(c>>>0>128){break m}d=2;f=(c&254)>>>1|0;break n}v[h+15|0]=d;if(!Dq(h+15|0,h+14|0,1)){break m}d=y[h+15|0];if(!d){break m}g=y[b+12|0];f=y[h+14|0]}v[b+11|0]=f;v[b+10|0]=d;v[b+12|0]=g&254}g=y[b+12|0]}d=1;if(g&1){break f}v[b+12|0]=g^4;if(ie(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=ie(a,b);break a}d=1}hb=h+16|0;return d}function uG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=x[d>>2];if(!h){break k}if(!a){g=c;break j}x[d>>2]=0;g=c;break i}l:{if(!x[x[115922]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=v[e|0];if(g){x[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return qf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=y[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=x[e>>2];if((d|d-16843009)&-2139062144){break p}x[a>>2]=d&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=y[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}x[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=x[(f<<2)+81600>>2];d=1;continue}d=y[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=y[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=y[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;x[a>>2]=d;g=g-1|0;a=a+4|0;break q}x[115896]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=y[e|0];if(!(e&3|d-1>>>0>126)){d=x[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=x[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=x[(h<<2)+81600>>2];d=1;continue}d=y[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=y[e|0]}if(d&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-g|0}x[115896]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function ji(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=mb[x[x[a>>2]+136>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(mb[x[x[a>>2]+136>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((mb[x[x[a>>2]+152>>2]](a)|0)<=0){break a}if(!QK(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Ec(l,0);l=Ec(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=QK(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(mb[x[x[a>>2]+136>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function Paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;c=ff(a,c);ae(i,x[a+28>>2]);j=a;a:{if(!c){e=0;if(gd(a,5)){break a}}e=hb-224|0;hb=e;g=El(e+120|0,x[a+28>>2]);x[23420]=0;f=Q(396,e+104|0,27640)|0;a=x[23420];x[23420]=0;b:{c:{d:{e:{if((a|0)!=1){x[23420]=0;x[e+88>>2]=19924737;x[e+92>>2]=0;U(397,g|0,f|0,e+88|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}Sb(f);if(!(y[g+3|0]&64)){break d}break b}b=P()|0;break c}b=P()|0;Sb(f);break c}v[e+103|0]=0;x[23420]=0;f=Q(396,e+88|0,5466)|0;a=x[23420];x[23420]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[23420]=0;U(398,g|0,e+103|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break q}Sb(f);f=Jb(e+72|0);x[23420]=0;a=Q(396,e+56|0,9986)|0;h=x[23420];x[23420]=0;if((h|0)==1){break p}x[23420]=0;U(709,g|0,f|0,a|0);h=x[23420];x[23420]=0;if((h|0)==1){break o}Sb(a);x[23420]=0;U(11,e+40|0,(y[e+103|0]?0:d)|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break n}x[23420]=0;R(260,b|0,e+40|0);d=x[23420];x[23420]=0;if((d|0)==1){break m}d=e+40|0;yb(d);w[e+38>>1]=0;x[23420]=0;d=Q(396,d|0,10646)|0;a=x[23420];x[23420]=0;if((a|0)==1){break g}x[23420]=0;W(426,g|0,e+38|0,d|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break l}Sb(d);tg(e+38|0,4e3);x[23420]=0;d=Q(396,e+24|0,13263)|0;a=x[23420];x[23420]=0;if((a|0)==1){break k}h=z[e+38>>1];a=x[gc(e+16|0,h)>>2];x[23420]=0;X(710,g|0,b|0,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}Sb(d);w[e+14>>1]=65535;x[23420]=0;d=Q(396,e|0,8866)|0;a=x[23420];x[23420]=0;if((a|0)==1){break i}x[23420]=0;k=W(426,g|0,e+14|0,d|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break h}a=z[e+14>>1];Sb(d);if(!((k|0)==1|a>>>0>=h>>>0)){Ze(b,a)}xb(f);break b}b=P()|0;break c}b=P()|0;Sb(f);break c}b=P()|0;break f}b=P()|0;Sb(a);break f}b=P()|0;break f}b=P()|0;yb(e+40|0);break f}b=P()|0;Sb(d);break f}b=P()|0;break f}b=P()|0;Sb(d);break f}b=P()|0;break f}b=P()|0;Sb(d);break f}b=P()|0}xb(f)}Zg(g);S(b|0);p()}Zg(g);hb=e+224|0;e=c}af(j,e);hb=i+16|0}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;e=hb-48|0;hb=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+72>>2];b=x[a+68>>2];v=b;y=b>>31;b=x[a+64>>2];z=b;A=b>>31;b=x[a+60>>2];B=b;C=b>>31;while(1){if(d){b=x[e+16>>2];E=((((x[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=w[b+14>>1];g=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;x[(e+8|0)+(n<<2)>>2]=(((((((D(w[i-8>>1],f)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)+D(w[i+4>>1],p)|0)+D(w[i+8>>1],o)|0)+D(g,w[i+12>>1])|0)+D(F,w[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=x[o>>2];g=(e+24|0)+(m<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=Wia(B,C,b,b>>31);f=lb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Wia(z,A,b,b>>31);h=g+b|0;g=lb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(p,-16777216,16776704);f=Wia(v,y,b,b>>31);h=f+h|0;b=lb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);x[i+4>>2]=b-(k&u);x[o>>2]=(b|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],s);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function m5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=hb-96|0;hb=j;a:{b:{c:{k=Np(1,32);d:{e:{if(!k){a=Pl(ba(4)|0);x[23420]=0;U(107,a|0,91780,25);a=x[23420];x[23420]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:883;x[k>>2]=f;c=gg(j+80|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23420]=0;e=Q(54,j- -64|0,e|0)|0;m=x[23420];x[23420]=0;j:{if((m|0)!=1){x[23420]=0;m=Q(894,c|0,e|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break j}x[23420]=0;R(257,m|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;xb(e);break f}x[23420]=0;e=Q(54,j+48|0,e|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break g}vs(c,e)}xb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23420]=0;a=T(767,96)|0;m=x[23420];x[23420]=0;k:{l:{m:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[23420]=0;b=Q(895,f|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break m}x[j+16>>2]=b;b=x[Tf(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[23420]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(925,a|0,j|0,b|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break k}i=V(0)|0;se(j+16|0);break l}i=V(0)|0;break f}i=V(0)|0}Ib(a);break f}x[k+28>>2]=b;se(j+16|0);x[k+24>>2]=b+8;Uk(c);break d}i=V(0)|0}Uk(c);_(i|0)|0;x[23420]=0;X(889,11198,k|0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){a=x[k+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Ib(a);x[k+20>>2]=0}Ib(k);k=0;break d}i=V(0)|0;break e}i=V(0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;x[23420]=0;X(889,11198,0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}$()}hb=j+96|0;return k|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Ub()}p()}function Mt(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ld(b)}if(b>>>0>=4294967232){x[115896]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=x[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=x[23416]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}x[f+4>>2]=j&1|g|2;c=f+g|0;x[c+4>>2]=d|3;x[h+4>>2]=x[h+4>>2]|1;mR(c,d);break b}if(x[23302]==(h|0)){e=e+x[23299]|0;if(e>>>0<=g>>>0){break a}x[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;x[d+4>>2]=c|1;x[23299]=c;x[23302]=d;break b}if(x[23301]==(h|0)){d=e+x[23298]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){x[f+4>>2]=j&1|g|2;e=f+g|0;x[e+4>>2]=c|1;d=d+f|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[f+4>>2]=d|j&1|2;c=d+f|0;x[c+4>>2]=x[c+4>>2]|1;c=0;e=0}x[23301]=e;x[23298]=c;break b}d=x[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=x[h+8>>2];c=d>>>3|0;d=x[h+12>>2];if((d|0)==(e|0)){n=93184,o=x[23296]&_ia(-2,c),x[n>>2]=o;break d}x[e+12>>2]=d;x[d+8>>2]=e;break d}l=x[h+24>>2];i=x[h+12>>2];e:{if((i|0)!=(h|0)){c=x[h+8>>2];x[c+12>>2]=i;x[i+8>>2]=c;break e}f:{e=h+20|0;c=x[e>>2];if(c){break f}e=h+16|0;c=x[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=x[e>>2];if(c){continue}e=i+16|0;c=x[i+16>>2];if(c){continue}break}x[d>>2]=0}if(!l){break d}d=x[h+28>>2];c=(d<<2)+93488|0;g:{if(x[c>>2]==(h|0)){x[c>>2]=i;if(i){break g}n=93188,o=x[23297]&_ia(-2,d),x[n>>2]=o;break d}x[(x[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}x[i+24>>2]=l;c=x[h+16>>2];if(c){x[i+16>>2]=c;x[c+24>>2]=i}c=x[h+20>>2];if(!c){break d}x[i+20>>2]=c;x[c+24>>2]=i}if(m>>>0<=15){x[f+4>>2]=j&1|k|2;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[f+4>>2]=j&1|g|2;d=f+g|0;x[d+4>>2]=m|3;c=f+k|0;x[c+4>>2]=x[c+4>>2]|1;mR(d,m)}c=f}if(c){return c+8|0}f=Ld(b);if(!f){return 0}c=x[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;pc(f,a,b>>>0>c>>>0?c:b);Ib(a);return f}function nh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Jb(a);d=Eb(c);x[23420]=0;R(45,a|0,d|0);d=x[23420];x[23420]=0;d:{if((d|0)!=1){e:{while(1){if(Eb(c)>>>0>b>>>0){d=x[fj(c,b)>>2];x[23420]=0;R(46,a|0,(d>>>0>=128?63:d)<<24>>24);d=x[23420];x[23420]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Jb(a);d=Eb(c);x[23420]=0;R(45,a|0,d|0);d=x[23420];x[23420]=0;f:{if((d|0)!=1){g:{while(1){if(Eb(c)>>>0>b>>>0){d=x[fj(c,b)>>2];x[23420]=0;R(46,a|0,(d>>>0>=256?63:d)<<24>>24);d=x[23420];x[23420]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:_l(a,c,49504);return;case 5:_l(a,c,50528);return;case 4:_l(a,c,51552);return;case 6:_l(a,c,52576);return;case 7:_l(a,c,53600);return;case 8:_l(a,c,54624);return;case 9:Ny(a,c,55648);return;case 10:Ny(a,c,49504);return;case 11:Ny(a,c,53600);return;default:a=ba(8)|0;x[23420]=0;b=Q(44,a|0,10965)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);S(b|0);p();case 0:break c}}e=hb-16|0;hb=e;f=Jb(a);h:{while(1){i:{j:{k:{if(Eb(c)>>>0>g>>>0){b=x[fj(c,g)>>2];if(b>>>0>=2097152){x[23420]=0;R(46,f|0,63);a=x[23420];x[23420]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[23420]=0;R(46,f|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break j}break i}hb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=y[j|0];x[23420]=0;R(46,f|0,(a|i)<<24>>24);h=x[23420];x[23420]=0;a=d;break l}x[23420]=0;a=a-1|0;R(46,f|0,v[a+(e+10|0)|0]|-128);h=x[23420];x[23420]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;xb(f);S(a|0);p()}return}ha(b|0,91912,24);p()}b=P()|0;xb(a);S(b|0);p()}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;e=hb-48|0;hb=e;a:{b:{c:{j=x[a+12>>2];l=x[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|(j|0)==-1){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;x[k+4>>2]=x[f+44>>2];x[k+8>>2]=x[f+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[e+16>>2]=x[a>>2];x[e+20>>2]=b;u=x[a+72>>2];b=x[a+68>>2];y=b;z=b>>31;b=x[a+64>>2];A=b;B=b>>31;b=x[a+60>>2];C=b;E=b>>31;while(1){if(d){b=x[e+16>>2];F=(((x[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=w[b+14>>1];g=w[b+12>>1];o=w[b+10>>1];p=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];f=w[b+2>>1];b=w[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;x[(e+8|0)+(n<<2)>>2]=(((((((D(v[i-4|0],f)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)|0)+D(v[i+2|0],p)|0)+D(v[i+4|0],o)|0)+D(g,v[i+6|0])|0)+D(G,v[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=x[o>>2];g=(e+24|0)+(m<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;k=b<<8;b=k;b=Wia(C,E,b,b>>31);f=lb;i=g;g=b;b=Xb(h,-16777216,16776704);b=Wia(A,B,b,b>>31);h=g+b|0;g=lb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Xb(p,-16777216,16776704);f=Wia(y,z,b,b>>31);h=f+h|0;b=lb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);x[i+4>>2]=b-(k&u);x[o>>2]=(b|0)/256;m=m+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[e+12>>2],s);Rb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=x[e+20>>2];x[a>>2]=x[e+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=e+48|0}function G_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-16|0;hb=j;k=Gw(g);o=ow(g);Ng(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23420]=0;g=Q(1104,k|0,g<<24>>24)|0;i=x[23420];x[23420]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23420]=0;g=Q(1104,k|0,48)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[23420]=0;g=Q(1104,k|0,g|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Ad();if(!HG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Ad();if(!Mj(h)){break d}g=g+1|0;continue}}e:{if(De(j)){h=x[f>>2];x[23420]=0;X(1098,k|0,i|0,g|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}Fl(i,g);x[23420]=0;r=T(1096,o|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Er((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[Nc(j,l)|0]<=0){break f}if(v[Nc(j,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Eb(j)-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[23420]=0;q=Q(1104,k|0,q|0)|0;n=x[23420];x[23420]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[23420]=0;i=T(1099,o|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[23420]=0;i=Q(1104,k|0,i<<24>>24)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[23420]=0;X(1098,k|0,g|0,c|0,h|0);i=x[23420];x[23420]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;xb(j);hb=j+16|0;return}a=P()|0;xb(j);S(a|0);p()}function TJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=hb-96|0;hb=j;a:{b:{c:{d:{e:{f:{k=Np(1,28);if(!k){a=Pl(ba(4)|0);x[23420]=0;U(107,a|0,91780,25);a=x[23420];x[23420]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:883;x[k>>2]=f;c=gg(j+80|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23420]=0;e=Q(54,j- -64|0,e|0)|0;m=x[23420];x[23420]=0;k:{if((m|0)!=1){x[23420]=0;m=Q(894,c|0,e|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break k}x[23420]=0;R(257,m|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;xb(e);break g}x[23420]=0;e=Q(54,j+48|0,e|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break h}vs(c,e)}xb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[23420]=0;a=T(767,80)|0;m=x[23420];x[23420]=0;l:{m:{n:{if((m|0)!=1){x[j+44>>2]=e;x[j+40>>2]=i;x[j+36>>2]=l;x[j+32>>2]=b;x[23420]=0;b=Q(895,f|0,d|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break n}x[j+16>>2]=b;b=x[Tf(j+24|0,j+16|0)>>2];d=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=d;x[23420]=0;d=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=d;b=fa(896,a|0,j|0,b|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break l}i=V(0)|0;se(j+16|0);break m}i=V(0)|0;break g}i=V(0)|0}Ib(a);break g}x[k+24>>2]=b;se(j+16|0);Uk(c);i=k;break d}i=V(0)|0}Uk(c);_(i|0)|0;x[23420]=0;X(889,14982,k|0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Ib(us(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Ib(a);x[k+20>>2]=0}Ib(k);break d}i=V(0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[23420]=0;X(889,14982,0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}$()}hb=j+96|0;return i|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Ub()}p()}function z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-96|0;hb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[Kk(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Tk(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;Qd(f);e=x[d+72>>2];Qd(d+56|0);e=Jk(e,x[d+60>>2],b);Qd(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=qc(d+88|0,21473);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Lc(e,a,d)){a=ba(8)|0;x[23420]=0;c=Q(54,d+72|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}e=0;f=0;if(!c){break e}c=ba(8)|0;a=x[b+4>>2];b=x[b>>2];x[23420]=0;e=Ch(d+56|0,b,a);a=x[23420];x[23420]=0;f:{g:{h:{if((a|0)!=1){x[23420]=0;U(917,d+72|0,17488,e|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}a=0;b=rc(c,d+72|0);x[23420]=0;U(107,b|0,61592,906);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=P()|0;xb(d+72|0);break g}b=P()|0;break f}b=P()|0;a=1}xb(e);if(!a){break c}}ca(c|0);break c}if(x[e+4>>2]!=1){a=ba(8)|0;x[23420]=0;c=Q(54,d+72|0,11442)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}c=x[b+4>>2];b=x[b>>2];e=qc(d+48|0,21473);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Lc(b,c,d+24|0)){a=ba(8)|0;x[23420]=0;c=Q(54,d+72|0,10374)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}b=P()|0;xb(c);break c}b=P()|0;ca(a|0);break c}e=qc(d+40|0,10833);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Lc(b,c,d+16|0)){a=x[a+8>>2];e=a;f=a>>31;break e}e=qc(d+32|0,8529);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Lc(b,c,d+8|0)){break e}e=Nj(y[x[a+32>>2]+140|0]);f=0}hb=d+96|0;lb=f;return e|0}b=P()|0;ca(a|0)}S(b|0)}p()}function Q_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=hb-16|0;hb=j;k=Lu(g);o=uw(g);Ng(j,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[23420]=0;g=Q(19,k|0,g<<24>>24)|0;i=x[23420];x[23420]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[23420]=0;g=Q(19,k|0,48)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[23420]=0;g=Q(19,k|0,g|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Ad();if(!HG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Ad();if(!Mj(h)){break d}g=g+1|0;continue}}e:{if(De(j)){h=x[f>>2];x[23420]=0;X(1084,k|0,i|0,g|0,h|0);h=x[23420];x[23420]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}Fl(i,g);x[23420]=0;r=T(1082,o|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Fl((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[Nc(j,m)|0]<=0){break f}if(v[Nc(j,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Eb(j)-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[23420]=0;q=Q(19,k|0,q|0)|0;n=x[23420];x[23420]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[23420]=0;i=T(1085,o|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[23420]=0;X(1084,k|0,g|0,c|0,i|0);i=x[23420];x[23420]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;xb(j);hb=j+16|0;return}x[23420]=0;i=Q(19,k|0,i<<24>>24)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=P()|0;xb(j);S(a|0);p()}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=hb-1104|0;hb=d;x[d+1100>>2]=c;i=qB(d+40|0,b);r=kq(i);e=Qb(a);x[23420]=0;a=T(190,b|0)|0;c=x[23420];x[23420]=0;a:{if((c|0)!=1){x[d+8>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Hb(d+8|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Hb(d+1100|0,d+24|0)>>2];x[23420]=0;R(308,e|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;h=T(320,d+24|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;f=Q(321,d+8|0,8192)|0;a=x[23420];x[23420]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=Cb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[23420]=0;o=Q(152,i|0,s|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Wc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=Cb(a,c);l=l-1|0;q=l&65535;t=Kb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[Cb(a,c)>>1];if(c>>>0<8192){continue}break}a=gc(d,Db(x[e+4>>2]));c=_g(Db(x[f>>2]),q);l=Db(x[f+4>>2]);a=x[a>>2];x[23420]=0;X(309,e|0,a|0,c|0,l|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[23420]=0;R(322,e|0,Kb(a,q)|0);a=x[23420];x[23420]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Wc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[Kb(x[f>>2],q)|0];c=Cb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=kq(i);x[23420]=0;Q(143,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}dc(f);tc(h);zb(i);hb=d+1104|0;return}c=P()|0;dc(f);break b}c=P()|0}tc(h);break a}c=P()|0;break a}c=P()|0;break a}c=P()|0}dc(e);zb(i);S(c|0);p()}function uO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=hb-176|0;hb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=dd(i,e+l|0);d=dd(i,e);o=C[h>>3];p=C[h+8>>3];dj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;ay(dd(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=dd(d,j<<1);d=dd(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];ni(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=dd(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=dd(f,t);ni(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=dd(f,u);ni(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=dd(f,v);ni(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Ok(k,f,m,n);q=c- -64|0;dj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Ok(c+48|0,g,m,n);f=c+16|0;Wk(f,-0,-1);dj(c,g,m,n);ni(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Ok(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;dj(f,k,C[c+48>>3],C[c+56>>3]);d=dd(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Ok(f,q,C[c+32>>3],C[c+40>>3]);d=dd(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;dj(f,q,C[c+32>>3],C[c+40>>3]);d=dd(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}hb=c+176|0}function N3(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=hb-16|0;hb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=hb-16|0;hb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ba(8)|0;x[23420]=0;c=Q(54,c|0,5084)|0;d=x[23420];x[23420]=0;if((d|0)==1){break k}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break i}d=P()|0;xb(c);break j}hb=c+16|0;a=x[(a<<2)+61336>>2];break h}d=P()|0;ca(a|0)}S(d|0)}p()}break b;case 3:x[d>>2]=0;m=x[a+24640>>2];c=hb-80|0;hb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[Le(n,c)>>2];l:{if((a|0)==x[Kp(n)+32>>2]){a=-1;if(x[Kp(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d>>2]=a;hb=c+80|0;a=x[d>>2];break b;default:break d}}c=ba(8)|0;x[23420]=0;d=Q(54,d|0,10277)|0;a=x[23420];x[23420]=0;m:{if((a|0)!=1){a=rc(c,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break m}a=P()|0;ca(c|0)}S(a|0);p()}a=-2147483648}hb=d+16|0;return a|0}p()}function x5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-96|0;hb=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[Kk(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Tk(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;Qd(f);g=x[e+72>>2];Qd(e+56|0);h=Jk(g,x[e+60>>2],c);Qd(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=qc(e+88|0,21473);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Lc(g,f,e)){a=ba(8)|0;x[23420]=0;b=Q(54,e+72|0,10374)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}if(d){a=ba(8)|0;b=x[c+4>>2];c=x[c>>2];x[23420]=0;b=Ch(e+56|0,c,b);c=x[23420];x[23420]=0;f:{g:{h:{if((c|0)!=1){x[23420]=0;U(917,e+72|0,17488,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break h}d=0;c=rc(a,e+72|0);x[23420]=0;U(107,c|0,61592,906);c=x[23420];x[23420]=0;if((c|0)!=1){break b}c=P()|0;xb(e+72|0);break g}c=P()|0;break f}c=P()|0;d=1}xb(b);if(!d){break c}}ca(a|0);break c}Jb(a);break e}c=qc(e+48|0,21473);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Lc(g,f,e+24|0)){a=ba(8)|0;x[23420]=0;b=Q(54,e+72|0,10374)|0;c=x[23420];x[23420]=0;if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}c=P()|0;ca(a|0);break c}c=qc(e+40|0,12211);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Lc(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Vb(a,5562);break e;case 1:Vb(a,11143);break e;case 2:Vb(a,9108);break e;default:break i}}Jb(a);break e}c=qc(e+32|0,11380);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Lc(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Vb(a,15408);break e;case 1:Vb(a,15413);break e;case 2:Vb(a,12485);break e;case 3:Vb(a,9172);break e;default:break j}}Jb(a);break e}Jb(a)}hb=e+96|0;return}c=P()|0;ca(a|0)}S(c|0)}p()}function jfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb-48|0;hb=c;a:{b:{c:{d:{e:{f:{if(wd(x[a+24>>2])){break f}h=a+4|0;j=Eb(h);e=hb-32|0;hb=e;d=e+24|0;b=d;x[b>>2]=-1;x[b+4>>2]=-1;x[23420]=0;g=WE(38);f=x[23420];x[23420]=0;b=lb;if((f|0)==1){V(0)|0;Ub();p()}x[e+8>>2]=g;x[e+12>>2]=b;g=hb-16|0;hb=g;i=e+8|0;b=i;l=g,m=Wia(x[b>>2],x[b+4>>2],1e3,0),x[l>>2]=m;x[g+4>>2]=lb;f=kt(g+8|0,g);b=x[f+4>>2];hb=g+16|0;x[e+16>>2]=x[f>>2];x[e+20>>2]=b;b=e+16|0;l=e,m=Uz(x[b>>2],x[b+4>>2]),x[l+16>>2]=m;x[e+20>>2]=lb;k=nQ(d,b,Fb(b));x[23420]=0;d=WE(39);g=x[23420];x[23420]=0;f=lb;if((g|0)==1){V(0)|0;Ub();p()}g=a+24|0;x[e+8>>2]=d;x[e+12>>2]=f;d=hb-16|0;hb=d;a=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=a;f=kt(d+8|0,d);a=x[f+4>>2];hb=d+16|0;x[e+16>>2]=x[f>>2];x[e+20>>2]=a;l=e,m=Uz(x[b>>2],x[b+4>>2]),x[l+16>>2]=m;x[e+20>>2]=lb;a=nQ(k,b,Fb(b));b=x[a>>2];a=x[a+4>>2];hb=e+32|0;if(j){d=Qb(c+32|0);x[23420]=0;x[c+16>>2]=a;R(32,d|0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;x[c+16>>2]=b;R(32,d|0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}a=0;g:{while(1){if(Eb(h)>>>0<=a>>>0){b=Db(x[d>>2]);a=Db(x[d+4>>2]);x[23420]=0;f=W(33,c+16|0,b|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break g}a=P()|0;break b}b=y[Nc(h,a)|0];x[23420]=0;x[c+16>>2]=b;R(32,d|0,c+16|0);b=x[23420];x[23420]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;break b}x[23420]=0;b=T(34,f|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){x[c+8>>2]=b;a=c+8|0;Vz(g,a);oj(a);km(f);tc(d);break f}a=P()|0;km(f);break b}lb=b;x[c+16>>2]=a;x[c+20>>2]=lb;b=Qb(c+32|0);x[23420]=0;U(37,b|0,c+16|0,c+24|0);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;tc(b);S(a|0);p()}x[23420]=0;f=T(34,b|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break e}x[c+8>>2]=f;a=c+8|0;Vz(g,a);oj(a);km(b)}hb=c+48|0;return}a=P()|0;km(b);break a}a=P()|0;break b}a=P()|0}tc(d)}S(a|0);p()}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;g=hb-48|0;hb=g;p=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;x[i+4>>2]=x[e+44>>2];x[i+8>>2]=x[e+48>>2];f=f+1|0;continue}break}i=x[a+40>>2];k=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;v=b>>31;b=x[a+64>>2];y=b;z=b>>31;b=x[a+60>>2];A=b;B=b>>31;C=x[a+8>>2];E=x[a+12>>2];while(1){if(d){f=x[g+16>>2];l=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=w[b+14>>1];h=w[b+12>>1];m=w[b+10>>1];n=w[b+8>>1];o=w[b+6>>1];F=w[b+4>>1];G=w[b+2>>1];H=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((((D(w[b+8>>1],m)+D(w[b+4>>1],n)|0)+D(h,w[b+12>>1])|0)+D(j,w[b+16>>1])|0)/2|0)+((((D(w[b-8>>1],G)+D(w[b-12>>1],H)|0)+D(w[b-4>>1],F)|0)+D(w[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=x[l>>2];b=(g+24|0)+(f<<3)|0;j=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;m=e<<8;e=m;e=Wia(A,B,e,e>>31);n=lb;o=b;b=Xb(h,-16777216,16776704);h=Wia(y,z,b,b>>31);e=h+e|0;b=lb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(j,-16777216,16776704);j=Wia(u,v,e,e>>31);e=h+j|0;b=lb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Qc(e,b,24);x[o+4>>2]=b-(m&t);x[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],i>>12);Rb(g+16|0,C,E);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;g=hb-48|0;hb=g;p=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;x[i+4>>2]=x[e+44>>2];x[i+8>>2]=x[e+48>>2];f=f+1|0;continue}break}i=x[a+40>>2];k=x[a+36>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];b=x[a+68>>2];u=b;y=b>>31;b=x[a+64>>2];z=b;A=b>>31;b=x[a+60>>2];B=b;C=b>>31;E=x[a+8>>2];F=x[a+12>>2];while(1){if(d){f=x[g+16>>2];l=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=w[b+14>>1];h=w[b+12>>1];m=w[b+10>>1];n=w[b+8>>1];o=w[b+6>>1];G=w[b+4>>1];H=w[b+2>>1];I=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;x[(g+8|0)+(e<<2)>>2]=(((((D(v[b+4|0],m)+D(v[b+2|0],n)|0)+D(h,v[b+6|0])|0)+D(j,v[b+8|0])<<8)/2|0)+((((D(v[b-4|0],H)+D(v[b-6|0],I)|0)+D(v[b-2|0],G)|0)+D(v[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=x[l>>2];b=(g+24|0)+(f<<3)|0;j=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;m=e<<8;e=m;e=Wia(B,C,e,e>>31);n=lb;o=b;b=Xb(h,-16777216,16776704);h=Wia(z,A,b,b>>31);e=h+e|0;b=lb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(j,-16777216,16776704);j=Wia(u,y,e,e>>31);e=h+j|0;b=lb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Qc(e,b,24);x[o+4>>2]=b-(m&t);x[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],i>>12);Rb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}
function E5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;f=1;a:{if(De(c)){break a}e=y[vJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+80|0;Fv(e,c,0,Eb(c)-1|0);Ac(c,e);xb(e)}e=d+80|0;Qd(e);g=x[d+80>>2];Qd(d+72|0);g=uJ(g,x[d+76>>2],c);Qd(e);b:{c:{d:{e:{f:{if((g|0)==x[d+84>>2]){if(ne(c,21473)){a=ba(8)|0;x[23420]=0;b=Q(54,d+80|0,10374)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}if(!f){break f}a=ba(8)|0;x[23420]=0;U(908,d+80|0,17488,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,d+80|0);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}c=P()|0;xb(d+80|0);break c}c=P()|0;ca(a|0);break c}e=Jb(d+80|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ue(d- -64|0,c);x[23420]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=W(909,b|0,d+8|0,f|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){x[23420]=0;v[d+72|0]=b;R(910,a|0,d+72|0);a=x[23420];x[23420]=0;if((a|0)!=1){break g}}break i;case 1:ue(d+56|0,c);x[23420]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=ZE(b,d+16|0,f);c=lb;f=x[23420];x[23420]=0;if((f|0)!=1){x[23420]=0;x[d+72>>2]=b;x[d+76>>2]=c;R(912,a|0,d+72|0);a=x[23420];x[23420]=0;if((a|0)!=1){break g}}break i;case 2:ue(d+48|0,c);x[23420]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;h=+qa(913,b|0,d+24|0,f|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;C[d+72>>3]=h;R(914,a|0,d+72|0);a=x[23420];x[23420]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ue(d+40|0,c);x[23420]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;X(915,a|0,b|0,d+32|0,f|0);a=x[23420];x[23420]=0;if((a|0)!=1){break g}}c=P()|0;xb(e);break c}Rc(a,e)}xb(e);break e}Jb(a)}hb=d+96|0;return}c=P()|0;ca(a|0)}S(c|0)}p()}function oh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Jb(a);d=Eb(c);x[23420]=0;R(47,a|0,d|0);d=x[23420];x[23420]=0;d:{if((d|0)!=1){e:{while(1){if(Eb(c)>>>0>b>>>0){d=v[Xf(c,b)|0];x[23420]=0;R(48,a|0,((d|0)<0?65533:d&255)|0);d=x[23420];x[23420]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Jb(a);d=Eb(c);x[23420]=0;R(47,a|0,d|0);d=x[23420];x[23420]=0;f:{if((d|0)!=1){while(1){if(Eb(c)>>>0<=b>>>0){break f}d=y[Xf(c,b)|0];x[23420]=0;R(48,a|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:Yl(a,c,49504);return;case 5:Yl(a,c,50528);return;case 4:Yl(a,c,51552);return;case 6:Yl(a,c,52576);return;case 7:Yl(a,c,53600);return;case 8:Yl(a,c,54624);return;case 9:Cy(a,c,55648);return;case 10:Cy(a,c,49504);return;case 11:Cy(a,c,53600);return;default:a=ba(8)|0;x[23420]=0;b=Q(44,a|0,10965)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}b=P()|0;ca(a|0);S(b|0);p();case 0:break c}}e=hb-16|0;hb=e;f=Jb(a);g=e,h=Ns(c),x[g+8>>2]=h;g=e,h=Ls(c),x[g>>2]=h;a=0;g:{h:{while(1){i:{if(!Lh(e+8|0,e)){if(!a){break i}x[23420]=0;R(48,f|0,65533);a=x[23420];x[23420]=0;if((a|0)!=1){break i}break h}b=y[x[e+8>>2]];j:{k:{if(!a){if(b<<24>>24>=0){a=0;x[23420]=0;R(48,f|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;x[23420]=0;R(48,f|0,65533);c=x[23420];x[23420]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;x[23420]=0;R(48,f|0,d|0);b=x[23420];x[23420]=0;d=0;if((b|0)==1){break h}}Be(e+8|0);continue}break}hb=e+16|0;break g}a=P()|0;Jc(f);S(a|0);p()}return}ha(b|0,91912,24);p()}b=P()|0;Jc(a);S(b|0);p()}function pR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Wb(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:v[a+5|0]=d;v[a+3|0]=c;Of(a);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=xi(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}v[a+5|0]=d;v[a+3|0]=c;VA(a,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}hb=f+16|0;return g}function Nn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;x[b+88>>2]=x[b+88>>2]|524288;a:{b:{if(!(x[a+480208>>2]&8)){Ab(e+8|0,a+1074312|0,15);if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break b}}if(x[a+480180>>2]!=268435456){break a}}c=c?c:y[b+811|0];v[b+812|0]=c;v[b+811|0]=c}if(c){w[b+768>>1]=c}d=x[b+656>>2];c:{if(nj(d)){c=z[b+768>>1];if(!c){break c}f=x[b+856>>2];g=x[a+1074392>>2];i=0-c|0;j=c;c=x[b+708>>2];h=(+(g>>>0)+1)*+(((c|0)<0?i:j)|0)/+A[a+1074416>>2];d:{if(F(h)<2147483648){a=~~h;break d}a=-2147483648}x[b+856>>2]=a;if(y[b+90|0]&16){a=D(x[x[d+44>>2]+36>>2]+1|0,a);x[b+856>>2]=a}a=a-(g?f:0)|0;d=a>>31;f=c>>31;if((f^c)-f>>>0<=(a^d)-d>>>0){if(!c){break c}x[b+708>>2]=0;x[b+852>>2]=c+x[b+852>>2];v[b+851|0]=y[b+851|0]|64;break c}x[b+708>>2]=c-a;x[b+852>>2]=a+x[b+852>>2];v[b+851|0]=y[b+851|0]|64;break c}c=1;e:{if(!(v[b+851|0]&1)){break e}d=x[a+480180>>2];if(d&524352){break e}if(x[a+1074416>>2]==1){Ab(e+8|0,a+1074312|0,6);if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break e}d=x[a+480180>>2]}c=0;if((d|0)!=8){break e}c=(y[a+480208|0]&2)>>>1|0}f:{if(!x[b+700>>2]|!x[b+708>>2]){break f}f=x[a+480180>>2];d=z[b+768>>1];g=(f|0)==268435456&d>>>0>239;if(!((g?y[b+851|0]:c)&1)){break f}c=b+700|0;d=D((f|0)==64?2:4,g?d-240|0:d);d=gj(a)?d:0-d|0;f=x[b+700>>2];g=x[b+708>>2];if(!(!(y[b+851|0]&16)&(f|0)>=(g|0))){Qj(a,b,c,d,1);d=x[b+708>>2];if((d|0)>=x[b+700>>2]){break f}x[c>>2]=d;break f}if((f|0)<=(g|0)){break f}Qj(a,b,c,0-d|0,1);f=x[b+700>>2];d=x[b+708>>2];g:{if((f|0)<(d|0)){x[c>>2]=d;break g}if((d|0)!=(f|0)){break f}}Ab(e+8|0,a+1074312|0,112);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}v[b+851|0]=y[b+851|0]|16}if(x[b+700>>2]!=x[b+708>>2]){break c}Ab(e+8|0,a+1074312|0,25);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])&x[a+480180>>2]!=1){break c}x[b+708>>2]=0}hb=e+16|0}function Qj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{if(!d){break a}j=x[c>>2];if(!j){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+j|0;break d}f=((D(d,36318)|0)/1024|0)+j|0;break d}f:{g:{h:{if(y[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;x[i+12>>2]=(f^d)-f;xc(i+12|0,1020);f=x[i+12>>2];h=c;i:{if((d|0)>0){if(f>>>0<=15){g=hb-16|0;hb=g;Ab(g+8|0,a+1074312|0,7);f=x[(f<<2)+(Bb(x[x[g+8>>2]>>2],x[g+12>>2])?37008:37072)>>2];break i}g=hb-16|0;hb=g;Ab(g+8|0,a+1074312|0,7);f=x[(f&-4)+(Bb(x[x[g+8>>2]>>2],x[g+12>>2])?37136:38160)>>2];break i}if(f>>>0<=15){g=hb-16|0;hb=g;Ab(g+8|0,a+1074312|0,7);f=x[(f<<2)+(Bb(x[x[g+8>>2]>>2],x[g+12>>2])?37072:37008)>>2];break i}g=hb-16|0;hb=g;Ab(g+8|0,a+1074312|0,7);f=x[(f&-4)+(Bb(x[x[g+8>>2]>>2],x[g+12>>2])?38160:37136)>>2]}hb=g+16|0;g=h;h=Wia(f,f>>31,j,j>>31)+32768|0;f=lb;f=Hc(Xia(h,h>>>0<32768?f+1|0:f,65536,0),lb);x[g>>2]=f;if((f|0)!=(j|0)){break c}Ab(i,a+1074312|0,7);h=x[c>>2];if(!(Bb(x[x[i>>2]>>2],x[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((h|0)==2147483647){break c}break f}d=-1;if((h|0)>=2){break f}f=h;break c}Ab(i,a+1074312|0,7);if(Bb(x[x[i>>2]>>2],x[i+4>>2])){break g}j=x[c>>2]}f=j-d|0;break d}f=x[c>>2];if((d|0)<0){h=Wia(f,0,14317456,0);g=lb;f=Wia(f,0,0-d|0,0)+14317456|0;d=lb;f=YM(Zia(h,g,f,f>>>0<14317456?d+1|0:d),lb);break d}d=Wia(f,f>>31,d,0);h=lb;if((h|0)>=0&d>>>0>=14317456|(h|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=YM(Zia(Wia(f,0,14317456,0),lb,14317456-d|0,0-(h+(d>>>0>14317456)|0)|0),lb);x[c>>2]=d;if((d|0)>0){break a}break b}f=d+h|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}hb=i+16|0}function Zf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=j;i=y[a+79|0]?z[x[a>>2]+3836>>1]:i;c=z[a+20>>1];l=z[a+22>>1];m=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=z[a+46>>1];f=c+(b?g&b?0:f:f)|0;w[a+20>>1]=f;b=2;h=z[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];h=z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=z[a+58>>1];f=c+(f?g&f?0:h:h)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];k=z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=z[a+34>>1];f=c+(f?g&f?0:k:k)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+28240>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+28240>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+28240>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+28240>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+28240>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+28240>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+i&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+27728>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function k5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=hb+-64|0;hb=k;a:{b:{c:{j=Np(1,32);d:{e:{if(!j){a=Pl(ba(4)|0);x[23420]=0;U(107,a|0,91780,25);a=x[23420];x[23420]=0;if((a|0)!=1){break a}i=V(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:883;x[j>>2]=f;c=gg(k+48|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[23420]=0;e=Q(54,k+32|0,e|0)|0;m=x[23420];x[23420]=0;j:{if((m|0)!=1){x[23420]=0;m=Q(894,c|0,e|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break j}x[23420]=0;R(257,m|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break j}break i}i=V(0)|0;break f}i=V(0)|0;xb(e);break f}x[23420]=0;e=Q(54,k+16|0,e|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break g}vs(c,e)}xb(e);i=i+8|0;continue}}x[23420]=0;e=T(767,96)|0;i=x[23420];x[23420]=0;k:{l:{m:{if((i|0)!=1){x[23420]=0;d=Q(895,f|0,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break m}x[k>>2]=d;d=x[Tf(k+8|0,k)>>2];x[23420]=0;a=ja(926,e|0,a|0,b|0,d|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break k}i=V(0)|0;se(k);break l}i=V(0)|0;break f}i=V(0)|0}Ib(e);break f}x[j+28>>2]=a;se(k);x[j+24>>2]=a+8;Uk(c);break d}i=V(0)|0}Uk(c);_(i|0)|0;x[23420]=0;X(889,4934,j|0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){a=x[j+28>>2];if(a){mb[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Ib(a);x[j+20>>2]=0}Ib(j);j=0;break d}i=V(0)|0;break e}i=V(0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;x[23420]=0;X(889,4934,0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return j|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Ub()}p()}function ZZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=hb-1072|0;hb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+960|0;x[a+956>>2]=j;j=xw(j,100,11028,a+16|0);x[a+48>>2]=1073;k=a+48|0;o=le(a+536|0,0,k);x[a+48>>2]=1073;k=le(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Ad();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Si(a+956|0,j,11028,a);if((j|0)!=-1){f=x[a+956>>2];Me(o,f);Me(k,Ld(j<<2));h=x[k>>2];if(!Uj(h)){break d}}x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break a}j=P()|0;break c}g=a+520|0;ad(g,d);x[23420]=0;r=T(1086,g|0)|0;g=x[23420];x[23420]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23420]=0;X(1098,r|0,f|0,f+j|0,h|0);g=x[23420];x[23420]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Jb(a+488|0);f=Jb(a+472|0);g=Jb(a+456|0);x[23420]=0;la(1125,c|0,q|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=x[23420];x[23420]=0;if((c|0)==1){break i}x[a+36>>2]=1073;c=le(a+40|0,0,a+36|0);m=a+48|0;n=x[a+452>>2];k:{if((n|0)<(j|0)){l=((Eb(g)+(j-n<<1)|0)+Eb(f)|0)+1|0;break k}l=(Eb(g)+Eb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Me(c,Ld(l<<2));m=x[c>>2];if(m){break h}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[23420]=0;oa(1126,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+512|0,x[a+508>>2],x[a+504>>2],i|0,f|0,g|0,n|0);h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;b=ka(1107,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break b}}}j=P()|0;Pc(c)}Jc(g);Jc(f);xb(i)}Zb(a+520|0)}Pc(k);Pc(o);S(j|0);p()}Pc(c);Jc(g);Jc(f);xb(i);Zb(a+520|0);Pc(k);Pc(o);hb=a+1072|0;return b|0}p()}function PQ(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;g=x[b>>2];i=x[b+4>>2];a:{if((i|0)==(f|0)){b=fc(l+8|0,e,f);j=hb-16|0;hb=j;e=_k(c,d,g,f);x[j+12>>2]=e;b:{if((e|0)<=0){e=x[b>>2];break b}c:{if(!f){f=x[b>>2];break c}h=32-f|0;x[j+8>>2]=h;c=x[td(j+8|0,j+12|0)>>2];x[j+12>>2]=e-c;d=x[b>>2];e=-1<<f&-1>>>h-c;x[d>>2]=x[d>>2]&(e^-1)|e&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;x[b>>2]=f;g=g+4|0;e=x[j+12>>2]}d=(e|0)/32|0;c=d<<2;Ji(f,g,c);d=e-(d<<5)|0;x[j+12>>2]=d;e=c+x[b>>2]|0;x[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;x[e>>2]=x[e>>2]&(d^-1)|d&x[c+g>>2];x[b+4>>2]=x[j+12>>2]}fc(a,e,x[b+4>>2]);hb=j+16|0;break a}j=a;h=fc(l,e,f);f=hb-16|0;hb=f;e=_k(c,d,g,i);x[f+12>>2]=e;d:{if((e|0)<=0){a=x[h+4>>2];break d}e:{if(!i){a=x[h+4>>2];break e}k=32-i|0;x[f+8>>2]=k;c=f+8|0;b=x[td(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[h+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[h>>2];n=x[d>>2];c=x[Hb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;x[h+4>>2]=a;d=d+(k>>>3&536870908)|0;x[h>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+i;x[h+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=x[h>>2];e=x[g>>2];x[b>>2]=i&x[b>>2]|e<<a;x[h>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=x[g>>2];x[f+8>>2]=c;g=x[h>>2];b=x[g>>2];k=b;b=x[td(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;x[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;x[h+4>>2]=a;c=g+(c>>>3&536870908)|0;x[h>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|e>>>b;a=x[f+12>>2];x[h+4>>2]=a}fc(j,x[h>>2],a);hb=f+16|0}hb=l+16|0}function XL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){h=a+480180|0;e=x[h>>2];i=1;c:{d:{e:{f=x[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Ab(g+8|0,a+1074312|0,21);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}e=D(b,872)+a|0;f=e+1075811|0;v[f|0]=y[f|0]+(y[e+1075815|0]<<2)}f=D(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=my(a,y[k|0],y[l|0]);f:{if(nj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[f+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=f+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}f=x[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Ab(g+8|0,k,21);f=x[a+480208>>2];g:{if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Ab(g+8|0,k,80);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;Qj(a,j,c,d,0);e=x[j+656>>2];c=Ts(a,x[j+88>>2],e);if(!c){break f}mb[x[x[c>>2]+88>>2]](c,d,(e?v[e+33|0]:2)<<24>>24,b)}if(!i){break a}Ab(g+8|0,a+1074312|0,21);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=Ts(a,i,x[j+656>>2]);if(!a){break a}mb[x[x[a>>2]+88>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}hb=g+16|0}function Cp(a,b,c,d){var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;x[e+12>>2]=w[b+780>>1]+y[b+837|0];x[e+8>>2]=w[b+782>>1]+(y[b+838|0]&127);ge(e+12|0,0,127);ge(e+8|0,0,127);k=a+1074312|0;Ab(e,k,1);j=x[e+12>>2];a:{if(Bb(x[x[e>>2]>>2],x[e+4>>2])){i=x[e+8>>2];break a}w[b+780>>1]=0;v[b+837|0]=j;i=x[e+8>>2];w[b+782>>1]=0;v[b+838|0]=i}Ab(e,k,36);l=D(j,d+256|0);m=(l|0)/256|0;b:{if(!(!Bb(x[x[e>>2]>>2],x[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Uc(y[b+788|0])){break b}if(at(y[b+790|0],y[b+791|0])|z[b+786>>1]|!(y[b+851|0]&2)){break b}x[b+88>>2]=x[b+88>>2]&-32769;break b}x[b+88>>2]=x[b+88>>2]|32768;f=me(E(10),E(E(0-i|0)*E(.00937500037252903)));i=hb-16|0;hb=i;h=E(D(j,d+256|0)>>>0);c:{if(x[a+480180>>2]!=33554432){g=E(110);h=E(E(h/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break c}g=E(125);h=E(E(h*E(6))/E(65024))}n=i,o=Mh(E(me(E(2),h)*g)),x[n+12>>2]=o;ge(i+12|0,120,2e4);d=x[i+12>>2];j=x[a+24620>>2];hb=i+16|0;Ab(e,k,36);h=E(E(((j|0)<d<<1?j>>>1|0:d)>>>0)*E(6.2831854820251465));d:{if(!(!Bb(x[x[e>>2]>>2],x[e+4>>2])|x[a+480208>>2]&32768)){g=E(E(A[a+24620>>2])/h);h=E(E(E(f*g)+f)+E(-1));f=E(g*g);break d}g=E(f+f);f=E(h/E(A[a+24620>>2]));B[e>>2]=E(E(1)-g)*f;IN(e,E(2));h=E(E(g-B[e>>2])/f);f=E(E(1)/E(f*f))}g=E(f+E(h+E(1)));h=E(E(f+E(f+h))/g);f=E(E(-f)/g);g=E(E(1)/g);e:{if(y[b+845|0]==1){n=b,o=Mh(E(E(E(1)-g)*E(16777216))),x[n+60>>2]=o;n=b,o=Mh(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Mh(E(f*E(16777216))),x[n+68>>2]=o;a=-1;break e}d=Mh(E(g*E(16777216)));x[b+60>>2]=d;n=b,o=Mh(E(h*E(16777216))),x[n+64>>2]=o;n=b,o=Mh(E(f*E(16777216))),x[n+68>>2]=o;a=0;if(d){break e}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break b}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}hb=e+16|0;return m}function zY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=hb-16|0;hb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=hb-16|0;hb=s;u=ai(s+8|0,x[a+8>>2]);m=j-c|0;k=0;o=0;n=hb-1040|0;hb=n;i=x[e>>2];x[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=uG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=x[n+12>>2];break g}t=(n+16|0)!=(p|0)?q:0;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=x[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Ir(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){x[e>>2]=o}hb=n+1040|0;$h(u);hb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=mF(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!mF(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}hb=r+16|0;return a|0}f=x[h>>2];continue}}function b_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=hb-464|0;hb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+352|0;x[a+348>>2]=j;j=xw(j,100,11028,a+16|0);x[a+48>>2]=1073;k=a+48|0;o=le(a+232|0,0,k);x[a+48>>2]=1073;k=le(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Ad();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=Si(a+348|0,j,11028,a);if((j|0)!=-1){f=x[a+348>>2];Me(o,f);Me(k,Ld(j));h=x[k>>2];if(!Uj(h)){break d}}x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break a}j=P()|0;break c}g=a+216|0;ad(g,d);x[23420]=0;r=T(18,g|0)|0;g=x[23420];x[23420]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[23420]=0;X(1084,r|0,f|0,f+j|0,h|0);g=x[23420];x[23420]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Jb(a+192|0);f=Jb(a+176|0);g=Jb(a+160|0);x[23420]=0;la(1123,c|0,q|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=x[23420];x[23420]=0;if((c|0)==1){break i}x[a+36>>2]=1073;c=le(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Eb(g)+(j-n<<1)|0)+Eb(f)|0)+1|0;break k}l=(Eb(g)+Eb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Me(c,Ld(l));m=x[c>>2];if(m){break h}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)!=1){break a}break g}j=P()|0;break e}j=P()|0;break f}l=x[d+4>>2];x[23420]=0;oa(1124,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+208|0,v[a+207|0],v[a+206|0],i|0,f|0,g|0,n|0);h=x[23420];x[23420]=0;if((h|0)!=1){x[23420]=0;b=ka(14,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break b}}}j=P()|0;Pc(c)}xb(g);xb(f);xb(i)}Zb(a+216|0)}Pc(k);Pc(o);S(j|0);p()}Pc(c);xb(g);xb(f);xb(i);Zb(a+216|0);Pc(k);Pc(o);hb=a+464|0;return b|0}p()}function RJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=hb+-64|0;hb=k;a:{b:{c:{d:{e:{f:{j=Np(1,28);if(!j){a=Pl(ba(4)|0);x[23420]=0;U(107,a|0,91780,25);a=x[23420];x[23420]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:883;x[j>>2]=f;c=gg(k+48|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[23420]=0;e=Q(54,k+32|0,e|0)|0;m=x[23420];x[23420]=0;k:{if((m|0)!=1){x[23420]=0;m=Q(894,c|0,e|0)|0;n=x[23420];x[23420]=0;if((n|0)==1){break k}x[23420]=0;R(257,m|0,l|0);l=x[23420];x[23420]=0;if((l|0)==1){break k}break j}i=V(0)|0;break g}i=V(0)|0;xb(e);break g}x[23420]=0;e=Q(54,k+16|0,e|0)|0;l=x[23420];x[23420]=0;if((l|0)==1){break h}vs(c,e)}xb(e);i=i+8|0;continue}}x[23420]=0;e=T(767,80)|0;i=x[23420];x[23420]=0;l:{m:{n:{if((i|0)!=1){x[23420]=0;d=Q(895,f|0,d|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break n}x[k>>2]=d;d=x[Tf(k+8|0,k)>>2];x[23420]=0;a=ja(900,e|0,a|0,b|0,d|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break l}i=V(0)|0;se(k);break m}i=V(0)|0;break g}i=V(0)|0}Ib(e);break g}x[j+24>>2]=a;se(k);Uk(c);i=j;break d}i=V(0)|0}Uk(c);_(i|0)|0;x[23420]=0;X(889,14925,j|0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Ib(us(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Ib(a);x[j+20>>2]=0}Ib(j);break d}i=V(0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){break e}break b}i=V(0)|0}_(i|0)|0;i=0;x[23420]=0;X(889,14925,0,g|0,h|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}$()}hb=k- -64|0;return i|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}V(0)|0;Ub()}p()}function ni(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!ri(p)){break a}if(!ri(m)){break a}h=bf(b);f=bf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=ri(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=ri(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=bf(d);f=bf(e);b:{if(h|f){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=ri(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=ri(c),w?u:v);break b}if(k){break b}c:{if(bf(s)){break c}if(bf(t)){break c}if(bf(r)){break c}if(!bf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=ri(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=ri(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=ri(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=ri(e),w?u:v)}m=(b*e+d*c)*O;p=(b*d-e*c)*O}Wk(a,p,m)}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;g=hb-48|0;hb=g;o=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;x[j+4>>2]=x[e+44>>2];x[j+8>>2]=x[e+48>>2];f=f+1|0;continue}break}j=x[a+24>>2];p=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){f=x[g+16>>2];k=((((x[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=w[b+14>>1];h=w[b+12>>1];l=w[b+10>>1];m=w[b+8>>1];n=w[b+6>>1];C=w[b+4>>1];E=w[b+2>>1];F=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((((D(w[b+8>>1],l)+D(w[b+4>>1],m)|0)+D(h,w[b+12>>1])|0)+D(i,w[b+16>>1])|0)/2|0)+((((D(w[b-8>>1],E)+D(w[b-12>>1],F)|0)+D(w[b-4>>1],C)|0)+D(w[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=x[k>>2];b=(g+24|0)+(f<<3)|0;i=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;l=e<<8;e=l;e=Wia(y,z,e,e>>31);m=lb;n=b;b=Xb(h,-16777216,16776704);h=Wia(u,v,b,b>>31);e=h+e|0;b=lb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(i,-16777216,16776704);i=Wia(s,t,e,e>>31);e=h+i|0;b=lb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Qc(e,b,24);x[n+4>>2]=b-(l&r);x[k>>2]=(b|0)/256;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],p);x[c+4>>2]=x[c+4>>2]+D(j,x[g+12>>2]);Rb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function $V(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=hb+-64|0;hb=e;zc(b);Lo(a);a:{if(!Yh(b,e+56|0)){break a}if(!kD(e+56|0)){break a}if(!c){l=1;break a}if(!Nb(x[b>>2],x[b+8>>2],4)){break a}Av(a);q=e,r=zv(),x[q+32>>2]=r;c=e+32|0;yv(Cj(x[a+4>>2])+32|0,c);er(c);k=x[Cj(x[a+4>>2])+32>>2];c=Hg(x[b>>2]);if(c&1){break a}d=c-4|0;$c(b,d);h=hb-16|0;hb=h;c=h+8|0;lv(c,b);f=y[Kb(c,0)|0];i=y[Kb(c,1)|0];c=y[Kb(c,2)|0];hb=h+16|0;h=c|(i<<8|f<<16);if(!h){break a}x[23420]=0;R(163,k|0,h|0);c=x[23420];x[23420]=0;l=1;if((c|0)==1){a=V(91780)|0;if((ib|0)==(da(91780)|0)){_(a|0)|0;$();l=0;break a}S(a|0);p()}$c(b,4);m=e+32|0;jD(m,b);i=x[k>>2];f=hb-32|0;hb=f;b=x[e+32>>2];v[f+24|0]=y[b|0];v[f+25|0]=y[b+1|0];v[f+26|0]=y[b+2|0];v[f+27|0]=y[b+3|0];c=Xq(f+8|0);d=b+d|0;x[c+12>>2]=d-4;x[c+8>>2]=b;Bj(c,y[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Bj(c,1)){break d}d=1;while(1){g=Bj(c,2);d=g+d|0;if((g|0)==3){continue}break}x[f+4>>2]=d;xc(f+4|0,b);d=0;g=x[f+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;q=i+b|0,r=Bj(c,8),v[q|0]=r;d=d+1|0;continue}}hb=f+32|0;break c}g=Bj(c,2);d=g+2|0;x[f+4>>2]=d;f:{if((g|0)==3){if(Bj(c,1)){g=y[Kb(f+24|0,3)|0]}else{g=7}g=Bj(c,g);while(1){j=Bj(c,3);d=j+d|0;if((j|0)==7){continue}break}x[f+4>>2]=d;break f}g=Bj(c,y[Kb(f+24|0,g)|0])}xc(f+4|0,b);d=0;o=x[f+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=y[i+n|0]}b=b-1|0;v[i+b|0]=j;d=d+1|0;continue}}break}ke(e+16|0,x[k>>2],x[k+4>>2]);Lg(e+24|0,x[e+16>>2],x[e+20>>2]);b=$d(e+8|0);c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;b=cr(m,x[e+24>>2],x[e+28>>2],e);bd(Cj(x[a+4>>2])+12|0,b);zb(b)}hb=e- -64|0;return l|0}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;h=hb-48|0;hb=h;f=wO(h+32|0,1<<x[b+12>>2]);g=x[f>>2];while(1){c=x[a>>2];if(Gg(c,x[a+4>>2])>>>0>d>>>0){c=Pe(c,d);vO(dd(g,d),C[c>>3]);d=d+1|0;continue}break}uO(b,f);w=h,y=Db(x[f>>2]),x[w+8>>2]=y;v=Db(x[f+4>>2]);while(1){g=x[h+8>>2];if(Pb(g,v)){m=C[g+8>>3];k=hb-32|0;hb=k;o(+C[g>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=e&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;e=c?r:s;c=c?q:d;d=c;l(0,e|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|e)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}FH(k+24|0,k+16|0,m);FH(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;hb=k+32|0;vO(g,Zo(p));co(h+8|0);continue}break}tO(b,f);rO(f);e=x[f>>2];g=fh(e,x[f+4>>2])>>>1|0;c=g>>>0<=1?1:g;d=1;while(1){if((c|0)!=(d|0)){iz(dd(e,d),2);iz(dd(e,d+g|0),0);d=d+1|0;continue}break}uO(b,f);w=h,y=Db(x[f>>2]),x[w+24>>2]=y;g=Db(x[f+4>>2]);while(1){e=x[h+24>>2];if(Pb(e,g)){qO(h+8|0,C[e>>3],C[e+8>>3]);c=x[h+20>>2];x[e+8>>2]=x[h+16>>2];x[e+12>>2]=c;c=x[h+12>>2];x[e>>2]=x[h+8>>2];x[e+4>>2]=c;co(h+24|0);continue}break}tO(b,f);rO(f);g=x[a>>2];c=Gg(g,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){dl(f);hb=h+48|0}else{a=dd(b,d);w=Pe(g,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;g=hb-48|0;hb=g;o=x[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;x[j+4>>2]=x[e+44>>2];x[j+8>>2]=x[e+48>>2];f=f+1|0;continue}break}j=x[a+24>>2];p=x[a+20>>2];f=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=f;q=b+24|0;r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){if(d){f=x[g+16>>2];k=(((x[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=w[b+14>>1];h=w[b+12>>1];l=w[b+10>>1];m=w[b+8>>1];n=w[b+6>>1];E=w[b+4>>1];F=w[b+2>>1];G=w[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;x[(g+8|0)+(e<<2)>>2]=(((((D(v[b+4|0],l)+D(v[b+2|0],m)|0)+D(h,v[b+6|0])|0)+D(i,v[b+8|0])<<8)/2|0)+((((D(v[b-4|0],F)+D(v[b-6|0],G)|0)+D(v[b-2|0],E)|0)+D(v[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=x[k>>2];b=(g+24|0)+(f<<3)|0;i=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;l=e<<8;e=l;e=Wia(z,A,e,e>>31);m=lb;n=b;b=Xb(h,-16777216,16776704);h=Wia(u,y,b,b>>31);e=h+e|0;b=lb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Xb(i,-16777216,16776704);i=Wia(s,t,e,e>>31);e=h+i|0;b=lb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Qc(e,b,24);x[n+4>>2]=b-(l&r);x[k>>2]=(b|0)/256;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],p);x[c+4>>2]=x[c+4>>2]+D(j,x[g+12>>2]);Rb(g+16|0,B,C);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];f=f+1|0;continue}break}hb=g+48|0}function Fr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=qG(c,d);x[i+4>>2]=1073;m=oG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ld(k);if(!j){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;break b}Me(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[23420]=0;h=Q(1075,a|0,i+120|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){x[23420]=0;b=Q(1076,a|0,i+120|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23420]=0;n=T(1077,b|0)|0;b=x[23420];x[23420]=0;g:{if((b|0)!=1){if(g){break g}x[23420]=0;n=Q(1078,e|0,n|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[23420]=0;T(1079,a|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=v[Xf(b,o)|0];j:{if(g){break j}x[23420]=0;q=Q(1078,e|0,q<<24>>24)|0;t=x[23420];x[23420]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n&255)==(q&255)){s=1;if((Eb(b)|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Pc(m);hb=i+128|0;return d|0}a=P()|0}else{n:{if(!De(b)){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Pc(m);S(a|0)}p()}function Dr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=hb-128|0;hb=i;x[i+120>>2]=b;k=qG(c,d);x[i+4>>2]=1073;m=oG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ld(k);if(!j){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;break b}Me(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{x[23420]=0;h=Q(1091,a|0,i+120|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){x[23420]=0;b=Q(1092,a|0,i+120|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[23420]=0;n=T(1093,b|0)|0;b=x[23420];x[23420]=0;g:{if((b|0)!=1){if(g){break g}x[23420]=0;n=Q(1094,e|0,n|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break g}}a=P()|0;break b}r=o+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=r;if(!s){continue e}x[23420]=0;T(1095,a|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Eb(b)|0)==(o|0)){break h}v[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}a=P()|0;break b}i:{if(y[h|0]!=1){break i}q=x[fj(b,o)>>2];j:{if(g){break j}x[23420]=0;q=Q(1094,e|0,q|0)|0;t=x[23420];x[23420]=0;if((t|0)!=1){break j}a=P()|0;break b}k:{if((n|0)==(q|0)){s=1;if((Eb(b)|0)!=(r|0)){break i}v[h|0]=2;l=l+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}a=P()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Pc(m);hb=i+128|0;return d|0}a=P()|0}else{n:{if(!De(b)){v[h|0]=1;break n}v[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Pc(m);S(a|0)}p()}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){e=x[g+16>>2];m=((((x[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=w[b+39718>>1];i=w[b+39716>>1];n=w[b+39714>>1];l=w[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((D(w[f>>1],n)+D(w[f-4>>1],l)|0)+D(i,w[f+4>>1])|0)+D(j,w[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=Wia(y,z,f,f>>31);l=lb;C=e;e=Xb(i,-16777216,16776704);i=Wia(u,v,e,e>>31);f=i+f|0;e=lb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Xb(j,-16777216,16776704);j=Wia(s,t,f,f>>31);f=l+j|0;e=lb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[C+4>>2]=e-(n&r);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-48|0;hb=g;k=c+484344|0;lg(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=pg(a);$b(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=Ee(a)+1|0;break c}c=Eg(a)}d=Eg(a);$c(a,e+f|0);Xd(g,a,d);f=jc(g+24|0,g);zb(g);x[23420]=0;c=W(214,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=_b(x[k>>2],j);m=g,n=Db(x[c>>2]),x[m>>2]=n;l=Db(x[c+4>>2]);while(1){c=x[g>>2];if(!Pb(c,l)){break d}x[23420]=0;d=T(194,f|0)|0;e=x[23420];x[23420]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[23420]=0;d=T(194,f|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[23420]=0;e=T(194,f|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}v[c+1|0]=e}e=0;if(d&4){x[23420]=0;e=T(194,f|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}}if(d&8){x[23420]=0;h=T(194,f|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break a}v[c+3|0]=h}if(d&16){x[23420]=0;d=T(194,f|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}i=255;if((d|0)==97){break h}if(d>>>0>96){break i}i=d+12|0;break h}i=0}v[c|0]=i;j:{if(y[c+5|0]|y[c+3|0]){Of(c);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+26974|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}jk(g);continue}}zb(f);j=j+1|0;continue}break}break a}hb=g+48|0;return}a=P()|0;zb(f);S(a|0);p()}function Y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=hb-208|0;hb=c;e=El(c+104|0,a);x[23420]=0;d=Q(396,c+88|0,43806)|0;a=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[23420]=0;x[c+72>>2]=19924737;x[c+76>>2]=0;U(397,e|0,d|0,c+72|0);a=x[23420];x[23420]=0;if((a|0)==1){break n}Sb(d);if(y[e+3|0]&64){break e}x[23420]=0;d=Q(396,c+72|0,13188)|0;a=x[23420];x[23420]=0;if((a|0)==1){break m}x[23420]=0;X(428,e|0,b|0,d|0,826);a=x[23420];x[23420]=0;if((a|0)==1){break l}Sb(d);x[c+68>>2]=0;x[c+64>>2]=0;x[23420]=0;d=Q(396,c+48|0,16569)|0;a=x[23420];x[23420]=0;if((a|0)==1){break k}x[23420]=0;U(827,e|0,c+68|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}Sb(d);x[23420]=0;d=Q(396,c+32|0,16541)|0;a=x[23420];x[23420]=0;if((a|0)==1){break i}x[23420]=0;U(827,e|0,c- -64|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}Sb(d);a=x[c+68>>2];d=x[c+64>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Qb(c+16|0);x[23420]=0;f=Q(396,c|0,13965)|0;a=x[23420];x[23420]=0;if((a|0)==1){break d}x[23420]=0;U(828,e|0,d|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}Sb(f);if(uc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[23420]=0;R(781,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){break f}break c}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;break a}a=P()|0;Sb(d);break a}a=P()|0;Sb(f);break b}x[23420]=0;R(829,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}tc(d)}Zg(e);hb=c+208|0;return}a=P()|0;break b}a=P()|0}tc(d)}Zg(e);S(a|0);p()}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;y=b>>31;b=x[a+60>>2];z=b;A=b>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){if(d){e=x[g+16>>2];m=(((x[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=w[b+39718>>1];i=w[b+39716>>1];n=w[b+39714>>1];l=w[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;x[(g+8|0)+(e<<2)>>2]=(((D(v[f|0],n)+D(v[f-2|0],l)|0)+D(i,v[f+2|0])|0)+D(j,v[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=Wia(z,A,f,f>>31);l=lb;E=e;e=Xb(i,-16777216,16776704);i=Wia(u,y,e,e>>31);f=i+f|0;e=lb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Xb(j,-16777216,16776704);j=Wia(s,t,f,f>>31);f=l+j|0;e=lb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[E+4>>2]=e-(n&r);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,B,C);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function Dq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=y[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}v[a|0]=0;break b}e=1;v[a|0]=1;v[f+15|0]=64;h=b,i=y[Wb(b,f+15|0)|0],v[h|0]=i;break a}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=12;break b}d=c;c=y[b|0];if(!(c&3|c>>>0>223?d:1)){break a}v[b|0]=(c&252)>>>2;v[a|0]=13;break b}d=y[b|0];if(d>>>0<240){while(1){if((e|0)==10){e=0;break a}g=y[e+43744|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}v[a|0]=11;v[b|0]=e;e=e>>>0<10;break a}e=e+1|0;continue}}v[a|0]=11;v[b|0]=9;break b}o:{p:{q:{d=y[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}v[b|0]=0;v[a|0]=0;break b}v[a|0]=2;v[b|0]=y[b|0]<<2&60|2;break b}c=y[b|0];if(!c){break a}d=c&15;if(!d){v[b|0]=c>>>4;v[a|0]=3;break b}g=c&240;if(!g){v[a|0]=4;break b}if((d|0)==15){v[b|0]=c>>>4;v[a|0]=5;break b}if((g|0)!=240){break a}v[b|0]=d;v[a|0]=6;break b}c=b;b=y[b|0];v[c|0]=(b|0)==255?64:b>>>2|0;v[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){v[b|0]=0;break r}if(y[b|0]){break a}}v[a|0]=8;break b}s:{if(c){v[f+14|0]=y[b|0]&15;v[f+13|0]=9;c=y[Wb(f+14|0,f+13|0)|0];break s}c=y[b|0];if(c>>>0>15|(c&14)>>>0>9){break a}}v[b|0]=c&15;v[a|0]=8}e=1}hb=f+16|0;return e}function mL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=qh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=aS(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(qh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(qh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;Ol(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){Ol(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!qh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Zp(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!qh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;Yp(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;Zp(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Yp(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(qh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;Zp(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;Yp(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=hb-16|0;hb=g;i=ff(a,c);ae(g,x[a+28>>2]);j=a;a:{if(!i){c=0;if(gd(a,5)){break a}}e=hb-192|0;hb=e;f=El(e+88|0,x[a+28>>2]);x[23420]=0;a=Q(396,e+72|0,27647)|0;c=x[23420];x[23420]=0;b:{c:{d:{e:{if((c|0)!=1){x[23420]=0;x[e+8>>2]=19924737;x[e+12>>2]=0;U(397,f|0,a|0,e+8|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}Sb(a);if(!(y[f+3|0]&64)){break d}break b}c=P()|0;break c}c=P()|0;Sb(a);break c}v[e+71|0]=0;v[e+70|0]=0;x[23420]=0;a=Q(396,e+56|0,9986)|0;c=x[23420];x[23420]=0;f:{g:{h:{i:{if((c|0)!=1){x[23420]=0;U(436,f|0,e+71|0,a|0);c=x[23420];x[23420]=0;if((c|0)==1){break i}Sb(a);if(!y[e+71|0]){break b}nf(e+71|0,50);x[23420]=0;a=Q(396,e+40|0,13078)|0;c=x[23420];x[23420]=0;if((c|0)==1){break f}x[23420]=0;U(436,f|0,e+70|0,a|0);c=x[23420];x[23420]=0;if((c|0)==1){break g}Sb(a);a=x[b>>2];c=jj(a,x[b+4>>2]);h=y[e+71|0];if(c>>>0<h>>>0){a=wz(e+8|0,x[b+12>>2]);x[23420]=0;U(437,b|0,h|0,a|0);c=x[23420];x[23420]=0;if((c|0)==1){break h}Yk(a);a=x[b>>2]}k=z[pj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+70|0];n=b,o=jj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}Ze(pj(x[b>>2],a),k);l=x[b>>2];x[23420]=0;R(438,e+8|0,c|0);m=x[23420];x[23420]=0;if((m|0)!=1){x[23420]=0;X(439,f|0,pj(l,a)|0,e+8|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}c=c+1|0;Sb(e+8|0);continue}break}c=P()|0;break c}c=P()|0;Sb(e+8|0);break c}c=P()|0;break c}c=P()|0;Sb(a);break c}c=P()|0;Yk(a);break c}c=P()|0;Sb(a);break c}c=P()|0}Zg(f);S(c|0);p()}Zg(f);hb=e+192|0;c=i}af(j,c);hb=g+16|0}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=1042;x[e+12>>2]=2;d=hb+-64|0;hb=d;j=x[e+8>>2]&2?16:10;l=hb-32|0;hb=l;g=Qe(l+16|0,1,0);a:{b:{c:{while(1){m=l+8|0;c=sc(g);n=c;o=Eb(g)+c|0;i=z[b>>1];h=0;d:{if((j|0)==10){jx(m,n,o,i);break d}f=i;c=D(j,j);r=D(c,j);q=D(c,c);e:{while(1){f=f&65535;k=h|1;if(f>>>0<j>>>0){break e}k=h|2;if(c>>>0>f>>>0){break e}k=h|3;if(f>>>0<r>>>0){break e}if(f>>>0<q>>>0){k=h+4|0}else{h=h+4|0;f=(f>>>0)/(q>>>0)|0;continue}break}}c=k;if((c|0)>(o-n|0)){x[m+4>>2]=61;x[m>>2]=o;break d}f=c+n|0;c=f;while(1){h=i&65535;i=(h|0)/(j|0)|0;c=c-1|0;v[c|0]=y[(h-D(i,j)|0)+4856|0];if(i&65535){continue}break}x[m+4>>2]=0;x[m>>2]=f}if(!x[l+12>>2]){break c}c=If(Eb(g));x[23420]=0;R(58,g|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){continue}break}break b}b=x[l+8>>2];c=sc(g);x[23420]=0;R(59,g|0,b-c|0);b=x[23420];x[23420]=0;f:{if((b|0)!=1){x[23420]=0;R(71,d|0,g|0);b=x[23420];x[23420]=0;if((b|0)!=1){break f}break b}break b}xb(g);hb=l+32|0;break a}a=P()|0;xb(g);S(a|0);p()}b=d+16|0;$r(b,d,x[e+8>>2]);c=x[e+12>>2];i=x[e+8>>2];x[23420]=0;X(75,d+32|0,b|0,i|0,c|0);b=x[23420];x[23420]=0;g:{h:{i:{j:{k:{if((b|0)!=1){b=y[e+24|0];c=x[e+20>>2];x[23420]=0;X(76,d+48|0,d+32|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break k}x[23420]=0;R(70,a|0,d+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}yb(d+48|0);yb(d+32|0);yb(d+16|0);yb(d);hb=d- -64|0;break g}a=P()|0;break h}a=P()|0;break i}a=P()|0;yb(d+48|0)}yb(d+32|0)}yb(d+16|0);yb(d);S(a|0);p()}hb=e+32|0}function i_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-624|0;hb=a;x[a+608>>2]=c;x[a+616>>2]=b;x[a+16>>2]=1108;h=le(a+200|0,a+208|0,a+16|0);b=a+192|0;ad(b,e);x[23420]=0;i=T(1086,b|0)|0;b=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[23420]=0;b=pa(1116,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}if(!b){break e}b=y[14498]|y[14499]<<8|(y[14500]<<16|y[14501]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14495]|y[14496]<<8|(y[14497]<<16|y[14498]<<24);x[a+176>>2]=y[14491]|y[14492]<<8|(y[14493]<<16|y[14494]<<24);x[a+180>>2]=b;x[23420]=0;X(1098,i|0,a+176|0,a+186|0,a+128|0);b=x[23420];x[23420]=0;if((b|0)==1){break g}x[a+4>>2]=1073;d=le(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Me(d,Ld((c>>2)+2|0));e=x[d>>2];if(e){break f}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((AG(a+16|0,a)|0)!=1){x[23420]=0;Y(1110,7918);b=x[23420];x[23420]=0;if((b|0)!=1){break a}break c}Pc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(nw(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[23420]=0;b=Q(1092,a+616|0,a+608|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+616>>2];Zb(a+192|0);Pc(h);hb=a+624|0;return b|0}c=P()|0;break b}c=P()|0;Pc(d)}Zb(a+192|0);Pc(h);S(c|0);p()}p()}function p_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;x[a+16>>2]=1108;h=le(a+152|0,a+160|0,a+16|0);b=a+144|0;ad(b,e);x[23420]=0;i=T(18,b|0)|0;b=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[23420]=0;b=pa(1109,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}if(!b){break e}b=y[14498]|y[14499]<<8|(y[14500]<<16|y[14501]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14495]|y[14496]<<8|(y[14497]<<16|y[14498]<<24);x[a+128>>2]=y[14491]|y[14492]<<8|(y[14493]<<16|y[14494]<<24);x[a+132>>2]=b;x[23420]=0;X(1084,i|0,a+128|0,a+138|0,a+118|0);b=x[23420];x[23420]=0;if((b|0)==1){break g}x[a+4>>2]=1073;d=le(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Me(d,Ld(c+2|0));e=x[d>>2];if(e){break f}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)==1){break c}break a}c=P()|0;break b}c=P()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((AG(a+16|0,a)|0)!=1){x[23420]=0;Y(1110,7918);b=x[23420];x[23420]=0;if((b|0)!=1){break a}break c}Pc(d)}else{b=a+118|0;j=e,k=y[((ii(b,b+10|0,c)-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[23420]=0;b=Q(1076,a+280|0,a+272|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+280>>2];Zb(a+144|0);Pc(h);hb=a+288|0;return b|0}c=P()|0;break b}c=P()|0;Pc(d)}Zb(a+144|0);Pc(h);S(c|0);p()}p()}function ly(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=hb-16|0;hb=e;i=WL(b,c);a:{if(!x[b+656>>2]|!(v[i+6|0]&1)){break a}f=x[i>>2];j=a+1074312|0;Ab(e+8|0,j,31);g=Bb(x[x[e+8>>2]>>2],x[e+12>>2]);d=Uu(x[b+656>>2],c);if(uc(x[d>>2],x[d+4>>2])){break a}g=f+(g^1)|0;Ab(e+8|0,j,31);f=y[d+12|0];b:{c:{if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){d:{if(!(f&2)){break d}h=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[Cb(x[d>>2],h)>>1]|0;if(!(y[b+89|0]&8)|(!(f&4)|(h|0)!=y[d+16|0])){f=l}else{Ab(e+8|0,j,70);f=Bb(x[x[e+8>>2]>>2],x[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=z[Cb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[Cb(a,y[d+16|0])>>1]+1|0)!=(g|0)){break b}g=z[Cb(a,y[d+15|0])>>1];Ab(e+8|0,j,93);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])|(c|0)!=1|x[b+88>>2]&2048){break b}v[i+6|0]=y[i+6|0]&254;break b}k=1;f=z[Jn(x[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|y[b+669|0]&8)){if(z[i+4>>1]==65535){break f}Ab(e+8|0,j,97);if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}f=y[d+12|0]}if(f&2){h=x[d>>2];f=z[Cb(h,y[d+13|0])>>1];h=z[Cb(h,y[d+14|0])>>1]+1|0;break e}f=z[Jn(x[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=x[d>>2];f=z[Cb(h,y[d+15|0])>>1];h=z[Cb(h,y[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=x[a+480180>>2];c=x[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[Jn(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}g=f}Ab(e+8|0,j,31);m=i,n=Bb(x[x[e+8>>2]>>2],x[e+12>>2])+g|0,x[m>>2]=n}hb=e+16|0}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[g+16>>2];l=b>>>18|0;j=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=w[i>>1];x[(g+8|0)+(e<<2)>>2]=f+((D(l,w[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=Wia(y,z,f,f>>31);m=lb;C=e;e=Xb(i,-16777216,16776704);i=Wia(u,v,e,e>>31);f=i+f|0;e=lb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Xb(j,-16777216,16776704);j=Wia(s,t,f,f>>31);f=m+j|0;e=lb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[C+4>>2]=e-(r&n);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function Ms(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=hb-144|0;hb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}h=x[c+4>>2];if(!h&A[c>>2]>=A[b+4>>2]|h){break h}a=ba(8)|0;x[23420]=0;b=Q(26,a|0,21473)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break g}b=P()|0;ca(a|0);break a}if(!x[b>>2]){a=ba(8)|0;x[23420]=0;b=T(770,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break f}b=P()|0;ca(a|0);break a}d=hb-16|0;hb=d;h=x[b+4>>2];Lg(d+8|0,x[b>>2],h);g=f+120|0;FD(g,x[d+8>>2],x[d+12>>2]);x[g+12>>2]=0;hb=d+16|0;i:{j:{if(a&2){b=Km(f+96|0,g);x[23420]=0;b=T(771,b|0)|0;e=x[23420];x[23420]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=Km(f+72|0,g);x[23420]=0;e=T(772,d|0)|0;i=x[23420];x[23420]=0;d=1;if((i|0)==1){break e}k=(e|0)==1;if(k){break j}d=Km(f+48|0,g);x[23420]=0;i=Q(773,d|0,c|0)|0;j=x[23420];x[23420]=0;d=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}d=Km(f+24|0,g);x[23420]=0;j=Q(774,d|0,c|0)|0;m=x[23420];x[23420]=0;d=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31392;while(1){if((b|0)==31908){break k}a=x[b>>2];if(a){d=Km(f,g);x[23420]=0;a=Q(a|0,d|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=h;if(c){d=0;if((e|0)!=-1){break j}d=Vc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}hb=f+144|0;return d}b=P()|0;break a}ha(b|0,92072,24);p()}ha(b|0,91968,24);p()}b=P()|0;break a}b=P()|0;break a}b=P()|0;break a}b=P()|0}S(b|0);p()}function OM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=hb-16|0;hb=c;d=a+1074376|0;e=D(b,872);a:{if(x[(d+e|0)+704>>2]&134218752){break a}g=x[(a+e|0)+1075648>>2];if(!Rj(g)|y[g+15|0]&2){break a}d=ul(a,d,b,2,1);if((d-1&255)>>>0>249){break a}h=x[(D(d,160)+a|0)+906140>>2];if(!h){break a}f=D(b,872)+a|0;d=y[f+1075780|0];b:{if(y[f+1075782|0]==1){v[c+8|0]=64;e=y[Wb(f+1075784|0,c+8|0)|0];break b}e=255;if(y[f+1075783|0]!=13){break b}v[c+8|0]=64;e=y[Wb((D(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Ab(c+8|0,i,2);if(Bb(x[x[c+8>>2]>>2],x[c+12>>2])){if(d){if(Uc(d)){d=y[Kb(g+108|0,d-1|0)|0]}Xl(a,b,d,z[(D(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}mb[x[x[h>>2]+76>>2]](h,39,e,b);break a}j=x[g+4>>2];if(d){f=y[g+35|0]?j<<2:x[(D(b,872)+a|0)+1075680>>2];k=w[(D(b,872)+a|0)+1075768>>1];Ab(c+8|0,i,28);l=c,m=f+(Bb(x[x[c+8>>2]>>2],x[c+12>>2])?k<<2:k)|0,x[l+4>>2]=m;ge(c+4|0,0,256);f=a;if(Uc(d)){a=y[Kb(g+108|0,d-1|0)|0]}else{a=d}Xl(f,b,a&255,z[c+4>>1])}f=y[g+35|0];Ab(c+8|0,i,101);if(Bb(x[x[c+8>>2]>>2],x[c+12>>2])){a=(d|0)!=0}else{a=Uc(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}c:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((e|0)!=255){Us(a,E(E(E(e<<1)/E(-127))+E(1)));break a}Us(a,E(E(E(j<<1>>>0)/E(-127))+E(1)));break a;case 0:break c;default:break a}}if((e|0)!=255){v[c+8|0]=127;v[c+4|0]=e<<1;m=h,n=7,o=y[Wb(c+8|0,c+4|0)|0],p=b,l=x[x[h>>2]+76>>2],mb[l](m|0,n|0,o|0,p|0);break a}x[c+8>>2]=127;x[c+4>>2]=j<<1;p=h,o=7,n=y[Hb(c+8|0,c+4|0)|0],m=b,l=x[x[h>>2]+76>>2],mb[l](p|0,o|0,n|0,m|0)}hb=c+16|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;w=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[g+16>>2];l=b>>>10&4194048;j=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=v[i|0];x[(g+8|0)+(e<<2)>>2]=((D(l,v[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=x[l>>2];e=(g+24|0)+(b<<3)|0;j=x[e+8>>2];i=x[e+4>>2];x[e+8>>2]=i;n=f<<8;f=n;f=Wia(y,z,f,f>>31);m=lb;C=e;e=Xb(i,-16777216,16776704);i=Wia(u,w,e,e>>31);f=i+f|0;e=lb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Xb(j,-16777216,16776704);j=Wia(s,t,f,f>>31);f=m+j|0;e=lb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[C+4>>2]=e-(r&n);x[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],k>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,A,B);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function XZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Eb(n)>>>0>1){f=Yd(n);e=hb-16|0;hb=e;x[e+8>>2]=f;f=x[Ce(e+8|0)>>2];hb=e+16|0;B=c,C=Hi(f,yk(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=Lr(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(De(n)){break a}h=x[fj(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(De(m)|!w){break a}B=c,C=Hi(Yd(m),yk(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Ck(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=Lr(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=Lr(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(De(l)){s=-1}else{s=v[Xf(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Eb(l)>>>0<=t>>>0){s=q;break f}s=-1;if(y[Xf(l,t)|0]==127){break f}s=v[Xf(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}Er(A,h)}u=u+1|0;continue}break}}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){e=x[g+16>>2];k=((((x[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=w[b+39718>>1];h=w[b+39716>>1];l=w[b+39714>>1];j=w[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;x[(g+8|0)+(e<<2)>>2]=(((D(w[f>>1],l)+D(w[f-4>>1],j)|0)+D(h,w[f+4>>1])|0)+D(i,w[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,v,f,f>>31);j=lb;A=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=j+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[A+4>>2]=e-(l&p);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],n);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function wK(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=hb-16|0;hb=c;e=a+4208|0;b=Ex(B[Cb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=lp(E(B[Rl(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[Cb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=me(E(10),E(E(E(B[e>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Ex(B[Cb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Rl(c+12|0,c+8|0)>>2];m=c,n=E(Ex(B[Cb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Rl(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=hb-16|0;hb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=un(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=un(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=un(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=un(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=un(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Rw(b,f+8|0);b=un(C[f+8>>3],d&1)}hb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=lp(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+45568>>2];hb=c+16|0}function H3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-48|0;hb=c;g=Qb(a);a:{b:{c:{d=b+36|0;a=x[d>>2];f=x[b+40>>2];d:{if(Pb(a,f)){Bc(c+40|0);break d}x[23420]=0;R(977,c+24|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}x[23420]=0;a=T(961,c+24|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}x[c+40>>2]=a;Vf(c+24|0);f=x[b+40>>2];a=x[b+36>>2]}if(!Pb(a,f)){d=x[c+40>>2];a=x[d>>2]}f=x[d+4>>2];x[23420]=0;R(169,g|0,Cn(a,f)|0);a=x[23420];x[23420]=0;e:{if((a|0)!=1){i=c,j=Db(x[d>>2]),x[i+16>>2]=j;f=Db(x[d+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=x[c+16>>2];if(!Pb(a,f)){Ik(c+40|0);hb=c+48|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[23420]=0;d=pj(e,d);R(978,c|0,d|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;R(964,c+24|0,c|0);e=x[23420];x[23420]=0;if((e|0)==1){break k}x[23420]=0;R(171,g|0,c+24|0);e=x[23420];x[23420]=0;if((e|0)==1){break j}xb(c+24|0);yb(c);l:{if(!De(hx(x[g+4>>2]))){break l}e=y[a+12|0];x[23420]=0;e=Q(297,d|0,e|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break f}if(!e){break l}e=x[b+24>>2];h=x[e+1298404>>2];a=z[bc(x[d>>2],x[a+12>>2])>>1];d=x[e+484344>>2];x[23420]=0;R(971,c|0,_b(d,a)|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}x[23420]=0;X(223,c+24|0,0,h|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}a=c+24|0;Ac(hx(x[g+4>>2]),a);xb(a);xb(c)}JI(c+16|0);continue}break}a=P()|0;break e}a=P()|0;break i}a=P()|0;xb(c+24|0)}yb(c);break e}a=P()|0;break e}a=P()|0;xb(c);break e}a=P()|0;break e}a=P()|0}Ik(c+40|0);break a}a=P()|0;Vf(c+24|0);break a}a=P()|0}Ke(g);S(a|0);p()}function Eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;k=f,l=ak(b),x[k>>2]=l;e=hb-16|0;hb=e;h=a;c=Vd(a);a:{if(c){g=ic(h);while(1){a=c;c=a+14|0;if(st(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!st(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ic(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=hb-16|0;hb=i;a=ic(h);j=rh(e,wc(48),sh(i+8|0,a));a=x[j>>2];b=x[f>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=ic(j),l=1,v[k+4|0]=l;hb=i+16|0;Yg(h,x[e+12>>2],g,x[e>>2]);b=Zd(e);cl(e);d=1}Xg(f+8|0,x[gc(e,b)>>2],d);hb=e+16|0;a=Vp(x[f+8>>2]);hb=f+16|0;return a+32|0}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-16|0;hb=g;u=x[a+16>>2];v=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);p=x[a+128>>2];a:{if(!p){n=x[a+8>>2];s=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];o=0;break a}b=x[a+12>>2];s=b;n=x[a+8>>2];q=cg(n,b,p);r=lb;k=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Hf(i,e,$e(n,b,d),lb);o=k>>>0<lb>>>0?d:0}h=a+112|0;f=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+u|0;b=p;while(1)if((b|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];y=x[a+32>>2];m=x[a+28>>2]+m|0;b=x[a+60>>2];e=b;j=b>>31;t=_f(h,v)<<8;b=t;b=Wia(e,j,b,b>>31);z=lb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(k,-16777216,16776704);j=Wia(j,A,b,b>>31);e=e+j|0;b=lb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=Wia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(m>>12,f)+x[c>>2];l=l+y|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,f);Rb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=k;continue b}else{Kd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(h,4);Rb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=f;x[a+44>>2]=k;x[a+24>>2]=l>>12;hb=g+16|0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){if(d){e=x[g+16>>2];k=(((x[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=w[b+39718>>1];h=w[b+39716>>1];l=w[b+39714>>1];j=w[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;x[(g+8|0)+(e<<2)>>2]=(((D(v[f|0],l)+D(v[f-2|0],j)|0)+D(h,v[f+2|0])|0)+D(i,v[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,y,f,f>>31);j=lb;B=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=j+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[B+4>>2]=e-(l&p);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],n);Rb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=hb-16|0;hb=h;a:{b:{c:{i=x[a+12>>2];j=x[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=x[a+16>>2];f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];e=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=e;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];e=x[a+68>>2];u=e;v=e>>31;e=x[a+64>>2];y=e;z=e>>31;e=x[a+60>>2];A=e;B=e>>31;while(1){e=b;if(d){b=Xb(e,-16777216,16776704);b=Wia(y,z,b,b>>31);m=lb;n=b;g=(x[h+12>>2]<<1)+q|0;b=(x[h+8>>2]>>>16&65520)+p|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=Wia(b,b>>31,A,B);n=n+b|0;o=lb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Xb(f,-16777216,16776704);f=Wia(u,v,b,b>>31);m=f+n|0;b=lb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Qc(f,b,24);b=(f|0)/256|0;l=l+s|0;x[c>>2]=D(b,l>>12)+x[c>>2];k=k+r|0;x[c+4>>2]=x[c+4>>2]+D(b,k>>12);Rb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=e;x[a+24>>2]=k>>12;hb=h+16|0}function Sg(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=hb-16|0;hb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Yn(f,g);break b}Yn(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];JO(x[a>>2],d);JO(x[a+4>>2],d);w[a+22>>1]=h;oz(a);LO(a);v[a+21|0]=f;oz(a);LO(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;oz(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+28832|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Zn(a);w[a+14>>1]=z[((e&15)<<1)+28864>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+21458|0];KO(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Zn(a);w[a+26>>1]=e&15;Zn(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Zn(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}hb=c+16|0;return}mb[x[x[b>>2]>>2]](b,c,d,e)}function JJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=hb-48|0;hb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;pc(a,d+24604|0,40);x[e+8>>2]=b;py(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=hb-16|0;hb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;x[23420]=0;b=Q(54,d|0,10689)|0;a=x[23420];x[23420]=0;i:{if((a|0)!=1){a=rc(c,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break g}a=P()|0;xb(b);break i}a=P()|0;ca(c|0)}S(a|0);p()}hb=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!tx(e+8|0,a+24648|0)){break d}ny(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];pc(f,d+24604|0,40);b=hb-48|0;hb=b;j:{if((c|0)==-1){os(f,x[Kp(b+8|0)+32>>2]);Yn(f,x[Kp(b+8|0)+36>>2]);break j}if((c|0)<=0){os(f,0);Yn(f,0);break j}a=D(c,1e3);os(f,a);Yn(f,a)}hb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}py(d,e+8|0);break d;default:d=ba(8)|0;x[23420]=0;c=Q(54,e+8|0,10277)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(d,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b;case 0:break e}}g=a,h=me(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}hb=e+48|0;return}b=P()|0;ca(d|0)}S(b|0)}p()}function WV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-48|0;hb=f;g=mi(b)^-1;a:{if(vc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){Js(a);break a}mi(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){$b(b,4)}j=f,k=mi(b),x[j+44>>2]=k;$b(b,4);h=mi(b);i=mi(b);if(!((h|0)>0&(i|0)>36)){Js(a);break a}if(dq(Hd(x[e>>2],x[Cb(x[d>>2],g)>>2]),12955)){Js(a);break a}wv(f,b,i,h);d=jc(f+24|0,f);zb(f);b=x[d>>2];x[23420]=0;b=T(166,b|0)|0;e=x[23420];x[23420]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[23420]=0;T(175,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[23420]=0;Q(176,d|0,8)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[23420]=0;Q(176,d|0,16)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}}x[23420]=0;T(177,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[23420]=0;T(177,d|0)|0;c=x[23420];x[23420]=0;b=8;break g}h:{if(b>>>0>=100){x[23420]=0;Q(176,d|0,4)|0;b=x[23420];x[23420]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[23420]=0;T(177,d|0)|0;c=x[23420];x[23420]=0;b=4}if((c|0)==1){break b}x[23420]=0;Q(176,d|0,b|0)|0;break e}x[23420]=0;T(177,d|0)|0}b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;b=T(177,d|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}x[23420]=0;U(178,f|0,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}j=jc(a,f),k=x[f+44>>2],x[j+20>>2]=k;zb(f)}zb(d);break a}}a=P()|0;zb(d);S(a|0);p()}hb=f+48|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;v=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;f=((((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=w[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;k=x[e+8>>2];j=x[e+4>>2];x[e+8>>2]=j;n=f<<8;f=n;f=Wia(y,z,f,f>>31);l=lb;C=e;e=Xb(j,-16777216,16776704);j=Wia(u,v,e,e>>31);f=j+f|0;e=lb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Xb(k,-16777216,16776704);k=Wia(s,t,f,f>>31);f=l+k|0;e=lb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[C+4>>2]=e-(r&n);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],i>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,A,B);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function $Z(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Eb(n)>>>0>1){f=Ns(n);e=hb-16|0;hb=e;x[e+8>>2]=f;f=x[Be(e+8|0)>>2];hb=e+16|0;B=c,C=IF(f,Ls(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=jl(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(De(n)){break a}p=y[Xf(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(De(m)|!z){break a}B=c,C=IF(Ns(m),Ls(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!jh(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;p=p-1|0;continue}break}if(p){q=jl(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=jl(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}if(De(l)){q=-1}else{q=v[Xf(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Eb(l)>>>0<=t>>>0){q=p;break e}q=-1;if(y[Xf(l,t)|0]==127){break e}q=v[Xf(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}Fl(A,x[c>>2])}u=u+1|0;continue}break}}function sV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=hb-32|0;hb=f;zc(c);while(1){a:{if(!Nb(x[c>>2],x[c+8>>2],3)){break a}d=f+24|0;Lq(d,c);i=jd(d);h=Ue(d);d=y[f+24|0];if(d>>>0>=A[a+12>>2]){break a}g=ed(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=y[d+26048|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=y[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((e|0)>=0){break f}d=0-e&15;break e}v[f+16|0]=64;e=y[Wb(f+23|0,f+16|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue}d=3;if((e|0)>=0){break c}d=0-e&127;break e}if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e}if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+23|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+23|0]=e;break c}d=e&15|-48;break e}d=e&15|-64;break e}d=164;if((e|0)==100){break e}x[f+16>>2]=e- -64;x[f+12>>2]=0;x[f+8>>2]=128;e=x[vj(f+16|0,f+12|0,f+8|0)>>2];if(!y[g+3|0]){break d}o:{switch(y[g+2|0]){case 0:case 2:break o;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+23|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}hb=f+32|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=hb-16|0;hb=h;a:{b:{c:{i=x[a+12>>2];k=x[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=x[a+16>>2];b=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];e=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];f=x[a+68>>2];s=f;t=f>>31;f=x[a+64>>2];u=f;y=f>>31;f=x[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Xb(f,-16777216,16776704);e=Wia(u,y,e,e>>31);g=lb;j=e;b=Xb(b,-16777216,16776704);e=Wia(s,t,b,b>>31);j=j+e|0;b=lb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=x[h+12>>2]+o|0;e=(x[h+8>>2]>>>16&65520)+n|0;g=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=g;e=Wia(e,e>>31,z,A);j=e+j|0;b=lb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;m=m+q|0;x[c>>2]=D(b,m>>12)+x[c>>2];l=l+p|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,b);Rb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=b;x[a+44>>2]=f;x[a+24>>2]=l>>12;hb=h+16|0}function xaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=hb+-64|0;hb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[23420]=0;b=W(144,h|0,b|0,l|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[23420]=0;U(178,f+16|0,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}b=f+16|0;h=jc(f+40|0,b);zb(b);x[23420]=0;R(512,b|0,h|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}z=xe(f+16|0);q=x[f+16>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Oc(f+16|0);zb(h);n=(q-l<<1)+n|0;continue h}x[23420]=0;g=T(505,h|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){x[23420]=0;b=T(194,h|0)|0;j=x[23420];x[23420]=0;if((j|0)==1){break f}x[f+8>>2]=b;ge(f+8|0,0,89);x[23420]=0;Q(176,h|0,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f+8>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f+8>>2]=r+v[(i&7)+30104|0];B=g;g=w[(r<<1)+30112>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+12>>2]=B+(i>>>0<8?g:0-g|0);ge(f+8|0,0,88);ge(f+12|0,-32768,32767);g=x[f+12>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}zb(c);hb=f- -64|0;return}b=P()|0;Oc(f+16|0);break d}b=P()|0}zb(h);break a}b=P()|0;break a}b=P()|0}zb(c);S(b|0);p()}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-16|0;hb=g;u=x[a+16>>2];w=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);p=x[a+128>>2];a:{if(!p){n=x[a+8>>2];s=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];o=0;break a}b=x[a+12>>2];s=b;n=x[a+8>>2];q=cg(n,b,p);r=lb;k=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Hf(i,e,$e(n,b,d),lb);o=k>>>0<lb>>>0?d:0}h=a+112|0;f=x[a+48>>2];l=x[a+40>>2];m=x[a+36>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+u|0;b=p;while(1)if((b|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(h,v[e+x[g+12>>2]|0]<<6);Jd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];y=x[a+32>>2];m=x[a+28>>2]+m|0;b=x[a+60>>2];e=b;j=b>>31;t=_f(h,w)<<8;b=t;b=Wia(e,j,b,b>>31);z=lb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(k,-16777216,16776704);j=Wia(j,A,b,b>>31);e=e+j|0;b=lb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=Wia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(m>>12,f)+x[c>>2];l=l+y|0;x[c+4>>2]=x[c+4>>2]+D(l>>12,f);Rb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=k;continue b}else{Kd(h,v[e+x[g+12>>2]|0]<<6);Jd(h,4);Rb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+48>>2]=f;x[a+44>>2]=k;x[a+24>>2]=l>>12;hb=g+16|0}function JU(){var a=0,b=0,c=0;if(!y[466832]){a=hb-16|0;hb=a;ls(466480);x[116632]=-1;x[116630]=466536;x[116628]=92872;x[116620]=77268;v[466532]=0;b=a+8|0;Nr(b,466480);c=x[x[116620]+8>>2];x[23420]=0;R(c|0,466480,b|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){Zb(a+8|0);hb=a+16|0;break a}b=P()|0;Zb(a+8|0);En(466480);S(b|0);p()}rs(465808);x[116452]=77400;x[116450]=77380;x[116451]=0;An(465808,466480);QG(466544,93016,466592);Aw(465976,466544);QG(466600,92720,466648);Aw(466144,466600);Aw(466312,x[(x[x[116536]-12>>2]+466144|0)+24>>2]);PG(x[x[116450]-12>>2]+465800|0);HH(x[x[116536]-12>>2]+466144|0);PG(x[x[116536]-12>>2]+466144|0);a=hb-16|0;hb=a;bH(466656);x[116676]=-1;x[116674]=466712;x[116672]=92872;x[116664]=77660;v[466708]=0;b=a+8|0;Nr(b,466656);c=x[x[116664]+8>>2];x[23420]=0;R(c|0,466656,b|0);b=x[23420];x[23420]=0;b:{if((b|0)!=1){Zb(a+8|0);hb=a+16|0;break b}b=P()|0;Zb(a+8|0);Qr(466656);S(b|0);p()}MG(465896);x[116474]=77792;x[116472]=77772;x[116473]=0;An(465896,466656);OG(466720,93016,466768);zw(466060,466720);OG(466776,92720,466824);zw(466228,466776);zw(466396,x[(x[x[116557]-12>>2]+466228|0)+24>>2]);NG(x[x[116472]-12>>2]+465888|0);HH(x[x[116557]-12>>2]+466228|0);NG(x[x[116557]-12>>2]+466228|0);v[466832]=1}a=hb-16|0;hb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Ld((x[a+12>>2]<<2)+4|0);x[116710]=b;if(!b){break c}b=Ld(x[a+8>>2]);if(b){c=x[116710];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[116710]=0}hb=a+16|0;x[115904]=42;x[115922]=466932}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=hb-48|0;hb=g;o=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;x[h+4>>2]=x[e+44>>2];x[h+8>>2]=x[e+48>>2];b=b+1|0;continue}break}h=x[a+40>>2];i=x[a+36>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+32>>2];q=x[a+28>>2];r=x[a+72>>2];b=x[a+68>>2];s=b;t=b>>31;b=x[a+64>>2];u=b;w=b>>31;b=x[a+60>>2];y=b;z=b>>31;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;f=(((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=v[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=x[m>>2];e=(g+24|0)+(b<<3)|0;k=x[e+8>>2];j=x[e+4>>2];x[e+8>>2]=j;n=f<<8;f=n;f=Wia(y,z,f,f>>31);l=lb;C=e;e=Xb(j,-16777216,16776704);j=Wia(u,w,e,e>>31);f=j+f|0;e=lb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Xb(k,-16777216,16776704);k=Wia(s,t,f,f>>31);f=l+k|0;e=lb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[C+4>>2]=e-(r&n);x[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;x[c>>2]=x[c>>2]+D(x[g+8>>2],i>>12);h=h+p|0;x[c+4>>2]=x[c+4>>2]+D(x[g+12>>2],h>>12);Rb(g+16|0,A,B);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;x[a+40>>2]=h;x[a+20>>2]=i>>12;x[a+36>>2]=i;x[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-112|0;hb=c;sj(c+88|0,b,1413829443);x[23420]=0;b=T(166,x[c+88>>2])|0;d=x[23420];x[23420]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[23420]=0;U(726,c- -64|0,a+140|0,1413894985);a=x[23420];x[23420]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[23420]=0;a=Q(803,c- -64|0,13453)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}b=28591;if(a){b=Jb(c+48|0);x[23420]=0;a=T(190,c- -64|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break m}x[23420]=0;U(255,c- -64|0,b|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break m}x[23420]=0;d=Q(53,c+16|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break l}x[23420]=0;Y(804,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break k}x[23420]=0;U(805,c+32|0,d|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break j}a=c+32|0;e=Ac(b,a);xb(a);xb(c);xb(d);x[23420]=0;U(11,a|0,2,e|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}x[23420]=0;a=T(696,c+32|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}yb(c+32|0);xb(e);b=a-1>>>0<19398657?1252:28591}zb(c- -64|0);break a}a=P()|0;break b}a=P()|0;break f}a=P()|0;break f}a=P()|0;break i}a=P()|0;xb(c)}xb(d);break f}a=P()|0;break f}a=P()|0;yb(c+32|0)}xb(b);break d}a=P()|0}zb(c- -64|0);break b}x[23420]=0;a=W(144,x[c+88>>2],x[c+96>>2],2)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[23420]=0;b=T(182,c+88|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0}zb(c+88|0);S(a|0);p()}zb(c+88|0);hb=c+112|0;return b|0}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){b=x[g+16>>2];j=b>>>18|0;i=((((x[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=w[h>>1];x[(g+8|0)+(e<<2)>>2]=f+((D(j,w[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=x[j>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,v,f,f>>31);k=lb;A=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=k+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[A+4>>2]=e-(p&l);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;w=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){b=x[g+16>>2];j=b>>>10&4194048;i=(((x[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=v[h|0];x[(g+8|0)+(e<<2)>>2]=((D(j,v[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=x[j>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,w,f,f>>31);k=lb;A=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=k+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[A+4>>2]=e-(p&l);x[j>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function lj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Td(x[a>>2],x[a+20>>2])){break a}kk(a);b:{switch(Im(z[a+34>>1])-1|0){case 1:e=hb+-64|0;hb=e;h=x[a+20>>2];c=x[a>>2];d=Gd(z[a+34>>1]);f=h+(D(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=D(d,g);j=D(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=z[a+34>>1];if(c&2){i=x[a+8>>2];f=x[a+4>>2];Ab(e+32|0,b+1074312|0,33);cP(e+40|0,g,h+(D(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,Bb(x[x[e+32>>2]>>2],x[e+36>>2]));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];Ab(e+32|0,b+1074312|0,33);cP(e+8|0,g+(d<<7)|0,h+(D(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,Bb(x[x[e+32>>2]>>2],x[e+36>>2]))}hb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){w[f+(c+i<<1)>>1]=z[f+(c-d<<1)>>1];w[h+(c+j<<1)>>1]=z[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=hb+-64|0;hb=e;h=x[a+20>>2];c=x[a>>2];d=Gd(z[a+34>>1]);f=h+D(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=D(d,g);j=D(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=z[a+34>>1];if(c&2){i=x[a+8>>2];f=x[a+4>>2];Ab(e+32|0,b+1074312|0,33);bP(e+40|0,g,h+D(d,f)|0,i-f|0,d,(c&4)>>>2|0,Bb(x[x[e+32>>2]>>2],x[e+36>>2]));c=z[a+34>>1]}if(c&8){f=x[a+16>>2];a=x[a+12>>2];Ab(e+32|0,b+1074312|0,33);bP(e+8|0,g+(d<<6)|0,h+D(a,d)|0,f-a|0,d,(c&16)>>>4|0,Bb(x[x[e+32>>2]>>2],x[e+36>>2]))}hb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){v[f+(c+i|0)|0]=y[f+(c-d|0)|0];v[h+(c+j|0)|0]=y[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-384|0;hb=a;x[a+368>>2]=c;x[a+376>>2]=b;mw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Jb(a+200|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+196>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[23420]=0;b=Q(1091,a+376|0,a+368|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+196>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+196>>2]=b+c}x[23420]=0;b=T(1093,x[a+376>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(lw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[23420]=0;T(1095,a+376|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+216|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}cG(a,c,x[a+196>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;sf(a+216|0,a+32|0,x[a+28>>2],e);x[23420]=0;b=Q(1092,a+376|0,a+368|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+376>>2];xb(d);xb(a+216|0);hb=a+384|0;break a}}b=P()|0;xb(d);xb(a+216|0);S(b|0);p()}return b|0}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=hb-288|0;hb=a;x[a+272>>2]=c;x[a+280>>2]=b;qw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Jb(a+208|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=v[a+238|0];i=v[a+239|0];while(1){d:{x[23420]=0;b=Q(1075,a+280|0,a+272|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+204>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+204>>2]=b+c}x[23420]=0;b=T(1077,x[a+280>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(pw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[23420]=0;T(1079,a+280|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+224|0)|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}cG(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;sf(a+224|0,a+32|0,x[a+28>>2],e);x[23420]=0;b=Q(1076,a+280|0,a+272|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+280>>2];xb(d);xb(a+224|0);hb=a+288|0;break a}}b=P()|0;xb(d);xb(a+224|0);S(b|0);p()}return b|0}function F_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=hb-432|0;hb=i;x[i+424>>2]=37;x[i+428>>2]=0;l=Br(i+424|1,13723,x[c+4>>2]);x[i+380>>2]=i+384;a=Ad();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Mg(i+384|0,30,a,i+424|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Mg(i+384|0,30,a,i+424|0,i+80|0)}x[i+128>>2]=1073;k=le(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Ad();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Si(i+380|0,a,i+424|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Si(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)==1){break d}break e}a=x[i+380>>2];Me(k,a)}f=a+j|0;g=Ti(a,f,c);x[i+116>>2]=1073;e=le(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Ld(j<<3);if(!j){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break e}a=P()|0;break g}Me(e,j);b=a}a=i+104|0;ad(a,c);x[23420]=0;ia(1106,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23420];x[23420]=0;i:{if((a|0)!=1){Zb(i+104|0);x[23420]=0;a=ka(1107,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break i}Pc(e);Pc(k);hb=i+432|0;break b}a=P()|0;Zb(i+104|0);break g}a=P()|0}Pc(e);break c}p()}a=P()|0}Pc(k);S(a|0);p()}return a|0}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=hb-16|0;hb=g;s=x[a+16>>2];t=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=cg(k,l,n);p=lb;b=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Hf(i,e,$e(k,l,d),lb);m=b>>>0<lb>>>0?d:0}h=a+112|0;f=x[a+48>>2];u=x[a+24>>2];v=x[a+20>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];b=x[a+60>>2];e=b;j=b>>31;r=_f(h,t)<<8;b=r;b=Wia(e,j,b,b>>31);y=lb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=Wia(j,z,b,b>>31);e=e+j|0;b=lb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=Wia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,v)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,u);Rb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Kd(h,w[e+(x[g+12>>2]<<1)>>1]/4<<16>>16);Jd(h,4);Rb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;hb=g+16|0}function d5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=hb-16|0;hb=j;i=hb-32|0;hb=i;h=Qe(i+16|0,1,0);a:{b:{c:{while(1){g=sc(h);d=g+Eb(h)|0;c=x[b>>2];f=x[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){v[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=G(f);e=D(64-((e|0)==32?G(c|1)+32|0:e)|0,1233)>>12;n=(e<<3)+25648|0;l=k;k=x[n+4>>2];m=61;if((l|0)<(((f|0)==(k|0)&c>>>0>=A[n>>2]|f>>>0>k>>>0)+e|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Pw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=Zia(c,f,1e8,0);e=lb;l=Pw(g,d);d=Wia(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=Zi(Zi(l,d),c+D(d,-1e4)|0);break e}d=Zia(c,f,1874919424,2328306);e=lb;g=Ow(g,d);d=Wia(d,e,-1874919424,-2328307)+c|0;e=f+lb|0;e=c>>>0>d>>>0?e+1|0:e;c=Zia(d,e,1e8,0);e=lb;f=(c>>>0)/1e4|0;l=Zi(Zi(g,f),c+D(f,-1e4)|0);c=Wia(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=Zi(Zi(l,d),c+D(d,-1e4)|0)}m=0}x[i+12>>2]=m;x[i+8>>2]=d;if(!x[i+12>>2]){break c}c=If(Eb(h));x[23420]=0;R(58,h|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){continue}break}break b}b=x[i+8>>2];c=sc(h);x[23420]=0;R(59,h|0,b-c|0);b=x[23420];x[23420]=0;f:{if((b|0)!=1){x[23420]=0;R(60,j|0,h|0);b=x[23420];x[23420]=0;if((b|0)!=1){break f}break b}break b}xb(h);hb=i+32|0;break a}a=P()|0;xb(h);S(a|0);p()}x[23420]=0;R(57,a|0,j|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(j);hb=j+16|0;return}a=P()|0;xb(j);S(a|0);p()}function P_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=hb-256|0;hb=i;x[i+248>>2]=37;x[i+252>>2]=0;l=Br(i+248|1,13723,x[c+4>>2]);x[i+204>>2]=i+208;a=Ad();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=Mg(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=Mg(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1073;k=le(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Ad();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=Si(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=Si(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Me(k,a)}f=a+j|0;g=Ti(a,f,c);x[i+116>>2]=1073;e=le(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Ld(j<<1);if(!j){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break e}a=P()|0;break g}Me(e,j);b=a}a=i+104|0;ad(a,c);x[23420]=0;ia(1101,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[23420];x[23420]=0;i:{if((a|0)!=1){Zb(i+104|0);x[23420]=0;a=ka(14,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break i}Pc(e);Pc(k);hb=i+256|0;break b}a=P()|0;Zb(i+104|0);break g}a=P()|0}Pc(e);break c}p()}a=P()|0}Pc(k);S(a|0);p()}return a|0}function V3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-80|0;hb=e;f=Qb(a);a=0;c=x[b+24>>2];g=kj(Yb(x[c+484360>>2],y[c+484376|0]));x[23420]=0;R(169,f|0,g|0);c=x[23420];x[23420]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[bc(x[Yb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(zm(d,h,c)){x[23420]=0;R(971,e+48|0,_b(d,c)|0);c=x[23420];x[23420]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[23420]=0;U(958,e- -64|0,c|0,e+48|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;R(171,f|0,e- -64|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}xb(e- -64|0);xb(e+48|0);break b}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(e- -64|0)}xb(e+48|0);break a}f:{switch(c-65534|0){case 0:x[23420]=0;c=Q(54,e+32|0,9142)|0;d=x[23420];x[23420]=0;g:{if((d|0)!=1){x[23420]=0;R(171,f|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a;case 1:x[23420]=0;c=Q(54,e+16|0,9104)|0;d=x[23420];x[23420]=0;h:{if((d|0)!=1){x[23420]=0;R(171,f|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break h}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a;default:break f}}x[23420]=0;c=Q(54,e|0,14460)|0;d=x[23420];x[23420]=0;i:{if((d|0)!=1){x[23420]=0;R(171,f|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}xb(c);break b}a=P()|0;break a}a=P()|0;xb(c);break a}hb=e+80|0;return}a=a+1|0;continue}}a=P()|0}Ke(f);S(a|0);p()}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=hb-16|0;hb=h;a:{b:{c:{i=x[a+12>>2];j=x[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=x[a+16>>2];f=x[a+48>>2];p=x[a+24>>2];q=x[a+20>>2];b=x[a+44>>2];e=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=e;r=x[a+72>>2];e=x[a+68>>2];s=e;t=e>>31;e=x[a+64>>2];u=e;v=e>>31;e=x[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Xb(e,-16777216,16776704);b=Wia(u,v,b,b>>31);k=lb;l=b;g=(x[h+12>>2]<<1)+o|0;b=(x[h+8>>2]>>>16&65520)+n|0;g=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768<<8;b=g;b=Wia(b,b>>31,y,z);l=l+b|0;m=lb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Xb(f,-16777216,16776704);f=Wia(s,t,b,b>>31);k=f+l|0;b=lb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Qc(f,b,24);b=(f|0)/256|0;x[c>>2]=D(b,q)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,p);Rb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=b;x[a+48>>2]=f;x[a+44>>2]=e;hb=h+16|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;h=Jb(a+208|0);b=a+16|0;ad(b,d);x[23420]=0;b=T(1086,b|0)|0;c=x[23420];x[23420]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23420]=0;X(1098,b|0,81808,81834,a+224|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}Zb(a+16|0);c=Jb(a+192|0);b=Sc(c);x[23420]=0;R(59,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Nc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[23420]=0;d=Q(1091,a+344|0,a+336|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}if(!d){break c}g=x[a+188>>2];d=Eb(c);if((g|0)==(d+b|0)){x[23420]=0;R(59,c|0,d<<1);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Sc(c);x[23420]=0;R(59,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Nc(c,0);x[a+188>>2]=d+b}x[23420]=0;d=T(1093,x[a+344>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}if(ln(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}x[23420]=0;T(1095,a+344|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;Zb(a+16|0);break a}x[23420]=0;R(59,c|0,x[a+188>>2]-b|0);b=x[23420];x[23420]=0;f:{if((b|0)==1){break f}b=Ic(c);d=Ad();x[a>>2]=f;if((bG(b,d,a)|0)!=1){x[e>>2]=4}x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(c);xb(h);hb=a+352|0;return b|0}}b=P()|0;xb(c)}xb(h);S(b|0);p()}function Wca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-48|0;hb=e;w[e+46>>1]=254;c=kj(a);f=e+32|0;x[f>>2]=0;x[f+4>>2]=0;Bc(f+8|0);if(c){Pp(f,c);iC(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Db(x[a>>2]);d=Db(x[a+4>>2]);b=hb-16|0;hb=b;c=eA(c,d,z[e+46>>1]);x[b+8>>2]=c;if(Pb(c,d)){x[b>>2]=c;while(1){c=x[Re(b)>>2];if(Pb(c,d)){c=z[c>>1];if((c|0)==z[e+46>>1]){continue}w[x[b+8>>2]>>1]=c;Re(b+8|0);continue}break}c=x[b+8>>2]}hb=b+16|0;b=gc(e+24|0,c);c=x[gc(e+16|0,Db(x[a+4>>2]))>>2];d=x[b>>2];b=x[a>>2];b=(ro(d,Db(b))<<1)+b|0;if(Pb(d,c)){Nd(a,Hi(b+(ro(c,d)<<1)|0,x[a+4>>2],b))}Db(b);k=e,l=Db(x[a>>2]),x[k+8>>2]=l;d=Db(x[a+4>>2]);break c}k=bc(x[f>>2],b),l=b-d|0,w[k>>1]=l;g=x[a+4>>2];h=x[a>>2];x[23420]=0;g=W(702,h|0,g|0,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}b=b+1|0;d=(z[g>>1]==254)+d|0;continue}break}while(1){b=x[e+8>>2];if(Pb(b,d)){d:{c=x[a+24>>2];g=x[c+484344>>2];b=z[b>>1];if(!oe(g,x[c+484348>>2],b)){break d}b=_b(g,b);k=e,l=Db(x[b>>2]),x[k>>2]=l;g=Db(x[b+4>>2]);h=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Pb(b,g)){break d}e:{if(y[b+3|0]!=12){break e}j=Mc(c,h);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[bc(c,i)|0],v[k+5|0]=l}jk(e);continue}}Re(e+8|0);continue}else{b=x[f>>2];d=Mc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=z[bc(b,c)>>1],w[k+28>>1]=l;break a}}}a=P()|0;od(f);S(a|0);p()}od(f);hb=e+48|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;h=Jb(a+208|0);b=a+16|0;ad(b,d);x[23420]=0;b=T(18,b|0)|0;c=x[23420];x[23420]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23420]=0;X(1084,b|0,81808,81834,a+224|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}Zb(a+16|0);c=Jb(a+192|0);b=Sc(c);x[23420]=0;R(59,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Nc(c,0);x[a+188>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[23420]=0;d=Q(1075,a+264|0,a+256|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}if(!d){break c}g=x[a+188>>2];d=Eb(c);if((g|0)==(d+b|0)){x[23420]=0;R(59,c|0,d<<1);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Sc(c);x[23420]=0;R(59,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}b=Nc(c,0);x[a+188>>2]=d+b}x[23420]=0;d=T(1077,x[a+264>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}if(mn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}x[23420]=0;T(1079,a+264|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;Zb(a+16|0);break a}x[23420]=0;R(59,c|0,x[a+188>>2]-b|0);b=x[23420];x[23420]=0;f:{if((b|0)==1){break f}b=Ic(c);d=Ad();x[a>>2]=f;if((bG(b,d,a)|0)!=1){x[e>>2]=4}x[23420]=0;b=Q(1076,a+264|0,a+256|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(c);xb(h);hb=a+272|0;return b|0}}b=P()|0;xb(c)}xb(h);S(b|0);p()}function tN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-32|0;hb=e;f=x[b+64>>2];a:{b:{h=x[b+60>>2];g=z[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{d:{if((f|0)==-1){break d}f=a+1074312|0;Ab(e+24|0,f,68);if(Bb(x[x[e+24>>2]>>2],x[e+28>>2])){break d}Ab(e+16|0,f,103);if(i=Bb(x[x[e+16>>2]>>2],x[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Ab(e+8|0,f,49);if(i=Bb(x[x[e+8>>2]>>2],x[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=x[b+64>>2];break b}if((g|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((h|0)==-1){x[b+60>>2]=0}g=Mc(x[c>>2],x[c+4>>2]);f=z[b+68>>1];if(g>>>0<=f>>>0){f=z[c+28>>1];w[b+68>>1]=f}e:{if(z[b+72>>1]==(f&65535)){break e}c=a+1074312|0;Ab(e+24|0,c,26);if(Bb(x[x[e+24>>2]>>2],x[e+28>>2])){break e}Ab(e+16|0,c,68);if(Bb(x[x[e+16>>2]>>2],x[e+20>>2])|x[a+480180>>2]==1){break e}c=z[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break e}v[(D(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){c=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}x[b+52>>2]=f;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){Ab(e+24|0,a+1074312|0,103);if(Bb(x[x[e+24>>2]>>2],x[e+28>>2])){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}c=0;if(A[b+64>>2]<A[_b(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;c=0}hb=e+32|0;return c}function yz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;if(b&5){if((b|0)==1){d=Wia(x[a+24>>2],0,8363,0)+4136|0;c=lb;h=a,i=Vc(Zia(d,d>>>0<4136?c+1|0:c,8272,0),lb),x[h+24>>2]=i}d=hb-16|0;hb=d;f=d+8|0;c=hb-16|0;hb=c;g=x[a+24>>2];a:{if(!g){v[f|0]=0;v[f+1|0]=0;break a}sB(c+8|0,Xb(fm(Zo(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=x[c+8>>2];v[c+7|0]=x[c+12>>2];lt(f,g,c+7|0)}hb=c+16|0;gc(gc(d,a+36|0)+4|0,a+37|0);v[x[d>>2]]=y[f|0];v[x[d+4>>2]]=y[f+1|0];hb=d+16|0}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){d=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=d;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}nf(a+40|0,15);nf(a+41|0,63);if(!y[a+41|0]){break b}d=y[a+40|0];if(!d){break b}c=y[a+39|0];if(c){c=Cm(Vc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|y[a+38|0]!=2){break d}v[a+38|0]=3;break d}if(y[a+38|0]!=4){break d}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}e:{if(!(!(y[a+35|0]&2)|b&16777218)){x[e+24>>2]=0;x[e+8>>2]=0;x[e+16>>2]=0;x[e+20>>2]=0;x[e>>2]=0;x[e+4>>2]=0;il(a,0,e);break e}if(!(y[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Kb(a,8);v[b|0]=y[b|0]&3;a=Kb(a,9);v[a|0]=y[a|0]&3}hb=e+32|0}function JP(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-16|0;hb=j;a:{if((b|0)==(c|0)){break a}x[j+12>>2]=-1953789045;Gz(b,c,j+12|0);c=c-b|0;e=c>>2;x[j+8>>2]=e;f=vc(x[a>>2],x[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;x[j+4>>2]=c;n=x[Yc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=x[d>>2];i=D(qt(h^(x[b>>2]^x[((e<<2)+b|0)-4>>2])),1664525);x[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;x[d>>2]=f+x[d>>2];x[b>>2]=f;i=x[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=x[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=D(qt(x[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+x[i>>2]|0)|0),1566083941);x[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;x[d>>2]=a^x[d>>2];x[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=x[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=D(qt(h^(x[i>>2]^x[((c-1>>>0)%(e>>>0)<<2)+b>>2])),1664525);x[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;x[d>>2]=a+x[d>>2];x[i>>2]=a;c=c+1|0;continue}}else{l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=x[l>>2];d=(a>>>0)%(e>>>0)|0;h=(d<<2)+b|0;o=a-1|0;f=D(qt(m^(x[h>>2]^x[((o>>>0)%(e>>>0)<<2)+b>>2])),1664525);x[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=x[l>>2];f=x[Cb(i,o)>>2]+(f+d|0)|0;x[l>>2]=f+m;x[h>>2]=f;a=a+1|0;continue}}hb=j+16|0}function Uy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;f=x[c+656>>2];a:{if(!nj(f)){i=x[c+704>>2];f=hb-16|0;hb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;Ab(f,e,73);d=Bb(x[x[f>>2]>>2],x[f+4>>2])?d&65535:d;if(y[b+480208|0]&16){Ab(f,e,73);e=Bb(x[x[f>>2]>>2],x[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+33936>>2]<<6>>>e|0;break b}g=229079296/((d?d:1)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(qm(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}xc(f+12|0,16777215);if(j&17408){g=Vc(Zia(Wia(i?i:8363,0,3506176,0),lb,(x[f+12>>2]<<8)+e|0,0),lb);break b}if(gj(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Vc(Zia(Wia(i?i:8363,0,7012352,0),lb,(x[f+12>>2]<<8)+e|0,0),lb);break b}g=Vc(Zia(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),lb)}e=g;hb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Ie(Ej(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=Wia(f,f>>31,e,e>>31);f=d+e|0;d=lb+(d>>31)|0;k=h,l=Hc(Xia(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),lb),x[k+12>>2]=l}xc(h+12|0,2147483647);c=x[h+12>>2];b=Xia(0,c,x[b+24620>>2]<<4,0);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=lb;hb=h+16|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;f=((((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=w[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,v,f,f>>31);j=lb;A=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=j+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[A+4>>2]=e-(p&l);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function AY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=hb-16|0;hb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=hb-16|0;hb=r;s=ai(r+8|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=hb-16|0;hb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Qw(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}pc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}hb=o+16|0;$h(s);hb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=hw(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=m+x[h>>2]|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=hw(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}hb=n+16|0;return q|0}f=x[h>>2];continue}}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=hb-16|0;hb=h;a:{b:{c:{i=x[a+12>>2];k=x[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|(i|0)==-1){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=x[a+16>>2];b=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];e=x[a+44>>2];f=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=f;p=x[a+72>>2];f=x[a+68>>2];q=f;r=f>>31;f=x[a+64>>2];s=f;t=f>>31;f=x[a+60>>2];u=f;y=f>>31;while(1){f=e;if(d){e=Xb(f,-16777216,16776704);e=Wia(s,t,e,e>>31);g=lb;j=e;b=Xb(b,-16777216,16776704);e=Wia(q,r,b,b>>31);j=j+e|0;b=lb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=x[h+12>>2]+m|0;e=(x[h+8>>2]>>>16&65520)+l|0;g=(((((((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])|0)+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+2|0],w[e+10>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8)/32768<<8;e=g;e=Wia(e,e>>31,u,y);j=e+j|0;b=lb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Qc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,n);Rb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=f;hb=h+16|0}function iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=hb-16|0;hb=g;s=x[a+16>>2];t=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];i=x[a>>2];e=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=cg(k,l,n);p=lb;b=x[a+76>>2];i=x[a>>2];e=x[a+4>>2];Hf(i,e,$e(k,l,d),lb);m=b>>>0<lb>>>0?d:0}h=a+112|0;f=x[a+48>>2];u=x[a+24>>2];w=x[a+20>>2];b=x[a+44>>2];x[g>>2]=i;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=i;x[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(h,v[e+x[g+12>>2]|0]<<6);Jd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}i=x[a+72>>2];b=x[a+60>>2];e=b;j=b>>31;r=_f(h,t)<<8;b=r;b=Wia(e,j,b,b>>31);y=lb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=Wia(j,z,b,b>>31);e=e+j|0;b=lb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=Wia(e,e>>31,f,f>>31);f=j+e|0;b=lb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Qc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,w)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,u);Rb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=x[g>>2];e=x[g+4>>2];f=q;continue b}else{Kd(h,v[e+x[g+12>>2]|0]<<6);Jd(h,4);Rb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=i;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;hb=g+16|0}function ty(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=Xq(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Mb(Mb(Mb(Mb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Mb(c,g,1)}Mb(Mb(Mb(c,f,1),e,1),d,1)}}function gX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Jb(a);a=y[b+11|0];g=x[b+4>>2];x[23420]=0;k=ol(g,a);R(103,i|0,k|0);a=x[23420];x[23420]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[rd(b)+a|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[23420]=0;Q(104,i|0,Hd(c,g)|0)|0;h=x[23420];x[23420]=0;g=e;if((h|0)!=1){break d}a=P()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[23420]=0;Q(104,i|0,Hd(c,j)|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break d}a=P()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[23420]=0;Q(105,i|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break d}a=P()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;x[23420]=0;a=T(106,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){x[23420]=0;U(107,a|0,41812,24);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0;ca(b|0);break b}a=P()|0}yb(i);S(a|0)}p()}function Hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,B=0;i=hb-16|0;hb=i;pd(d,32);g=i+8|0;QP(g,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);g=ic(g);QP(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;g=x[g>>2];if(g-838861>>>0>=4294128436){a=x[ic(i)>>2];x[d>>2]=D(g,320);w[d+34>>1]=1;a:{m=Ag(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+A[d>>2];t=+A[i>>2];u=+A[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=x[b+20>>2];if(Td(x[b>>2],a)){e=n*r+u;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=z[b+34>>1];j=Gd(k);h=D(f,j);e=e-+(f>>>0);d:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break d}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=x[c+20>>2];if(Td(x[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=z[c+34>>1];j=Gd(k);h=D(f,j);e=e-+(f>>>0);f:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break f}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);v=x[d+20>>2]+(a<<1)|0,B=Mz(p*(1-e)+o*e),w[v>>1]=B;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}hb=i+16|0;return a|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-48|0;hb=g;m=x[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;x[f+4>>2]=x[e+44>>2];x[f+8>>2]=x[e+48>>2];b=b+1|0;continue}break}n=x[a+24>>2];o=x[a+20>>2];b=x[a+4>>2];x[g+16>>2]=x[a>>2];x[g+20>>2]=b;p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;w=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){if(d){d=d-1|0;f=(((x[g+20>>2]&2147483647)<<1|x[g+16>>2]>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){x[(g+8|0)+(e<<2)>>2]=v[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=x[k>>2];e=(g+24|0)+(b<<3)|0;i=x[e+8>>2];h=x[e+4>>2];x[e+8>>2]=h;l=f<<8;f=l;f=Wia(u,w,f,f>>31);j=lb;A=e;e=Xb(h,-16777216,16776704);h=Wia(s,t,e,e>>31);f=h+f|0;e=lb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Xb(i,-16777216,16776704);i=Wia(q,r,f,f>>31);f=j+i|0;e=lb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Qc(f,e,24);x[A+4>>2]=e-(p&l);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[g+8>>2],o);x[c+4>>2]=x[c+4>>2]+D(n,x[g+12>>2]);Rb(g+16|0,y,z);c=c+8|0;continue}break}b=x[g+20>>2];x[a>>2]=x[g+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}hb=g+48|0}function Rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Kb(h,d),j=y[f+4|0]+1|0,v[i|0]=j;i=bc(g,d),j=(y[f+6|0]|y[f+7|0]<<8)+1|0,w[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=bc(f,d+12|0),j=(y[g+6|0]|y[g+7|0]<<8)+1|0,w[i>>1]=j;d=d+1|0;continue}}pA(a+484|0,b+48|0,0);pA(a+590|0,b+68|0,0);pA(a+696|0,b+88|0,5);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;i=b,j=y[Wb(e+15|0,e+14|0)|0]>>>1|0,x[i+4>>2]=j}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;i=b,j=y[Zc(e+12|0,e+10|0)|0],v[i+20|0]=j;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;i=b,j=z[Zc(e+8|0,e+6|0)>>1]>>>2|0,v[i+19|0]=j;c=y[a+824|0];Em(b,c&127,c>>>7|0);a=y[a+825|0];Dm(b,a&127,a>>>7|0);hb=e+16|0}function ZA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=hb-16|0;hb=j;a:{if(b&4){break a}c=y[a+14|0];b:{if(c>>>0>=y[a+15|0]){break b}d=y[a+12|0];if(!(d&2)){break b}v[a+12|0]=d&251}if(!(y[a+12|0]&2)|c>>>0<=y[a+13|0]){break a}e=x[a>>2];d=x[a+4>>2];if(qe(e,d)>>>0<=c>>>0){break a}e=z[Kc(e,d,c)>>1];d=Kc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);c=y[a+14|0];if(z[d>>1]<(e-1|0)){c=z[Kc(x[a>>2],x[a+4>>2],c)>>1]-1&65535;e=Hp(a,c,64,64);d=gc(j+8|0,hm(Db(x[a>>2]),y[a+14|0]));k=jo(j,c,e&255);m=hb-32|0;hb=m;c=x[d>>2];d=x[a>>2];c=(Rt(c,Db(d))<<2)+d|0;h=x[a+4>>2];c:{d:{if(h>>>0<A[Fb(a)>>2]){if((c|0)!=(h|0)){break d}qS(a,k);break c}d=Fb(a);f=bg(m+8|0,Tg(a,vc(x[a>>2],h)+1|0),c-x[a>>2]>>2,d);x[23420]=0;R(704,f|0,k|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=x[f+4>>2];i=f+4|0;Jp(x[a>>2],c,i);e=x[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){io(x[g>>2],z[c>>1]|z[c+2>>1]<<16);x[g>>2]=x[g>>2]+4;c=c+4|0;continue}break}nc(a,i);nc(a+4|0,g);nc(Fb(a),yc(f));x[f>>2]=x[f+4>>2];c=d;ag(f);break c}a=P()|0;ag(f);S(a|0);p()}f=hb-16|0;hb=f;i=x[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=Nh(f,a,h-d>>2);l=x[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){kc(g);iB(c,d,i);hb=f+16|0}else{io(l,z[e>>1]|z[e+2>>1]<<16);l=l+4|0;x[g+4>>2]=l;e=e+4|0;continue}break}v[c+2|0]=y[k+2|0];w[c>>1]=z[k>>1]}Db(c);hb=m+32|0;break a}v[a+14|0]=c-1}if((b|0)!=16777216){v[a+17|0]=255}hb=j+16|0}function $D(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-96|0;hb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Vb(a,9642);break j}d=b>>>24|0;if(!(b&65535)){e=hb-16|0;hb=e;f=Vb(e,4360);Rc(c+80|0,f);yb(f);hb=e+16|0;x[23420]=0;x[c+24>>2]=d;R(97,c- -64|0,c+24|0);d=x[23420];x[23420]=0;k:{l:{m:{n:{if((d|0)!=1){x[23420]=0;x[c+8>>2]=b>>>16&255;R(98,c+48|0,c+8|0);b=x[23420];x[23420]=0;if((b|0)==1){break n}x[23420]=0;X(99,a|0,c+80|0,c- -64|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break m}yb(c+48|0);yb(c- -64|0);cc(c+80|0);break j}b=P()|0;break k}b=P()|0;break l}b=P()|0;yb(c+48|0)}yb(c- -64|0)}break a}e=hb-16|0;hb=e;f=Vb(e,4084);Rc(c+80|0,f);yb(f);hb=e+16|0;x[23420]=0;x[c+44>>2]=d;R(97,c- -64|0,c+44|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}x[23420]=0;x[c+40>>2]=b>>>16&255;R(98,c+48|0,c+40|0);d=x[23420];x[23420]=0;if((d|0)==1){break h}x[23420]=0;x[c+20>>2]=b>>>8&255;R(98,c+24|0,c+20|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;x[c+4>>2]=b&255;R(98,c+8|0,c+4|0);b=x[23420];x[23420]=0;if((b|0)==1){break f}x[23420]=0;ma(100,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}yb(c+8|0);yb(c+24|0);yb(c+48|0);yb(c- -64|0);cc(c+80|0)}hb=c+96|0;return}b=P()|0;break a}b=P()|0;break b}b=P()|0;break c}b=P()|0;break d}b=P()|0;yb(c+8|0)}yb(c+24|0)}yb(c+48|0)}yb(c- -64|0)}cc(c+80|0);S(b|0);p()}function pF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function lz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Kb(h,b);a=v[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=bc(e+26|0,a);g=z[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}w[d>>1]=b;v[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=bc(i,a);k=z[j>>1];if((k|0)==65535){w[j>>1]=b;v[f|0]=a;break b}else{if(!(y[Kb(l,a)|0]&32)){g=v[Kb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=bc(i,a&255);m=Kb(h,z[d>>1]),n=255,v[m|0]=n;w[d>>1]=b;v[f|0]=a}a=Xk(e,b)}g=a&255;if((g|0)==255){break a}if(Uj(x[e>>2])){break a}d=Hd(e+318|0,g);a=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[d+8|0]=a;v[d+9|0]=a>>>8;v[d+10|0]=a>>>16;v[d+11|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[d|0]=f;v[d+1|0]=f>>>8;v[d+2|0]=f>>>16;v[d+3|0]=f>>>24;v[d+4|0]=a;v[d+5|0]=a>>>8;v[d+6|0]=a>>>16;v[d+7|0]=a>>>24;f=FO(g);h=f+3|0;a=0;while(1){if((a|0)==2){Sg(x[e>>2],x[e+4>>2],b,it(g)|192,y[Kb(c,10)|0])}else{d=a?h:f;Sg(x[e>>2],x[e+4>>2],b,d|32,y[Kb(c,a)|0]);Sg(x[e>>2],x[e+4>>2],b,d|64,y[Kb(c,a+2|0)|0]);Sg(x[e>>2],x[e+4>>2],b,d|96,y[Kb(c,a+4|0)|0]);Sg(x[e>>2],x[e+4>>2],b,d|128,y[Kb(c,a+6|0)|0]);Sg(x[e>>2],x[e+4>>2],b,d|224,y[Kb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function oI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=hb-16|0;hb=h;g=x[a+32>>2];f=ts(g);if(!f){f=ss(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;x[23420]=0;c=Q(54,h|0,5961)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}if(c>>>0>=120){b=ba(8)|0;x[23420]=0;c=Q(54,h|0,11176)|0;a=x[23420];x[23420]=0;if((a|0)!=1){a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0);break b}f=Gy(g,65535);j=(f|0)==65535?255:f;w[h>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;_n(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;Zl(i);Ap(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;$s(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=fm(Wy(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=fm(Wy(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h>>1];continue}}l=x[a+32>>2],m=bz(i,c),w[l+480212>>1]=m;hb=h+16|0;return j|0}a=P()|0;ca(b|0)}S(a|0)}p()}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;pd(b,2);f=e+16|0;dk(f,2,a+1|0);d=e+32|0;Fc(d,f);ze(b+43|0,d);xb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+32>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+16>>2]=d-1;d=e+32|0;f=x[Hb(d,e+16|0)>>2];x[b+4>>2]=f;x[e+32>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Hb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+16|0;Bh(f,a+16|0);d=x[e+16>>2];x[e+32>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Bh(f,a+20|0);d=x[e+16>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);Bh(f,a+24|0);d=x[e+16>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+40>>2]=d;x[e+8>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;il(b,1,e)}v[e+32|0]=y[a+28|0];v[e+16|0]=64;g=b,h=y[Wb(e+32|0,e+16|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}hb=e+48|0}function sga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=x[a>>2];b=Vt(c,x[a+4>>2]);if(b>>>0<=63){g=hb-32|0;hb=g;f=64-b|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=hb-16|0;hb=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+D(f,33);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);hb=b+16|0}else{FA(a);a=a+33|0;x[b+4>>2]=a;continue}break}break a}i=Fb(a);c=g+8|0;h=Vt(x[a>>2],d)+f|0;d=hb-16|0;hb=d;x[d+12>>2]=h;e=hb-16|0;hb=e;x[e+12>>2]=130150524;x[e+8>>2]=2147483647;b=x[Hb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(b>>>0>=h>>>0){e=uS(a);if(e>>>0<b>>>1>>>0){x[d+8>>2]=e<<1;b=x[Yc(d+8|0,d+12|0)>>2]}hb=d+16|0;break b}Tc();p()}e=Vt(x[a>>2],x[a+4>>2]);Jf(c+12|0,i);if(b){if(b>>>0>=130150525){ig();p()}d=wc(D(b,33))}else{d=0}x[c>>2]=d;e=d+D(e,33)|0;x[c+8>>2]=e;x[c+4>>2]=e;j=yc(c),k=d+D(b,33)|0,x[j>>2]=k;b=hb-16|0;hb=b;x[b>>2]=x[c+8>>2];d=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=d+D(f,33);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){FA(d);d=x[b>>2]+33|0;x[b>>2]=d;continue}break}Id(b);hb=b+16|0;b=c+4|0;f=x[a>>2];d=x[a+4>>2]-f|0;e=x[b>>2]+D((d|0)/-33|0,33)|0;x[b>>2]=e;if((d|0)>0){pc(e,f,d)}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){yc(c);Ib(a)}}hb=g+32|0;return}if((b|0)!=64){Nd(a,c+2112|0)}}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Jb(a);k=Eb(b);x[23420]=0;R(283,h|0,k|0);a=x[23420];x[23420]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[Xf(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}x[23420]=0;Q(284,h|0,Hd(c,i)|0)|0;g=x[23420];x[23420]=0;i=e;if((g|0)!=1){break d}a=P()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[23420]=0;Q(284,h|0,Hd(c,j)|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break d}a=P()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;x[23420]=0;Q(285,h|0,e|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break d}a=P()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;x[23420]=0;a=T(106,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){x[23420]=0;U(107,a|0,41812,24);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;break b}a=P()|0;ca(b|0);break b}a=P()|0}xb(h);S(a|0)}p()}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;mw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Jb(a+184|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23420]=0;b=Q(1091,a+360|0,a+352|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+180>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+180>>2]=b+c}x[23420]=0;b=T(1093,x[a+360>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23420]=0;T(1095,a+360|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=fG(c,x[a+180>>2],e),B[j>>2]=k;sf(a+200|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+360|0,a+352|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=P()|0;xb(d);xb(a+200|0);S(b|0);p()}return b|0}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;qw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Jb(a+192|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[23420]=0;b=Q(1075,a+264|0,a+256|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+188>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=b+c}x[23420]=0;b=T(1077,x[a+264>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(pw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23420]=0;T(1079,a+264|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=fG(c,x[a+188>>2],e),B[j>>2]=k;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+264|0,a+256|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-368|0;hb=a;x[a+352>>2]=c;x[a+360>>2]=b;mw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Jb(a+184|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[23420]=0;b=Q(1091,a+360|0,a+352|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+180>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+180>>2]=b+c}x[23420]=0;b=T(1093,x[a+360>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23420]=0;T(1095,a+360|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+200|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=dG(c,x[a+180>>2],e),C[j>>3]=k;sf(a+200|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+360|0,a+352|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+360>>2];xb(d);xb(a+200|0);hb=a+368|0;break a}}b=P()|0;xb(d);xb(a+200|0);S(b|0);p()}return b|0}function WH(a){var b=0,c=0,d=0,e=0;re(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){re(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}re(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){re(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}re(x[a+80>>2],d)}re(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;re(x[a+80>>2],x[b+8>>2]);re(x[a+80>>2],x[b+28>>2]);re(x[a+80>>2],x[b+32>>2]);re(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];re(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}re(x[a+80>>2],d)}re(x[a+80>>2],x[a+260>>2]);re(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){re(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}re(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;re(x[a+80>>2],x[d+800>>2]);re(x[a+80>>2],x[d+928>>2]);re(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;re(x[a+80>>2],x[b+1068>>2]);re(x[a+80>>2],x[b+1076>>2]);re(x[a+80>>2],x[b+1084>>2]);re(x[a+80>>2],x[b+1092>>2]);re(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-272|0;hb=a;x[a+256>>2]=c;x[a+264>>2]=b;qw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Jb(a+192|0);b=Sc(d);x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=v[a+222|0];i=v[a+223|0];while(1){d:{x[23420]=0;b=Q(1075,a+264|0,a+256|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(!b){break c}g=x[a+188>>2];b=Eb(d);if((g|0)==(b+c|0)){x[23420]=0;R(59,d|0,b<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=b+c}x[23420]=0;b=T(1077,x[a+264>>2])|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}if(pw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[23420]=0;T(1079,a+264|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=dG(c,x[a+188>>2],e),C[j>>3]=k;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+264|0,a+256|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+264>>2];xb(d);xb(a+208|0);hb=a+272|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}
function IO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;c=x[a>>2];a:{if(Uj(c)){i=hb-16|0;hb=i;e=wc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Zn((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+28752>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;NO(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;NO(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}MO(e,b)}else{xd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[mf(i+8|0,e)>>2];hb=i+16|0;x[h+8>>2]=b;b=h+8|0;Vz(a,b);oj(b);break a}MO(c,b)}HO(a);hb=h+16|0}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;b=b&4095;w[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=hb-16|0;hb=e;f=Vb(e,4412);Rc(d- -64|0,f);yb(f);hb=e+16|0;x[23420]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Wia(e,e>>31,1e4,0)+14780|0;b=lb;b=Xia(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+44>>2]=g+f;R(86,d+48|0,d+44|0);g=x[23420];x[23420]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[23420]=0;x[d+28>>2]=(e+D(f,-12)|0)+1;R(88,d+32|0,d+28|0);e=x[23420];x[23420]=0;if((e|0)==1){break j}x[23420]=0;x[d+12>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;R(88,d+16|0,d+12|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;ea(349,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}yb(d+16|0);yb(d+32|0);break d}b=P()|0;break e}b=P()|0;break f}b=P()|0;break g}b=P()|0;yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}break a}rg(d- -64|0,4392);x[23420]=0;R(350,d+48|0,d+78|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}x[23420]=0;U(133,a|0,d- -64|0,d+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}}yb(d+48|0);cc(d- -64|0);hb=d+80|0;return}b=P()|0;break a}b=P()|0;yb(d+48|0)}cc(d- -64|0);S(b|0);p()}function Un(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb-16|0;hb=d;g=a+1074312|0;Ab(d+8|0,g,96);i=b,j=(k=0,l=x[b+660>>2],m=Bb(x[x[d+8>>2]>>2],x[d+12>>2]),m?k:l)+c|0,x[i+660>>2]=j;f=x[a+480180>>2];e=x[b+84>>2];if(!(!(f&18)|e>>>0>c>>>0|(!(y[b+88|0]&2)|!e))){h=c;c=x[b+80>>2];c=((h-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(f|0)==16384)|0;a:{b:{if(!Uc(y[b+788|0])){Ab(d+8|0,g,114);if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){break b}}e=x[b+656>>2];c:{if(!e){break c}f=y[b+788|0];if(!Uc(f)){break c}e=z[bc(e+236|0,f-1|0)>>1];if(!e|e>>>0>z[a+480190>>1]){break a}}if(y[a+480210|0]&32){e=c;c=x[b+660>>2];x[b+660>>2]=e+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}Ab(d+8|0,g,57);d:{if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;break a}if(!(c&1048581)){Ab(d+8|0,g,27);if(Bb(x[x[d+8>>2]>>2],x[d+12>>2])){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;break a}x[b>>2]=0;x[b+4>>2]=0;break a}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;break a}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;break a}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}hb=d+16|0}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=hb-16|0;hb=f;s=x[a+16>>2];t=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){k=x[a+8>>2];l=x[a+12>>2];e=x[a>>2];b=x[a+4>>2];m=0;break a}k=x[a+8>>2];l=x[a+12>>2];o=cg(k,l,n);p=lb;g=x[a+76>>2];e=x[a>>2];b=x[a+4>>2];Hf(e,b,$e(k,l,d),lb);m=g>>>0<lb>>>0?d:0}h=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[f>>2]=e;x[f+4>>2]=b;while(1){if(d){d=d-1|0;x[f+8>>2]=e;x[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break b}q=((x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Kd(h,(e|0)/8<<16>>16);Jd(h,4);Rb(f+8|0,o,p);g=g-1|0;continue c}else{e=(v[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(v[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Kd(h,(e|0)/8<<16>>16);Jd(h,g);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;g=_f(h,t);x[c>>2]=D(j>>12,g)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(g,i>>12);Rb(f,k,l);c=c+8|0;e=x[f>>2];b=x[f+4>>2];continue}break}x[a>>2]=e;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=f+16|0}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Xi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23420]=0;g=Q(1091,a+344|0,a+336|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1093,x[a+344>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(ln(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[23420]=0;T(1095,a+344|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=kG(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=lb;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Xi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23420]=0;g=Q(1091,a+344|0,a+336|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1093,x[a+344>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(ln(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[23420]=0;T(1095,a+344|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=gG(c,x[a+188>>2],e,b),x[k>>2]=l;x[f+4>>2]=lb;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function e4(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-160|0;hb=e;d=Vb(e,11458);x[23420]=0;b=d+12|0;Q(54,b|0,10864)|0;c=x[23420];x[23420]=0;a:{if((c|0)==1){break a}x[23420]=0;b=d+24|0;Q(54,b|0,11288)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+36|0;Q(54,b|0,10856)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+48|0;Q(54,b|0,8161)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+60|0;Q(54,b|0,10841)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+72|0;Q(54,b|0,8227)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+84|0;Q(54,b|0,5581)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+96|0;Q(54,b|0,11862)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+108|0;Q(54,b|0,11231)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+120|0;Q(54,b|0,12063)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+132|0;Q(54,b|0,5433)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;b=d+144|0;Q(54,b|0,7253)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;W(968,a|0,d|0,13)|0;a=x[23420];x[23420]=0;if((a|0)!=1){b=d+156|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}hb=e+160|0;return}b=d+156|0}a=P()|0;while(1){b=xb(b-12|0);if((d|0)!=(b|0)){continue}break}S(a|0);p()}function Vca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=hb-48|0;hb=d;l=a+480190|0;c=z[l>>1];v[d+32|0]=0;jO(b,c+1|0,d+32|0);j=a+480192|0;if(z[j>>1]){h=Qb(d+32|0);q=d,r=Db(x[a+484344>>2]),x[q+24>>2]=r;o=Db(x[a+484348>>2]);m=a+480188|0;while(1){i=x[d+24>>2];if(Pb(i,o)){a:{if(!Pb(x[i>>2],x[i+4>>2])){break a}c=z[m>>1];x[23420]=0;v[d+8|0]=0;U(703,h|0,c|0,d+8|0);c=x[23420];x[23420]=0;if((c|0)!=1){q=d,r=Db(x[i>>2]),x[q+16>>2]=r;k=0;b:while(1){f=0;if(A[i+12>>2]<=k>>>0){break a}while(1)if(z[m>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[d+16>>2];if(!Uc(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[j>>1];break e}g=z[j>>1];c=y[Kb(x[h>>2],f)|0];if(c){break e}c=1;break d}q=Kb(x[h>>2],f),r=c,v[q|0]=r;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[bc(e+236|0,y[x[d+16>>2]]-1|0)>>1];if(e>>>0>z[l>>1]){break f}n=d+8|0;Ab(n,x[b>>2],e);vg(n,1)}c=c+1|0;continue}}f=f+1|0;dA(d+16|0);continue}}}a=P()|0;dc(h);S(a|0);p()}Gt(d+24|0);continue}else{c=z[a+480190>>1];while(1){if(c){Ab(d+8|0,x[b>>2],c);if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){e=f;f=D(c,104)+a|0;f=e+Td(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{dc(h)}break}}break}}hb=d+48|0;return f&65535}function GO(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-240|0;hb=e;if(!y[93840]){if(!y[93716]){c=hb-16|0;hb=c;Jb(93692);x[23426]=0;v[93708]=0;x[23428]=0;x[23420]=0;b=ga(28)|0;a=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){x[c+8>>2]=b;b=c+8|0;bA(93704,Zd(b));oj(b);v[93708]=0;break f}a=Aa(91780,92364)|0;b=ib;if((da(91780)|0)==(b|0)){_(a|0)|0;x[23420]=0;Z(29);c=x[23420];x[23420]=0;if((c|0)==1){break d}p()}if((da(92364)|0)!=(b|0)){break c}_(a|0)|0;x[23420]=0;v[93708]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){a=P()|0;break c}if(y[93708]){break e}}x[23420]=0;Y(30,93688);b=x[23420];x[23420]=0;if((b|0)!=1){break e}a=P()|0;break c}hb=c+16|0;break a}a=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)==1){break b}}oj(93712);oj(93704);xb(93692);S(a|0);p()}V(0)|0;Ub();p()}v[93716]=1}c=hb+-64|0;hb=c;b=c+16|0;g=hb-16|0;hb=g;h=mO(g+8|0);j=e+120|0;while(1){if((i|0)==12){hb=g+16|0}else{f=hb-48|0;hb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=aO(hO(f+8|0,32));break g}d=G(a);d=hO(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=aO(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}hb=f+48|0;l=Cb(b,i),m=a,x[l>>2]=m;i=i+1|0;continue}break}b=xO(c,b,CO(b));sO(j,b);km(b);hb=c- -64|0;pc(93720,pc(e,j,120),116);v[93840]=1}hb=e+240|0}function qF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return f|0}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Xi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23420]=0;g=Q(1091,a+344|0,a+336|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1093,x[a+344>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(ln(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[23420]=0;T(1095,a+344|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=mG(c,x[a+188>>2],e,b),x[k>>2]=l;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Xi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23420]=0;g=Q(1091,a+344|0,a+336|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1093,x[a+344>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(ln(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[23420]=0;T(1095,a+344|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=jG(c,x[a+188>>2],e,b),w[k>>1]=l;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function $F(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=hb-352|0;hb=a;x[a+336>>2]=c;x[a+344>>2]=b;b=Xi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+332>>2];while(1){d:{x[23420]=0;g=Q(1091,a+344|0,a+336|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1093,x[a+344>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(ln(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}x[23420]=0;T(1095,a+344|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=hG(c,x[a+188>>2],e,b),x[k>>2]=l;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1092,a+344|0,a+336|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+344>>2];xb(d);xb(a+208|0);hb=a+352|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[23420]=0;R(609,a|0,b|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;kc(c);hb=c+16|0;break a}a=P()|0;kc(c);S(a|0);p()}return}h=hb-32|0;hb=h;i=Fb(a);f=h+8|0;g=Op(x[a>>2],x[a+4>>2])+1|0;d=hb-16|0;hb=d;x[d+12>>2]=g;e=hb-16|0;hb=e;x[e+12>>2]=76695844;x[e+8>>2]=2147483647;c=x[Hb(e+12|0,e+8|0)>>2];hb=e+16|0;b:{if(c>>>0>=g>>>0){e=SQ(a);if(e>>>0<c>>>1>>>0){x[d+8>>2]=e<<1;c=x[Yc(d+8|0,d+12|0)>>2]}hb=d+16|0;break b}Tc();p()}e=Op(x[a>>2],x[a+4>>2]);Jf(f+12|0,i);if(c){if(c>>>0>=76695845){ig();p()}d=wc(D(c,56))}else{d=0}x[f>>2]=d;e=d+D(e,56)|0;x[f+8>>2]=e;x[f+4>>2]=e;j=yc(f),k=d+D(c,56)|0,x[j>>2]=k;c=x[f+8>>2];x[23420]=0;R(609,c|0,b|0);b=x[23420];x[23420]=0;c:{if((b|0)!=1){x[f+8>>2]=x[f+8>>2]+56;e=x[a>>2];b=x[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=Zj(x[d>>2]-56|0,b);Zj(c+12|0,b+12|0);Xz(c+24|0,b+24|0);w[c+52>>1]=z[b+52>>1];g=x[b+48>>2];x[c+44>>2]=x[b+44>>2];x[c+48>>2]=g;g=x[b+40>>2];x[c+36>>2]=x[b+36>>2];x[c+40>>2]=g;x[d>>2]=x[d>>2]-56;continue}break}nc(a,d);nc(a+4|0,f+8|0);nc(Fb(a),yc(f));x[f>>2]=x[f+4>>2];RQ(f);hb=h+32|0;break c}a=P()|0;RQ(f);S(a|0);p()}}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=hb-16|0;hb=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+32>>2];o=x[a+28>>2];p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;v=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(s,t,e,e>>31);g=lb;f=Xb(f,-16777216,16776704);k=Wia(q,r,f,f>>31);e=k+e|0;f=lb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(x[h+12>>2]<<1)+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(w[e+4>>1],w[g+10>>1])+D(w[e+2>>1],w[g+8>>1])|0)+D(w[e+6>>1],w[g+12>>1])|0)+D(w[e+8>>1],w[g+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[g+2>>1])+D(w[e-6>>1],w[g>>1])|0)+D(w[e-2>>1],w[g+4>>1])|0)+D(w[e>>1],w[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=Wia(e,e>>31,u,v);e=A+k|0;f=lb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+o|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+n|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Rb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Xi(d);cp(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[23420]=0;g=Q(1075,a+232|0,a+224|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1077,x[a+232>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}x[23420]=0;T(1079,a+232|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=kG(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=lb;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+232|0,a+224|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Xi(d);cp(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[23420]=0;g=Q(1075,a+232|0,a+224|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1077,x[a+232>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}x[23420]=0;T(1079,a+232|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=gG(c,x[a+188>>2],e,b),x[j>>2]=k;x[f+4>>2]=lb;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+232|0,a+224|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function me(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),k=0;f=(q(b),j(2));d=$E(f);a:{b:{c:{d:{c=(q(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=E(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=E(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=e>>>0>2130706431^(f|0)>=0?E(0):E(b*b);break a}if($E(c)){i=E(a*a);if((c|0)<0){i=(_E(f)|0)==1?E(-i):i}if((f|0)>=0){break b}a=Gv(E(E(1)/i));break a}if((c|0)<0){e=_E(f);if(!e){a=aE(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),r())*C[d+92408>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(C[d+92416>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=uD(e);break a}if(!(h<=-150)){break f}a=WC(e);break a}k=h;g=C[160];h=g+h;g=k-(h-g);k=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=x[d>>2];c=e;d=x[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=E(k*+n())}a=i}return a}function Qg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!qm(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+33248>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(gj(a)){a=((e&255)>>>0)/12|0;b=Wia(x[(D(a,-12)+e<<6&960)+37136>>2]<<a,0,d,0);a=lb;c=a>>>21|0;h=f,i=Vc((a&2097151)<<11|b>>>21,c),x[h>>2]=i;xc(f,2147483647);e=x[f>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+33248>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;xc(f+12|0,-1>>>a|0);e=Vc(Zia(Wia(z[((D(a,-12)+e&255)<<1)+33248>>1],0,267616,0),lb,x[f+12>>2]<<a,0),lb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Ab(f,a+1074312|0,76);b=Bb(x[x[f>>2]>>2],x[f+4>>2])?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)<=1?1:a;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f>>2]=d+8;ge(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+33744>>1])+D(z[(x[f>>2]<<1)+33728>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(D(a,-12)+e&255)<<1)+32848>>1]<<5>>>a|0;break a}e=z[(b<<1)+32622>>1]<<2}hb=f+16|0;return e}function LH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=be(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=be(a,k),x[p>>2]=q;i=be(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(Oe(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(si(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(Oe(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(si(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(Oe(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(si(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=be(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(si((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(si(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=be(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Ml(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Kl(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}ec(a,3);return 0}function vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=hb-16|0;hb=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+32>>2];o=x[a+28>>2];p=x[a+72>>2];b=x[a+68>>2];q=b;r=b>>31;b=x[a+64>>2];s=b;t=b>>31;b=x[a+60>>2];u=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(s,t,e,e>>31);g=lb;f=Xb(f,-16777216,16776704);k=Wia(q,r,f,f>>31);e=k+e|0;f=lb+g|0;f=e>>>0<k>>>0?f+1|0:f;B=e;e=x[h+12>>2]+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(v[e+2|0],w[g+10>>1])+D(v[e+1|0],w[g+8>>1])|0)+D(v[e+3|0],w[g+12>>1])|0)+D(v[e+4|0],w[g+14>>1])<<8)/2|0)+((((D(v[e-2|0],w[g+2>>1])+D(v[e-3|0],w[g>>1])|0)+D(v[e-1|0],w[g+4>>1])|0)+D(v[e|0],w[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=Wia(e,e>>31,u,y);e=B+k|0;f=lb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+o|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+n|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Rb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Xi(d);cp(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[23420]=0;g=Q(1075,a+232|0,a+224|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1077,x[a+232>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}x[23420]=0;T(1079,a+232|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=mG(c,x[a+188>>2],e,b),x[j>>2]=k;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+232|0,a+224|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Xi(d);cp(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[23420]=0;g=Q(1075,a+232|0,a+224|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1077,x[a+232>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}x[23420]=0;T(1079,a+232|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=jG(c,x[a+188>>2],e,b),w[j>>1]=k;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+232|0,a+224|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function iG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=hb-240|0;hb=a;x[a+224>>2]=c;x[a+232>>2]=b;b=Xi(d);cp(a+208|0,d,a+223|0);d=Jb(a+192|0);c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){c=Nc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=v[a+223|0];while(1){d:{x[23420]=0;g=Q(1075,a+232|0,a+224|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(!g){break c}h=x[a+188>>2];g=Eb(d);if((h|0)==(g+c|0)){x[23420]=0;R(59,d|0,g<<1);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Sc(d);x[23420]=0;R(59,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}c=Nc(d,0);x[a+188>>2]=g+c}x[23420]=0;g=T(1077,x[a+232>>2])|0;h=x[23420];x[23420]=0;if((h|0)==1){break d}if(mn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}x[23420]=0;T(1079,a+232|0)|0;g=x[23420];x[23420]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Eb(a+208|0)){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=hG(c,x[a+188>>2],e,b),x[j>>2]=k;sf(a+208|0,a+16|0,x[a+12>>2],e);x[23420]=0;b=Q(1076,a+232|0,a+224|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+232>>2];xb(d);xb(a+208|0);hb=a+240|0;break a}}b=P()|0;xb(d);xb(a+208|0);S(b|0);p()}return b|0}function L_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Gw(g);g=ow(g);Ng(k,g);a:{b:{if(De(k)){x[23420]=0;X(1098,l|0,a|0,c|0,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23420]=0;j=Q(1104,l|0,h<<24>>24)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23420]=0;h=Q(1104,l|0,48)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[23420]=0;h=Q(1104,l|0,h|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}Fl(j,c);i=0;x[23420]=0;o=T(1096,g|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Er((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[Nc(k,h)|0]){break e}if(v[Nc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23420]=0;n=Q(1104,l|0,n|0)|0;m=x[23420];x[23420]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;xb(k);S(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;xb(k);hb=k+16|0}function tS(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=y[a|0];a:{if(d>>>0>21){break a}v[a|0]=y[d+26512|0];b:{switch(d-8|0){case 0:v[b|0]=y[b|0]<<1;break a;case 4:v[b|0]=y[b|0]+1>>>1;break a;case 5:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=y[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}v[a|0]=0;break a}v[a|0]=29;v[c+15|0]=y[b|0]&15;v[c+14|0]=14;e=b,f=y[Wb(c+15|0,c+14|0)|0]<<4|15,v[e|0]=f;break a}v[a|0]=29;v[c+13|0]=y[b|0]&15;v[c+12|0]=14;e=b,f=y[Wb(c+13|0,c+12|0)|0]|240,v[e|0]=f;break a}v[b|0]=d&15|48;break a}v[a|0]=35;v[b|0]=y[b|0]<<4^128;break a}v[b|0]=d&15|176;break a}v[b|0]=d&15|64;break a}v[a|0]=15;v[b|0]=y[b|0]&15;break a}v[a|0]=24;v[b|0]=(y[b|0]<<3&120)+8&240;break a}v[a|0]=24;v[b|0]=(y[b|0]&15)+1>>>1;break a}v[a|0]=10;break a;case 8:a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){v[b|0]=a<<2&48|15;break a}v[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=y[b|0];if(a>>>0<=223){v[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}v[b|0]=a>>>2&3|240}hb=c+16|0}function hM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;f=a+484376|0;while(1){a:{c=Yb(x[a+484360>>2],y[f|0]);e=b&65535;if(Mc(x[c>>2],x[c+4>>2])>>>0>e>>>0){if(!oq(c,e)){break a}c=Yb(x[a+484360>>2],y[a+484376|0])}if(Mc(x[c>>2],x[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){gM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Wn(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;Py(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{_n((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Ab(d+8|0,e,23);if(Bb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}hb=d+16|0;return}b=b+1|0;continue}}function KR(a,b){var c=0;a:{b:{c:{d:{if(ee(a,16546)){break d}if(ee(a,17315)){break d}if(ee(a,13428)){break d}if(ee(a,13538)){break d}if(!ee(a,14103)){break c}}w[b+10>>1]=4;x[b>>2]=11894;break b}e:{f:{if(ee(a,17310)){break f}if(ee(a,13438)){break f}if(!ee(a,16531)){break e}}v[b+12|0]=1;x[b>>2]=8309;w[b+10>>1]=4;return 1}g:{if(!ee(a,14149)){if(!ee(a,14154)){break g}}w[b+10>>1]=8;x[b>>2]=8087;break b}h:{if(!ee(a,15133)){if(!ee(a,15138)){break h}}x[b>>2]=16918;w[b+10>>1]=v[a+2|0]-48;break b}i:{if(!ee(a,26714)){if(!ee(a,26719)){break i}}x[b+4>>2]=1;x[b>>2]=16724;w[b+10>>1]=y[a|0]==56?8:4;return 1}if(!(Ob(a,15239,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8427;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break b}j:{if(Ob(a,13466,3)){if(Ob(a,13600,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8186;w[b+10>>1]=v[a+3|0]-48;return 1}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!Ob(a+1|0,13624,3)){v[b+14|0]=1;x[b>>2]=8475;w[b+10>>1]=v[a|0]-48;return 1}if((y[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Ob(c,13952,2)){if(Ob(c,13628,2)){break k}}v[b+14|0]=1;x[b>>2]=8475;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;return 1}c=0;if(Ob(a,13294,3)|(y[a+3|0]-49&255)>>>0>8){break a}x[b>>2]=8336;w[b+10>>1]=v[a+3|0]-48}c=1}return c}function Uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=ff(a,c);ae(g,x[a+28>>2]);i=a;a:{if(!h){c=0;if(gd(a,5)){break a}}d=hb-160|0;hb=d;e=El(d+56|0,x[a+28>>2]);x[23420]=0;a=Q(396,d+40|0,43811)|0;c=x[23420];x[23420]=0;b:{c:{d:{e:{if((c|0)!=1){x[23420]=0;x[d+24>>2]=19924737;x[d+28>>2]=0;U(397,e|0,a|0,d+24|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}Sb(a);if(!(y[e+3|0]&64)){break d}break b}c=P()|0;break c}c=P()|0;Sb(a);break c}k=d,l=of(x[b>>2],x[b+4>>2]),w[k+38>>1]=l;w[d+36>>1]=65535;x[23420]=0;a=Q(396,d+24|0,9997)|0;c=x[23420];x[23420]=0;f:{if((c|0)!=1){x[23420]=0;c=W(426,e|0,d+36|0,a|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break f}Sb(a);if((c|0)!=1){w[d+38>>1]=z[d+36>>1]}tg(d+38|0,4e3);a=z[d+38>>1];g:{if(of(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[23420]=0;R(213,b|0,a|0);c=x[23420];x[23420]=0;if((c|0)!=1){break g}c=P()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}f=x[b>>2];x[23420]=0;R(427,d+8|0,c|0);j=x[23420];x[23420]=0;if((j|0)!=1){x[23420]=0;X(428,e|0,_b(f,c)|0,d+8|0,429);f=x[23420];x[23420]=0;if((f|0)==1){break h}c=c+1|0;Sb(d+8|0);continue}break}c=P()|0;break c}c=P()|0;Sb(d+8|0);break c}c=P()|0;break c}c=P()|0;Sb(a)}Zg(e);S(c|0);p()}Zg(e);hb=d+160|0;c=h}af(i,c);hb=g+16|0}function PV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=hb-1088|0;hb=g;e=zh(a);Tb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Gd(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[23420]=0;a=W(144,f|0,a|0,2)|0;f=x[23420];x[23420]=0;if((f|0)==1){break i}if(!a){break j}x[23420]=0;a=T(182,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break h}if(!a){break e}x[23420]=0;U(178,g|0,b|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}a=dr(g+24|0,g);f=bd(e,a);pc(f+20|0,a+20|0,1040);zb(a);zb(g);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Im(z[h+34>>1])>>>0>=2){x[23420]=0;R(183,f|0,a+(d<<1)|0);a=x[23420];x[23420]=0;if((a|0)!=1){break e}break f}x[23420]=0;R(184,f|0,a+d|0);a=x[23420];x[23420]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=V(30320)|0;if((ib|0)!=(da(30320)|0)){break b}_(a|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=P()|0}zb(e);S(a|0);p()}hb=g+1088|0;return e|0}function a3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-80|0;hb=e;a:{b:{c:{d:{f=a+36|0;d=x[f>>2];c=x[a+40>>2];e:{if(Pb(d,c)){Bc(e+72|0);break e}c=e+32|0;Dn(c,a);x[23420]=0;c=T(961,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break d}x[e+72>>2]=c;Vf(e+32|0);c=x[a+40>>2];d=x[a+36>>2]}c=(k=f,l=x[e+72>>2],m=Pb(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=d-24|0;g=x[c>>2];i=Cn(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=bl(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=bl(x[c>>2],f);break b}d=P()|0;Vf(e+32|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[23420]=0;R(994,d|0,f|0);f=x[23420];x[23420]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=$L(CR(e+32|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[23420]=0;g=x[c+12>>2];x[e+16>>2]=x[c+8>>2];x[e+20>>2]=g;g=x[c+20>>2];x[e+24>>2]=x[c+16>>2];x[e+28>>2]=g;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;X(995,e+56|0,f|0,(d?7:1)|0,e+8|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}c=aM(x[e+60>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];ui(e+56|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;Ik(e+72|0);hb=e+80|0;return+b}}d=P()|0;Ik(e+72|0)}S(d|0);p()}function WN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=hb-48|0;hb=f;n=gz(x[a+24>>2],y[a+32|0]);o=kj(n);a:{b:{while(1){c:{w[b>>1]=m;e=m&65535;if(e>>>0>=o>>>0){break c}if(oq(n,e)){e=x[a>>2];d=vd(e,x[a+4>>2]);g=z[b>>1];if(d>>>0<=g>>>0){x[c>>2]=0;break a}l=Hd(e,g);$k(f+32|0,x[l>>2]);lm(f+24|0,x[l>>2],x[l+4>>2]);e=x[f+36>>2];x[f+8>>2]=x[f+32>>2];x[f+12>>2]=e;g=hb-32|0;hb=g;e=x[f+12>>2];i=e;d=x[f+8>>2];e=_k(x[f+24>>2],x[f+28>>2],d,e);x[g+8>>2]=d;x[g+12>>2]=i;x[g+24>>2]=d;x[g+28>>2]=i;i=f+40|0;j=hb-16|0;hb=j;x[j+12>>2]=e;d=x[g+12>>2];d:{if(d){h=32-d|0;x[j+8>>2]=h;k=-1<<d;d=x[Hb(j+8|0,j+12|0)>>2];k=k&-1>>>h-d;h=x[g+8>>2];k=k&x[h>>2];if(k){fc(i,h,Via(k));break d}if((e|0)==(d|0)){d=x[g+12>>2];x[i>>2]=x[g+8>>2];x[i+4>>2]=d;pP(i,e);break d}e=e-d|0;x[j+12>>2]=e;d=h+4|0}else{d=x[g+8>>2]}while(1){if(e>>>0>=32){h=x[d>>2];if(h){fc(i,d,Via(h));break d}else{e=e-32|0;x[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){fc(i,d,0);break d}h=x[d>>2]&-1>>>32-e;if(!h){fc(i,d,e);break d}fc(i,d,Via(h))}hb=j+16|0;hb=g+32|0;lm(f+16|0,x[l>>2],x[l+4>>2]);if(x[f+40>>2]==x[f+16>>2]&x[f+44>>2]==x[f+20>>2]){break b}}m=z[b>>1]+1|0;continue}break}w[b>>1]=65535;x[c>>2]=-1;break a}x[c>>2]=0}hb=f+48|0;return(m&65535)>>>0<o>>>0|0}function DG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=nd(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=nd(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=nd(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Wia(e,d,10,0);c=b+c|0;d=lb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=nd(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=nd(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}lb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}lb=-2147483648;return 0}function AK(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=hb-16|0;hb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=me(E(10),E(E(E(B[Cb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=me(E(10),E(E(-1)/E(k*E(E(B[Cb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=me(E(10),E(E(-1)/E(k*E(E(B[Cb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(me(E(10),E(E(E(B[Cb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(Gv(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=aE(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Rl(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[Cb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[Cb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;hb=d+16|0}function V_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-16|0;hb=k;l=Lu(g);g=uw(g);Ng(k,g);a:{b:{if(De(k)){x[23420]=0;X(1084,l|0,a|0,c|0,d|0);g=x[23420];x[23420]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[23420]=0;j=Q(19,l|0,h<<24>>24)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[23420]=0;h=Q(19,l|0,48)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[23420]=0;h=Q(19,l|0,h|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}Fl(j,c);i=0;x[23420]=0;o=T(1082,g|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Fl((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[Nc(k,h)|0]){break e}if(v[Nc(k,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Eb(k)-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[23420]=0;n=Q(19,l|0,n|0)|0;m=x[23420];x[23420]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;xb(k);S(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;xb(k);hb=k+16|0}function Eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=hb-16|0;hb=l;k=hb-32|0;hb=k;h=k+28|0;f=k+24|0;g=hb-16|0;hb=g;a:{b:{if(!uc(b,x[gc(g+8|0,Kf(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=ud(b);m=z[j>>1];j=x[j+4>>2];if(!Vk(e,i,m,j)){break b}}x[g+8>>2]=b;e=gc(g,Db(x[a>>2]));c:{f=x[g+8>>2];if(!uc(f,x[e>>2])){f=x[fz(g+8|0)>>2];e=ud(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!Vk(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=ez(a,h,e,i);break a}if(Vk(m,j,e,i)){d:{f=dz(b);if(!uc(f,x[gc(g+8|0,Kf(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=ud(f);if(!Vk(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=ez(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}hb=g+16|0;f=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;g=ic(a);h=k+8|0;e=rh(h,wc(36),sh(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;Zj(g+8|0,d);o=ic(e),p=1,v[o+4|0]=p;hb=b+16|0;Yg(a,x[k+28>>2],f,x[k+8>>2]);b=Zd(h);cO(h);n=1}Xg(l,x[gc(k+8|0,b)>>2],n);hb=k+32|0;if(!y[ic(l)|0]){a=ud(x[l>>2])+8|0;bO(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Fb(d);o=Fb(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[gc(l+8|0,x[l>>2])>>2];hb=l+16|0;return a|0}function Uia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=G(f)-G(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;jb=a-D(b,c)|0;kb=0;lb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}jb=a;kb=e&g;a=e>>>Via(f)|0;lb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(G(c)+33|0)-G(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}jb=0;a=(e>>>0)/(f>>>0)|0;kb=e-D(a,f)|0;lb=0;return a}e=G(f)-G(e)|0;if(e>>>0<31){break d}break b}jb=a&f;kb=0;if((c|0)==1){break a}d=a;c=Via(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}lb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}jb=k;kb=f;e=b<<1|a>>>31;a=l|a<<1;lb=e|j;return a}jb=a;kb=b;a=0;b=0}lb=b;return a}function WZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-496|0;hb=a;g=a+488|0;ad(g,d);x[23420]=0;m=T(1086,g|0)|0;g=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=x[fj(f,0)>>2];x[23420]=0;h=Q(1104,m|0,45)|0;k=x[23420];x[23420]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Jb(a+456|0);g=Jb(a+440|0);h=Jb(a+424|0);x[23420]=0;la(1125,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}x[a+4>>2]=1073;c=le(a+8|0,0,a+4|0);j=Eb(f);l=x[a+420>>2];h:{if((j|0)>(l|0)){i=((Eb(h)+(j-l<<1)|0)+Eb(g)|0)+1|0;break h}i=(Eb(h)+Eb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Me(c,Ld(i<<2));j=x[c>>2];if(j){break e}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)==1){break d}p()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}o=x[d+4>>2];i=sc(f);f=Eb(f);x[23420]=0;oa(1126,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,x[a+476>>2],x[a+472>>2],k|0,g|0,h|0,l|0);f=x[23420];x[23420]=0;if((f|0)!=1){x[23420]=0;b=ka(1107,b|0,j|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break a}}}f=P()|0;Pc(c)}Jc(h);Jc(g);xb(k)}Zb(a+488|0);S(f|0);p()}Pc(c);Jc(h);Jc(g);xb(k);Zb(a+488|0);hb=a+496|0;return b|0}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=hb-16|0;hb=e;q=x[a+16>>2];r=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){j=x[a+8>>2];k=x[a+12>>2];f=x[a>>2];g=x[a+4>>2];i=0;break a}j=x[a+8>>2];k=x[a+12>>2];m=cg(j,k,l);n=lb;b=x[a+76>>2];f=x[a>>2];g=x[a+4>>2];Hf(f,g,$e(j,k,d),lb);i=b>>>0<lb>>>0?d:0}h=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=f;x[e+4>>2]=g;while(1){if(d){b=x[e+4>>2];f=x[e>>2];x[e+8>>2]=f;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);f=x[a+116>>2];if(!f){break b}o=((x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Kd(h,(g|0)/8<<16>>16);Jd(h,4);Rb(e+8|0,m,n);f=f-1|0;continue c}else{g=(v[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Kd(h,(g|0)/8<<16>>16);Jd(h,f);x[h>>2]=x[h>>2];x[h+4>>2]=0}f=x[c>>2];b=_f(h,r);x[c>>2]=f+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Rb(e,j,k);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){h=x[f+8>>2];o=((((x[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=w[e+14>>1];q=w[e+12>>1];r=w[e+10>>1];s=w[e+8>>1];t=w[e+6>>1];u=w[e+4>>1];v=w[e+2>>1];y=w[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;x[(h<<2)+f>>2]=(((((((D(w[e-8>>1],v)+D(w[e-12>>1],y)|0)+D(w[e-4>>1],u)|0)+D(w[e>>1],t)|0)+D(w[e+4>>1],s)|0)+D(w[e+8>>1],r)|0)+D(w[e+12>>1],q)|0)+D(w[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=f+16|0}function aJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;uf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}l=x[c+28>>2];if(We(x[c+24>>2],l)>>>0<f>>>0){break b}m=b+12|0;n=x[c+16>>2];o=x[c>>2];e:while(1){d=0;if((f|0)==(h|0)){break a}while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{j=Og(o,k,d,h);e=Cb(x[b>>2],d);i=fe(dg(C[j>>3])*134217728);j=e;e=(x[e>>2]>>1)+em(i)|0;q=e;e=hs(m)+e&-4096;x[j>>2]=q-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Xc(e);r=yn(n,l,d,h),s=e,w[r>>1]=s;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function KX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Kg(a,x[b+8>>2],e)){ew(b,c,d);return}a:{if(Kg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;bw(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;ur(x[h>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}ur(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}ur(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}ur(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function _Z(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=hb-192|0;hb=a;g=a+184|0;ad(g,d);x[23420]=0;m=T(18,g|0)|0;g=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Eb(f)){g=y[Xf(f,0)|0];x[23420]=0;h=Q(19,m|0,45)|0;k=x[23420];x[23420]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Jb(a+160|0);g=Jb(a+144|0);h=Jb(a+128|0);x[23420]=0;la(1123,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}x[a+4>>2]=1073;c=le(a+8|0,0,a+4|0);j=Eb(f);l=x[a+124>>2];h:{if((j|0)>(l|0)){i=((Eb(h)+(j-l<<1)|0)+Eb(g)|0)+1|0;break h}i=(Eb(h)+Eb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Me(c,Ld(i));j=x[c>>2];if(j){break e}x[23420]=0;Z(1074);b=x[23420];x[23420]=0;if((b|0)==1){break d}p()}f=P()|0;break b}f=P()|0;break b}f=P()|0;break c}o=x[d+4>>2];i=Ic(f);f=Eb(f);x[23420]=0;oa(1124,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,v[a+175|0],v[a+174|0],k|0,g|0,h|0,l|0);f=x[23420];x[23420]=0;if((f|0)!=1){x[23420]=0;b=ka(14,b|0,j|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break a}}}f=P()|0;Pc(c)}xb(h);xb(g);xb(k)}Zb(a+184|0);S(f|0);p()}Pc(c);xb(h);xb(g);xb(k);Zb(a+184|0);hb=a+192|0;return b|0}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=hb-16|0;hb=f;q=x[a+16>>2];r=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);n=x[a+128>>2];a:{if(!n){l=x[a+8>>2];m=x[a+12>>2];e=x[a>>2];b=x[a+4>>2];h=0;break a}l=x[a+8>>2];m=x[a+12>>2];o=cg(l,m,n);p=lb;h=x[a+76>>2];e=x[a>>2];b=x[a+4>>2];Hf(e,b,$e(l,m,d),lb);h=h>>>0<lb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[f>>2]=e;x[f+4>>2]=b;b:while(1){if(d){d=d-1|0;x[f+8>>2]=e;x[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Rb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){k=(x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31;Kd(g,(w[(k<<1|2)+e>>1]+w[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;e=_f(g,r);x[c>>2]=D(j>>12,e)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(e,i>>12);Rb(f,l,m);c=c+8|0;e=x[f>>2];b=x[f+4>>2];continue b}else{k=(x[f+12>>2]&2147483647)<<1|x[f+8>>2]>>>31;Kd(g,(w[(k<<1|2)+e>>1]+w[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Jd(g,4);Rb(f+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=e;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=f+16|0}function VI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;uf(c+48|0,c+32|0,f);a=x[d+4>>2];g=x[a+8>>2];j=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;f=c+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=j>>>0){if(A[f+4>>2]<j>>>0){break d}if(A[c+8>>2]<g>>>0){break c}if(We(x[f+8>>2],x[f+12>>2])>>>0<g>>>0){break b}m=b+12|0;n=x[c>>2];e:while(1){d=0;if((g|0)==(h|0)){break a}while(1)if((d|0)==(j|0)){h=h+1|0;continue e}else{k=Og(n,l,d,h);e=Cb(x[b>>2],d);i=fe(dg(C[k>>3])*134217728);k=e;e=(x[e>>2]>>1)+em(i)|0;o=e;e=hs(m)+e&-4096;x[k>>2]=o-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;i=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}e=Xc(e);q=xn(f,d,h),r=e,w[q>>1]=r;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function H_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=hb-384|0;hb=f;x[f+376>>2]=37;x[f+380>>2]=0;h=Br(f+376|1,21473,x[c+4>>2]);x[f+332>>2]=f+336;a=Ad();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Mg(f+336|0,30,a,f+376|0,f+32|0);break a}C[f+48>>3]=e;g=Mg(f+336|0,30,a,f+376|0,f+48|0)}x[f+80>>2]=1073;i=le(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Ad();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Si(f+332|0,a,f+376|0,f);break f}C[f+16>>3]=e;g=Si(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)==1){break d}break e}a=x[f+332>>2];Me(i,a)}j=a+g|0;l=Ti(a,j,c);x[f+68>>2]=1073;h=le(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Ld(g<<3);if(!g){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break e}a=P()|0;break g}Me(h,g);b=a}a=f+56|0;ad(a,c);x[23420]=0;ia(1106,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23420];x[23420]=0;i:{if((a|0)!=1){Zb(f+56|0);x[23420]=0;a=ka(1107,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break i}Pc(h);Pc(i);hb=f+384|0;break b}a=P()|0;Zb(f+56|0);break g}a=P()|0}Pc(h);break c}p()}a=P()|0}Pc(i);S(a|0);p()}return a|0}function R_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=hb-208|0;hb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Br(f+200|1,21473,x[c+4>>2]);x[f+156>>2]=f+160;a=Ad();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=Mg(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=Mg(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1073;i=le(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Ad();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=Si(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=Si(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Me(i,a)}j=a+g|0;l=Ti(a,j,c);x[f+68>>2]=1073;h=le(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Ld(g<<1);if(!g){x[23420]=0;Z(1074);a=x[23420];x[23420]=0;if((a|0)!=1){break e}a=P()|0;break g}Me(h,g);b=a}a=f+56|0;ad(a,c);x[23420]=0;ia(1101,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[23420];x[23420]=0;i:{if((a|0)!=1){Zb(f+56|0);x[23420]=0;a=ka(14,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break i}Pc(h);Pc(i);hb=f+208|0;break b}a=P()|0;Zb(f+56|0);break g}a=P()|0}Pc(h);break c}p()}a=P()|0}Pc(i);S(a|0);p()}return a|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){h=x[f+8>>2];o=(((x[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=w[e+14>>1];q=w[e+12>>1];r=w[e+10>>1];s=w[e+8>>1];t=w[e+6>>1];u=w[e+4>>1];y=w[e+2>>1];z=w[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;x[(h<<2)+f>>2]=(((((((D(v[e-4|0],y)+D(v[e-6|0],z)|0)+D(v[e-2|0],u)|0)+D(v[e|0],t)|0)+D(v[e+2|0],s)|0)+D(v[e+4|0],r)|0)+D(v[e+6|0],q)|0)+D(v[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;x[c>>2]=x[c>>2]+D(x[f>>2],k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=f+16|0}function sF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return b|0}function X9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=hb-16|0;hb=l;x[l+8>>2]=b;q=yf(a);while(1){if(zg(b,c)){b=x[gc(l,q)>>2];k=ud(x[l+8>>2]);o=hb-16|0;hb=o;p=0;m=hb-16|0;hb=m;i=hb-32|0;hb=i;g=i+28|0;d=i+24|0;e=hb-16|0;hb=e;a:{b:{if(!uc(b,x[gc(e+8|0,Kf(a))>>2])){f=y[k|0];j=x[k+4>>2];h=ud(b);n=y[h|0];h=x[h+4>>2];if(!Kn(f,j,n,h)){break b}}x[e+8>>2]=b;f=gc(e,Db(x[a>>2]));c:{d=x[e+8>>2];if(!uc(d,x[f>>2])){d=x[fz(e+8|0)>>2];f=ud(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!Kn(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=Hy(a,g,f,j);break a}if(Kn(n,h,f,j)){d:{d=dz(b);if(!uc(d,x[gc(e+8|0,Kf(a))>>2])){f=y[k|0];j=x[k+4>>2];h=ud(d);if(!Kn(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=Hy(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}hb=e+16|0;d=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;e=ic(a);g=i+8|0;e=rh(g,wc(28),sh(b+8|0,e));Qz(x[e>>2]+16|0,k);r=ic(e),s=1,v[r+4|0]=s;hb=b+16|0;Yg(a,x[i+28>>2],d,x[i+8>>2]);b=Zd(g);cl(g);p=1}Xg(m+8|0,x[gc(i+8|0,b)>>2],p);hb=i+32|0;hb=m+16|0;gc(o+8|0,x[m+8>>2]);hb=o+16|0;b=x[Wg(l+8|0)>>2];continue}else{hb=l+16|0}break}}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=hb-288|0;hb=f;Df(b);a:{if(!Nb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=f+32|0;gn(f+8|0,d,fq(d));k=x[a>>2];g=x[a+8>>2];d=hb-32|0;hb=d;Lg(d+16|0,x[f+8>>2],x[f+12>>2]);e=x[x[k>>2]+28>>2];l=x[d+20>>2];x[d+8>>2]=x[d+16>>2];x[d+12>>2]=l;mb[e|0](d+24|0,k,g,d+8|0);Lg(f+16|0,x[d+24>>2],x[d+28>>2]);hb=d+32|0;x[f+28>>2]=x[f+20>>2];o=f,q=c-Eb(b)|0,x[o+4>>2]=q;d=x[Hb(f+28|0,f+4|0)>>2];if(!d){break a}v[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=ii(k,m,d);o=f,q=mh(b),x[o+16>>2]=q;e=x[Gf(f,d)>>2];g=hb-32|0;hb=g;x[g+24>>2]=e;o=g,q=Yd(b),x[o+8>>2]=q;h=$j(g+24|0,g+8|0);b:{c:{d=k;i=oi(d,l);if(!i){break c}if(!As(b,d)){e=Eb(b);j=Sc(b);d:{if(i>>>0<=j-e>>>0){j=sc(b);if((e|0)==(h|0)){break d}n=h+j|0;rj(i+n|0,n,e-h|0);break d}Sl(b,j,(e+i|0)-j|0,e,h,0,i);j=x[b>>2]}e=e+i|0;Kh(b,e);v[g+8|0]=0;sd(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}sd(e,d);d=d+1|0;e=e+1|0;continue}}d=Yf(g+8|0,d,l);h=Ic(d);i=Eb(d);x[23420]=0;fa(342,b|0,e|0,h|0,h+i|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){xb(d);break b}a=P()|0;xb(d);S(a|0);p()}Yd(b)}hb=g+32|0;$b(a,l-k|0);if(l>>>0>=m>>>0){continue}break}$b(a,1)}hb=f+288|0}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;pd(b,0);zo(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Ie(Ej(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Wb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+39696|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Wb(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);hb=e+16|0}function YP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=x[a>>2];e=ph(c,x[a+4>>2]);if(e>>>0<b>>>0){g=hb-32|0;hb=g;f=b-e|0;b=x[Fb(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=hb-16|0;hb=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<8);a=x[b+4>>2];e=x[b+8>>2];while(1){if((a|0)==(e|0)){kc(b);hb=b+16|0}else{Hz(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Fb(a);b=g+8|0;e=a;h=ph(x[a>>2],c)+f|0;c=hb-16|0;hb=c;x[c+12>>2]=h;d=hb-16|0;hb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Hb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=h>>>0){d=Oz(e);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;break b}Tc();p()}d=ph(x[e>>2],x[e+4>>2]);Jf(b+12|0,i);if(a){if(a>>>0>=16777216){ig();p()}c=wc(a<<8)}else{c=0}x[b>>2]=c;d=c+(d<<8)|0;x[b+8>>2]=d;x[b+4>>2]=d;j=yc(b),k=c+(a<<8)|0,x[j>>2]=k;a=hb-16|0;hb=a;x[a>>2]=x[b+8>>2];c=x[b+8>>2];x[a+8>>2]=b+8;x[a+4>>2]=c+(f<<8);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){Hz(c);c=x[a>>2]+256|0;x[a>>2]=c;continue}break}Id(a);hb=a+16|0;zd(e,b);e=x[b+4>>2];a=x[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;x[b+8>>2]=a;continue}break}a=x[b>>2];if(a){yc(b);Ib(a)}}hb=g+32|0;return}if(b>>>0<e>>>0){Nd(a,c+(b<<8)|0)}}function y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=hb-16|0;hb=i;if(Uh(a+44|0)){n=x[a+44>>2];j=Ec(n,0);k=Ec(n,1);n=x[a+56>>2];t=Ec(n,0);n=Ec(n,1);u=B[Cb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Hb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Hb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{ji(a,b,c,t,n,d)}break}}hb=i+16|0}function Y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=hb-2160|0;hb=b;Ox(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ba(8)|0;x[23420]=0;b=Q(54,b+96|0,10345)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+88>>2]=e;x[b+92>>2]=d;c=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=c;x[b+84>>2]=f;x[b+80>>2]=g;c=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=c;h=RI(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=LI(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=mb[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=fc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=Ms(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ba(8)|0;x[23420]=0;b=Q(54,b+96|0,7975)|0;c=x[23420];x[23420]=0;if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0);break b}hb=b+2160|0;return a|0}c=P()|0;ca(a|0)}S(c|0)}p()}function KV(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;if(!Ob(a,13496,4)){pd(b,32);zo(b);Th(d,1,a+4|0);c=d+16|0;Fc(c,d);ze(b+43|0,c);xb(c);w[b+30>>1]=y[a+19|0]<<2;tg(b+30|0,256);w[b+32>>1]=y[a+17|0];tg(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;tg(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);kk(b);v[b+38|0]=y[(y[a+79|0]&7)+39696|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}hb=d+32|0;return c|0}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=hb-48|0;hb=k;if(of(x[b>>2],x[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=Pf(x[b>>2],i);e=x[g>>2];if(Pb(e,x[g+4>>2])){n=k+24|0;e=Db(e);o=Db(x[Pf(x[b>>2],i)+4>>2]);f=BP(k,d);l=hb-16|0;hb=l;x[l+8>>2]=e;while(1){if(Pb(e,o)){j=hb-16|0;hb=j;if(!(y[e+5|0]|y[e+3|0]!=4)){g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);vg(g,0);v[e+3|0]=0}h=y[e+2|0];if(!(y[e+4|0]|(h|0)!=11)){g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);vg(g,0);v[e+2|0]=0;h=0}a:{b:{if(!y[e|0]){Ab(j+8|0,x[f>>2],z[f+14>>1]);if(Bb(x[x[j+8>>2]>>2],x[j+12>>2])){break b}h=y[e+2|0]}i=y[e+3|0];g=j+8|0;Ab(g,x[f>>2],z[f+14>>1]);vg(g,(i|0)==4|(h|0)==11);h=y[e+3|0];break a}h=y[e+3|0];g=y[e+2|0];if(!(h|(g|0)==11)){v[e+5|0]=0;h=4;v[e+3|0]=4;break a}if(g|(h|0)==4){break a}v[e+4|0]=0;v[e+2|0]=11}c:{d:{e:{if(!(!y[f+16|0]|h)){v[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(y[e+5|0]){break c}i=1;h=6}v[e+5|0]=h}v[f+16|0]=i}w[f+14>>1]=(z[f+14>>1]+1>>>0)%z[f+12>>1];hb=j+16|0;e=x[jk(l+8|0)>>2];continue}break}zP(n,f);hb=l+16|0;Je(n);Je(f)}m=m+1|0;continue}break}}zP(a,d);hb=k+48|0}function M9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=hb-16|0;hb=i;e=x[b+1298304>>2];if(!wd(e)){d=hb-16|0;hb=d;c=wc(12);x[23420]=0;e=T(863,c|0)|0;f=x[23420];x[23420]=0;a:{if((f|0)!=1){c=x[mf(d+8|0,e)>>2];hb=d+16|0;break a}a=P()|0;Ib(c);S(a|0);p()}x[i+8>>2]=c;c=b+1298304|0;d=i+8|0;vM(c,Zd(d));yy(d);e=x[c>>2]}f=hb-48|0;hb=f;c=f+16|0;lM(c,a);x[23420]=0;U(8,f+32|0,0,c|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){yb(f+16|0);m=f,n=Db(x[e>>2]),x[m+8>>2]=n;l=Db(x[e+4>>2]);c=0;e=0;d:{while(1){e:{h=x[f+8>>2];if(!Pb(h,l)){if(!e){break e}c=x[e+4>>2];if(!c){break e}x[23420]=0;W(c|0,e|0,b|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break e}break d}j=0;d=x[h>>2];if(x[d+32>>2]==x[a+16>>2]){j=x[d+36>>2]==x[a+20>>2]}x[23420]=0;R(864,f+16|0,d+8|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}g=hb-16|0;hb=g;k=f+16|0;ue(g+8|0,k);ue(g,f+32|0);d=rL(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);hb=g+16|0;xb(k);f:{if(!(!j|(d|0)!=0)){e=x[h>>2];c=3;break f}if((c|0)<2&j){e=x[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?x[h>>2]:e;c=d?1:c}Ce(f+8|0);continue}break}xb(f+32|0);hb=f+48|0;break b}e=P()|0;xb(f+32|0);break c}e=P()|0;yb(f+16|0)}S(e|0);p()}hb=i+16|0}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;uf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=hb-32|0;hb=a;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[c+20>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(We(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(e|0)){break a}while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{n=a,o=+(em(fe(dg(C[Og(m,h,d,b)>>3])*134217728))+hd(gs(k),21)|0)*7.450580596923828e-9,C[n+24>>3]=o;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);n=yn(l,i,d,b),q=g,w[n>>1]=q;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=hb-16|0;hb=h;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+72>>2];b=x[a+68>>2];o=b;p=b>>31;b=x[a+64>>2];q=b;r=b>>31;b=x[a+60>>2];s=b;t=b>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(q,r,e,e>>31);g=lb;f=Xb(f,-16777216,16776704);i=Wia(o,p,f,f>>31);e=i+e|0;f=lb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(x[h+12>>2]<<1)+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(w[e+4>>1],w[g+10>>1])+D(w[e+2>>1],w[g+8>>1])|0)+D(w[e+6>>1],w[g+12>>1])|0)+D(w[e+8>>1],w[g+14>>1])|0)/2|0)+((((D(w[e-4>>1],w[g+2>>1])+D(w[e-6>>1],w[g>>1])|0)+D(w[e-2>>1],w[g+4>>1])|0)+D(w[e>>1],w[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=Wia(e,e>>31,s,t);e=y+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Rb(h+8|0,u,v);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=h+16|0}function Dd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;x[a+480180>>2]=b;b=cq(a);Pz(d,b);e=x[d+12>>2];c=a+1074320|0;x[c>>2]=x[d+8>>2];x[c+4>>2]=e;c=x[d+4>>2];x[a+1074312>>2]=x[d>>2];x[a+1074316>>2]=c;Os(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;uy(a,4);e=hb+-64|0;hb=e;b=a+484344|0;Qs(b);f=ik(x[b>>2],x[b+4>>2]);c=Xx(e+8|0,b);x[23420]=0;U(769,b|0,f|0,c|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){Pk(c);hb=e- -64|0;break a}a=P()|0;Pk(c);S(a|0);p()}UO(a+484360|0);Df(a+1298308|0);oA(a+1298320|0);Df(a+1298332|0);c=Tb(d,0,64);b=BM(c);d=Gb(a+1298344|0,b);Gb(d+12|0,b+12|0);Gb(d+24|0,b+24|0);Gb(d+36|0,b+36|0);Gb(d+48|0,b+48|0);x[d+60>>2]=x[b+60>>2];zy(b);Gc(a+1298408|0);Gc(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}hb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=x[c>>2];if(e){Ib(St(e))}x[c>>2]=0;b=b+1|0;continue}}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;uf(c+48|0,c+32|0,e);a=x[d+4>>2];f=x[a+8>>2];h=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;e=c+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=h>>>0){if(A[e+4>>2]<h>>>0){break d}if(A[c+8>>2]<f>>>0){break c}if(We(x[e+8>>2],x[e+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];b=0;e:while(1){d=0;if((b|0)==(f|0)){break a}while(1)if((d|0)==(h|0)){b=b+1|0;continue e}else{m=a,n=+(em(fe(dg(C[Og(l,i,d,b)>>3])*134217728))+hd(gs(k),21)|0)*7.450580596923828e-9,C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);m=xn(e,d,b),o=g,w[m>>1]=o;d=d+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=c- -64|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=hb-16|0;hb=h;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];g=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=g;m=b+24|0;n=x[a+72>>2];b=x[a+68>>2];o=b;p=b>>31;b=x[a+64>>2];q=b;r=b>>31;b=x[a+60>>2];s=b;t=b>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(q,r,e,e>>31);g=lb;f=Xb(f,-16777216,16776704);i=Wia(o,p,f,f>>31);e=i+e|0;f=lb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=x[h+12>>2]+l|0;g=(((x[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((D(v[e+2|0],w[g+10>>1])+D(v[e+1|0],w[g+8>>1])|0)+D(v[e+3|0],w[g+12>>1])|0)+D(v[e+4|0],w[g+14>>1])<<8)/2|0)+((((D(v[e-2|0],w[g+2>>1])+D(v[e-3|0],w[g>>1])|0)+D(v[e-1|0],w[g+4>>1])|0)+D(v[e|0],w[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=Wia(e,e>>31,s,t);e=z+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Rb(h+8|0,u,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=h+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;h=hb-16|0;hb=h;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;o=x[a+32>>2];p=x[a+28>>2];q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];v=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(t,u,e,e>>31);k=lb;B=e;e=(x[h+12>>2]<<1)+n|0;g=x[h+8>>2]>>>21&2040;l=(((D(w[e>>1],w[g+39714>>1])+D(w[e-2>>1],w[g+39712>>1])|0)+D(w[e+2>>1],w[g+39716>>1])|0)+D(w[e+4>>1],w[g+39718>>1])|0)/16384<<8;e=l;m=Wia(e,e>>31,v,y);g=B+m|0;e=lb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Wia(r,s,f,f>>31);g=k+g|0;f=lb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+p|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+o|0;x[c+4>>2]=x[c+4>>2]+D(e,i>>12);Rb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=h+16|0}function V7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=hb-16|0;hb=h;if(!y[a+4242|0]){Kx(a);a:{if(!y[a+4240|0]){break a}e=iM(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;Cs(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Jx(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=si(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];JN(h+8|0,1);g=Oj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|ho(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],mb[j](k|0,l|0)|0;break f}mb[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];ji(g,b,c,Ec(a,0),Ec(a,1),d);hb=h+16|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(r,s,e,e>>31);h=lb;f=Xb(f,-16777216,16776704);k=Wia(p,q,f,f>>31);e=k+e|0;f=lb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=x[g+12>>2]+l|0;h=x[g+8>>2]>>>21&2040;h=(((D(v[e|0],w[h+39714>>1])+D(v[e-1|0],w[h+39712>>1])|0)+D(v[e+1|0],w[h+39716>>1])|0)+D(v[e+2|0],w[h+39718>>1])<<8)/16384<<8;e=h;k=Wia(e,e>>31,t,u);e=A+k|0;f=lb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+n|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Rb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=hb-16|0;hb=e;o=x[a+16>>2];p=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){j=x[a+8>>2];k=x[a+12>>2];f=x[a>>2];g=x[a+4>>2];i=0;break a}j=x[a+8>>2];k=x[a+12>>2];m=cg(j,k,l);n=lb;b=x[a+76>>2];f=x[a>>2];g=x[a+4>>2];Hf(f,g,$e(j,k,d),lb);i=b>>>0<lb>>>0?d:0}h=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=f;x[e+4>>2]=g;b:while(1){if(d){b=x[e+4>>2];f=x[e>>2];x[e+8>>2]=f;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Rb(h,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){g=(x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31;Kd(h,(w[(g<<1|2)+f>>1]+w[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Jd(h,b);x[h>>2]=x[h>>2];x[h+4>>2]=0}f=x[c>>2];b=_f(h,p);x[c>>2]=f+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Rb(e,j,k);c=c+8|0;continue b}else{g=(x[e+12>>2]&2147483647)<<1|x[e+8>>2]>>>31;Kd(h,(w[(g<<1|2)+f>>1]+w[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Jd(h,4);Rb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function tG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=hb-16|0;hb=k;f=y[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Ak(f<<24>>24)){break b}f=y[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|y[g|0]!=48)){n=1;if((y[g+1|0]&223)==88){g=g+2|0;l=16;break d}g=g+1|0;l=c?c:8;break d}l=c?c:10}c=0;while(1){e:{f=-48;i=v[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(l|0)){break e}lf(k,l,0,0,0,j,h,0,0);f=1;g:{if(x[k+8>>2]|x[k+12>>2]){break g}o=Wia(j,h,l,0);p=lb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;f=i+o|0;h=f>>>0<i>>>0?h+1|0:h;j=f;n=1;f=c}g=g+1|0;c=f;continue}break}if(b){x[b>>2]=n?g:a}h:{i:{j:{if(c){x[115896]=68;a=d&1;m=a?0:m;j=d;h=e;break j}if((e|0)==(h|0)&d>>>0>j>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){x[115896]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=j>>>0|e>>>0>h>>>0){break i}x[115896]=68;break h}a=m;b=a^j;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}hb=k+16|0;lb=e;return d}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){h=x[f+8>>2];m=((((x[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=w[e+14>>1];o=w[e+12>>1];p=w[e+10>>1];q=w[e+8>>1];r=w[e+6>>1];s=w[e+4>>1];t=w[e+2>>1];u=w[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;x[(h<<2)+f>>2]=(((((((D(w[e-8>>1],t)+D(w[e-12>>1],u)|0)+D(w[e-4>>1],s)|0)+D(w[e>>1],r)|0)+D(w[e+4>>1],q)|0)+D(w[e+8>>1],p)|0)+D(w[e+12>>1],o)|0)+D(w[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=hb-16|0;hb=i;x[i+8>>2]=b;o=yf(a);while(1){if(zg(b,c)){b=x[gc(i,o)>>2];j=ud(x[i+8>>2]);m=hb-16|0;hb=m;n=0;k=hb-16|0;hb=k;h=hb-32|0;hb=h;f=h+28|0;d=h+24|0;e=hb-16|0;hb=e;a:{b:{if(!uc(b,x[gc(e+8|0,Kf(a))>>2])){g=y[j|0];l=y[ud(b)|0];if(!Ln(g,l)){break b}}x[e+8>>2]=b;g=gc(e,Db(x[a>>2]));c:{d=x[e+8>>2];if(!uc(d,x[g>>2])){d=x[fz(e+8|0)>>2];l=y[ud(d)|0];g=y[j|0];if(!Ln(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=Iy(a,f,g);break a}if(Ln(l,g)){d:{d=dz(b);if(!uc(d,x[gc(e+8|0,Kf(a))>>2])){g=y[j|0];if(!Ln(g,y[ud(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=Iy(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}hb=e+16|0;d=b;b=x[b>>2];if(!b){b=hb-16|0;hb=b;e=ic(a);f=h+8|0;e=rh(f,wc(24),sh(b+8|0,e));TM(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=ic(e),q=1,v[p+4|0]=q;hb=b+16|0;Yg(a,x[h+28>>2],d,x[h+8>>2]);b=Zd(f);cl(f);n=1}Xg(k+8|0,x[gc(h+8|0,b)>>2],n);hb=h+32|0;hb=k+16|0;gc(m+8|0,x[k+8>>2]);hb=m+16|0;b=x[Wg(i+8|0)>>2];continue}else{hb=i+16|0}break}}function RR(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;a:{if((d&255)>>>0<=4){while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!cf(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!cf(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=cf(a,f+13|0);if(d){g=y[f+13|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!cf(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){d=cf(a,f+11|0);if(d){g=y[f+11|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!d){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}hb=f+16|0}function e_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-448|0;hb=a;x[a+432>>2]=c;x[a+440>>2]=b;x[a+20>>2]=1108;b=le(a+24|0,a+32|0,a+20|0);h=a+16|0;ad(h,e);x[23420]=0;h=T(1086,h|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23420]=0;c=pa(1116,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Se(g)){xd(x[g>>2],0);Sd(g,0);break d}xd(g,0);we(g,0)}if(y[a+15|0]){x[23420]=0;c=Q(1104,h|0,45)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[23420]=0;R(48,g|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}}x[23420]=0;d=Q(1104,h|0,48)|0;c=x[23420];x[23420]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[23420]=0;W(1121,g|0,c|0,e|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break c}break a}x[23420]=0;c=Q(1092,a+440|0,a+432|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+440>>2];Zb(a+16|0);Pc(b);hb=a+448|0;return c|0}}}c=P()|0;Zb(a+16|0);Pc(b);S(c|0);p()}function XU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=hb-32|0;hb=g;v[g+12|0]=0;m=wm(g+16|0,d,g+12|0);f=x[m>>2];x[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+8>>2]=y[a+1|0];i=a+2|0;j=Hb(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+12>>2]-1|0;x[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);hb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function MM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;f=D(b,872)+a|0;a:{if(c){Ab(g+8|0,a+1074312|0,90);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){v[(D(b,872)+a|0)+1075803|0]=c}v[(D(b,872)+a|0)+1075804|0]=c;break a}c=y[f+1075804|0]}f=f+1074992|0;h=c&255;i=0-h|0;e=a+480180|0;j=!(x[e>>2]&204473357)&(d^-1);HM(a,b,i,j);e=x[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}k=x[(D(b,872)+a|0)+1075648>>2];if(!k|!x[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){GM(x[a+1074392>>2],x[a+1074416>>2],f,240-h|0);break b}if(!(b>>>0<224|d)){FM(f,224-h|0);break b}EM(f,i);break b}x[(D(b,872)+a|0)+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&j)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}Ay(a,f,d);break b}if((e|0)==524288){break d}JM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break f}e=x[a+480180>>2]}if(e&32832){break f}if(!(x[a+480208>>2]&2)|(e|0)!=8){break b}}Qj(a,f,(D(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}hb=g+16|0}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=hb-32|0;hb=j;e=b;b=x[a>>2];f=D(Is(e,Db(b)),6)+b|0;a:{if(!c){break a}b=x[Fb(a)>>2];g=x[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){RA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=hb-16|0;hb=k;m=x[a+4>>2];h=D((m-(D(c,6)+f|0)|0)/6|0,6)+f|0;l=mq(k,a,(g-h|0)/6|0);i=x[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){kc(l);if((f|0)!=(h|0)){e=h-f|0;Ji(m+D((e|0)/-6|0,6)|0,f,e)}hb=k+16|0}else{Yt(i,e);i=i+6|0;x[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=D(e>>>0<=d>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[e|0]=c;v[e+1|0]=c>>>8;v[e+2|0]=c>>>16;v[e+3|0]=c>>>24;c=y[a+4|0]|y[a+5|0]<<8;v[e+4|0]=c;v[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Fb(a);e=NS(j+8|0,LA(a,ck(x[a>>2],g)+c|0),(f-x[a>>2]|0)/6|0,b);MS(e,c,d);b=x[e+4>>2];d=e+4|0;KS(x[a>>2],f,d);h=x[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){Yt(x[c>>2],f);x[c>>2]=x[c>>2]+6;f=f+6|0;continue}break}nc(a,d);nc(a+4|0,c);nc(Fb(a),yc(e));x[e>>2]=x[e+4>>2];f=b;LS(e)}Db(f);hb=j+32|0}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=hb-1072|0;hb=d;x[d+1068>>2]=c;o=d,q=Ee(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[_e(c,d+4|0)|0];f=qB(c,b);l=kq(f);x[23420]=0;c=T(190,b|0)|0;e=x[23420];x[23420]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;xc(d+1068|0,x[Hb(d+4|0,d)>>2]<<3);x[23420]=0;m=x[d+1068>>2];k=Q(321,a|0,m|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;c=8;h=Q(152,f|0,8)|0;a=x[23420];x[23420]=0;b:{if((a|0)!=1){c:{o=Kb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[23420]=0;j=Q(152,f|0,c|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Kb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=kq(f);x[23420]=0;Q(143,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}}c=P()|0;dc(k);break a}zb(f);hb=d+1072|0;return}c=P()|0;break a}c=P()|0}zb(f);S(c|0);p()}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1058;x[d+12>>2]=2;c=hb+-64|0;hb=c;h=x[d+8>>2]&2?16:10;f=hb-32|0;hb=f;e=Qe(f+16|0,1,0);a:{b:{c:{while(1){g=sc(e);cI(f+8|0,g,Eb(e)+g|0,x[b>>2],h);if(!x[f+12>>2]){break c}g=If(Eb(e));x[23420]=0;R(58,e|0,g|0);g=x[23420];x[23420]=0;if((g|0)!=1){continue}break}break b}b=x[f+8>>2];h=sc(e);x[23420]=0;R(59,e|0,b-h|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(60,c|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(e);hb=f+32|0;break a}a=P()|0;xb(e);S(a|0);p()}b=c+16|0;ds(b,c,x[d+8>>2]);e=x[d+12>>2];f=x[d+8>>2];x[23420]=0;X(73,c+32|0,b|0,f|0,e|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[d+24|0];e=x[d+20>>2];x[23420]=0;X(74,c+48|0,c+32|0,e|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(57,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);S(a|0);p()}hb=d+32|0}function VA(a,b){a:{b:{switch((y[a+3|0]|64)+-64|0){case 0:v[a+3|0]=y[a+5|0]?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(b){break a}b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=b?32:31;return;case 29:v[a+3|0]=b?33:0;return;case 27:v[a+3|0]=b?34:0;return;case 30:v[a+3|0]=b?35:0;return;case 31:v[a+3|0]=b?36:0;return;case 50:v[a+3|0]=b?25:0;return;case 51:v[a+3|0]=b?30:0;return;default:break b}}v[a+3|0]=0}}function Nt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;v[d+24|0]=44;x[d+16>>2]=-1;x[d+20>>2]=0;x[d+8>>2]=1058;x[d+12>>2]=2;c=hb+-64|0;hb=c;h=x[d+8>>2]&2?16:10;f=hb-32|0;hb=f;e=Qe(f+16|0,1,0);a:{b:{c:{while(1){g=sc(e);eI(f+8|0,g,Eb(e)+g|0,y[b|0],h);if(!x[f+12>>2]){break c}g=If(Eb(e));x[23420]=0;R(58,e|0,g|0);g=x[23420];x[23420]=0;if((g|0)!=1){continue}break}break b}b=x[f+8>>2];h=sc(e);x[23420]=0;R(59,e|0,b-h|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(60,c|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(e);hb=f+32|0;break a}a=P()|0;xb(e);S(a|0);p()}b=c+16|0;ds(b,c,x[d+8>>2]);e=x[d+12>>2];f=x[d+8>>2];x[23420]=0;X(73,c+32|0,b|0,f|0,e|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[d+24|0];e=x[d+20>>2];x[23420]=0;X(74,c+48|0,c+32|0,e|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(57,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);S(a|0);p()}hb=d+32|0}function o2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=hb+-64|0;hb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;uf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=hb-32|0;hb=a;a:{b:{c:{d:{h=x[b+4>>2];if(h>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(We(x[b+24>>2],i)>>>0<d>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){c=0;if((d|0)==(f|0)){break a}while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{m=a,n=C[Og(l,h,c,f)>>3],C[m+24>>3]=n;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);m=yn(k,i,c,f),o=g,w[m>>1]=o;c=c+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=b- -64|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);i=x[a+44>>2];h=Ec(i,0);i=Ec(i,1);j=x[a+56>>2];n=Ec(j,0);j=Ec(j,1);k=a+4208|0;g=vc(x[k>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){Pj(k,e)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;v=Cb(k,g);f=B[Cb(k,g|1)>>2];s=B[h>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;w=Cb(k,g),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=Cb(k,g|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;ah(e,e+h|0,n);ah(i,i+h|0,j)}h=a;a=x[a+56>>2];ji(h,b,c,Ec(a,0),Ec(a,1),d)}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){h=x[f+8>>2];m=(((x[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=w[e+14>>1];o=w[e+12>>1];p=w[e+10>>1];q=w[e+8>>1];r=w[e+6>>1];s=w[e+4>>1];t=w[e+2>>1];u=w[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;x[(h<<2)+f>>2]=(((((((D(v[e-4|0],t)+D(v[e-6|0],u)|0)+D(v[e-2|0],s)|0)+D(v[e|0],r)|0)+D(v[e+2|0],q)|0)+D(v[e+4|0],p)|0)+D(v[e+6|0],o)|0)+D(v[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function Dn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-80|0;hb=c;g=Qb(a);a=x[b+24>>2];a:{b:{if(jj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(jj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=$L(DR(c+40|0,1),f&255,0,0);x[23420]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;X(995,c- -64|0,a|0,0,c+8|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}j=c,k=Db(x[c+64>>2]),x[j+32>>2]=k;d=Db(x[c+68>>2]);while(1){a=x[c+32>>2];if(!Pb(a,d)){f=f+1|0;ui(c- -64|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[23420]=0;R(1012,g|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){uz(c+32|0);continue}break}break}a=P()|0;ui(c- -64|0);break b}hb=c+80|0;return}a=P()|0;break b}b=ba(8)|0;x[23420]=0;d=Q(54,c+40|0,7228)|0;a=x[23420];x[23420]=0;if((a|0)!=1){a=rc(b,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}a=P()|0;ca(b|0)}Vf(g);S(a|0)}p()}function oE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=1058;x[e+12>>2]=c;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Qe(f+16|0,1,0);a:{b:{c:{while(1){h=sc(d);fx(f+8|0,h,Eb(d)+h|0,x[b>>2],i);if(!x[f+12>>2]){break c}h=If(Eb(d));x[23420]=0;R(58,d|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=sc(d);x[23420]=0;R(59,d|0,b-i|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(60,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);S(a|0);p()}b=c+16|0;ds(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23420]=0;X(73,c+32|0,b|0,f|0,d|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23420]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(57,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}xb(c+48|0);xb(c+32|0);xb(c+16|0);xb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;xb(c+48|0)}xb(c+32|0)}xb(c+16|0);xb(c);S(a|0);p()}hb=e+32|0}function NM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;f=D(b,872)+a|0;a:{if(c){Ab(g+8|0,a+1074312|0,90);if(!Bb(x[x[g+8>>2]>>2],x[g+12>>2])){v[(D(b,872)+a|0)+1075804|0]=c}v[(D(b,872)+a|0)+1075803|0]=c;break a}c=y[f+1075803|0]}f=f+1074992|0;h=c&255;e=a+480180|0;i=!(x[e>>2]&204473357)&(d^-1);HM(a,b,h,i);e=x[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}j=x[(D(b,872)+a|0)+1075648>>2];if(!j|!x[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){GM(x[a+1074392>>2],x[a+1074416>>2],f,h-240|0);break b}if(!(b>>>0<224|d)){FM(f,h-224|0);break b}EM(f,h);break b}x[(D(b,872)+a|0)+1075700>>2]=1}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}By(a,f,d);break b}if((e|0)==524288){break d}IM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break f}if(x[a+1074416>>2]==1){Ab(g+8|0,a+1074312|0,6);if(Bb(x[x[g+8>>2]>>2],x[g+12>>2])){break f}e=x[a+480180>>2]}if(e&32832){break f}if(!(x[a+480208>>2]&2)|(e|0)!=8){break b}}Qj(a,f,(D(b,872)+a|0)+1075692|0,h<<2,0)}hb=g+16|0}
function or(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Qe(f+16|0,1,0);a:{b:{c:{while(1){h=sc(d);fx(f+8|0,h,Eb(d)+h|0,x[b>>2],i);if(!x[f+12>>2]){break c}h=If(Eb(d));x[23420]=0;R(58,d|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=sc(d);x[23420]=0;R(59,d|0,b-i|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(71,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);S(a|0);p()}b=c+16|0;$r(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23420]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23420]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(70,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);p()}hb=e+32|0}function Sv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Qe(f+16|0,1,0);a:{b:{c:{while(1){h=sc(d);cI(f+8|0,h,Eb(d)+h|0,x[b>>2],i);if(!x[f+12>>2]){break c}h=If(Eb(d));x[23420]=0;R(58,d|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=sc(d);x[23420]=0;R(59,d|0,b-i|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(71,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);S(a|0);p()}b=c+16|0;$r(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23420]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23420]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(70,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);p()}hb=e+32|0}function Xv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[e+24|0]=44;x[e+16>>2]=-1;x[e+20>>2]=0;x[e+8>>2]=c;x[e+12>>2]=d;c=hb+-64|0;hb=c;g=e+8|0;i=x[g>>2]&2?16:10;f=hb-32|0;hb=f;d=Qe(f+16|0,1,0);a:{b:{c:{while(1){h=sc(d);eI(f+8|0,h,Eb(d)+h|0,y[b|0],i);if(!x[f+12>>2]){break c}h=If(Eb(d));x[23420]=0;R(58,d|0,h|0);h=x[23420];x[23420]=0;if((h|0)!=1){continue}break}break b}b=x[f+8>>2];i=sc(d);x[23420]=0;R(59,d|0,b-i|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(71,c|0,d|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(d);hb=f+32|0;break a}a=P()|0;xb(d);S(a|0);p()}b=c+16|0;$r(b,c,x[g>>2]);d=x[g+4>>2];f=x[g>>2];x[23420]=0;X(75,c+32|0,b|0,f|0,d|0);b=x[23420];x[23420]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=y[g+16|0];d=x[g+12>>2];x[23420]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break i}x[23420]=0;R(70,a|0,c+48|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);hb=c- -64|0;break e}a=P()|0;break f}a=P()|0;break g}a=P()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);p()}hb=e+32|0}function a7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!Uh(a+44|0)){break a}f=x[a+44>>2];l=Ec(f,0);m=Ec(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Ec(f,0);o=q;r=Ec(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=Cb(k,f);g=B[l>>2];B[h>>2]=g;y=Cb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(zK(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[Cb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[Cb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{ji(a,b,c,q,r,d)}break}}}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb+-64|0;hb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;uf(b+48|0,b+32|0,d);a=x[c+4>>2];e=x[a+8>>2];h=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=b+16|0;a=hb-32|0;hb=a;a:{b:{c:{d:{i=x[b+4>>2];if(i>>>0>=h>>>0){if(A[d+4>>2]<h>>>0){break d}if(A[b+8>>2]<e>>>0){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}k=x[b>>2];e:while(1){c=0;if((e|0)==(f|0)){break a}while(1)if((c|0)==(h|0)){f=f+1|0;continue e}else{l=a,m=C[Og(k,i,c,f)>>3],C[l+24>>3]=m;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=fe(C[yg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);l=xn(d,c,f),n=g,w[l>>1]=n;c=c+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=a+32|0;hb=b- -64|0}function F7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=hb+-64|0;hb=b;g=Qb(a);x[23420]=0;Y(865,g|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){a=44560;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==44872){hb=b- -64|0;return g|0}k:{h=Ks(44);if(h){d=x[a>>2];e=x[a+4>>2];x[23420]=0;e=Q(54,b+32|0,e|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break k}x[23420]=0;R(866,b+48|0,e|0);c=x[23420];x[23420]=0;if((c|0)==1){break j}c=x[a+8>>2];x[23420]=0;c=Q(54,b|0,c|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break i}x[23420]=0;R(866,b+16|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break h}x[23420]=0;d=fa(867,h|0,d|0,b+48|0,b+16|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break g}Sb(b+16|0);xb(c);Sb(b+48|0);xb(e);x[b+60>>2]=d;x[23420]=0;R(868,g|0,b+60|0);e=x[23420];x[23420]=0;if((e|0)==1){break b}x[d+32>>2]=x[a+12>>2];x[d+36>>2]=x[a+16>>2];v[d+40|0]=y[a+20|0];v[d+41|0]=y[d+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;break c}a=P()|0;break d}a=P()|0;break e}a=P()|0;break f}a=P()|0;Sb(b+16|0)}xb(c)}Sb(b+48|0)}xb(e)}Ib(h);break a}a=P()|0;break a}a=P()|0}tc(g);S(a|0);p()}function SH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){Hk(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Ll(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}ec(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}ec(a,21);return 0}aa(7470,13048,1887,6512);p()}function wM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=hb-32|0;hb=g;b=mt(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;hb=g+32|0;f=f+1|0;continue}break}}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=hb-16|0;hb=g;f=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(r,s,e,e>>31);i=lb;f=Xb(f,-16777216,16776704);h=Wia(p,q,f,f>>31);e=h+e|0;f=lb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=x[g+12>>2]+l|0;e=v[h|0];z=i;i=((D(v[h+1|0]-e|0,x[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Wia(e,e>>31,t,u);e=z+h|0;f=lb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;k=k+n|0;x[c>>2]=D(e,k>>12)+x[c>>2];j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,e);Rb(g+8|0,w,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;hb=g+16|0}function zN(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=Wia(c,c>>31,5e4,0);e=lb;b=x[Yc(d+12|0,d+8|0)>>2];c=Hc(Xia(c,e,b,b>>31),lb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=Wia(c,c>>31,1e4,0);e=lb;b=x[Yc(d+12|0,d+8|0)>>2];c=Hc(Xia(c,e,b,b>>31),lb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(Wia(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(lb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!oe(c,x[a+484348>>2],e)){break d}c=_b(c,e);if(!Pb(x[c+24>>2],x[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!uc(e,c)){f=f*+A[Cb(e,A[b+48>>2]%(vc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=Wia(x[a+480244>>2],0,c,0)+32768|0;a=lb;a=b>>>0<32768?a+1|0:a;a=Vc((a&65535)<<16|b>>>16,a>>>16|0);hb=d+16|0;return a?a:1}function K8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);h=w[d>>1];j=w[d+2>>1];a:{if((h|0)>(j|0)){break a}k=x[b>>2];g=vc(k,x[b+4>>2]);if(!g){break a}i=w[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Cb(k,f);f=f+1|0;if(!(B[i>>2]<E(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=h;w[a>>1]=1;m=a,n=pL(g),w[m+30>>1]=n;B[a+32>>2]=F(l);Pj(a+4|0,(j-h|0)+1|0);ah(Db(x[b>>2]),Db(x[b+4>>2]),hm(Db(x[a+4>>2]),w[e>>1]-w[d>>1]|0));c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Cb(c,b+g|0);m=Cb(c,b),o=E(B[j>>2]/B[a+32>>2]),B[m>>2]=o;b=w[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Cb(b,f-h|0);m=Cb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{np(a)}break}}break}f=1}return f|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-48|0;hb=d;i=a+484344|0;j=a+480280|0;while(1){a:{if(Nb(x[b>>2],x[b+8>>2],9)){e=d+44|0;mo(b,e);c=pg(b);b:{if(!Ob(e,13840,4)){break b}if(!Ob(d+44|0,13496,4)){break b}if(!Ob(d+44|0,13672,4)){break b}if(!Ob(d+44|0,13677,4)){break b}if(Nb(x[b>>2],x[b+8>>2],c)){break a}}mg(b,8)}hb=d+48|0;return k|0}Xd(d,b,c);e=jc(d+24|0,d);zb(d);c=j;c:{d:{e:{if(!Ob(d+44|0,13407,4)){while(1){if((c|0)==(i|0)){break c}x[23420]=0;f=T(145,e|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break e}v[c+8|0]=f;c=c+32|0;continue}}if(y[d+44|0]!=70){break d}f=y[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=v[d+46|0];if((c|0)>47){break f}break d}c=v[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=v[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:D(f,100)+48|0)|0)+D(c,10)&255;if(c>>>0>249){break c}x[23420]=0;R(386,e|0,(D(c,160)+a|0)+906300|0);c=x[23420];x[23420]=0;if((c|0)!=1){break c}}a=P()|0;zb(e);S(a|0);p()}if(Ob(d+44|0,13423,4)){break c}x[a+1074308>>2]=0;k=1}zb(e);continue}}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=hb-16|0;hb=g;f=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(r,s,e,e>>31);i=lb;f=Xb(f,-16777216,16776704);h=Wia(p,q,f,f>>31);e=h+e|0;f=lb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(x[g+12>>2]<<1)+l|0;e=w[h>>1];z=i;i=e+((D(w[h+2>>1]-e|0,x[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Wia(e,e>>31,t,u);e=z+h|0;f=lb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;k=k+n|0;x[c>>2]=D(e,k>>12)+x[c>>2];j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,e);Rb(g+8|0,v,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=j>>12;hb=g+16|0}function Ry(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;f=a+1074312|0;Ab(e+8|0,f,77);a:{if(j=Bb(x[x[e+8>>2]>>2],x[e+12>>2]),k=0,l=x[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=y[c+841|0];if(!g){break c}d=g-1|0;v[c+841|0]=d;if(d&255){break b}Ab(e+8|0,f,16);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])&x[a+480180>>2]!=2){break a}a=x[b+48>>2]+1|0}else{a=x[b+48>>2]}x[c+764>>2]=a;break a}Ab(e+8|0,f,17);d:{if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480180>>2]&3){break d}g=b+616|0;i=z[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(y[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}v[c+841|0]=d}d=x[c+764>>2];x[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(x[b+60>>2]==-1){break f}Ab(e+8|0,f,68);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break f}x[b+60>>2]=d}x[b+64>>2]=d;Ab(e+8|0,f,103);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break e}w[b+68>>1]=65535}if(x[a+480180>>2]!=2){break a}d=z[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=D(a,872)+b|0;x[f+1380>>2]=x[c+764>>2];v[f+1457|0]=y[c+841|0];a=a+1|0;continue}}hb=e+16|0}function MH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;b=4;f=4;e=2;while(1){g=b;b=(b+f|0)+4|0;x[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;f=g;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){f=0;e=1;h=0;b=1;g=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Uw(a,c,b,d+16|0);Yr(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(A[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Xr(a,c,e,x[d+12>>2],b,0,d+16|0);break d}Uw(a,c,b,d+16|0)}if((b|0)==1){Wr(d+8|0,1);b=0;break c}Wr(d+8|0,g);b=1}g=x[d+8>>2];e=g|1;x[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}h=g>>>0>1;f=x[d+12>>2];g=(f|0)!=0}Xr(a,c,e,f,b,0,d+16|0);if(!(g|((b|0)!=1|h))){break a}while(1){e:{if((b|0)<=1){g=EH(e,f);Yr(d+8|0,g);f=x[d+12>>2];e=x[d+8>>2];b=b+g|0;break e}e=d+8|0;Wr(e,2);x[d+8>>2]=x[d+8>>2]^7;Yr(e,1);f=a-4|0;h=d+16|0;g=b-2|0;Xr(f-x[h+(g<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],b-1|0,1,h);Wr(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;b=f;f=x[d+12>>2];Xr(b,c,e,f,g,1,h);b=g}a=a-4|0;if((b|0)!=1|(e|0)!=1|f){continue}break}}hb=d+208|0}function k_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=hb-160|0;hb=a;x[a+144>>2]=c;x[a+152>>2]=b;x[a+20>>2]=1108;b=le(a+24|0,a+32|0,a+20|0);h=a+16|0;ad(h,e);x[23420]=0;h=T(18,h|0)|0;i=x[23420];x[23420]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[23420]=0;c=pa(1109,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Df(g);if(y[a+15|0]){x[23420]=0;c=Q(19,h|0,45)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[23420]=0;R(46,g|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}}x[23420]=0;d=Q(19,h|0,48)|0;c=x[23420];x[23420]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[23420]=0;W(1115,g|0,c|0,e|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break c}break a}x[23420]=0;c=Q(1076,a+152|0,a+144|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+152>>2];Zb(a+16|0);Pc(b);hb=a+160|0;return c|0}}}c=P()|0;Zb(a+16|0);Pc(b);S(c|0);p()}function _n(a,b,c,d){var e=0;e=hb-16|0;hb=e;v[a+841|0]=0;x[a+708>>2]=0;v[a+797|0]=0;x[a+764>>2]=0;w[a+802>>1]=0;w[a+804>>1]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;Ab(e+8|0,b+1074312|0,23);if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;eo(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0;hb=e+16|0}function J7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=hb-32|0;hb=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=mb[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Hb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[23420]=0;R(272,e+4|0,b+4|0);b=x[23420];x[23420]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];ke(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=hb-16|0;hb=e;x[e+8>>2]=0;RK(b,e+8|0);hb=e+16|0;b=x[x[a>>2]+180>>2];x[23420]=0;R(b|0,a|0,-1);b=x[23420];x[23420]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+184>>2];x[23420]=0;Y(d|0,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[23420]=0;g=E(Ya(b|0,a|0,d|0));b=x[23420];x[23420]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;RK(c+16|0,c+8|0);continue}break}d=V(91780)|0;break c}d=V(91780)|0;break c}d=V(91780)|0}if((ib|0)!=(da(91780)|0)){break a}_(d|0)|0;Gc(x[a+20>>2]+4|0);$()}hb=c+32|0;return}S(d|0);p()}function DQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-80|0;hb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;Bz(a,Cz(a),c+48|0);b=qc(c+40|0,14033);Xe(pe(a,0),x[b>>2],x[b+4>>2]);b=qc(c+32|0,14137);Xe(pe(a,1),x[b>>2],x[b+4>>2]);b=qc(c+24|0,5457);Xe(pe(a,3),x[b>>2],x[b+4>>2]);b=qc(c+16|0,15525);Xe(pe(a,4),x[b>>2],x[b+4>>2]);b=qc(c+8|0,9167);Xe(pe(a,8),x[b>>2],x[b+4>>2]);e=pe(a+288|0,0);b=hb-16|0;hb=b;d=e;e=qc(b+8|0,4893);Xe(d,x[e>>2],x[e+4>>2]);hb=b+16|0;e=a+800|0;b=0;a=hb-80|0;hb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){ru(a+32|0,4045);x[23420]=0;R(274,a+16|0,a+76|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}x[23420]=0;U(275,a+48|0,a+32|0,a+16|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=a+48|0;ue(a- -64|0,d);Xe(pe(e,b),x[a+64>>2],x[a+68>>2]);xb(d);xb(a+16|0);Sb(a+32|0);break d}b=P()|0;xb(a+16|0);break b}d=qc(a+8|0,21473);Xe(pe(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=P()|0}Sb(a+32|0);S(b|0);p()}hb=a+80|0;hb=c+80|0}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=x[a+16>>2];q=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];f=x[a>>2];b=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=cg(k,b,l);o=lb;h=x[a+76>>2];f=x[a>>2];b=x[a+4>>2];Hf(f,b,$e(k,m,d),lb);h=h>>>0<lb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=f;x[e+4>>2]=b;b:while(1){if(d){d=d-1|0;x[e+8>>2]=f;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Rb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;f=_f(g,q);x[c>>2]=D(j>>12,f)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Rb(e,k,m);c=c+8|0;f=x[e>>2];b=x[e+4>>2];continue b}else{Kd(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Jd(g,4);Rb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=f;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function hP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0;i=hb-16|0;hb=i;if(nj(x[a+656>>2])){e=y[a+797|0];g=Uc(e);f=y[a+799|0];Ab(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!Bb(x[x[i+8>>2]>>2],x[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=y[Kb(x[a+656>>2]+108|0,e-1|0)|0]}l=E(E(x[a+704>>2])*b);e=x[x[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){h=x[e+36>>2];if(h){break c}}b=Vl(e,c+f<<16>>16);break b}k=h+1|0;j=Rx(c,k);d=Sx(c,k);b=E(1);g=w[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=x[e+4>>2];if((c|0)>(vc(f,x[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=B[Cb(f,c-g|0)>>2];break b}e:{f:{g:{switch(z[e>>1]-1|0){case 2:h=x[e+16>>2];if(!vc(h,x[e+20>>2])){break f}b=B[Cb(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=x[e+16>>2];if(!vc(j,x[e+20>>2])){break f}b=B[Cb(j,(d+D(h,Ux(c,z[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=me(E(Vl(e,(c<<16)+65536>>16)/Vl(e,c)),E(E(d|0)/E(k|0)))}b=E(b*B[Cb(f,c-g|0)>>2])}}m=a,n=Vj(E(E(l*b)*E(16))),x[m+700>>2]=n}hb=i+16|0}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;pd(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Zc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Zc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+42714|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}hb=d+16|0}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-32|0;hb=h;e=b;b=x[a>>2];b=(ro(e,Db(b))<<1)+b|0;a:{b:{f=x[a+4>>2];if(f>>>0<A[Fb(a)>>2]){if((b|0)!=(f|0)){break b}d=hb-16|0;hb=d;a=Gi(d,a,1);sq(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;kc(a);hb=d+16|0;break a}d=Fb(a);d=xj(h+8|0,yj(a,Mc(x[a>>2],f)+1|0),b-x[a>>2]>>1,d);x[23420]=0;R(279,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){c=x[d+4>>2];f=d+4|0;Jp(x[a>>2],b,f);g=x[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){sq(x[e>>2],y[b|0]|y[b+1|0]<<8);x[e>>2]=x[e>>2]+2;b=b+2|0;continue}break}nc(a,f);nc(a+4|0,e);nc(Fb(a),yc(d));x[d>>2]=x[d+4>>2];b=c;Fi(d);break a}a=P()|0;Fi(d);S(a|0);p()}i=hb-16|0;hb=i;j=x[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=Gi(i,a,f-e>>1);g=x[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){kc(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=wU(j-2|0,e);continue}break}hb=i+16|0}else{sq(g,y[d|0]|y[d+1|0]<<8);g=g+2|0;x[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}Db(b);hb=h+32|0}function bX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;f=Qb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Jv(b,c,a)|0)==-1){break b}e=Jv(b,c,a);x[23420]=0;X(110,d|0,b|0,a|0,e-a|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;R(111,d+16|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break e}x[23420]=0;R(112,f|0,d+16|0);e=x[23420];x[23420]=0;if((e|0)==1){break d}yb(d+16|0);yb(d);a=Jv(b,c,a)+ol(x[c+4>>2],y[c+11|0])|0;continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;yb(d+16|0)}yb(d);break a}f:{g:{h:{i:{j:{k:{if(uc(x[f>>2],x[f+4>>2])){x[23420]=0;X(110,d+16|0,b|0,a|0,-1);c=x[23420];x[23420]=0;if((c|0)==1){break j}c=ol(x[d+20>>2],y[d+27|0]);yb(d+16|0);if(!c){break k}}x[23420]=0;X(110,d|0,b|0,a|0,-1);a=x[23420];x[23420]=0;if((a|0)==1){break i}x[23420]=0;R(111,d+16|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}x[23420]=0;R(112,f|0,d+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}yb(d+16|0);yb(d)}hb=d+32|0;return}a=P()|0;break a}a=P()|0;break a}a=P()|0;break f}a=P()|0;yb(d+16|0)}yb(d)}yl(f);S(a|0);p()}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){e=(x[f+12>>2]<<1)+l|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(w[e-4>>1],w[h+2>>1])+D(w[e-6>>1],w[h>>1])|0)+D(w[e-2>>1],w[h+4>>1])|0)+D(w[e>>1],w[h+6>>1])|0)+D(w[e+2>>1],w[h+8>>1])|0)+D(w[e+4>>1],w[h+10>>1])|0)+D(w[e+6>>1],w[h+12>>1])|0)+D(w[e+8>>1],w[h+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(e,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(e,j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=f+16|0}function RH(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15614,13048,2423,9113);p()}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=hb-16|0;hb=h;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(r,s,e,e>>31);i=lb;z=e;e=(x[h+12>>2]<<1)+n|0;g=x[h+8>>2]>>>21&2040;j=(((D(w[e>>1],w[g+39714>>1])+D(w[e-2>>1],w[g+39712>>1])|0)+D(w[e+2>>1],w[g+39716>>1])|0)+D(w[e+4>>1],w[g+39718>>1])|0)/16384<<8;e=j;k=Wia(e,e>>31,t,u);g=z+k|0;e=lb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Wia(p,q,f,f>>31);g=i+g|0;f=lb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,m)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,l);Rb(h+8|0,v,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=h+16|0}function Bz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){e=x[f+12>>2]+l|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(v[e-2|0],w[h+2>>1])+D(v[e-3|0],w[h>>1])|0)+D(v[e-1|0],w[h+4>>1])|0)+D(v[e|0],w[h+6>>1])|0)+D(v[e+1|0],w[h+8>>1])|0)+D(v[e+2|0],w[h+10>>1])|0)+D(v[e+3|0],w[h+12>>1])|0)+D(v[e+4|0],w[h+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(e,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(e,j>>12);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;hb=f+16|0}function $I(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=hb+-64|0;hb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;uf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{h=x[c+4>>2];if(f>>>0<=h>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(We(x[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){a=0;if((e|0)==(g|0)){break a}while(1)if((a|0)==(f|0)){g=g+1|0;continue e}else{d=Ih(m,h,a,g);j=Cb(x[b>>2],a);d=x[d>>2]+(x[j>>2]>>1)|0;n=d;d=hs(k)+d&-4096;x[j>>2]=n-d;d=hd(d|2048,12);d=(d|0)>=32767?32767:d;o=yn(l,i,a,g),q=(d|0)<=-32768?-32768:d,w[o>>1]=q;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(p,q,e,e>>31);h=lb;f=Xb(f,-16777216,16776704);i=Wia(n,o,f,f>>31);e=i+e|0;f=lb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=x[g+12>>2]+l|0;h=x[g+8>>2]>>>21&2040;h=(((D(v[e|0],w[h+39714>>1])+D(v[e-1|0],w[h+39712>>1])|0)+D(v[e+1|0],w[h+39716>>1])|0)+D(v[e+2|0],w[h+39718>>1])<<8)/16384<<8;e=h;i=Wia(e,e>>31,r,s);e=y+i|0;f=lb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Rb(g+8|0,t,u);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function TG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=hb-1040|0;hb=i;r=x[115896];a:{b:{a=i+16|0;l=z[((b>>>0<=149?b:0)<<1)+90672>>1]+88848|0;c=x[x[115922]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=Il(x[c+8>>2],e);f=Il(x[c+12>>2],e);d=Il(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=Il(x[d>>2],e);d=Il(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=ej(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=Il(x[f>>2],e);e=Il(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=qf(g);d:{if(c>>>0>=1024){pc(a,g,1023);v[a+1023|0]=0;g=68;break d}pc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21473}break a}wa();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;xw(a,1024,12865,i)}x[115896]=r;Vb(q,a);hb=i+1040|0}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;p=x[a+16>>2];q=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];f=x[a>>2];b=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=cg(k,b,l);o=lb;h=x[a+76>>2];f=x[a>>2];b=x[a+4>>2];Hf(f,b,$e(k,m,d),lb);h=h>>>0<lb>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=f;x[e+4>>2]=b;b:while(1){if(d){d=d-1|0;x[e+8>>2]=f;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Rb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(g,v[f+x[e+12>>2]|0]<<6);Jd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=x[a+32>>2];j=x[a+28>>2]+j|0;f=_f(g,q);x[c>>2]=D(j>>12,f)+x[c>>2];i=b+i|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Rb(e,k,m);c=c+8|0;f=x[e>>2];b=x[e+4>>2];continue b}else{Kd(g,v[f+x[e+12>>2]|0]<<6);Jd(g,4);Rb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=f;x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;hb=e+16|0}function KU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-144|0;hb=f;x[23420]=0;l=T(258,a|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){zb(a);hb=f+144|0;return}x[23420]=0;R(277,a|0,f+8|0);e=x[23420];x[23420]=0;if((e|0)!=1){b:{e=Lb(z[f+8>>1]);if(!e|e>>>0>z[m>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Ci(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Wb(f+4|0,f+7|0)|0];x[23420]=0;h=h+1&255;R(278,e|0,h|0);g=x[23420];x[23420]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Lb(z[i+8>>1]);k=Cb(g,e);w[k>>1]=n;i=Lb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;tg(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;zb(a);S(b|0);p()}function Kj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;b=i+8|0;ad(b,d);c=0;x[23420]=0;j=T(18,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){Zb(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Yi(i+24|0,i+16|0)){break b}c:{if((jn(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=jn(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=jn(j,v[g+2|0])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,b,k)|0,x[l+24>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(jh(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(jh(b,1,v[g|0])){continue}}break}while(1){if(!dp(i+24|0,i+16|0)){break c}b=Ek(x[i+24>>2]);if(!jh(x[j+8>>2],1,b)){break c}Jl(i+24|0);continue}}if((sw(j,Ek(x[i+24>>2]))|0)==(sw(j,v[g|0])|0)){g=g+1|0;Jl(i+24|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(Yi(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=P()|0;Zb(i+8|0);S(a|0);p()}function ff(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-80|0;hb=d;c=x[a+28>>2];Ym(x[x[c>>2]-12>>2]+c|0,0);if(!gd(a,4)){Ov(a)}a:{if(!x[a+4>>2]){break a}if(gd(a,6)){break a}if(gd(a,7)){break a}f=x[a+28>>2];c=x[a+84>>2];g=D(x[a+20>>2],x[a+4>>2]);e=g+x[a+80>>2]|0;c=gh(d- -64|0,e,e>>>0<g>>>0?c+1|0:c);e=x[c+12>>2];x[d+24>>2]=x[c+8>>2];x[d+28>>2]=e;e=x[c+4>>2];x[d+16>>2]=x[c>>2];x[d+20>>2]=e;Hj(f,d+16|0)}e=0;b:{if(!gd(a,5)){break b}f=fh(x[a+44>>2],x[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(x[a+96>>2]+c>>>0)%(f>>>0)|0;i=dd(x[a+44>>2],g);h=x[i>>2];c:{j=x[a+32>>2];if(Wc(j,x[a+36>>2])>>>0<=h>>>0){break c}h=Zm(d+48|0,Kb(j,h),z[i+12>>1]);i=Vv(b,h);Sb(h);if(!i){break c}x[a+96>>2]=(g+1>>>0)%(f>>>0);e=dd(x[a+44>>2],g);b=x[e+4>>2];if(!b){break b}f=x[a+28>>2];c=x[a+12>>2];e=b+x[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=gh(d+32|0,e,c);c=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=c;c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;Hj(f,d);e=dd(x[a+44>>2],g);break b}c=c+1|0;continue}}hb=d+80|0;return e}function Ev(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-32|0;hb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;wf(g+16|0,a,b,c,e,h-15233|0);Wl(g,a,b,c,e,15361-h|0);e=x[g+4>>2];h=e;a=x[g+8>>2];c=x[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}hb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=hb-16|0;hb=e;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){f=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;x[(f<<2)+e>>2]=(((((D(w[b+8>>1],r)+D(w[b+4>>1],s)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/2|0)+((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Rb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=e+16|0}function AP(a,b,c){var d=0,e=0;d=y[a|0]&15;v[a|0]=y[d+26912|0];a:{b:{c:{switch(d|0){case 0:if(y[b|0]?c>>>0>=51:0){break b}v[a|0]=0;return;case 5:d:{e:{d=y[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){v[a|0]=20;d=159;v[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}v[a|0]=25;v[b|0]=0;return;case 7:if(c>>>0>51){break b}v[a|0]=0;return;case 10:a=y[b|0]&240;if(!a){break b}v[b|0]=a;return;case 11:v[b|0]=D(y[b|0]&15,17);return;case 12:v[b|0]=y[b|0]>>>2;return;case 13:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 14:g:{switch((y[b|0]>>>4|0)-1|0){case 0:v[a|0]=2;break a;case 1:v[a|0]=3;break a;case 7:if(c>>>0<52){break b}v[a|0]=20;v[b|0]=y[b|0]&15|96;return;case 8:v[a|0]=15;v[b|0]=y[b|0]&15;return;case 9:v[a|0]=11;v[b|0]=y[b|0]<<4|15;return;case 10:v[a|0]=11;break a;case 11:case 12:break g;default:break b}}v[a|0]=20;return;case 15:break c;default:break b}}if(y[b|0]<48){break b}v[a|0]=17}return}v[b|0]=y[b|0]|240}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;o=x[a+32>>2];p=x[a+28>>2];q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];v=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){l=w[(x[g+12>>2]<<1)+n>>1]<<8;e=l;e=Wia(e,e>>31,v,y);k=lb;h=e;e=Xb(b,-16777216,16776704);m=Wia(t,u,e,e>>31);h=h+m|0;e=lb+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Wia(r,s,f,f>>31);h=k+h|0;f=lb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+p|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+o|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Rb(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function UI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;uf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{i=x[c+4>>2];if(i>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=x[c>>2];e:while(1){a=0;if((f|0)==(h|0)){break a}while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{e=Ih(l,i,a,h);j=Cb(x[b>>2],a);e=x[e>>2]+(x[j>>2]>>1)|0;m=e;e=hs(k)+e&-4096;x[j>>2]=m-e;e=hd(e|2048,12);e=(e|0)>=32767?32767:e;n=xn(d,a,h),o=(e|0)<=-32768?-32768:e,w[n>>1]=o;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function U4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=hb-160|0;hb=e;d=e+24|0;f=d+56|0;c=rs(f);x[d>>2]=76788;x[c>>2]=76808;x[d+56>>2]=76848;x[d>>2]=76828;h=f;f=d+4|0;An(h,f);x[d>>2]=76788;x[c>>2]=76808;c=ls(f);x[c>>2]=76272;Jb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[23420]=0;f=ga(61)|0;h=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}x[23420]=0;U(62,e+16|0,c+d|0,f|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}Zb(e+16|0);c=hb-16|0;hb=c;x[c+8>>2]=17;hb=c+16|0;Ol(x[x[d>>2]-12>>2]+d|0,x[c+8>>2]);i=C[b>>3];x[23420]=0;b=Za(63,d|0,+i)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;R(64,e|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}x[23420]=0;R(60,g|0,e|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}xb(e);jp(b);hb=e+160|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break b}a=P()|0;xb(e)}jp(d);S(a|0);p()}x[23420]=0;R(57,a|0,g|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(g);hb=g+16|0;return}a=P()|0;xb(g);S(a|0);p()}function Ej(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Mi(a)&2047;c=Mi(5551115123125783e-32);d=e-c|0;a:{if(d>>>0>=Mi(512)-c>>>0){if((d|0)<0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(Mi(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(Mi(O)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return tr(3105036184601418e216)}if(c>>>0<3230714880){break b}return tr(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){fE(iE()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;pd(b,32);g=b,h=ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=ac(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=ac(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=ac(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Lb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}gq(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Wb(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}hb=e+16|0}function KJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=x[f>>2];c=x[a+40>>2];h:{if(Pb(e,c)){Bc(d+24|0);break h}c=d+8|0;Dn(c,a);x[23420]=0;c=T(961,c|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break g}x[d+24>>2]=c;Vf(d+8|0);c=x[a+40>>2];e=x[a+36>>2]}e=(h=f,i=x[d+24>>2],j=Pb(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((Cn(f,x[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;x[23420]=0;c=Q(54,d+8|0,10825)|0;a=x[23420];x[23420]=0;if((a|0)==1){break f}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}a=P()|0;xb(c);break d}a=P()|0;Vf(d+8|0);break c}a=P()|0;ca(b|0);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;zi(b+484360|0,y[bl(f,c)+16|0]);b=bl(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[23420]=0;+qa(992,a|0,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break a}a=P()|0}Ik(d+24|0)}S(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;Ik(d+24|0);hb=d+32|0}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=hb-16|0;hb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;o=x[a+32>>2];p=x[a+28>>2];q=x[a+72>>2];b=x[a+68>>2];r=b;s=b>>31;b=x[a+64>>2];t=b;u=b>>31;b=x[a+60>>2];w=b;y=b>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){l=v[x[g+12>>2]+n|0]<<16;e=l;e=Wia(e,e>>31,w,y);k=lb;h=e;e=Xb(b,-16777216,16776704);m=Wia(t,u,e,e>>31);h=h+m|0;e=lb+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);k=Wia(r,s,f,f>>31);h=k+h|0;f=lb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;j=j+p|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+o|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Rb(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;hb=g+16|0}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Vt(c,d);d=b&63;if(e>>>0>d>>>0){c=vS(c,d);d=0;g=hb-16|0;hb=g;v[a+12|0]=0;Gc(a);e=hb-32|0;hb=e;a:{b:{if(ti(a)>>>0<=14){if(hh(1073741823)>>>0<=14){break b}f=Fb(a);f=bg(e+8|0,15,vc(x[a>>2],x[a+4>>2]),f);zd(a,f);ag(f)}hb=e+32|0;break a}Tc();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+7|0]=64;h=f+(h<<16>>16)|0;f=jo(g+8|0,h&65535,y[Wb(e+2|0,g+7|0)|0]);d:{if(A[a+4>>2]<A[Fb(a)>>2]){qS(a,f);break d}i=hb-32|0;hb=i;e=Fb(a);e=bg(i+8|0,Tg(a,vc(x[a>>2],x[a+4>>2])+1|0),vc(x[a>>2],x[a+4>>2]),e);io(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;zd(a,e);ag(e);hb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}hb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|uc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function Fc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=hb-48|0;hb=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Jb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){v[e+32|0]=0;a=ii(c,c+d|0,e+32|0);x[23420]=0;W(52,f|0,c|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break h}a=P()|0;break b}if((b-3&255)>>>0>1){break h}x[23420]=0;b=W(52,f|0,c|0,c+d|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break g}c=Yd(b);d=mh(b);g=Yd(b);a=hb-32|0;hb=a;x[a+16>>2]=d;x[a+24>>2]=c;x[a+8>>2]=g;while(1){if(Lh(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=v[x[d>>2]];v[x[c>>2]]=g?g:32;Be(d);Be(c);continue}break}hb=a+32|0;x[23420]=0;c=Q(53,e+16|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break f}x[23420]=0;d=Q(54,e|0,17644)|0;a=x[23420];x[23420]=0;if((a|0)==1){break e}x[23420]=0;U(55,e+32|0,c|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}a=e+32|0;Ac(b,a);xb(a);xb(d);xb(c)}hb=e+48|0;break a}a=P()|0;break b}a=P()|0;break b}a=P()|0;break c}a=P()|0;xb(d)}xb(c)}xb(f);S(a|0);p()}}function Jj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;x[i+16>>2]=c;x[i+24>>2]=b;c=i+8|0;ad(c,d);b=0;x[23420]=0;j=T(1086,c|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Zb(i+8|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Lj(i+24|0,i+16|0)){break b}c:{if((hn(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=hn(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=hn(j,x[g+8>>2])}l=i,m=mb[x[x[a>>2]+36>>2]](a,x[i+24>>2],x[i+16>>2],d,e,f,c,k)|0,x[l+24>>2]=m;g=b+8|0;break c}if(Ck(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Ck(j,1,x[g>>2])){continue}}break}while(1){if(!Pr(i+24|0,i+16|0)){break c}if(!Ck(j,1,Dk(x[i+24>>2]))){break c}pn(i+24|0);continue}}if((jl(j,Dk(x[i+24>>2]))|0)==(jl(j,x[g>>2])|0)){g=g+4|0;pn(i+24|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(Lj(i+24|0,i+16|0)){x[e>>2]=x[e>>2]|2}hb=i+32|0;return x[i+24>>2]}a=P()|0;Zb(i+8|0);S(a|0);p()}function ep(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function Of(a){var b=0;a:{b:{switch(y[a+3|0]){case 0:if(!y[a+5|0]){break a}v[a+3|0]=1;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;b=a;a=y[a+5|0];v[b+5|0]=D(a>>>4|0,10)+(a&15);return;case 14:v[a+3|0]=19;return;case 15:if(y[a+5|0]<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break b}}v[a+3|0]=0}}function Nx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=hb-48|0;hb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Wc(d,b)>>>0<4){break b}ke(c+16|0,d,b);b=$d(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=KT(c+24|0,x[c+16>>2],x[c+20>>2],c);x[23420]=0;b=T(145,d|0)|0;f=x[23420];x[23420]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[23420]=0;f=T(b|0,a|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Wc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+172>>2];b=0;x[23420]=0;R(e|0,a|0,-1);e=x[23420];x[23420]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+176>>2];x[23420]=0;Y(b|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){break c}break a}x[23420]=0;g=E(za(408,d|0));e=x[23420];x[23420]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[23420]=0;ya(e|0,a|0,b|0,E(Ul(g)?g:E(0)));e=x[23420];x[23420]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}zb(d)}hb=c+48|0;return}a=P()|0;zb(d);S(a|0);p()}function ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-2608|0;hb=f;d=qB(f,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[23420]=0;Y(304,d|0);a=x[23420];x[23420]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[23420]=0;j=Q(152,d|0,1)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=0;d:{while(1){x[23420]=0;k=Q(152,d|0,1)|0;e=x[23420];x[23420]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=V(30320)|0;break b}a=V(30320)|0;break b}a=V(30320)|0}if((ib|0)==(da(30320)|0)){_(a|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0}zb(d);S(a|0);p()}a=kq(d);zb(d);hb=f+2608|0;return a|0}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=hb-16|0;hb=e;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){f=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;x[(f<<2)+e>>2]=(((((D(v[b+4|0],r)+D(v[b+2|0],s)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/2|0)+((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Rb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=e+16|0}function h5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23420]=0;Y(927,a|0);e=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[23420]=0;Y(903,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break e}e=0;x[23420]=0;Y(928,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break e}a=Tb(c,0,d);if(!y[b|0]){break b}if(ej(b,7184)|(d|0)!=8){break d}x[a+4>>2]=929;x[a>>2]=930;break c}_(V(0)|0)|0;x[23420]=0;X(889,12134,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();return 0}if(!(ej(b,11099)|(d|0)!=64)){x[a+60>>2]=931;x[a+56>>2]=932;x[a+52>>2]=933;x[a+48>>2]=934;x[a+44>>2]=935;x[a+40>>2]=936;x[a+36>>2]=937;x[a+32>>2]=938;x[a+28>>2]=939;x[a+24>>2]=940;x[a+20>>2]=941;x[a+16>>2]=942;x[a+12>>2]=943;x[a+8>>2]=944;x[a+4>>2]=945;x[a>>2]=946;break c}if(ej(b,14969)|(d|0)!=24){break b}x[a+20>>2]=947;x[a+16>>2]=948;x[a+12>>2]=949;x[a+8>>2]=950;x[a+4>>2]=951;x[a>>2]=952}e=1}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ad(g,d);x[23420]=0;b=T(1086,g|0)|0;a=x[23420];x[23420]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);ad(g,d);x[23420]=0;a=T(1087,g|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}Zb(g);x[23420]=0;R(1088,g|0,a|0);d=x[23420];x[23420]=0;if((d|0)==1){b=P()|0;break d}x[23420]=0;R(1089,g|12,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break f}x[23420]=0;d=g+24|0;a=ua(1090,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=Jc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;Zb(g);break d}b=P()|0;Zb(g);break d}b=P()|0;Jc(g);break d}b=P()|0;while(1){d=Jc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-32|0;hb=g;x[g+24>>2]=b;a:{b:{if(!(x[d+4>>2]&1)){x[g>>2]=-1;b=mb[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}ad(g,d);x[23420]=0;b=T(18,g|0)|0;a=x[23420];x[23420]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);ad(g,d);x[23420]=0;a=T(1069,g|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break g}Zb(g);x[23420]=0;R(1070,g|0,a|0);d=x[23420];x[23420]=0;if((d|0)==1){b=P()|0;break d}x[23420]=0;R(1071,g|12,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break f}x[23420]=0;d=g+24|0;a=ua(1072,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+24>>2];while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;Zb(g);break d}b=P()|0;Zb(g);break d}b=P()|0;xb(g);break d}b=P()|0;while(1){d=xb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);p()}v[f|0]=0}hb=g+32|0;return b|0}function tF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=hb-16|0;hb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];hb=a+16|0;return c|0}function Zx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=hb-16|0;hb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;bh(b,x[td(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=qe(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=Cb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[Cb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=Cb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[vj(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}hb=d+16|0}function PW(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb+-64|0;hb=b;e=Jb(a);x[23420]=0;a=ga(114)|0;c=x[23420];x[23420]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[23420]=0;c=Q(1,b+32|0,8865)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}x[23420]=0;a=ga(114)|0;d=x[23420];x[23420]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[23420]=0;x[b+12>>2]=a;R(120,b+16|0,b+12|0);a=x[23420];x[23420]=0;if((a|0)==1){break h}x[23420]=0;U(2,b+48|0,c|0,b+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break g}d=b+48|0;a=Gb(e,d);yb(d);yb(b+16|0);yb(c);x[23420]=0;c=ga(116)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}if(!c){break e}x[23420]=0;Q(121,a|0,17318)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break e}break b}a=P()|0;break f}a=P()|0;yb(b+16|0)}yb(c);break a}x[23420]=0;c=ga(115)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}if(!c){break d}x[23420]=0;Q(121,a|0,16620)|0;a=x[23420];x[23420]=0;if((a|0)==1){break b}}hb=b- -64|0;return}a=P()|0;break a}a=P()|0}yb(e);S(a|0);p()}function Jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;c=f+44|0;mo(b,c);a:{if(!mP(c)){break a}d=y[f+46|0];g=y[f+47|0];e=y[f+45|0];v[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e^-1)>>>1&3;g=g>>>0<192;w[a+2>>1]=z[(D(c,6)+(e<<1)|0)+27208>>1]<<g;i=D(D(y[(e+D(c,3)|0)+26984|0],z[((D(c,90)+D(e,30)|0)+(d>>>3&30)|0)+26992>>1]),1e3);d=d>>>1|0;d=D(((i>>>0)/z[(D(h,6)+(d&6)|0)+27184>>1]|0)+(d&1)|0,e?1:4);w[a>>1]=d;e=y[(g|c<<1)+27220|0];if(e+8>>>0>(d&65535)>>>0){break a}c=hb-32|0;hb=c;x[c+28>>2]=e+4;x[c+8>>2]=36;g=x[b>>2];h=x[b+8>>2];d=x[Hb(c+28|0,c+8|0)>>2];if(!Nb(g,h,d)){d=df(b)}h=c+8|0;Vq(h,f);g=fc(c+16|0,x[c+8>>2],d);mc(c,x[b>>2],x[b+8>>2],x[g>>2],x[g+4>>2]);Vq(h,f);Tb(x[c+8>>2]+d|0,0,36-d|0);$b(b,x[c+28>>2]);hb=c+32|0;b=2;c=e>>>0<=2?2:e;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!y[d|0]){continue}break a}break}b=e+f|0;if(Ob(b,9468,4)){b=Ob(b,10986,4)}else{b=0}v[a+5|0]=!b}hb=f+48|0;return a|0}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=hb+-64|0;hb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;uf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(e>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(We(x[c+24>>2],h)>>>0<e>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=hd((x[Ih(k,g,a,b)>>2]+hd(gs(i),21)|0)+2048|0,12);d=(d|0)>=32767?32767:d;l=yn(j,h,a,b),m=(d|0)<=-32768?-32768:d,w[l>>1]=m;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function cq(a){var b=0,c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=Db(x[a+484344>>2]);x[e+8>>2]=c;a=Db(x[a+484348>>2]);while(1){if(!Pb(c,a)){d=1;break a}if(!(!Pb(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[Gt(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}hb=e+16|0;return d}function _V(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=hb-32|0;hb=j;e=Km(j+8|0,a);c=hb-48|0;hb=c;k=-1;a:{if(!cD(e,c+8|0)){break a}k=0;if(!gD(c+8|0)){break a}l=qf(12955);if(l){o=x[e+12>>2];b:{if(!al(e,y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))){break b}while(1){c:{if((y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24))>>>0>n>>>0){if(Uf(e,5)){break c}}f=m&1;break b}f=0;h=1;d:{if((y[c+12|0]|y[c+13|0]<<8)>>>0>=64){d=Cq(e);a=d&63;g=d<<24>>24;e:{if(!(d&64)){break e}d=6;while(1){i=Cq(e);a=(i&127)<<d|a;if(i<<24>>24>=0){break e}i=d>>>0<25;d=d+7|0;if(i){continue}break}}d=(g|0)<0;g=d?-2147483648:a;if(((d?(a|0)>=0?0-a|0:g:g)|0)<=0){break d}}while(1){d=Cq(e);if(d){g=f>>>0>=l>>>0;a=g&h;if(!((h^1)&1|g)){a=(op(d<<24>>24)&255)==y[f+12955|0]}h=a;f=f+1|0;continue}break}cd(e,4);m=(f|0)==(l|0)?h&1?1:m:m}n=n+1|0;continue}}al(e,o)}if(!f){break a}k=Ge(e,b,fD(c+8|0),0)}hb=c+48|0;hb=j+32|0;return k|0}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=x[a+16>>2];o=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){i=x[a+8>>2];j=x[a+12>>2];g=x[a>>2];b=x[a+4>>2];h=0;break a}i=x[a+8>>2];j=x[a+12>>2];l=cg(i,j,k);m=lb;h=x[a+76>>2];g=x[a>>2];b=x[a+4>>2];Hf(g,b,$e(i,j,d),lb);h=h>>>0<lb>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=g;x[e+4>>2]=b;b:while(1){if(d){b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Rb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Jd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=_f(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Rb(e,i,j);c=c+8|0;continue b}else{Kd(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Jd(f,4);Rb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function p8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=zj(d,x[a+4>>2]);if(c>>>0<b>>>0){g=hb-32|0;hb=g;e=b-c|0;b=x[Fb(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=hb-16|0;hb=b;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(e<<11);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);hb=b+16|0}else{Ox(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=Fb(a);i=g+8|0;b=a;f=zj(x[a>>2],c)+e|0;c=hb-16|0;hb=c;x[c+12>>2]=f;d=hb-16|0;hb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Hb(d+12|0,d+8|0)>>2];hb=d+16|0;b:{if(a>>>0>=f>>>0){d=Px(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;break b}Tc();p()}d=cL(i,a,zj(x[b>>2],x[b+4>>2]),h);c=d;a=hb-16|0;hb=a;x[a>>2]=x[c+8>>2];f=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=f+(e<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){Ox(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}Id(a);hb=a+16|0;zd(b,d);bL(d)}hb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<11)|0)}}function sr(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=Mi(a)&2047;e=Mi(5551115123125783e-32);c=d-e|0;if(c>>>0<Mi(512)-e>>>0){e=d;break b}if((c|0)<0){return a+1}e=0;if(Mi(1024)>>>0>d>>>0){break b}o(+a);e=j(1)|0;b=0;if(!(j(0)|0)&(e|0)==-1048576){break a}if(Mi(O)>>>0<=d>>>0){return a+1}if((e|0)<0){return tr(12882297539194267e-247)}return tr(3105036184601418e216)}b=C[170];f=C[169]*a+b;b=f-b;a=b*C[172]+(b*C[171]+a);b=a*a;g=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+f);j(1)|0;i=j(0)|0;c=i<<4&2032;a=g+(b+(C[c+1464>>3]+a));c=c+1472|0;h=x[c>>2];d=x[c+4>>2];c=h;h=0;c=c+h|0;d=(i<<13)+d|0;d=c>>>0<h>>>0?d+1|0:d;if(!e){c:{if(!(i&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){fE(iE()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;g=hb-16|0;hb=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(p,q,e,e>>31);i=lb;f=Xb(f,-16777216,16776704);h=Wia(n,o,f,f>>31);e=h+e|0;f=lb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=x[g+12>>2]+l|0;e=v[h|0];w=i;i=((D(v[h+1|0]-e|0,x[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Wia(e,e>>31,r,s);e=w+h|0;f=lb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Rb(g+8|0,t,u);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function Bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;h=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|kj(a)>>>0>=h>>>0){break a}tg(f+12|0,h-b&65535);k=f,l=fl(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];eS(a,d+z[Ve(f+14|0,f+8|0)>>1]|0);c=x[a>>2];e=a;if(Mc(c,x[a+4>>2])>>>0<b>>>0){jg(e,b);c=x[e>>2]}a=Db(c);c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[YO(c+8|0,b)>>2];hb=c+16|0;a=x[gc(f,a)>>2];i=f+10|0;j=hb-32|0;hb=j;b=a;a=x[e>>2];g=(ro(b,Db(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Fb(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){vo(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}WO(e,g,d,(a<<1)+g|0);Pt(g,b,((g>>>0<=i>>>0?A[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Fb(e);b=xj(j+8|0,yj(e,Mc(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);AC(b,a,i);g=VO(e,b,g);Fi(b)}Db(g);hb=j+32|0;if(Mc(x[e>>2],x[e+4>>2])>>>0<=h>>>0){break a}jg(e,h)}hb=f+16|0}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;DJ(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;kc(c);hb=c+16|0;return}g=hb-32|0;hb=g;h=Fb(a);c=g+8|0;e=Cn(x[a>>2],x[a+4>>2])+1|0;d=hb-16|0;hb=d;x[d+12>>2]=e;a:{f=hh(178956970);if(e>>>0<=f>>>0){e=Kt(a);if(e>>>0<f>>>1>>>0){x[d+8>>2]=e<<1;f=x[Yc(d+8|0,d+12|0)>>2]}hb=d+16|0;break a}Tc();p()}e=Cn(x[a>>2],x[a+4>>2]);Jf(c+12|0,h);if(f){if(f>>>0>=178956971){ig();p()}d=wc(D(f,24))}else{d=0}x[c>>2]=d;e=d+D(e,24)|0;x[c+8>>2]=e;x[c+4>>2]=e;i=yc(c),j=d+D(f,24)|0,x[i>>2]=j;DJ(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;b=c+4|0;e=x[a>>2];f=x[a+4>>2]-e|0;d=x[b>>2]+D((f|0)/-24|0,24)|0;x[b>>2]=d;if((f|0)>0){pc(d,e,f)}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-24|0;x[c+8>>2]=b;continue}break}a=x[c>>2];if(a){yc(c);Ib(a)}hb=g+32|0}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=hb-16|0;hb=g;f=x[a+48>>2];j=x[a+24>>2];k=x[a+20>>2];e=x[a+44>>2];l=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;m=x[a+72>>2];b=x[a+68>>2];n=b;o=b>>31;b=x[a+64>>2];p=b;q=b>>31;b=x[a+60>>2];r=b;s=b>>31;t=x[a+8>>2];u=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);e=Wia(p,q,e,e>>31);i=lb;f=Xb(f,-16777216,16776704);h=Wia(n,o,f,f>>31);e=h+e|0;f=lb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(x[g+12>>2]<<1)+l|0;e=w[h>>1];v=i;i=e+((D(w[h+2>>1]-e|0,x[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Wia(e,e>>31,r,s);e=v+h|0;f=lb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,k)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,j);Rb(g+8|0,t,u);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function c2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;uf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(e>>>0>A[c+8>>2]){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=b+12|0;j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=hd((x[Ih(j,h,a,b)>>2]+hd(gs(i),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;k=xn(d,a,b),l=(g|0)<=-32768?-32768:g,w[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function hJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;x[a+4>>2]=b;x[a>>2]=93720;e=(b>>>0)/48|0;d=((0-b|0)!=(D(e,-48)|0))+e|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;x[a+24>>2]=c;f=f?g&65536:0;x[a+28>>2]=f;g=Zia(c,f,d,0);h=lb;f=f^65536;if((h|0)==(f|0)&c>>>0>g>>>0|f>>>0>h>>>0){d=d+1|0;x[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;x[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;x[a+28>>2]=f?c&65536:0}x[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;c=63-e|0;d=c&31;if((c&63)>>>0>=32){c=0;d=-1>>>d|0}else{c=-1>>>d|0;d=c|(1<<d)-1<<32-d}x[a+48>>2]=b?d:-1;x[a+52>>2]=b?c:-1;c=64-e|0;d=c&31;if((c&63)>>>0>=32){c=0;d=-1>>>d|0}else{c=-1>>>d|0;d=c|(1<<d)-1<<32-d}x[a+40>>2]=e?d:0;x[a+44>>2]=e?c:0;d=e+1|0;e=d&31;if((d&63)>>>0>=32){c=-1<<e}else{c=(1<<e)-1&-1>>>32-e|-1<<e}x[a+32>>2]=0;x[a+36>>2]=b?c&65536:0;return a}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=hb-16|0;hb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!Uh(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Ec(e,0),x[D+8>>2]=G;D=g,G=Ec(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Ec(e,0);x[g>>2]=o;p=Ec(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[Cb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=Cb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}ji(a,b,c,o,p,d)}hb=g+16|0}function pw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=hb-16|0;hb=m;v[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break b}a=0;v[b|0]=0;b=x[e>>2];x[e>>2]=b+1;v[b|0]=46;if(!Eb(h)){break a}b=x[j>>2];if((b-i|0)>159){break a}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!y[b|0]){break b}a=0;b=x[j>>2];if((b-i|0)>159){break a}a=x[k>>2];x[j>>2]=b+4;x[b>>2]=a;a=0;x[k>>2]=0;break a}a=-1;f=ii(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=y[f+81808|0];d:{e:{switch((f&-2)-22|0){case 2:b=x[e>>2];if((b|0)!=(d|0)&(y[b-1|0]&95)!=(y[c|0]&127)){break a}x[e>>2]=b+1;v[b|0]=g;a=0;break a;case 0:v[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=y[c|0]){break d}v[c|0]=a|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(h)){break d}a=x[j>>2];if((a-i|0)>159){break d}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b}a=x[e>>2];x[e>>2]=a+1;v[a|0]=g;a=0;if((f|0)>21){break a}x[k>>2]=x[k>>2]+1;break a}a=-1}hb=m+16|0;return a}function np(a){a=a|0;var b=0,c=0,d=E(0),e=E(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Gc(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Gc(c);return}Pj(c,b);b=w[a+28>>1];d=E(Vl(a,(b<<16)+65536>>16)/Vl(a,b));c=x[a+36>>2]+1|0;d=me(d,E(E(1)/E(c>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=me(d,E(b>>>0));n=Cb(a,b-1|0),o=e,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=z[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Gc(c);return}Pj(c,D(b,f));h=z[a+30>>1];j=Ux(w[a+28>>1],h);i=x[a+36>>2];d=E(E(1)/E(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=Ux(c+j<<16>>16,h)<<16;e=Vl(a,b+65536>>16);b=b>>16;e=me(E(e/Vl(a,b)),d);k=D(b,x[a+36>>2]);l=x[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=me(e,E(g>>>0));n=Cb(l,(g+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Gc(a+16|0);return;default:break b}}Gc(a+16|0);x[a+36>>2]=0}}function o4(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;x[23420]=0;g=Q(12,d+24|0,a|0)|0;c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)!=1){d:{if(!y[g|0]){break d}c=d+16|0;ad(c,x[x[a>>2]-12>>2]+a|0);x[23420]=0;c=T(67,c|0)|0;e=x[23420];x[23420]=0;e:{f:{if((e|0)!=1){Zb(d+16|0);e=xm(d+8|0,a);f=x[x[a>>2]-12>>2];x[23420]=0;f=a+f|0;h=T(13,f|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break f}e=x[e>>2];x[23420]=0;c=Ra(68,c|0,e|0,f|0,h|0,+b)|0;e=x[23420];x[23420]=0;if((e|0)==1){break f}x[d+16>>2]=c;if(!uu(d+16|0)){break d}c=x[x[a>>2]-12>>2];x[23420]=0;R(15,a+c|0,5);c=x[23420];x[23420]=0;if((c|0)!=1){break d}c=V(0)|0;break e}c=V(0)|0;Zb(d+16|0);break e}c=V(0)|0}hl(g);break c}hl(g);break b}c=V(0)|0}_(c|0)|0;c=x[x[a>>2]-12>>2];x[23420]=0;Y(16,a+c|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}$()}hb=d+32|0;return a|0}a=P()|0;x[23420]=0;Z(17);d=x[23420];x[23420]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function m2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(We(x[c+24>>2],h)>>>0<d>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=hd(x[Ih(j,g,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;k=yn(i,h,a,b),l=(f|0)<=-32768?-32768:f,w[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function nx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(We(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=em(fe(dg(C[Og(i,f,a,b)>>3])*134217728));k=mx(h,g,a,b),l=E(+(j|0)*7.450580596923828e-9),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;RR(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!cf(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}hb=e+16|0}function I5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-80|0;hb=e;x[e+72>>2]=c;a=Tf(a,e+72|0);c=Bc(a+4|0);g=Bc(a+24|0);h=Bc(a+32|0);i=Qb(a+36|0);x[a+56>>2]=3;j=Qb(a+68|0);x[23420]=0;R(897,a|0,d|0);f=x[23420];x[23420]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+40>>2]=x[b+8>>2];x[e+44>>2]=l;x[e+32>>2]=f;x[e+36>>2]=k;b=$d(e+24|0);f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;x[23420]=0;f=x[e+36>>2];x[e+8>>2]=x[e+32>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;U(886,e+48|0,e+8|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}x[23420]=0;U(898,a|0,e+48|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}zb(e+48|0);x[23420]=0;Y(899,a|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}se(e+72|0);hb=e+80|0;return a|0}d=P()|0;break a}d=P()|0;break a}d=P()|0;zb(e+48|0);break a}d=P()|0}Ke(j);Vf(i);ns(h);cj(g);bj(c);se(a);se(e+72|0);S(d|0);p()}function k8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Ec(f,0);l=Ec(f,1);g=x[a+56>>2];s=Ec(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Ec(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=Cb(j,e);n=B[Cb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=Cb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=Cb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{ji(a,b,c,s,t,d)}break}}}function IG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Le(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=ot(x[a+32>>2]);if((g|0)==-1){break a}v[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{d=x[a+40>>2];g=x[d>>2];j=x[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(WG(x[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=x[a+40>>2];x[d>>2]=g;x[d+4>>2]=j;if((e|0)==8){break b}d=ot(x[a+32>>2]);if((d|0)==-1){break b}v[f|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Kr(Mf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=Mf(v[c+23|0]);x[a+48>>2]=d;break a}d=Mf(v[c+23|0]);break a}d=-1}hb=c+32|0;return d}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=hb-16|0;hb=e;n=x[a+16>>2];o=$f(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){i=x[a+8>>2];j=x[a+12>>2];g=x[a>>2];b=x[a+4>>2];h=0;break a}i=x[a+8>>2];j=x[a+12>>2];l=cg(i,j,k);m=lb;h=x[a+76>>2];g=x[a>>2];b=x[a+4>>2];Hf(g,b,$e(i,j,d),lb);h=h>>>0<lb>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=g;x[e+4>>2]=b;b:while(1){if(d){b=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Rb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){Kd(f,v[x[e+12>>2]+g|0]<<6);Jd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}g=x[c>>2];b=_f(f,o);x[c>>2]=g+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Rb(e,i,j);c=c+8|0;continue b}else{Kd(f,v[x[e+12>>2]+g|0]<<6);Jd(f,4);Rb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;hb=e+16|0}function Gu(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&15|32;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[td(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}hb=c+16|0}function oF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){e=(x[f+12>>2]<<1)+j|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(w[e-4>>1],w[h+2>>1])+D(w[e-6>>1],w[h>>1])|0)+D(w[e-2>>1],w[h+4>>1])|0)+D(w[e>>1],w[h+6>>1])|0)+D(w[e+2>>1],w[h+8>>1])|0)+D(w[e+4>>1],w[h+10>>1])|0)+D(w[e+6>>1],w[h+12>>1])|0)+D(w[e+8>>1],w[h+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(e,l);x[c+4>>2]=x[c+4>>2]+D(e,k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function JG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[Le(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=ot(x[a+32>>2]);if((g|0)==-1){break a}v[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{d=x[a+40>>2];g=x[d>>2];j=x[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(WG(x[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=x[a+40>>2];x[d>>2]=g;x[d+4>>2]=j;if((e|0)==8){break b}d=ot(x[a+32>>2]);if((d|0)==-1){break b}v[f|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Kr(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}hb=c+32|0;return d}function d2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];g=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{h=x[c+4>>2];if(h>>>0>=g>>>0){if(A[d+4>>2]<g>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}i=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{f=hd(x[Ih(i,h,a,b)>>2]+2048|0,12);f=(f|0)>=32767?32767:f;j=xn(d,a,b),k=(f|0)<=-32768?-32768:f,w[j>>1]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function lx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=em(fe(dg(C[Og(h,g,a,b)>>3])*134217728));j=kx(d,a,b),k=E(+(i|0)*7.450580596923828e-9),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-144|0;hb=g;pq(a);a:{b:{if(!Uf(a,64)){break b}c:{d:{if(!al(a,60)){break d}if(!zQ(a,13983)){break d}c=15;d=450;break c}pq(a);if(!Uf(a,128)){break b}b=0;if(!al(a,124)){break a}if(!zQ(a,15143)){break a}c=31;d=930}pq(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(xQ(a)>>>0<=131072){continue}break}b=0;break a}cd(a,4);if(!Uf(a,2)){break b}b=0;e=hb-16|0;hb=e;c=hb-16|0;hb=c;sl(c+8|0,e+8|0);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);h=x[c+4>>2];if((f|0)==(h|0)){cd(a,x[c+12>>2])}hb=c+16|0;if((f|0)==(h|0)){i=Lb(z[e+8>>1])}hb=e+16|0;if(i>>>0<178){break a}b=-1;if(!Uf(a,d)){break a}cd(a,d);d=hb-16|0;hb=d;e=g+8|0;zR(d+8|0,e);c=x[d+12>>2];ld(d,a,x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(c|0)){cd(a,x[d+12>>2])}hb=d+16|0;a=(c|0)==(f|0);if(!a){gA(e)}if(!a){break a}b=yQ(y[g+8|0]);break a}b=-1}hb=g+144|0;return b|0}function rF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function QB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=hb-560|0;hb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=fP(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;qy(b+48|0,c+48|0);qy(b+68|0,c+68|0);qy(b+88|0,c+88|0);pc(b+108|0,c+108|0,448);d=b;St(c);break b}b=Ks(556);if(!b){x[e>>2]=0;break a}d=fP(b,c);x[e>>2]=d}g=a,h=z[Ve(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}hb=f+560|0;return d|0}function Nga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;b=hb-32|0;hb=b;x[b+16>>2]=1073741824;w[b+22>>1]=12;c=wc(64);x[23420]=0;d=T(790,c|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{if((f|0)!=1){c=mf(b+8|0,d);d=x[c>>2];x[23420]=0;R(791,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=x[c>>2];x[23420]=0;a=W(792,a|0,b+22|0,b+16|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}d:{if(!a){Bc(b+24|0);break d}a=x[c>>2];x[23420]=0;R(793,a|0,15);a=x[23420];x[23420]=0;if((a|0)==1){break c}Tf(b+24|0,c)}hg(c);hb=b+32|0;b=x[b+24>>2];break a}a=P()|0;Ib(c);break b}a=P()|0;hg(c)}S(a|0);p()}x[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[23420]=0;c=Q(1,e+8|0,(a<<2)+32e3|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;U(433,b|0,a|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}yb(c);a=a+1|0;continue}break}a=P()|0;break f}a=P()|0;yb(c)}hg(e+24|0);S(a|0);p()}hb=e+32|0;return b|0}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;a:{b:{c:{g=x[a+12>>2];i=x[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|(g|0)==-1){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;while(1){if(d){e=x[f+12>>2]+j|0;h=(x[f+8>>2]>>>16&65520)+b|0;e=(((((((D(v[e-2|0],w[h+2>>1])+D(v[e-3|0],w[h>>1])|0)+D(v[e-1|0],w[h+4>>1])|0)+D(v[e|0],w[h+6>>1])|0)+D(v[e+1|0],w[h+8>>1])|0)+D(v[e+2|0],w[h+10>>1])|0)+D(v[e+3|0],w[h+12>>1])|0)+D(v[e+4|0],w[h+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(e,l);x[c+4>>2]=x[c+4>>2]+D(e,k);Rb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function fs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(We(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Ih(i,f,a,b);k=mx(h,g,a,b),l=E(E(x[j>>2])*E(7.450580596923828e-9)),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;x[e+12>>2]=1;a:{if(go(a)){c=x[a>>2];j=fg(c,x[a+4>>2]);x[e+8>>2]=j;k=x[Hb(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Db(x[b>>2]);g=Db(x[b+4>>2]);d=hb-16|0;hb=d;h=yB(f,g);b:{if(h>>>0<=Gm(c)>>>0){x[d+8>>2]=g;l=x[c>>2];i=Mc(l,x[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{x[d+8>>2]=f;YO(d+8|0,i);i=x[d+8>>2]}f=Hi(f,i,l);if(!m){_O(c,x[d+8>>2],g,h-Mc(x[c>>2],x[c+4>>2])|0);break b}Nd(c,f);break b}ZO(c);Pp(c,yj(c,h));_O(c,f,g,h)}hb=d+16|0;No(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!j){sz(a,1-j|0,b);break a}RO(a,x[a>>2]+32|0);break a}if(x[a>>2]){TO(a);c=x[a>>2];go(a);Ib(c);n=Fb(a),o=0,x[n>>2]=o;x[a>>2]=0;x[a+4>>2]=0}c=Mp(a,1);if(hh(134217727)>>>0<c>>>0){Tc();p()}d=EP(c);x[a>>2]=d;x[a+4>>2]=d;n=Fb(a),o=d+(c<<5)|0,x[n>>2]=o;sz(a,1,b)}hb=e+16|0}function SV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-96|0;hb=d;zc(b);Lo(a);a:{if(!jv(b,d+56|0)){break a}if(!bD(d+56|0)){break a}b:{if(!c){break b}if(!Nb(x[b>>2],x[b+8>>2],ac(x[d+60>>2])-28|0)){break a}Av(a);g=d,h=zv(),x[g+32>>2]=h;e=d+32|0;yv(Cj(x[a+4>>2])+32|0,e);er(e);c=x[Cj(x[a+4>>2])+32>>2];x[23420]=0;R(179,e|0,b|0);b=x[23420];x[23420]=0;c:{if((b|0)==1){break c}b=x[d+32>>2];e=x[d+60>>2];f=x[d+68>>2];x[23420]=0;b=fa(180,b|0,ac(e)-28|0,c|0,ac(f)|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}e=0;if(!b){break a}ke(d+16|0,x[c>>2],x[c+4>>2]);Lg(d+24|0,x[d+16>>2],x[d+20>>2]);b=$d(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=cr(d+32|0,x[d+24>>2],x[d+28>>2],d);bd(Cj(x[a+4>>2])+12|0,b);zb(b);break b}a=Aa(91780,25912)|0;b=ib;d:{if((da(91780)|0)==(b|0)){break d}if((da(25912)|0)==(b|0)){break d}S(a|0);p()}_(a|0)|0;$();e=0;break a}e=1}hb=d+96|0;return e|0}function SL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=hb-16|0;hb=c;d=Jb(a);while(1){b:{c:{d:{if(Eb(g)>>>0>f>>>0){b=x[fj(g,f)>>2];if(b>>>0>=2097152){x[23420]=0;R(50,d|0,63);a=x[23420];x[23420]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[23420]=0;R(50,d|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break c}break b}hb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[23420]=0;R(50,d|0,(a|i)<<24>>24);h=x[23420];x[23420]=0;a=e;break e}x[23420]=0;a=a-1|0;R(50,d|0,v[a+(c+10|0)|0]|-128);h=x[23420];x[23420]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;yb(d);S(a|0);p()}}function MD(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=hb-32|0;hb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;wf(g+16|0,a,b,c,e,f-16129|0);Wl(g,a,b,c,e,16257-f|0);b=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|b>>>25;h=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}hb=g+32|0;return l(2,d&-2147483648|e),r()}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;QR(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!cf(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}hb=e+16|0}function HU(a,b){var c=0,d=0;d=y[a|0];if(d>>>0>=36){v[a|0]=0;return}c=y[d+26144|0];v[a|0]=c;a:{b:{c:{d:{e:{f:{switch(c-6|0){default:if((c|0)==31){break b}if((c|0)==23){break e}if(y[b|0]|(c|0)!=1){break a}v[a|0]=0;return;case 8:a=y[b|0];v[b|0]=D(a>>>4|0,10)+(a&15);return;case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f}}c=y[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}v[b|0]=a;return}a=y[b|0];if(a>>>0<=64){v[b|0]=a<<1;return}v[b|0]=128;return}g:{h:{i:{j:{c=y[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}v[a|0]=20;v[b|0]=159;return}v[a|0]=20;v[b|0]=192;return}if(c&14){break a}v[a|0]=21;v[b|0]=(y[b|0]!=80)<<6;return}v[a|0]=20;v[b|0]=y[b|0]&15|160;return}if(y[b|0]>31){break a}v[a|0]=16;return}v[b|0]=(d<<5|y[b|0]>>>3)^128}}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=hb-16|0;hb=e;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){f=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;x[(f<<2)+e>>2]=(((((D(w[b+8>>1],p)+D(w[b+4>>1],q)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/2|0)+((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g);Rb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function g6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=hb-16|0;hb=h;if(Uh(a+44|0)){f=x[a+44>>2];g=Ec(f,0);x[h+8>>2]=g;f=Ec(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Ec(j,0);x[h>>2]=m;j=Ec(j,1);x[h+4>>2]=j;a:{if(B[Cb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;pc(m,e,g);pc(j,f,g);f=x[a+56>>2];m=Ec(f,0);j=Ec(f,1)}ji(a,b,c,m,j,d)}hb=h+16|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=vd(d,x[a+4>>2]);if(c>>>0<b>>>0){f=hb-32|0;hb=f;c=b-c|0;b=x[Fb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=hb-16|0;hb=d;b=zt(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);hb=d+16|0}else{$P(a);a=a+12|0;x[b+4>>2]=a;continue}break}break a}b=Fb(a);b=nk(f+8|0,Vm(a,vd(x[a>>2],d)+c|0),vd(x[a>>2],x[a+4>>2]),b);e=hb-16|0;hb=e;d=aQ(e,b+8|0,c);c=x[d>>2];while(1){if(x[d+4>>2]!=(c|0)){$P(c);c=x[d>>2]+12|0;x[d>>2]=c;continue}break}Id(d);hb=e+16|0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Zj(x[d>>2]-12|0,c);x[d>>2]=x[d>>2]-12;continue}break}nc(a,d);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2];a=x[b+4>>2];while(1){c=x[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;x[b+8>>2]=c;bQ(c);continue}break}a=x[b>>2];if(a){Po(b);Ib(a)}}hb=f+32|0;return}if(b>>>0<c>>>0){cQ(a,d+D(b,12)|0)}}function es(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Ih(h,g,a,b);j=kx(d,a,b),k=E(E(x[i>>2])*E(7.450580596923828e-9)),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);p()}aa(7115,8947,34,8660);p()}aa(5858,8947,35,8660);p()}aa(5828,8947,36,8660);p()}hb=c- -64|0}function daa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;b=x[a+4>>2];if(Rd(y[b+223884|0])){GN(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=hb-16|0;hb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Tm(b)>>>0>=c>>>0){g=x[b>>2];h=Gg(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Hb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){UM(b,c-h|0,d);break a}Nd(b,x[b>>2]+(c<<3)|0);break a}bO(b);hz(b,br(b,c));UM(b,c,d)}hb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){hb=f+16|0}else{d=D(b,872);_n((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1418|0]=0;v[c+1415|0]=0;v[c+1413|0]=0;b=b+1|0;continue}break}}function lA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=hb-32|0;hb=i;BR(a,b);h=hb-16|0;hb=h;pd(c,1);g=Lb(y[b+22|0]|y[b+23|0]<<8)<<1;x[c>>2]=g;v[c+37|0]=y[b+24|0]<<4;v[h+15|0]=y[b+25|0];v[h+14|0]=64;l=c,m=y[Wb(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Lb(y[b+26|0]|y[b+27|0]<<8);a=f<<1;j=f;k=Lb(y[b+28|0]|y[b+29|0]<<8);f=k<<1;a=k>>>0>=2?a+f>>>0<=g>>>0?a:j+f>>>0>g>>>0?a:j:a;a:{b:{switch(g|0){case 2:x[c>>2]=0;break a;case 0:break a;default:break b}}x[c+4>>2]=a;f=a+f|0;x[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;x[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){x[c+4>>2]=0;x[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){x[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}w[c+34>>1]=z[c+34>>1]|2}hb=h+16|0;ml(i,3,b);a=i+16|0;Fc(a,i);c=Dc(d,a);xb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((y[d|0]-1&255)>>>0<=30){v[d|0]=32}a=a+1|0;continue}break}a=nA(b);hb=i+32|0;return a}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=x[a>>2];d=ik(e,x[a+4>>2]);if(d>>>0<b>>>0){h=hb-32|0;hb=h;a:{b:{e=b-d|0;b=x[Fb(a)>>2];f=x[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Wx(a,e,c);break c}d=Fb(a);f=uL(a,ik(x[a>>2],f)+e|0);g=ik(x[a>>2],x[a+4>>2]);b=h+8|0;Jf(b+12|0,d);if(f){d=tL(f)}else{d=0}x[b>>2]=d;g=d+D(g,52)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=yc(b),j=d+D(f,52)|0,x[i>>2]=j;x[23420]=0;U(834,b|0,e|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}f=x[a>>2];c=x[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=Zj(x[e>>2]-52|0,c);x[d+20>>2]=x[c+20>>2];g=x[c+16>>2];x[d+12>>2]=x[c+12>>2];x[d+16>>2]=g;Zj(d+24|0,c+24|0);Rc(d+36|0,c+36|0);x[d+48>>2]=x[c+48>>2];x[e>>2]=x[e>>2]-52;continue}break}nc(a,e);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2];sL(b)}hb=h+32|0;break a}a=P()|0;sL(b);S(a|0);p()}return}if(b>>>0<d>>>0){vL(a,e+D(b,52)|0)}}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){j=w[(x[g+12>>2]<<1)+n>>1]<<8;e=j;e=Wia(e,e>>31,t,u);i=lb;h=e;e=Xb(b,-16777216,16776704);k=Wia(r,s,e,e>>31);h=h+k|0;e=lb+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Wia(p,q,f,f>>31);h=i+h|0;f=lb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,m)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,l);Rb(g+8|0,v,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function lw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Eb(h)){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Eb(h)){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=nw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=y[(a>>2)+81808|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((y[a-1|0]&95)!=(y[c|0]&127)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Eb(h)){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0;g=hb-16|0;hb=g;f=x[a+48>>2];l=x[a+24>>2];m=x[a+20>>2];e=x[a+44>>2];n=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;o=x[a+72>>2];b=x[a+68>>2];p=b;q=b>>31;b=x[a+64>>2];r=b;s=b>>31;b=x[a+60>>2];t=b;u=b>>31;w=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){j=v[x[g+12>>2]+n|0]<<16;e=j;e=Wia(e,e>>31,t,u);i=lb;h=e;e=Xb(b,-16777216,16776704);k=Wia(r,s,e,e>>31);h=h+k|0;e=lb+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Xb(f,-16777216,16776704);i=Wia(p,q,f,f>>31);h=i+h|0;f=lb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Qc(e,f,24);e=(f|0)/256|0;x[c>>2]=D(e,m)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,l);Rb(g+8|0,w,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;hb=g+16|0}function i2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(We(x[c+24>>2],g)>>>0<d>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Og(i,f,a,b);k=mx(h,g,a,b),l=E(C[j>>3]),B[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function Ll(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Hk(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Kl(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}ec(a,21);x[a+1396>>2]=0}return-1}aa(11236,13048,1705,5406);p()}function KB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((y[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=D(c,13)+a|0;if(y[d+14|0]){break b}b=(c<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break b}f=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(y[d+942|0]|f>>>0>1048575){break b}d=D(c,11)+a|0;g=d+1346|0;if(y[g|0]>15|y[d+1351|0]>3|y[d+1356|0]>3){break b}c:{d:{e:{if(f){d=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}if(f){break d}break e}b=1;if(e){break c}}if(Ob(g,26109,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=v[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function YW(){var a=0,b=0,c=0,d=0;c=hb-32|0;hb=c;a:{a=Vb(c+16|0,14812);if(!Eb(a)){break a}b:{if((sg(a,14489)|0)!=-1){b=sg(a,14489);x[23420]=0;X(118,c|0,a|0,b+1|0,-1);b=x[23420];x[23420]=0;if((b|0)==1){break b}Ac(a,c);xb(c)}if((sg(a,16618)|0)!=-1){b=sg(a,16618);x[23420]=0;X(118,c|0,a|0,b+1|0,-1);b=x[23420];x[23420]=0;if((b|0)==1){break b}Ac(a,c);xb(c)}if((sg(a,13706)|0)!=-1){b=sg(a,13706);x[23420]=0;X(118,c|0,a|0,0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}Ac(a,c);xb(c)}if((sg(a,13555)|0)!=-1){b=sg(a,13555);x[23420]=0;X(118,c|0,a|0,0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}Ac(a,c);xb(c)}if((sg(a,13598)|0)!=-1){b=sg(a,13598);x[23420]=0;X(118,c|0,a|0,0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}Ac(a,c);xb(c)}x[23420]=0;b=T(119,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break a}}c=P()|0;xb(a);S(c|0);p()}xb(a);hb=c+32|0;return b|0}function ww(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[116710];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function aO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;b=x[a>>2];gc(g+8|0,b);a:{b:{c:{d:{e:{if(wd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[23420]=0;d=ga(42)|0;e=x[23420];x[23420]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(92364)|0;if((ib|0)!=(da(92364)|0)){break c}_(c|0)|0;v[b+20|0]=0;x[23420]=0;Y(30,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}$();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}hb=g+16|0;break a}c=P()|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break b}}S(c|0);p()}V(0)|0;Ub();p()}return x[a+28>>2]&f}function IE(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=hb-96|0;hb=i;oy(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;e=i+32|0;c=i+80|0;a:{d=0;while(1){b:{if((d|0)!=4){if(x[(d<<2)+c>>2]){break b}}else{d=4}break a}d=d+1|0;continue}}c=Vg(e,c,d,b);k=B[a+48>>2];e=x[a+32>>2];x[i+8>>2]=x[c+8>>2];d=x[c+4>>2];x[i>>2]=x[c>>2];x[i+4>>2]=d;d=hb-16|0;hb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=dJ(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=k;x[c>>2]=g;hb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=fJ(d,x[Nq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=i+96|0;return j}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[a+4>>2]=0;if(Rd(y[sn(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;b=T(92,b|0)|0;c=x[23420];x[23420]=0;d:{if((c|0)!=1){if(!uc(b,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}e:{while(1){c=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;c=T(92,c|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break e}if(uc(c,-1)){break b}c=x[a+4>>2]+1|0;x[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}_(V(0)|0)|0;c=1;rn(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break f}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break g}S(a|0);p()}$();break a}V(0)|0;Ub()}p()}c=2}hk(x[x[a>>2]-12>>2]+a|0,c)}hb=d+16|0;return a|0}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=hb-16|0;hb=e;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];f=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=f;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){f=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;x[(f<<2)+e>>2]=(((((D(v[b+4|0],p)+D(v[b+2|0],q)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/2|0)+((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g);Rb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;hb=e+16|0}function dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;d=hb-16|0;hb=d;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;IL(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);IL(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}v[b+31|0]=e}w[d+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[d+12>>1]=127;i=b,j=y[Zc(d+14|0,d+12|0)|0]+1|0,v[i+30|0]=j}v[b+33|0]=y[c+212|0];hb=d+16|0}else{i=bc(f,e+12|0),j=y[c+e|0],w[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=bc(e,h+12|0);d=y[c+h|0];w[f>>1]=d>>>0<(y[a+27|0]|y[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}ml(g,3,a+4|0);c=g+16|0;Fc(c,g);Dc(b+492|0,c);xb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}hb=g+32|0}function $1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);c=hb+-64|0;hb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;uf(c+48|0,c+32|0,d);a=x[b+4>>2];e=x[a+8>>2];f=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=f>>>0){if(A[d+4>>2]<f>>>0){break d}if(A[c+8>>2]<e>>>0){break c}if(We(x[d+8>>2],x[d+12>>2])>>>0<e>>>0){break b}h=x[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Og(h,g,a,b);j=kx(d,a,b),k=E(C[i>>3]),B[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);p()}aa(7115,8947,78,8627);p()}aa(5858,8947,79,8627);p()}aa(5828,8947,80,8627);p()}hb=c- -64|0}function PP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=hb-16|0;hb=f;n=x[a+20>>2];g=z[a+34>>1]&65;x[f+8>>2]=g;x[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=gj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=g}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){xc(e+76|0,c);b=x[e+104>>2]}d=x[e+88>>2];b=_C(d,b);h=x[(b?q:p)>>2];x[e+84>>2]=x[(b?s:r)>>2];x[e+80>>2]=h;b=d|x[f+8>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[f>>2]^-1);b=e+704|0;h=x[a+24>>2];a:{if(!x[e+704>>2]|!h){break a}if(qm(x[t>>2])){break a}d=x[(j?b:i)>>2];k=Wia(x[(j?i:b)>>2],0,x[e+700>>2],0);l=k+(d>>>1|0)|0;m=lb;u=e,v=Vc(Zia(l,k>>>0>l>>>0?m+1|0:m,d,0),lb),x[u+700>>2]=v}x[b>>2]=h}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=g;xz(n);hb=f+16|0}function up(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;f=Wia(b,d,5e4,0);e=lb;b=x[Yc(c+8|0,c)>>2];b=Hc(Xia(f,e,b,b>>31),lb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=Wia(x[a+1074420>>2],0,Wia(x[a+1074408>>2],0,x[a+1074416>>2],0),lb),x[g>>2]=h;x[c+4>>2]=lb;b=Wia(b,0,6e5,0);d=c+8|0;e=b;f=lb;b=Yu(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=Zia(e,f,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];f=Wia(b,d,1e4,0);e=lb;b=x[Yc(c+8|0,c)>>2];b=Hc(Xia(f,e,b,b>>31),lb);x[a+1074404>>2]=b}e=a+1074404|0;a=x[a+480244>>2];b=Wia(a,a>>31,b,b>>31)+32768|0;a=lb;a=Hc(Xia(b,b>>>0<32768?a+1|0:a,65536,0),lb);x[e>>2]=a?a:1;hb=c+16|0}function z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;e=Jb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}x[23420]=0;c=T(177,b|0)|0;f=x[23420];x[23420]=0;d:{if((f|0)!=1){x[d+12>>2]=c;if((c|0)>0){break d}x[23420]=0;Q(54,a|0,21473)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}break a}x[23420]=0;c=T(190,b|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){g=d,h=vi(c),x[g+8>>2]=h;c=x[td(d+12|0,d+8|0)>>2];x[23420]=0;R(45,e|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[23420]=0;c=T(194,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break f}if(!c){break e}x[23420]=0;W(802,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[23420];x[23420]=0;if((c|0)!=1){continue}}break}break a}x[23420]=0;Q(176,b|0,4)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}Rc(a,e)}xb(e);hb=d+32|0;return}a=P()|0;xb(e);S(a|0);p()}function hK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=0,p=E(0);d=a+4208|0;j=E(E(B[Cb(d,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[Cb(d,3)>>2]*E(.9980000257492065));f=-3e3/+E(j*E(A[x[a+16>>2]+24620>>2]));h=a+4272|0;c=Gj(10,f*+A[Cb(h,4)>>2]);d=a+4232|0;o=Cb(d,0),p=E(c),B[o>>2]=p;c=Gj(10,f*+A[Cb(h,5)>>2]);o=Cb(d,1),p=E(c),B[o>>2]=p;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=Gj(10,+eK(B[Cb(e,0)>>2])*.05);b=4/M(c)*f;c=Gj(10,+eK(B[Cb(e,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{g=Cb(h,e);k=e>>>1|0;n=x[Cb(h,k+4|0)>>2];g=x[g>>2];i=Gj(10,m*+(n+g>>>0));b=Gj(10,f*+(g>>>0));j=B[Cb(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Cb(d,g+2|0),p=E(b*(1-i)),B[o>>2]=p;o=Cb(d,g+3|0),p=E(b*i),B[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function Jda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(y[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Df(a);Ws(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}wp(a,e);c=c+1|0;continue}break}}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;pd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Gq(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=Gq(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(Iu(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}hb=e+16|0}function ZH(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=hb-96|0;hb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}YH(e+48|0);YH(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+7e4>>2];m=B[d+70036>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}hb=e+96|0}function c3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb+-64|0;hb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(kj(Yb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[bc(x[Yb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!zm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[_b(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;hM(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+48|0;Jt(b,c,g?7:1,e);j=a,k=C[aM(x[e+52>>2])>>3],C[j+16>>3]=k;ui(b);a=a+16|0}hb=e- -64|0;return+C[a>>3]}function IL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=hb-16|0;hb=k;v[k+15|0]=c;v[k+14|0]=12;bh(b,y[Wb(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=qe(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(uc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}hb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Cb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Cb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=Cb(l,c);j=z[i>>1];n=Cb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function eN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;h=-1;a:{if(!ky(a,b,2)){break a}f=x[b+656>>2];g=a+1074312|0;Ab(e+8|0,g,31);b:{if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){d=x[b+740>>2];if(d){break b}break a}d=x[b+740>>2]}Ab(e+8|0,g,31);g=d-Bb(x[x[e+8>>2]>>2],x[e+12>>2])|0;i=x[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=Hp(j,g,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){h=Cp(a,b,!(x[b+88>>2]&32768),d);break a}if(nj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=Xc(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=gj(a);x[e+8>>2]=d;c:{if((d|0)<0){x[e+8>>2]=0-d;Vh(e+8|0,255);a=(x[e+8>>2]<<2)+(a?38160:37136)|0;break c}Vh(e+8|0,255);a=(x[e+8>>2]<<2)+(a?37136:38160)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Hc(Xia(Wia(b,d,a,a>>31),lb,65536,0),lb),x[k>>2]=l}hb=e+16|0;return h}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){f=x[b+8>>2];n=((((x[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=w[e+39718>>1];p=w[e+39716>>1];q=w[e+39714>>1];r=w[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;x[(e<<2)+b>>2]=(((D(w[f>>1],q)+D(w[f-4>>1],r)|0)+D(w[f+4>>1],p)|0)+D(w[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;x[c>>2]=x[c>>2]+D(x[b>>2],h>>12);g=g+j|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=b+16|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;pd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+42714|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function Gy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Rj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!wd(f)){break a}if(!RM(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){c=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=x[(D(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=x[(D(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function CC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-32|0;hb=c;x[23420]=0;e=Q(12,c+24|0,466312)|0;d=x[23420];x[23420]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!y[e|0]){break e}f=xm(c+8|0,466312);d=x[x[116578]-12>>2]+466312|0;g=x[d+4>>2];x[23420]=0;h=T(13,d|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break d}f=x[f>>2];x[23420]=0;b=a+b|0;a=ka(14,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break d}x[c+16>>2]=a;if(!uu(c+16|0)){break e}a=x[x[116578]-12>>2];x[23420]=0;R(15,a+466312|0,5);a=x[23420];x[23420]=0;if((a|0)!=1){break e}break d}hl(e);break b}a=V(0)|0;hl(e);break c}a=V(0)|0}_(a|0)|0;a=x[x[116578]-12>>2];x[23420]=0;Y(16,a+466312|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=c+32|0;return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){V(0)|0;Ub();p()}S(a|0);p()}function V9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-880|0;hb=b;c=Tb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=HP(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Qb(d);g=Ky(c+223860|0);f=b+8|0;Tb(f,0,108);Jz(b+120|0,48e3);Tb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Tb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=yp(e,f)+872|0;continue}break}x[23420]=0;R(489,d|0,32);a=x[23420];x[23420]=0;if((a|0)!=1){hb=b+880|0;return c|0}a=P()|0;zp(g);dc(d);S(a|0);p()}function VH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){ec(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){ec(a,1);break a}if(Ob(c,92708,4)){ec(a,21);break a}if(y[c+4|0]){ec(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}ec(a,21);break a}if(v[c+5|0]&1){break d}ec(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){ec(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}ec(a,1)}return 0}function t6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=li(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=46700;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Qb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=Cb(a,0),g=1063675494,x[f>>2]=g;f=Cb(a,1),g=1065185444,x[f>>2]=g;f=Cb(a,2),g=0,x[f>>2]=g;f=Cb(a,3),g=1032805417,x[f>>2]=g;f=Cb(a,4),g=1053079357,x[f>>2]=g;f=Cb(a,5),g=1059859440,x[f>>2]=g;f=Cb(a,6),g=1047457519,x[f>>2]=g;f=Cb(a,7),g=1062836634,x[f>>2]=g;f=Cb(a,8),g=1038174126,x[f>>2]=g;f=Cb(a,9),g=1065353216,x[f>>2]=g;f=Cb(a,10),g=1065353216,x[f>>2]=g;f=Cb(a,11),g=1048525618,x[f>>2]=g;f=Cb(a,12),g=1059760811,x[f>>2]=g;x[23420]=0;R(853,b+44|0,2);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;while(1){c=tc(c-24|0);if((e|0)!=(c|0)){continue}break}vf(b);S(a|0);p()}ki(b);return b|0}function cG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=hb-32|0;hb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[115896];x[115896]=0;g=hb-16|0;hb=g;Ad();e=hb-16|0;hb=e;f=hb-16|0;hb=f;vw(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;hb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;hb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;hb=g+16|0;i=x[h+16>>2];f=x[h+20>>2];g=x[h+8>>2];e=x[h+12>>2];b=x[115896];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[115896]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;g=l;e=m;i=n;f=o}x[a>>2]=g;x[a+4>>2]=e;x[a+8>>2]=i;x[a+12>>2]=f;hb=h+32|0}function jia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-32|0;hb=g;e=b;b=x[a>>2];b=We(e,Db(b))+b|0;e=IT(c,d);a:{if((e|0)<=0){break a}f=x[Fb(a)>>2];h=x[a+4>>2];if((f-h|0)>=(e|0)){x[g+8>>2]=d;i=h-b|0;if((i|0)<(e|0)){x[g+8>>2]=c;MA(g+8|0,i);f=x[g+8>>2];l=hb-16|0;hb=l;j=Bl(l,a,e-i|0);k=hb-16|0;hb=k;x[k+8>>2]=f;while(1){if(Pb(f,d)){tk(x[j+4>>2],y[f|0]);f=Be(k+8|0);x[j+4>>2]=x[j+4>>2]+1;f=x[f>>2];continue}break}hb=k+16|0;kc(j);hb=l+16|0;if((i|0)<=0){break a}}HT(a,b,h,b+e|0);ah(c,x[g+8>>2],b);break a}f=Fb(a);f=Dl(g+8|0,Al(a,Wc(x[a>>2],h)+e|0),b-x[a>>2]|0,f);e=hb-32|0;hb=e;x[e+24>>2]=c;c=Nv(e+8|0,f+8|0,IT(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){tk(d,y[x[e+24>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;Be(e+24|0);continue}break}Id(c);hb=e+32|0;b=GT(a,f,b);Cl(f)}Db(b);hb=g+32|0}function W1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-96|0;hb=d;x[23420]=0;e=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=e;e=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=e;e=T(1030,d+32|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){a:{b:{if(e){x[23420]=0;R(1031,d+72|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){b=d+80|0;pv(b,x[d+72>>2],x[d+76>>2]);e=qg(d+88|0,b);f=qg(d- -64|0,c);g=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=g;e=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=e;qv(a,d+8|0,d);break b}break a}x[23420]=0;R(1032,d+72|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}b=d+80|0;pv(b,x[d+72>>2],x[d+76>>2]);e=qg(d+56|0,b);f=qg(d+48|0,c);g=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=g;e=x[f+4>>2];x[d+16>>2]=x[f>>2];x[d+20>>2]=e;qv(a,d+24|0,d+16|0)}de(b);de(d+72|0);de(c);hb=d+96|0;return}}a=P()|0;de(c);S(a|0);p()}function w5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-32|0;hb=e;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[23420]=0;Y(903,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}x[23420]=0;Y(903,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break g}f=x[a+24>>2];x[23420]=0;d=Q(54,e+16|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break g}x[23420]=0;c=Q(54,e|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break f}x[23420]=0;X(918,f|0,d|0,c|0,1);b=x[23420];x[23420]=0;if((b|0)==1){break e}xb(c);xb(d);b=1;break b}b=V(0)|0;break c}b=V(0)|0;break d}b=V(0)|0;xb(c)}xb(d)}_(b|0)|0;b=0;x[23420]=0;X(889,6370,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=e+32|0;return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=hb-16|0;hb=b;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){f=x[b+8>>2];n=(((x[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=w[e+39718>>1];p=w[e+39716>>1];q=w[e+39714>>1];r=w[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;x[(e<<2)+b>>2]=(((D(v[f|0],q)+D(v[f-2|0],r)|0)+D(v[f+2|0],p)|0)+D(v[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;x[c>>2]=x[c>>2]+D(x[b>>2],h>>12);g=g+j|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=b+16|0}function st(a,b){var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=e+24|0;IP(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);IP(e,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=x[d+4>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e+4>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=x[d+8>>2];b=Lb(y[b|0]|y[b+1|0]<<8);a=x[e+8>>2];a=Lb(y[a|0]|y[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=x[d+16>>2];a=x[e+12>>2];f=x[e+16>>2];d=x[d+12>>2];d=Lb(y[d|0]|y[d+1|0]<<8)<<16>>16;a=Lb(y[a|0]|y[a+1|0]<<8)<<16>>16;c=1;d:{if((d|0)<(a|0)){break d}c=0;if((a|0)<(d|0)){break d}c=Lb(y[b|0]|y[b+1|0]<<8)>>>0<Lb(y[f|0]|y[f+1|0]<<8)>>>0}}}}a=c;hb=e+48|0;return a}function lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=hb-432|0;hb=d;zc(b);AA(b,d+376|0,d+296|0,d+8|0);k=d,l=xi((m=y[d+427|0]+1|0,n=1,o=ac(x[d+408>>2]),o?m:n)),v[k+4|0]=l;i=y[Wb(26640,d+4|0)|0];v[d+7|0]=i;w[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Lb(z[d+8>>1])<<16>>16;if(!((e|0)<0|y[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=ac(x[d+296>>2]);if(e>>>0<g>>>0){if($c(b,g)){break c}}v[d+7|0]=h+1;break b}}else{d:{if(!$c(b,ac(x[d+392>>2])+(f<<2)|0)){break d}if(!$c(b,to(b))){break d}e:{if(!c){j=Ee(b);break e}j=wq(b)}w[d+2>>1]=j;k=d,l=z[Ve(d+4|0,d+2|0)>>1],w[k+4>>1]=l}f=f+1|0;continue}break}g=ac(x[d+296>>2]);AA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}bv(a);break a}w[a>>1]=z[d+4>>1];v[a+2|0]=y[d+7|0]}hb=d+432|0}
function av(a,b,c,d){var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;a:{if(!c){break a}if(d){b=fc(g+8|0,a,b);a=hb-16|0;hb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];h=e;e=x[Hb(a+8|0,a+12|0)>>2];x[c>>2]=-1<<d&-1>>>h-e|x[c>>2];f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Tb(e,255,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+x[b>>2]|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-e}hb=a+16|0;break a}b=fc(g,a,b);a=hb-16|0;hb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Hb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Tb(e,0,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+x[b>>2]|0;x[c>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-e^-1)}hb=a+16|0}hb=g+16|0}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-48|0;hb=g;h=a+8|0;c=x[a+8>>2];j=yc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;e=x[a+4>>2];d=x[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=wU(e,a)+2|0;a=a+2|0;continue}break}c=e;x[h>>2]=c;x[i>>2]=d+x[i>>2];break a}x[g+24>>2]=c-d;x[g+44>>2]=1;e=g+24|0;c=x[Yc(e,g+44|0)>>2];c=xj(e,c,c>>>2|0,x[a+16>>2]);d=gc(g+16|0,x[a+4>>2]);f=x[gc(g+8|0,x[a+8>>2])>>2];e=hb-32|0;hb=e;d=x[d>>2];x[e+24>>2]=d;d=Co(e+8|0,c+8|0,yB(d,f));f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){k=f;f=x[e+24>>2];sq(k,y[f|0]|y[f+1|0]<<8);f=x[d>>2]+2|0;x[d>>2]=f;Re(e+24|0);continue}break}Id(d);hb=e+32|0;nc(a,c);nc(i,c+4|0);nc(h,c+8|0);nc(j,yc(c));Fi(c);c=x[a+8>>2]}sq(c,y[b|0]|y[b+1|0]<<8);x[h>>2]=x[h>>2]+2;hb=g+48|0}function an(a,b,c,d){var e=0,f=0;f=hb-16|0;hb=f;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[23420]=0;R(d|0,f|0,e|0);d=x[23420];x[23420]=0;if((d|0)==1){break i}d=x[f>>2];e=vd(d,x[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;x[23420]=0;b=Q(956,d|0,7347)|0;e=x[23420];x[23420]=0;if((e|0)==1){break g}x[23420]=0;U(107,b|0,92140,156);b=x[23420];x[23420]=0;if((b|0)!=1){break b}b=V(0)|0;break f}b=V(0)|0;break e}b=V(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Wf(21473);break j}b=Wf(Ic(Hd(d,b)))}Ke(f);break d}b=V(0)|0;ca(d|0)}Ke(f)}_(b|0)|0;b=0;x[23420]=0;X(889,c|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break c}$()}hb=f+16|0;return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break a}V(0)|0;Ub()}p()}S(a|0);p()}function Ad(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(y[467124]){return x[116780]}c=hb-32|0;hb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=zG(a,d?14138:21473)}else{d=x[a<<2>>2]}x[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!yG(0)){b=88800;if(!Ob(c+8|0,88800,24)){break a}b=88824;if(!Ob(c+8|0,88824,24)){break a}a=0;if(!y[466896]){while(1){f=(a<<2)+466848|0,g=zG(a,21473),x[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}v[466896]=1;x[116718]=x[116712]}b=466848;if(!Ob(c+8|0,466848,24)){break a}b=466872;if(!Ob(c+8|0,466872,24)){break a}b=Ld(24);if(!b){break b}}a=x[c+12>>2];x[b>>2]=x[c+8>>2];x[b+4>>2]=a;a=x[c+28>>2];x[b+16>>2]=x[c+24>>2];x[b+20>>2]=a;a=x[c+20>>2];x[b+8>>2]=x[c+16>>2];x[b+12>>2]=a;break a}b=0}hb=c+32|0;v[467124]=1;x[116780]=b;return b}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=(x[f+12>>2]<<1)+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(w[b+4>>1],w[e+10>>1])+D(w[b+2>>1],w[e+8>>1])|0)+D(w[b+6>>1],w[e+12>>1])|0)+D(w[b+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[e+2>>1])+D(w[b-6>>1],w[e>>1])|0)+D(w[b-2>>1],w[e+4>>1])|0)+D(w[b>>1],w[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Rb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=f+16|0}function Pz(a,b){var c=0;c=hb-16|0;hb=c;a=Xq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(Mb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:ty(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Cf(a,107);break a;case 3:ty(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Cf(a,4);break a;case 2:break b;case 0:break c}}Mb(a,88,1);break a}ty(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}hb=c+16|0}function q8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((zj(x[a>>2],x[a+4>>2])|0)==2){if((zj(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[23420]=0;R(855,a|0,2);c=x[23420];x[23420]=0;c:{if((c|0)==1){break c}x[23420]=0;R(855,a+12|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}x[23420]=0;R(856,a+24|0,2);c=x[23420];x[23420]=0;if((c|0)==1){break c}x[23420]=0;R(856,a+36|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Uq(x[c+12>>2],a);f=Cb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=Uq(x[a>>2],d);f=Cb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;Gc(a);eL(a);b=a+12|0;Gc(b);eL(b);b=a+24|0;Gc(b);dL(b);a=a+36|0;Gc(a);dL(a);$()}return}S(b|0);p()}function GL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=hb-16|0;hb=c;e=Jb(a);g=c,h=Ei(b),x[g+8>>2]=h;g=c,h=_u(b),x[g>>2]=h;a=0;b:{while(1){c:{if(!Lh(c+8|0,c)){if(!a){break c}x[23420]=0;R(48,e|0,65533);a=x[23420];x[23420]=0;if((a|0)!=1){break c}break b}b=y[x[c+8>>2]];d:{e:{if(!a){if(b<<24>>24>=0){a=0;x[23420]=0;R(48,e|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;x[23420]=0;R(48,e|0,65533);f=x[23420];x[23420]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;x[23420]=0;R(48,e|0,d|0);b=x[23420];x[23420]=0;d=0;if((b|0)==1){break b}}Be(c+8|0);continue}break}hb=c+16|0;break a}a=P()|0;Jc(e);S(a|0);p()}}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=hb-4112|0;hb=c;h=mb[x[x[a>>2]+116>>2]](a)|0;if(!h){mb[x[x[a>>2]+120>>2]](a)}x[c+12>>2]=0;f=hb-16|0;hb=f;while(1){d=x[a+44>>2];if(zj(d,x[a+48>>2])>>>0<=e>>>0){hb=f+16|0}else{x[f+12>>2]=0;d=Uq(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;xc(c+8|0,512);e=c+16|0;wy(e);d=x[c+8>>2];mb[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Ix(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Ix(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){mb[x[x[a>>2]+124>>2]](a)}hb=c+4112|0;return E(B[c+12>>2])}function nd(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=x[a+4>>2];e=x[a+44>>2];b=f-e|0;h=b;g=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=Bw(a);if((h|0)>=0){break a}f=x[a+4>>2];e=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=x[a+4>>2];e=x[a+8>>2];c=x[a+112>>2];g=x[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}x[a+104>>2]=e;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=h}return h}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;g=x[a+40>>2];h=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[f+12>>2]+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(v[b+2|0],w[e+10>>1])+D(v[b+1|0],w[e+8>>1])|0)+D(v[b+3|0],w[e+12>>1])|0)+D(v[b+4|0],w[e+14>>1])<<8)/2|0)+((((D(v[b-2|0],w[e+2>>1])+D(v[b-3|0],w[e>>1])|0)+D(v[b-1|0],w[e+4>>1])|0)+D(v[b|0],w[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+k|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Rb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;hb=f+16|0}function RE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-48|0;hb=d;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{if((e|0)!=1){e=Jb(d+32|0);x[23420]=0;Y(c|0,d+16|0);c=x[23420];x[23420]=0;d:{e:{if((c|0)!=1){h=d,i=Db(x[d+16>>2]),x[h+8>>2]=i;f=1;while(1){g=Db(x[d+20>>2]);c=x[d+8>>2];if(!Pb(c,g)){c=Wf(Ic(e));Ke(d+16|0);xb(e);break b}if(!f){x[23420]=0;Q(891,e|0,14464)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}c=x[d+8>>2]}x[23420]=0;Q(755,e|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break e}_p(d+8|0);f=0;continue}}c=V(0)|0;break d}c=V(0)|0;Ke(d+16|0)}xb(e);break c}c=V(0)|0}_(c|0)|0;c=0;x[23420]=0;X(889,b|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=d+48|0;return c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){V(0)|0;Ub();p()}S(a|0);p()}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=hb-16|0;hb=h;if(Uh(a+44|0)){g=x[a+44>>2];r=h,s=Ec(g,0),x[r+8>>2]=s;r=h,s=Ec(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Ec(g,0);x[h>>2]=l;m=Ec(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=zK(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{ji(a,b,c,l,m,d)}break}}hb=h+16|0}function Pn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=Xc(Hp(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[Cb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function lp(a){var b=E(0),c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Zh(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Zh(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=_h(f+1.5707963267948966);break a}b=_h(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Zh(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=_h(-4.71238898038469-+a);break a}b=_h(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Rw(a,c+8|0)&3){case 0:b=Zh(C[c+8>>3]);break a;case 1:b=_h(-C[c+8>>3]);break a;case 2:b=E(-Zh(C[c+8>>3]));break a;default:break b}}b=_h(C[c+8>>3])}a=b;hb=c+16|0;return a}function E2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-32|0;hb=d;j=d,k=BJ(),x[j+24>>2]=k;g=a+24|0;c=d+24|0;zJ(g,Zd(c));cj(c);w[a+28>>1]=0;GO();f=hb-16|0;hb=f;e=wc(144);x[23420]=0;h=Q(1014,e|0,4)|0;i=x[23420];x[23420]=0;a:{if((i|0)!=1){e=x[mf(f+8|0,h)>>2];hb=f+16|0;break a}a=P()|0;Ib(e);S(a|0);p()}x[d+24>>2]=e;yJ(a+32|0,Zd(c));ns(c);j=d,k=AJ(x[a>>2]),x[j+24>>2]=k;wJ(a+4|0,Zd(c));bj(c);Bn(x[g>>2],x[a+4>>2]);x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;v[a- -64|0]=0;j=d,k=qj(x[b>>2]),x[j+24>>2]=k;e=yf(b);b:{while(1){b=x[d+24>>2];if(!zg(b,e)){break b}c=ud(b);b=Oh(d+8|0,c);x[23420]=0;X(918,a|0,b|0,c+12|0,0);c=x[23420];x[23420]=0;if((c|0)!=1){xb(b);Wg(d+24|0);continue}break}a=P()|0;xb(b);S(a|0);p()}hb=d+32|0}function YV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=hb-16|0;hb=g;$c(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Qb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[23420]=0;R(172,h|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[23420]=0;e=W(144,f|0,e|0,4)|0;f=x[23420];x[23420]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[23420]=0;e=Q(173,b|0,e|0)|0;f=x[23420];x[23420]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(vd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[23420]=0;R(174,h|0,g+12|0);e=x[23420];x[23420]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}hb=g+16|0;return}}a=P()|0;tc(h);S(a|0);p()}function VK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];l=y[b+4244|0];k=b+4208|0;Ki(k,33);d=x[k>>2];v[d+32|0]=l;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;ke(c+8|0,x[k>>2],x[b+4212>>2]);fc(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function fL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;a:{if(vc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!Jg(x[x[b>>2]-12>>2]+b|0)){break a}d=hb-16|0;hb=d;f=wc(64);x[23420]=0;g=T(790,f|0)|0;h=x[23420];x[23420]=0;b:{c:{if((h|0)!=1){f=mf(d,g);g=x[f>>2];x[23420]=0;g=W(850,g|0,b|0,c|0)|0;h=x[23420];x[23420]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Bc(d+8|0);break d}a=P()|0;hg(f);break c}Tf(d+8|0,f)}hg(f);hb=d+16|0;d=x[d+8>>2];break b}a=P()|0;Ib(f)}S(a|0);p()}x[e+8>>2]=d;f:{g:{if(!wd(d)){x[23420]=0;b=Q(849,b|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break g}x[e>>2]=b;US(e+8|0,Zd(e));hg(e);d=x[e+8>>2]}if(!wd(d)){break f}x[23420]=0;R(434,a|0,e+8|0);a=x[23420];x[23420]=0;i=d;if((a|0)!=1){break f}}a=P()|0;hg(e+8|0);S(a|0);p()}hg(e+8|0)}hb=e+16|0;return i}function ZJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=hb-48|0;hb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[23420]=0;a=Q(882,(d?d:883)|0,e|0)|0;b=x[23420];x[23420]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+16>>2]=a;a=x[Tf(j+24|0,j+16|0)>>2];b=x[j+44>>2];x[j+8>>2]=x[j+40>>2];x[j+12>>2]=b;x[23420]=0;b=x[j+36>>2];x[j>>2]=x[j+32>>2];x[j+4>>2]=b;c=+xa(884,j|0,+c,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}se(j+16|0);break b}a=V(0)|0;break c}a=V(0)|0;se(j+16|0)}_(a|0)|0;x[23420]=0;ia(885,14893,d|0,e|0,f|0,g|0,h|0,i|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();c=0}hb=j+48|0;return+c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function EK(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=_h(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Zh(d+1.5707963267948966));break a}a=Zh(d+-1.5707963267948966);break a}a=_h(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Zh(d+4.71238898038469);break a}a=E(-Zh(d+-4.71238898038469));break a}a=_h(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Rw(a,b+8|0)&3){case 0:a=_h(C[b+8>>3]);break a;case 1:a=Zh(C[b+8>>3]);break a;case 2:a=_h(-C[b+8>>3]);break a;default:break b}}a=E(-Zh(C[b+8>>3]))}hb=b+16|0;return a}function YH(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function Hp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=x[a>>2];e=x[a+4>>2];i=qe(f,e)-1|0;while(1){a:{b:{if(qe(f,e)-1>>>0<=g>>>0){g=i;break b}if(z[Kc(f,e,g)>>1]<(b|0)){break a}e=x[a+4>>2];f=x[a>>2]}i=z[Kc(f,e,g)>>1];f=0;x[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(y[Kc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0,x[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(y[Kc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=f;e=z[Kc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((y[Kc(x[a>>2],x[a+4>>2],g)+2|0]<<16>>>0)/(d>>>0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Wia(d,g,a,a>>31);a=i-e|0;j=h,k=Hc(Xia(b,lb,a,a>>31),lb)+f|0,x[j+12>>2]=k}ge(h+12|0,0,65536);hb=h+16|0;return(D(x[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=x[a+4>>2];f=x[a>>2];continue}}function mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-80|0;hb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=$d(c+72|0);e=b-d|0;g=pt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){lm(c+56|0,x[a>>2],d);fc(f,x[c+56>>2],x[c+60>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=ao(c+56|0);x[23420]=0;b=Q(681,a|0,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break a}x[23420]=0;R(682,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;$k(c+40|0,x[a>>2]);lm(c+32|0,x[a>>2],x[a+4>>2]);$k(c+24|0,x[d>>2]);b=x[c+44>>2];x[c+8>>2]=x[c+40>>2];x[c+12>>2]=b;PQ(c+48|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);fc(f,x[c+48>>2],x[c+52>>2]);wt(a,d);Je(d)}a=fc(c+16|0,x[f>>2],x[f+4>>2]);av(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}hb=c+80|0;return}a=P()|0;Je(d);S(a|0);p()}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;RR(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!cf(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}hb=e+16|0}function YZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=LF(c);b:{if(b){wk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;vk(k,a);break b}vr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Gh(k,a)}Pi(i,k);Jc(k);l=e,m=Vi(a),x[l>>2]=m;l=f,m=Wi(a),x[l>>2]=m;Ng(k,a);Ac(g,k);xb(k);Hh(k,a);Pi(h,k);Jc(k);a=uk(a);break a}a=KF(c);c:{if(b){wk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;vk(k,a);break c}vr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Gh(k,a)}Pi(i,k);Jc(k);l=e,m=Vi(a),x[l>>2]=m;l=f,m=Wi(a),x[l>>2]=m;Ng(k,a);Ac(g,k);xb(k);Hh(k,a);Pi(h,k);Jc(k);a=uk(a)}x[j>>2]=a;hb=k+16|0}function Lk(a,b,c){var d=0,e=0,f=0,g=0;e=hb-48|0;hb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}_L(d,1);break a}f=e+8|0;pc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];os(f,x[e+40>>2]);Yn(f,c);py(d,f);if((b|0)==(g|0)){break a}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(mb[x[x[b>>2]+116>>2]](b)|0)){break b}mb[x[x[b>>2]+108>>2]](b,0);mb[x[x[b>>2]+96>>2]](b);mb[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=x[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(mb[x[x[b>>2]+116>>2]](b)|0){break c}mb[x[x[b>>2]+108>>2]](b,1);mb[x[x[b>>2]+120>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;hb=e+48|0}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;c=ff(a,c);ae(e,x[a+28>>2]);h=a;a:{if(!c){d=0;if(gd(a,5)){break a}}d=hb-32|0;hb=d;f=x[a+28>>2];Lf(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){i=x[b+12>>2];a=hb-16|0;hb=a;g=Vb(a,15750);Rc(d,g);yb(g);hb=a+16|0;x[23420]=0;U(425,d+16|0,d|0,d+30|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}a=x[i+1298464>>2];x[23420]=0;U(353,a|0,2,d+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}yb(d+16|0);cc(d);a=4e3}jg(pj(x[b>>2],0),a);b=pj(x[b>>2],0);j=d,k=Db(x[b>>2]),x[j+16>>2]=k;b=Db(x[b+4>>2]);break b}b=P()|0;break c}b=P()|0;yb(d+16|0)}cc(d);S(b|0);p()}while(1){a=x[d+16>>2];if(Pb(a,b)){Lf(f,d);w[a>>1]=z[d>>1];Re(d+16|0);continue}break}hb=d+32|0;d=c}af(h,d);hb=e+16|0}function a_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=OF(c);b:{if(b){wk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;vk(k,a);break b}vr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Gh(k,a)}Ac(i,k);xb(k);l=e,m=Vi(a),v[l|0]=m;l=f,m=Wi(a),v[l|0]=m;Ng(k,a);Ac(g,k);xb(k);Hh(k,a);Ac(h,k);xb(k);a=uk(a);break a}a=NF(c);c:{if(b){wk(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;vk(k,a);break c}vr(k,a);b=x[k>>2];v[d|0]=b;v[d+1|0]=b>>>8;v[d+2|0]=b>>>16;v[d+3|0]=b>>>24;Gh(k,a)}Ac(i,k);xb(k);l=e,m=Vi(a),v[l|0]=m;l=f,m=Wi(a),v[l|0]=m;Ng(k,a);Ac(g,k);xb(k);Hh(k,a);Ac(h,k);xb(k);a=uk(a)}x[j>>2]=a;hb=k+16|0}function yR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Lb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=fA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=xr(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function p0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;x[c+28>>2]=0;if(Rd(y[sn(c+24|0,a,0)|0])){d=c+16|0;ad(d,x[x[a>>2]-12>>2]+a|0);x[23420]=0;d=T(1047,d|0)|0;e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){e=xm(c+8|0,a);f=Bc(c);g=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[23420]=0;ma(1050,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=x[23420];x[23420]=0;if((d|0)!=1){break b}}b=V(0)|0;Zb(c+16|0);_(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;rn(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break d}S(a|0);p()}$();break a}V(0)|0;Ub()}p()}Zb(c+16|0);x[b>>2]=x[c+20>>2]}hk(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}hb=c+32|0;return a|0}function L5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;if(a){a=qc(f+8|0,a);e=x[a+4>>2];c=x[a>>2];a=hb-16|0;hb=a;x[a>>2]=c;x[a+4>>2]=e;x[a+8>>2]=c;x[a+12>>2]=e;b=hb+-64|0;hb=b;e=a;c=0;a:{if(!x[a+4>>2]){break a}g=x[e>>2];h=x[e+4>>2];a=32048;while(1){if((a|0)==32624){c=32624;while(1){a=c;if((a|0)!=32672){x[b+40>>2]=g;x[b+44>>2]=h;c=qc(b+32|0,x[a+8>>2]);d=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=d;d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;c=a+12|0;if(!RL(b+8|0,b)){continue}}break}c=(a|0)!=32672;break a}x[b+56>>2]=g;x[b+60>>2]=h;c=qc(b+48|0,x[a+8>>2]);d=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=d;d=x[c+4>>2];x[b+16>>2]=x[c>>2];x[b+20>>2]=d;a=a+12|0;if(!RL(b+24|0,b+16|0)){continue}break}c=1}hb=b- -64|0;hb=e+16|0}hb=f+16|0;return c|0}function UK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=hb-80|0;hb=c;d=x[b>>2];b=x[b+4>>2];e=$d(c+48|0);f=x[e+4>>2];x[c>>2]=x[e>>2];x[c+4>>2]=f;b=cr(c+56|0,d,b,c);x[23420]=0;d=T(190,b|0)|0;e=x[23420];x[23420]=0;a:{if((e|0)==1){break a}x[23420]=0;d=W(861,b|0,c+8|0,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Ob(c+8|0,17442,4)|x[c+12>>2]){break b}g=a,h=Fd(B[c+16>>2],E(0)),B[g+4220>>2]=h;g=a,h=Fd(B[c+20>>2],E(0)),B[g+4224>>2]=h;g=a,h=Fd(B[c+24>>2],E(0)),B[g+4228>>2]=h;d=x[c+28>>2];if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=x[c+32>>2];v[a+4240|0]=y[c+36|0]!=0;v[a+4241|0]=y[c+37|0]!=0;v[a+4242|0]=y[c+38|0]!=0;v[a+4243|0]=y[c+39|0]!=0;v[a+4244|0]=y[c+40|0]!=0;Ds(a)}zb(b);hb=c+80|0;return}a=P()|0;zb(b);S(a|0);p()}function Ey(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}f=x[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}Ab(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;g=b,h=Xb(a+c|0,0,256),x[g+692>>2]=h}hb=e+16|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=hb-16|0;hb=g;j=ff(a,c);ae(g,x[a+28>>2]);k=a;a:{if(!j){c=0;if(gd(a,5)){break a}}e=hb-48|0;hb=e;h=x[a+28>>2];pk(h,e+40|0);c=x[e+44>>2];if(!c&A[e+40>>2]>=257|c){x[e+40>>2]=256;x[e+44>>2]=0}l=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Lf(h,e+38|0);f=Jb(e+24|0);x[23420]=0;Q(432,h|0,f|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;U(11,e+8|0,d|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}x[23420]=0;a=Q(843,b|0,e+38|0)|0;i=x[23420];x[23420]=0;if((i|0)==1){break d}i=a;a=e+8|0;Gb(i,a);yb(a);xb(f);c=c+1|0;continue}break}c=P()|0;break c}c=P()|0;break c}c=P()|0;yb(e+8|0)}xb(f);S(c|0);p()}hb=e+48|0;c=j}af(k,c);hb=g+16|0}function Zo(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function oC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=Mc(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Fb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=hb-16|0;hb=f;e=Gi(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);hb=f+16|0}else{Iq(d);d=d+2|0;x[e+4>>2]=d;continue}break}break b}f=Fb(b);e=xj(i+8|0,yj(b,Mc(x[b>>2],e)+d|0),Mc(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=Co(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){Iq(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}Id(d);hb=h+16|0;zd(b,e);Fi(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<1)|0)}}c=Nb(x[a>>2],x[a+8>>2],c<<1);if(c){d=x[b>>2];hc(g+8|0,d,Mc(d,x[b+4>>2])<<1);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0;return c|0}function ZW(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;fi(b,a);x[23420]=0;R(77,c+32|0,b|0);a=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23420]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23420]=0;d=ga(61)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}x[23420]=0;U(62,c+8|0,a+b|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}Zb(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[23420]=0;b=Q(83,a|0,c+32|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=Fk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];gf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;gf(a)}S(b|0);p()}return a|0}function G5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=hb+-64|0;hb=f;x[f+56>>2]=d;d=Tf(a,f+56|0);g=Bc(d+4|0);h=Bc(d+24|0);i=Bc(d+32|0);j=Qb(d+36|0);x[d+56>>2]=3;k=Qb(d+68|0);x[23420]=0;R(897,d|0,e|0);a=x[23420];x[23420]=0;a:{b:{c:{d:{if((a|0)!=1){hc(f+24|0,b,c);a=$d(f+16|0);x[23420]=0;b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;Ea(901,f+32|0,x[f+24>>2],x[f+28>>2],f+8|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}x[23420]=0;U(898,d|0,f+32|0,e|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}zb(f+32|0);x[23420]=0;Y(899,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){break a}}e=P()|0;break b}e=P()|0;break b}e=P()|0;zb(f+32|0)}Ke(k);Vf(j);ns(i);cj(h);bj(g);se(d);se(f+56|0);S(e|0);p()}se(f+56|0);hb=f- -64|0;return d|0}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-48|0;hb=g;h=a+8|0;c=x[a+8>>2];j=yc(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Hi(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+24>>2]=c-e>>1;x[g+44>>2]=1;d=g+24|0;c=x[Yc(d,g+44|0)>>2];c=bg(d,c,c>>>2|0,x[a+16>>2]);e=gc(g+16|0,x[a+4>>2]);f=x[gc(g+8|0,x[a+8>>2])>>2];d=hb-32|0;hb=d;e=x[e>>2];x[d+24>>2]=e;e=ql(d+8|0,c+8|0,Rt(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+24>>2];io(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Ce(d+24|0);continue}break}Id(e);hb=d+32|0;nc(a,c);nc(i,c+4|0);nc(h,c+8|0);nc(j,yc(c));ag(c);c=x[a+8>>2]}io(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;hb=g+48|0}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=hb-16|0;hb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;QR(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!cf(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}hb=e+16|0}function oM(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:rp(a,E(1));In(a,E(3.725290298461914e-9));qp(a,E(268435456));pp(a,0);break b;case 1:rp(a,E(32));In(a,E(4.656612873077393e-10));qp(a,E(2147483648));pp(a,0);break b;case 2:rp(a,E(2));In(a,E(7.450580596923828e-9));qp(a,E(134217728));pp(a,1);break b;default:rp(a,E(1));In(a,E(7.450580596923828e-9));qp(a,E(134217728));pp(a,1);hy(a,0);gy(a,1);fy(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}rp(a,E(.75));In(a,E(7.450580596923828e-9));qp(a,E(134217728));pp(a,1);hy(a,0);b=(b|0)==4;gy(a,b?2:3);fy(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}hy(a,1);gy(a,0);fy(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function vH(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:mb[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function So(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[d+28>>2]=0;a:{b:{c:{if(Rd(y[sn(d+24|0,a,0)|0])){f=d+16|0;ad(f,x[x[a>>2]-12>>2]+a|0);x[23420]=0;f=T(1047,f|0)|0;e=x[23420];x[23420]=0;d:{e:{if((e|0)==1){break e}e=xm(d+8|0,a);g=Bc(d);h=x[x[a>>2]-12>>2];g=x[g>>2];e=x[e>>2];x[23420]=0;ma(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){break e}Zb(d+16|0);break d}b=V(0)|0;Zb(d+16|0);_(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;rn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break c}S(a|0);p()}$()}hk(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}hb=d+32|0;break a}V(0)|0;Ub()}p()}return a}function Qn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;if(e){x[e>>2]=0}a:{h=x[a+484344>>2];if(!oe(h,x[a+484348>>2],b)){break a}i=_b(h,b);k=x[i+48>>2];b=ed(x[i>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=x[a+480180>>2]==4;break b}x[g+12>>2]=2;h=0}x[g+8>>2]=x[i+12>>2]+(c^-1);d=0;c=x[Hb(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=D(Dg(x[k+12>>2]),6)+b|0;if(y[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}x[e>>2]=c;break a}i=f<<8;f=y[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}hb=g+16|0;return f}function FR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){jg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Hg(x[a>>2])&-2)){break c}$c(a,c+(f<<10)|0);if(!kA(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Hg(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}$c(a,c+D(f,z[e>>1])|0);h=kA(a,64,1)?h:k}$c(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(Hg(x[a>>2])|0)){break d}}if(c>>>0>=255){jA(b,254,65534);jA(b,255,65535)}l=h}a=l&65535}else{j=z[bc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function wv(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb+-64|0;hb=e;x[e+60>>2]=d;a:{f=x[b>>2];b:{if(!(mb[x[x[f>>2]+36>>2]](f,c,d)|0)){zh(a);break b}wl(e+40|0,x[b>>2],x[b+4>>2]);b=x[b>>2];d=x[x[b>>2]+24>>2];x[23420]=0;b=T(d|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[e+36>>2]=b-c;g=x[Hb(e+60|0,e+36|0)>>2];b=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=b;b=hb-16|0;hb=b;d=e+16|0;f=wl(b+8|0,x[d>>2],x[d+4>>2]);x[23420]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;X(160,e+48|0,b|0,c|0,g|0);c=x[23420];x[23420]=0;c:{if((c|0)!=1){de(d);hb=b+16|0;break c}a=P()|0;de(d);S(a|0);p()}b=$d(e+24|0);c=x[e+52>>2];x[e+8>>2]=x[e+48>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;qv(a,e+8|0,e)}hb=e- -64|0;return}a=P()|0;de(e+40|0);S(a|0);p()}function wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=fg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Fb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=hb-16|0;hb=f;e=Fz(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);hb=f+16|0}else{$z(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}f=Fb(b);e=rt(i+8|0,Mp(b,fg(x[b>>2],e)+d|0),fg(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=FP(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){$z(f);f=x[d>>2]+32|0;x[d>>2]=f;continue}break}Id(d);hb=h+16|0;zd(b,e);GP(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<5)|0)}}if(Nb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];hc(g+8|0,c,fg(c,x[b+4>>2])<<5);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0}function uda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;e=x[b>>2];d=fh(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=hb-32|0;hb=i;d=c-d|0;f=x[Fb(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){f=hb-16|0;hb=f;e=Ro(f,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){kc(e);hb=f+16|0}else{ku(d);d=d+16|0;x[e+4>>2]=d;continue}break}break b}f=Fb(b);e=Lv(i+8|0,Mv(b,fh(x[b>>2],e)+d|0),fh(x[b>>2],x[b+4>>2]),f);h=hb-16|0;hb=h;d=dE(h,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){ku(f);f=x[d>>2]+16|0;x[d>>2]=f;continue}break}Id(d);hb=h+16|0;zd(b,e);gE(e)}hb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<4)|0)}}if(Nb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];hc(g+8|0,c,fh(c,x[b+4>>2])<<4);qd(g,a,x[g+8>>2],x[g+12>>2])}hb=g+16|0}function FG(a,b,c,d,e,f){var g=0;g=hb-80|0;hb=g;a:{if((f|0)>=16384){Ed(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Ed(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Ed(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Ed(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Ed(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;hb=g+80|0}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=hb-32|0;hb=f;c=Dg(x[x[a+48>>2]+12>>2]);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((ck(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=hb-16|0;hb=b;d=Db(x[a>>2]);a=Db(x[a+4>>2]);Rh(b+8|0);e=Is(a,d);c=hb-16|0;hb=c;x[c+8>>2]=d;while(1){if((e|0)>0){a=x[c+8>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;e=e-1|0;jk(c+8|0);continue}break}hb=c+16|0;hb=b+16|0;break a}e=f+8|0;Rh(e);c=aT(f+16|0,c,e);yL(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];e=Fb(c);g=Fb(a),h=x[e>>2],x[g>>2]=h;x[e>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ek(c);x[a+12>>2]=b}hb=f+32|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=w[h>>1];x[(e<<2)+b>>2]=i+((D(w[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function Rw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=AH(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}hb=e+16|0;return c}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-sc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=x[b+12>>2]-x[b+8>>2]|0;j=e;k=e>>31;break b}e=i-x[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(x[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=x[b+8>>2];on(b,d,d+e|0,h)}if(f&16){Fw(b,x[b+20>>2],x[b+28>>2]);Or(b,e)}l=e;m=c}gh(a,l,m)}function x2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-80|0;hb=d;a=x[a+4>>2];sv(d+16|0,b);x[23420]=0;b=Q(1,d|0,17588)|0;e=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[23420]=0;U(2,d+32|0,d+16|0,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break h}x[23420]=0;U(424,d+48|0,d+32|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break g}x[23420]=0;R(964,d- -64|0,d+48|0);c=x[23420];x[23420]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[23420]=0;R(c|0,a|0,d- -64|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}xb(d- -64|0);yb(d+48|0);yb(d+32|0);yb(b);yb(d+16|0);hb=d+80|0;return}a=P()|0;break a}a=P()|0;break b}a=P()|0;break c}a=P()|0;break d}a=P()|0;xb(d- -64|0)}yb(d+48|0)}yb(d+32|0)}yb(b)}yb(d+16|0);S(a|0);p()}function vR(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}hA(c+8|0,b);qd(c+16|0,a,x[c+8>>2],x[c+12>>2])}hb=c+32|0}function mn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=hb-16|0;hb=l;v[l+15|0]=a;a:{b:{c:{k=x[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=y[j+24|0]){m=45;if(y[j+25|0]!=(n|0)){break c}}x[d>>2]=c+1;v[c|0]=m;break b}if(!(!Eb(g)|(a|0)!=(f|0))){a=0;b=x[i>>2];if((b-h|0)>159){break a}a=x[e>>2];x[i>>2]=b+4;x[b>>2]=a;break b}a=-1;f=ii(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|y[k-1|0]!=48){break a}a=0;x[e>>2]=0;x[d>>2]=k+1;v[k|0]=y[f+81808|0];break a}x[d>>2]=k+1;v[k|0]=y[f+81808|0];x[e>>2]=x[e>>2]+1;a=0;break a}a=0;x[e>>2]=0}hb=l+16|0;return a}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=v[h|0];x[(e<<2)+b>>2]=((D(v[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Rb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function lh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=kK(a);h=a+4208|0;c=E(E(B[Cb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=me(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[Cb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(me(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-lp(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!Ul(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=xf(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+8>>2];l=((((x[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=w[e+39718>>1];n=w[e+39716>>1];o=w[e+39714>>1];p=w[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;x[(e<<2)+b>>2]=(((D(w[f>>1],o)+D(w[f-4>>1],p)|0)+D(w[f+4>>1],n)|0)+D(w[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function Hj(a,b){var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;Ym(d,e);a:{b:{if(Rd(y[sn(c+56|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;U(96,c+40|0,d|0,c+8|0);b=x[23420];x[23420]=0;c:{if((b|0)!=1){b=gh(c+24|0,-1,-1);b=x[b+8>>2]==x[c+48>>2]&x[c+52>>2]==x[b+12>>2]?e|4:e;break c}_(V(0)|0)|0;b=e|1;rn(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}$()}hk(x[x[a>>2]-12>>2]+a|0,b)}hb=c- -64|0;return a}V(0)|0;Ub()}p()}function N5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=hb-48|0;hb=b;c=Jb(b+32|0);x[23420]=0;Y(890,b+16|0);a=x[23420];x[23420]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Db(x[b+16>>2]),x[f+8>>2]=g;d=1;while(1){e=Db(x[b+20>>2]);a=x[b+8>>2];if(!Pb(a,e)){a=Wf(Ic(c));Ke(b+16|0);xb(c);break b}if(!d){x[23420]=0;Q(891,c|0,14464)|0;a=x[23420];x[23420]=0;if((a|0)==1){break d}a=x[b+8>>2]}x[23420]=0;Q(755,c|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break d}_p(b+8|0);d=0;continue}}a=V(0)|0;break c}a=V(0)|0;Ke(b+16|0)}xb(c);_(a|0)|0;a=0;x[23420]=0;X(889,6946,0,0,0);c=x[23420];x[23420]=0;if((c|0)==1){break a}$()}hb=b+48|0;return a|0}b=P()|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){V(0)|0;Ub();p()}S(b|0);p()}function pA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;d=y[a|0];if(d&1){v[b+12|0]=y[b+12|0]|1;d=y[a|0]}if(d&2){v[b+12|0]=y[b+12|0]|4;d=y[a|0]}if(d&4){v[b+12|0]=y[b+12|0]|2;d=y[a|0]}if(d&16){v[b+12|0]=y[b+12|0]|16;d=y[a|0]}if(d&32){v[b+12|0]=y[b+12|0]|8}v[e+15|0]=y[a+1|0];v[e+14|0]=25;bh(b,y[Wb(e+15|0,e+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=x[b>>2];i=qe(g,x[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Cb(g,b);f=(b<<2)+a|0;d=y[f+6|0]|y[f+7|0]<<8;w[h>>1]=d;a:{if(!b){break a}j=d;d=z[Cb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[h>>1]=d+1}k=h,l=Xb((y[f+8|0]|y[f+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}hb=e+16|0}
function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;pd(c,2);v[d+16|0]=y[b+13|0];v[d|0]=64;e=d+16|0;i=c,j=y[Wb(e,d)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;dk(d,2,b+1|0);Fc(e,d);ze(c+43|0,e);xb(e);e=_c(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;f=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=f;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}Dh(e,16);Rf(e,9);x[c+8>>2]=h>>>1;x[c+4>>2]=f>>>1;x[c>>2]=g>>>1}hb=d+32|0}function zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=hb-16|0;hb=i;d=x[gc(i+8|0,Db(x[a+4>>2]))>>2];h=hb-32|0;hb=h;e=d;d=x[a>>2];f=(ro(e,Db(d))<<1)+d|0;e=bz(b,c);a:{if((e|0)<=0){break a}d=x[Fb(a)>>2];g=x[a+4>>2];if((e|0)<=d-g>>1){k=g-f|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[h+8>>2]=b;x[h+8>>2]=x[h+8>>2]+(j<<1);d=x[h+8>>2];QO(a,d,c,e-j|0);if((k|0)<=0){break a}}WO(a,f,g,(e<<1)+f|0);Vn(b,d,f);break a}d=Fb(a);e=xj(h+8|0,yj(a,Mc(x[a>>2],g)+e|0),f-x[a>>2]>>1,d);g=hb-16|0;hb=g;c=Co(g,e+8|0,bz(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){wj(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}Id(c);hb=g+16|0;f=VO(a,e,f);Fi(e)}Db(f);hb=h+32|0;hb=i+16|0;return a|0}function zG(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=ww(13708);if(y[b|0]?b:0){break a}b=ww(D(a,12)+78416|0);if(y[b|0]?b:0){break a}b=ww(13988);if(y[b|0]?b:0){break a}b=14597}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14597;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!ej(e,14597)){break e}if(ej(e,13370)){break d}}if(!a){c=78488;if(y[e+1|0]==46){break c}}return 0}c=x[116711];if(c){while(1){if(!ej(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Ld(36);if(c){x[c+4>>2]=20;x[c>>2]=78384;b=c+8|0;pc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[116711];x[116711]=c}c=a|c?c:78488}return c}function sI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=x[a+32>>2];if((Dg(a)|0)>(b|0)){break e}}a=ba(8)|0;x[23420]=0;b=Q(54,f|0,10598)|0;c=x[23420];x[23420]=0;if((c|0)==1){break d}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break b}c=P()|0;xb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;x[d>>2]=c|x[d>>2]&-134218753;d=(a+D(b,872)|0)+1075080|0;x[d>>2]=c|x[d>>2]&-134218753;a=z[a+480188>>1];d=a>>>0<=256?256:a;b=b+1|0;g=x[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+D(a,872)|0;if((b|0)==z[e+1075778>>1]){e=e+1075080|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;ca(a|0)}S(c|0)}p()}hb=f+16|0}function tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=hb-528|0;hb=b;e=-1;a:{if(!Uf(a,1468)){break a}al(a,1464);c=b+524|0;MR(a,c);if(!ee(c,26729)){e=0;if(!ee(b+524|0,15344)){break a}}al(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(JR(a,b)){c=c+1|0;d=nA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=hb-16|0;hb=c;b:{if(!Uf(a,2)){v[c|0]=0;hC(d,c);break b}sl(c+8|0,d);mA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;if(y[b+520|0]>128){break a}d=jd(b+520|0);c=hb-16|0;hb=c;c:{if(!Uf(a,512)){uR(b);break c}wu(c+8|0,b);mA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;c=0;e=1;a=y[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=y[d|0]){continue}break}e=0}hb=b+528|0;return e|0}function HE(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=hb-80|0;hb=g;oy(x[a+24>>2]);v[x[a+24>>2]+1298420|0]=x[a+52>>2]!=0;c=Vg(g+32|0,d,c,b);i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=x[c+8>>2];d=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=d;d=hb-16|0;hb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=dJ(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];B[c+24>>2]=i;x[c>>2]=e;hb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=fJ(d,x[Nq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}hb=g+80|0;return h}function Tn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Sn(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Rn(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Xb(c,0,256),x[h+688>>2]=i}function li(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=44304;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Qb(a+44|0);d=Qb(b+12|0);e=Qb(b+24|0);f=Qb(b+36|0);x[23420]=0;R(853,b|0,0);g=x[23420];x[23420]=0;if((g|0)==1){a=P()|0;tc(f);tc(e);Bs(d);Bs(b);S(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[23420]=0;d=T(854,a+92|0)|0;e=x[23420];x[23420]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;d=y[a+4200|0];c=x[a+16>>2];e=x[a+20>>2];while(1){if((e|0)==((c+D(d,160)|0)+906300|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=P()|0;SK(b);S(a|0);p()}return a}function gV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;pd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=Gq(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=Gq(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(Iu(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}hb=e+16|0}function Jy(a,b,c){var d=0,e=0,f=0,g=0;d=hb+-64|0;hb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(Kg(f,c,0)){x[d+56>>2]=1;mb[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}mb[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}hb=d- -64|0;return e}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb+-64|0;hb=c;i=c,j=df(a)>>>5|0,w[i+32>>1]=j;w[c+16>>1]=3999;h=b+480190|0;d=z[Zc(c+32|0,c+16|0)>>1];w[h>>1]=d;g=1;while(1){f=g&65535;if(d>>>0>=f>>>0){d=_j(b,f);e=c+32|0;Ht(a,e);pd(d,0);tj(c,2,e);e=c+16|0;Fc(e,c);Dc(((f<<5)+b|0)+946304|0,e);xb(e);x[d+24>>2]=8287;i=c,j=Lb(z[c+60>>1]),w[i+16>>1]=j;w[c>>1]=64;i=d,j=z[Zc(e,c)>>1]<<2,w[i+30>>1]=j;i=d,j=ac(x[c+52>>2])&-2,x[i>>2]=j;e=Lb(z[c+62>>1]);i=Cb(d+68|0,0),j=e,x[i>>2]=j;e=Lb(z[c+56>>1]);f=Lb(z[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[h>>1];continue}break}hb=c- -64|0}function sea(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;fi(b,a);x[23420]=0;R(77,c+32|0,b|0);a=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23420]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23420]=0;d=ga(61)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}x[23420]=0;U(62,c+8|0,a+b|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}Zb(c+8|0);x[23420]=0;b=Q(79,a|0,c+32|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=Fk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=z[c+32>>1];gf(b);hb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;gf(a)}S(b|0);p()}return a|0}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+8>>2];l=(((x[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=w[e+39718>>1];n=w[e+39716>>1];o=w[e+39714>>1];p=w[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;x[(e<<2)+b>>2]=(((D(v[f|0],o)+D(v[f-2|0],p)|0)+D(v[f+2|0],n)|0)+D(v[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],h);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function Zca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=hb-16|0;hb=g;pd(b,4);w[b+30>>1]=y[a+12|0]<<2;tg(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Vb(g,21473);ze(b+43|0,a);xb(a);hb=g+16|0}function J0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Sw(fb(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}hb=d+32|0;return a|0}function $g(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb+-64|0;hb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(oe(d,e,b)){break b}c:{d:{if(ik(d,e)>>>0<=b>>>0){d=Xx(f+8|0,a);x[23420]=0;U(189,a|0,b+1|0,d|0);e=x[23420];x[23420]=0;if((e|0)==1){break d}Pk(d);d=x[a>>2]}x[23420]=0;R(199,Pf(d,b)|0,c|0);c=x[23420];x[23420]=0;e:{if((c|0)!=1){c=Pf(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[23420]=0;Y(200,Pf(c,b)|0);c=x[23420];x[23420]=0;if((c|0)!=1){break e}}b=V(91780)|0;a=ib;break c}a=Pf(x[a>>2],b);g=Pb(x[a>>2],x[a+4>>2]);break b}b=V(91780)|0;a=ib;Pk(d)}if((da(91780)|0)!=(a|0)){break a}_(b|0)|0;$()}hb=f- -64|0;return g|0}S(b|0);p()}function $U(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-208|0;hb=d;if(!zu(c,a)){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0}NB(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=hb-16|0;hb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Hb(c+12|0,c+8|0)|0];hb=c+16|0;v[d+12|0]=e;bh(b,y[Wb(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=qe(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=Cb(e,0);break b}g=z[Cb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=Le(d+12|0,d+8|0);c=Cb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}hb=d+208|0}function oL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=hb-16|0;hb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Gc(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;qL(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Gc(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=hb-16|0;hb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Zc(e+14|0,e+12|0)>>1];hb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=me(i,E(E(1)/E(b|0)));Pj(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){np(a)}else{j=me(i,E(d|0));k=Cb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}hb=g+16|0;return h|0}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=(x[f+12>>2]<<1)+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(w[b+4>>1],w[e+10>>1])+D(w[b+2>>1],w[e+8>>1])|0)+D(w[b+6>>1],w[e+12>>1])|0)+D(w[b+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[b-4>>1],w[e+2>>1])+D(w[b-6>>1],w[e>>1])|0)+D(w[b-2>>1],w[e+4>>1])|0)+D(w[b>>1],w[e+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,h);x[c+4>>2]=x[c+4>>2]+D(b,g);Rb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function WW(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-192|0;hb=c;b=c+16|0;fi(b,a);x[23420]=0;R(77,c+32|0,b|0);a=x[23420];x[23420]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[23420]=0;a=Q(78,c+48|0,c+32|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}xb(c+32|0);xb(c+16|0);b=x[x[a>>2]-12>>2];x[23420]=0;d=ga(61)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}x[23420]=0;U(62,c+8|0,a+b|0,d|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}Zb(c+8|0);x[23420]=0;b=Q(82,a|0,c+32|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=Fk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>2];gf(b);hb=c+192|0;a=a?0:d;break a}b=P()|0;break d}b=P()|0;xb(c+32|0)}xb(c+16|0);break b}b=P()|0;gf(a)}S(b|0);p()}return a|0}function s5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{if((e|0)==1){break c}x[23420]=0;Y(903,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break c}x[23420]=0;Y(903,c|0);f=x[23420];x[23420]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[23420]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;YE(924,f,d+8|0,g,c);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,5468,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}hb=d+32|0;return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=ak(b),x[i>>2]=j;d=hb-16|0;hb=d;g=a;c=Vd(a);a:{if(c){f=ic(g);while(1){a=c;c=a+13|0;if(tt(b,c)){f=a;c=x[a>>2];if(c){continue}break a}if(!tt(c,b)){break a}f=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ic(g);f=a}x[d+12>>2]=a;b=x[f>>2];if(!b){c=hb-16|0;hb=c;a=ic(g);h=rh(d,wc(20),sh(c+8|0,a));b=x[h>>2];a=x[e>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=ic(h),j=1,v[i+4|0]=j;hb=c+16|0;Yg(g,x[d+12>>2],f,x[d>>2]);b=Zd(d);cl(d);h=1}Xg(e+8|0,x[gc(d,b)>>2],h);hb=d+16|0;hb=e+16|0;return x[e+8>>2]+17|0}function xN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=hb-112|0;hb=g;x[g+108>>2]=0;e=Qn(a,e&65535,d,c,g+108|0);f=y[b+790|0];if(!x[g+108>>2]){d=(f|0)==15;c=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=c?0:y[b+836|0]<<16}if((f|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[g>>2]=1;f=x[Yc(g,g+108|0)>>2]<<3;d=Wia(c,0,e,0);e=(256<<f>>>1|0)+d|0;c=lb;c=d>>>0>e>>>0?c+1|0:c;d=f+8|0;f=d&31;if((d&63)>>>0>=32){d=0;c=c>>>f|0}else{d=c>>>f|0;c=((1<<f)-1&c)<<32-f|e>>>f}e=Vc(c,d);break b}gQ(g);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[Cb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Un(a,b,e+h|0);hb=g+112|0}function sy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;b=x[a>>2];if(!uc(b,x[a+4>>2])){b=Db(b);x[e+8>>2]=b;c=Db(x[a+4>>2]);while(1){if(Pb(b,c)){Eo(b,4194304,67108864);g=x[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=x[Ce(e+8|0)>>2];continue}else{c=x[a>>2];b=vc(c,x[a+4>>2]);l=e,m=Db(c),x[l>>2]=m;d=Zia(f,d,b,0);h=d;g=((lb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Db(x[a+4>>2]);while(1){b=x[e>>2];if(Pb(b,i)){j=b;c=x[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Vc(Zia(c,c>>>0<g>>>0?b+1|0:b,h,k),lb);x[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Ce(e);continue}else{d=x[a>>2];if(!vc(d,x[a+4>>2])){Su();p()}x[d>>2]=f+x[d>>2]}break}}break}}hb=e+16|0}function aH(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23420]=0;c=Q(1054,d+8|0,a|0)|0;b=x[23420];x[23420]=0;c:{if((b|0)!=1){d:{if(!Rd(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;b=T(1055,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23420]=0;Y(1056,a+b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}}b=V(0)|0;$G(c);break c}$G(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[23420]=0;Y(16,a+c|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}$()}hb=d+16|0;return a|0}a=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Ny(a,b,c){var d=0,e=0,f=0,g=0;d=Jb(a);a=Eb(b);x[23420]=0;R(45,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){f=x[fj(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{x[23420]=0;R(46,d|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}x[23420]=0;R(46,d|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}x[23420]=0;R(46,d|0,63);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;xb(d);S(a|0);p()}function D0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-48|0;hb=d;if(GH(1,d+24|0)){Ur(x[115896],12569);p()}c=Bk(d+16|0,x[d+24>>2],x[d+28>>2]);g=rH(d+8|0,x[d+32>>2]);e=hb-32|0;hb=e;b=hb-16|0;hb=b;a=hb-16|0;hb=a;h=a,i=Wia(x[c>>2],x[c+4>>2],1e9,0),x[h>>2]=i;x[a+4>>2]=lb;c=kt(a+8|0,a);f=x[c+4>>2];c=x[c>>2];hb=a+16|0;x[b+8>>2]=c;x[b+12>>2]=f;a=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=a;hb=b+16|0;f=x[e+8>>2];c=x[e+12>>2];a=x[g+4>>2];x[e>>2]=x[g>>2];x[e+4>>2]=a;a=e;c=x[a+4>>2]+c|0;b=x[a>>2];f=f+b|0;x[a+16>>2]=f;x[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=kt(a+24|0,a+16|0);b=x[a+4>>2];a=x[a>>2];hb=e+32|0;a=Bk(d+40|0,a,b);b=x[a+4>>2];a=x[a>>2];hb=d+48|0;lb=b;return a|0}function iL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=hb-48|0;hb=e;d=Jb(e+32|0);x[23420]=0;R(844,b|0,e+24|0);g=x[23420];x[23420]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];Df(d);x[23420]=0;g=!g&f>>>0>=255|g?255:f;R(59,d|0,g|0);f=x[23420];x[23420]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=yU(Ic(d),Eb(d));if((b|0)==-1){break c}x[23420]=0;R(59,d|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break c}break b}f=Nc(d,h);x[23420]=0;Q(845,b|0,f|0)|0;f=x[23420];x[23420]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[23420]=0;U(11,e+8|0,a|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}a=e+8|0;Gb(c,a);yb(a);xb(d);hb=e+48|0;break a}}a=P()|0;xb(d);S(a|0);p()}}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-32|0;hb=e;x[e+24>>2]=b;j=e,k=Yd(a),x[j+8>>2]=k;f=$j(e+24|0,e+8|0);a:{b:{h=oi(c,d);if(!h){break b}if(!As(a,c)){b=Eb(a);g=Sc(a);c:{if(g-b>>>0>=h>>>0){g=sc(a);if((b|0)==(f|0)){break c}i=f+g|0;rj(i+h|0,i,b-f|0);break c}Sl(a,g,(b+h|0)-g|0,b,f,0,h);g=x[a>>2]}b=b+h|0;Kh(a,b);v[e+8|0]=0;sd(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}sd(b,c);c=c+1|0;b=b+1|0;continue}}d=Yf(e+8|0,c,d);c=Ic(d);f=Eb(d);x[23420]=0;c=fa(342,a|0,b|0,c|0,c+f|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){xb(d);break a}a=P()|0;xb(d);S(a|0);p()}j=e,k=Yd(a),x[j+8>>2]=k;c=Di(e+8|0,f)}hb=e+32|0;return c|0}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=e;j=b+24|0;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[f+12>>2]+i|0;e=(((x[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((D(v[b+2|0],w[e+10>>1])+D(v[b+1|0],w[e+8>>1])|0)+D(v[b+3|0],w[e+12>>1])|0)+D(v[b+4|0],w[e+14>>1])<<8)/2|0)+((((D(v[b-2|0],w[e+2>>1])+D(v[b-3|0],w[e>>1])|0)+D(v[b-1|0],w[e+4>>1])|0)+D(v[b|0],w[e+6>>1])<<8)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,h);x[c+4>>2]=x[c+4>>2]+D(b,g);Rb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;hb=f+16|0}function S3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-32|0;hb=d;e=Qb(a);a=0;c=x[b+24>>2];c=et(x[c+484344>>2],x[c+484348>>2]);x[23420]=0;R(169,e|0,c|0);c=x[23420];x[23420]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(et(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[23420]=0;R(971,d|0,_b(f,a)|0);c=x[23420];x[23420]=0;if((c|0)!=1){c=x[b+24>>2];x[23420]=0;U(958,d+16|0,c|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;R(171,e|0,d+16|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}a=a+1|0;xb(d+16|0);xb(d);continue}break}a=P()|0;break a}a=P()|0;break c}a=P()|0;xb(d+16|0)}xb(d);break a}hb=d+32|0;return}a=P()|0}Ke(e);S(a|0);p()}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;h=hb-16|0;hb=h;c=ff(a,c);ae(h,x[a+28>>2]);i=a;a:{if(!c){d=0;if(gd(a,5)){break a}}f=x[a+28>>2];a=hb-16|0;hb=a;x[a+12>>2]=0;pG(f,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Wb(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}bi(f,a+4|0);if((d|0)==1){break b}bi(f,a);if(d>>>0<3){break b}bi(f,a+10|0);g=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|g)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;Ax(b,x[Hb(a+4|0,a)>>2]);e=0;while(1){g=Eb(b);if(g>>>0<=e>>>0){if((d|0)!=(g|0)){Gl(f,d-g|0)}hb=a+16|0}else{zk(f,Nc(b,e),1);e=e+1|0;continue}break}d=c}af(i,d);hb=h+16|0}function Jq(a){a=a|0;var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[23420]=0;c=Q(12,d+8|0,a|0)|0;b=x[23420];x[23420]=0;c:{if((b|0)!=1){d:{if(!y[c|0]){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;b=T(21,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[23420]=0;R(15,a+b|0,1);b=x[23420];x[23420]=0;if((b|0)!=1){break d}}b=V(0)|0;hl(c);break c}hl(c);break b}b=V(0)|0}_(b|0)|0;c=x[x[a>>2]-12>>2];x[23420]=0;Y(16,a+c|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}$()}hb=d+16|0;return a|0}a=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=x[b+8>>2]>>>21&2040;e=(((D(w[e>>1],w[h+39714>>1])+D(w[e-2>>1],w[h+39712>>1])|0)+D(w[e+2>>1],w[h+39716>>1])|0)+D(w[e+4>>1],w[h+39718>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=hb-48|0;hb=c;d=a;a:{if(Xt(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}GS(c+16|0,c+32|0);mc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}$b(d,h);GS(c+8|0,c+32|0);mc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}$b(d,e);if(a>>>0<33){break a}x[g>>2]=-1}hb=c+48|0}function ln(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=x[d>>2];if((k|0)!=(c|0)){break b}l=43;if(x[j+96>>2]!=(a|0)){l=45;if(x[j+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=l;break a}c:{if(!(!Eb(g)|(a|0)!=(f|0))){g=0;a=x[i>>2];if((a-h|0)>159){break c}b=x[e>>2];x[i>>2]=a+4;x[a>>2]=b;break a}g=-1;f=nw(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|y[k-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=k+1;v[k|0]=y[a+81808|0];return 0}x[d>>2]=k+1;v[k|0]=y[a+81808|0];x[e>>2]=x[e>>2]+1;g=0}return g}x[e>>2]=0;return 0}function TV(){var a=0,b=0,c=0,d=0;a=vC(x[x[116578]-12>>2]+466312|0,10);c=hb-16|0;hb=c;x[23420]=0;b=Q(12,c+8|0,466312)|0;d=x[23420];x[23420]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!y[b|0]){break e}d=xm(c,466312);x[23420]=0;a=Q(20,d|0,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){if(!uu(a)){break e}a=x[x[116578]-12>>2];x[23420]=0;R(15,a+466312|0,1);a=x[23420];x[23420]=0;if((a|0)!=1){break e}}a=V(0)|0;hl(b);break d}hl(b);break c}a=V(0)|0}_(a|0)|0;b=x[x[116578]-12>>2];x[23420]=0;Y(16,b+466312|0);b=x[23420];x[23420]=0;if((b|0)==1){break b}$()}hb=c+16|0;break a}c=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(c|0);p()}V(0)|0;Ub();p()}Jq(466312)}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;x[d+28>>2]=0;bk(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Jb(d+16|0);x[23420]=0;w[d+14>>1]=0;e=W(430,a|0,g|0,255)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}if(!e){break d}x[23420]=0;R(419,a|0,d+14|0);e=x[23420];x[23420]=0;if((e|0)==1){break b}x[23420]=0;U(11,d|0,c|0,g|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;e=Q(431,b|0,d+14|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break e}Gb(e,d);yb(d);xb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;yb(d);break a}xb(g)}hb=d+32|0;return}f=P()|0}xb(g);S(f|0);p()}function $l(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=a+1074312|0;Ab(e+8|0,f,84);a:{if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}b:{if(x[a+480208>>2]&16384){break b}if((d|0)!=8){Ab(e+8|0,f,10);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;Ab(e+8|0,f,10);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}v[b+831|0]=0;w[b+778>>1]=0}hb=e+16|0}function mz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=hb-16|0;hb=g;i=Xk(a,b);a:{if((i|0)==255){break a}if(Uj(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Wia(1<<20-f,0,c,0)+24858e3|0;h=lb;c=Vc(Zia(c,c>>>0<24858e3?h+1|0:h,49716e3,0),lb)}if(e){w[g+14>>1]=(b&3)+c;w[g+12>>1]=1023;c=z[Zc(g+14|0,g+12|0)>>1]}h=it(i);e=Kb(a+8|0,i);v[e|0]=(f<<10|c)>>>8|(d?0:32);Sg(x[a>>2],x[a+4>>2],b,h|160,c&255);Sg(x[a>>2],x[a+4>>2],b,h|176,y[e|0]);v[a+534|0]=1}hb=g+16|0}function VE(a,b,c,d){var e=0,f=0,g=0;f=hb-32|0;hb=f;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[23420]=0;Y(903,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break f}g=x[a+24>>2];x[23420]=0;e=Q(54,f|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break e}x[23420]=0;U(d|0,f+16|0,g|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break d}a=f+16|0;b=Wf(Ic(a));xb(a);xb(e);break b}b=V(0)|0;break c}b=V(0)|0;break c}b=V(0)|0;xb(e)}_(b|0)|0;b=0;x[23420]=0;X(889,c|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=f+32|0;return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;w[d+30>>1]=0;Lf(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Jb(d+16|0);x[23420]=0;w[d+14>>1]=0;e=Q(432,a|0,g|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break b}if(!e){break d}x[23420]=0;R(419,a|0,d+14|0);e=x[23420];x[23420]=0;if((e|0)==1){break b}x[23420]=0;U(11,d|0,c|0,g|0);e=x[23420];x[23420]=0;if((e|0)!=1){x[23420]=0;e=Q(431,b|0,d+14|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break e}Gb(e,d);yb(d);xb(g);f=f+1|0;continue}break}f=P()|0;break a}f=P()|0;yb(d);break a}xb(g)}hb=d+32|0;return}f=P()|0}xb(g);S(f|0);p()}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=x[b+8>>2]>>>21&2040;e=(((D(v[e|0],w[h+39714>>1])+D(v[e-1|0],w[h+39712>>1])|0)+D(v[e+1|0],w[h+39716>>1])|0)+D(v[e+2|0],w[h+39718>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];h=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;i=x[a+32>>2];j=x[a+28>>2];k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){d=d-1|0;m=((((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+m>>1];e=e+1|0;continue}break}g=g+j|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+i|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Rb(b+8|0,k,l);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=Nf(d+48|0);x[23420]=0;g=Q(752,b|0,e|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(753,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23420]=0;U(178,d|0,b|0,g|0);f=x[23420];x[23420]=0;if((f|0)==1){break a}f=jc(d+24|0,d);bd(e+8|0,f);zb(f);zb(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[23420]=0;Q(176,b|0,2-c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);S(a|0);p()}function _l(a,b,c){var d=0,e=0,f=0;d=Jb(a);a=Eb(b);x[23420]=0;R(45,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){f=x[fj(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(x[(a<<2)+c>>2]==(f|0)){x[23420]=0;R(46,d|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(x[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}x[23420]=0;R(46,d|0,a<<24>>24);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}x[23420]=0;R(46,d|0,63);a=x[23420];x[23420]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;xb(d);S(a|0);p()}function Ir(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=hb-16|0;hb=h;f=d?d:466836;d=x[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=y[b|0];d=a<<24>>24;if((d|0)>=0){x[i>>2]=a;e=(d|0)!=0;break a}if(!x[x[115922]>>2]){x[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=x[(a<<2)+81600>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=y[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){x[f>>2]=0;x[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=y[b|0];if((g&192)==128){continue}break}}x[f>>2]=0;x[115896]=25;e=-1;break a}x[f>>2]=d}hb=h+16|0;return e}function IX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Kg(a,x[b+8>>2],f)){fw(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;bw(x[m>>2],x[a+20>>2],b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;bw(x[i>>2],x[i+4>>2],b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function uI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Dg(a)|0)>(b|0)){break d}}a=ba(8)|0;x[23420]=0;d=Q(54,d|0,10598)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}a=rc(a,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(d);break b}if(c<0|c>1){a=ba(8)|0;x[23420]=0;d=Q(54,d|0,11610)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=rc(a,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(d);break b}b=P()|0;ca(a|0);break b}e=(a+D(b,872)|0)+1075740|0,f=fm(c*64),x[e>>2]=f;hb=d+16|0;return}b=P()|0;ca(a|0)}S(b|0)}p()}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[a>>2];d=lq(c,x[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=x[Fb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=hb-16|0;hb=d;b=_T(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);hb=d+16|0}else{AS(a);a=a+48|0;x[b+4>>2]=a;continue}break}break a}b=Fb(a);d=XT(f+8|0,YT(a,lq(x[a>>2],e)+c|0),lq(x[a>>2],x[a+4>>2]),b);b=hb-16|0;hb=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,48)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){AS(c);c=x[b>>2]+48|0;x[b>>2]=c;continue}break}Id(b);hb=b+16|0;WT(a,d);VT(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+D(b,48)|0)}}function b0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;a:{b:{if(!uc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){e=-1;if(!(y[a+48|0]&16)){break a}h=x[a+20>>2];k=x[a+44>>2];x[23420]=0;c=a+32|0;R(46,c|0,0);f=x[23420];x[23420]=0;if((f|0)==1){break b}f=Sc(c);x[23420]=0;R(59,c|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break b}e=sc(c);Fw(a,e,Eb(c)+e|0);Or(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[g+12>>2]=d+1;d=x[Yc(g+12|0,a+44|0)>>2];x[a+44>>2]=d;if(y[a+48|0]&8){c=sc(a+32|0);on(a,c,c+(j-i|0)|0,d)}e=fH(a,wn(b));break a}e=Ew(b);break a}_(V(0)|0)|0;$()}hb=g+16|0;return e|0}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=Nf(d+48|0);x[23420]=0;c=Q(748,b|0,e|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(749,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23420]=0;c=ac(c);c=c?c:-1;U(178,d|0,b|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break a}f=jc(d+24|0,d);bd(e+8|0,f);zb(f);zb(d);d:{c=c&1;if(!c){break d}x[23420]=0;Q(176,b|0,2-c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);S(a|0);p()}function i4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Qb(a);a=b;b=z[x[b+24>>2]+480192>>1];x[23420]=0;R(169,f|0,b|0);c=x[23420];x[23420]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=x[a+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=eM(c,d);x[23420]=0;c=Q(54,e|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){d=x[a+24>>2];x[23420]=0;U(958,e+16|0,d|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break e}x[23420]=0;R(171,f|0,e+16|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}xb(e+16|0);xb(c);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;xb(e+16|0)}xb(c);break a}hb=e+32|0;return}b=P()|0}Ke(f);S(b|0);p()}function cv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=hb-16|0;hb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;bh(b,y[Wb(i,e)|0]);g=y[Wb(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Wd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Wb(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Wd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Wb(f+14|0,i)|0]){e=D(b,3)+a|0;h=Xb(y[e+6|0]+c<<24>>24,0,64);d=Cb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=Cb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}hb=f+16|0}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;h=Jb(a);f=Jb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[23420]=0;R(235,h|0,f|0);a=x[23420];x[23420]=0;if((a|0)!=1){break c}a=P()|0;break a}c=eM(c,d);x[23420]=0;c=Q(54,e|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}d=De(c);x[23420]=0;g=Q(755,f|0,c|0)|0;j=x[23420];x[23420]=0;d:{if((j|0)==1){break d}x[23420]=0;Q(891,g|0,21443)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}i=d^1|i;xb(c);a=a+1|0;continue}break}a=P()|0;xb(c);break a}xb(f);hb=e+32|0;return}a=P()|0}xb(f);xb(h);S(a|0);p()}function gD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Ob(a,3878,4)){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];h=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;i=x[a+32>>2];j=x[a+28>>2];k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){d=d-1|0;m=(((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+m|0]<<8;e=e+1|0;continue}break}g=g+j|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+i|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Rb(b+8|0,k,l);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function VW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{d:{if(h=eh(x[b+4>>2],y[b+11|0]),i=1,j=x[b+12>>2],j?h:i){Jb(a);break d}e=Jb(c+16|0);d=Bd(x[b+4>>2],y[b+11|0]);f=qf(14159);g=rd(b);x[23420]=0;X(90,e|0,g|0,d|0,d+f|0);d=x[23420];x[23420]=0;e:{if((d|0)!=1){x[23420]=0;W(91,e|0,14159,f|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break e}}a=P()|0;yb(e);S(a|0);p()}x[23420]=0;R(120,c|0,b+12|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}x[23420]=0;U(2,a|0,c+16|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}yb(c);yb(c+16|0)}hb=c+32|0;return}b=P()|0;break a}b=P()|0;yb(c)}yb(c+16|0);S(b|0);p()}function K3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-32|0;hb=e;f=Qb(a);a=b;b=z[x[b+24>>2]+480190>>1];x[23420]=0;R(169,f|0,b|0);d=x[23420];x[23420]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=x[a+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[23420]=0;d=Q(54,e|0,fM(d,c)|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){c=x[a+24>>2];x[23420]=0;U(958,e+16|0,c|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;R(171,f|0,e+16|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}xb(e+16|0);xb(d);b=b+1|0;continue}break}b=P()|0;break a}b=P()|0;break c}b=P()|0;xb(e+16|0)}xb(d);break a}hb=e+32|0;return}b=P()|0}Ke(f);S(b|0);p()}function y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;h=Jb(a);f=Jb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=x[b+24>>2];if(d>>>0>z[c+480190>>1]){if(!(i&1)){break c}x[23420]=0;R(235,h|0,f|0);a=x[23420];x[23420]=0;if((a|0)!=1){break c}a=P()|0;break a}x[23420]=0;c=Q(54,e|0,fM(c,d)|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}d=De(c);x[23420]=0;g=Q(755,f|0,c|0)|0;j=x[23420];x[23420]=0;d:{if((j|0)==1){break d}x[23420]=0;Q(891,g|0,21443)|0;g=x[23420];x[23420]=0;if((g|0)==1){break d}i=d^1|i;xb(c);a=a+1|0;continue}break}a=P()|0;xb(c);break a}xb(f);hb=e+32|0;return}a=P()|0}xb(f);xb(h);S(a|0);p()}function mZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=vc(d,x[a+4>>2]);if(c>>>0<b>>>0){g=hb-32|0;hb=g;d=b-c|0;b=x[Fb(a)>>2];e=x[a+4>>2];a:{if(d>>>0<=b-e>>2>>>0){EF(a,d);break a}c=jw(a);e=Tg(a,vc(x[a>>2],e)+d|0);f=vc(x[a>>2],x[a+4>>2]);b=g+8|0;Jf(b+12|0,c);if(e){c=AF(x[b+16>>2],e)}else{c=0}x[b>>2]=c;f=c+(f<<2)|0;x[b+8>>2]=f;x[b+4>>2]=f;h=yc(b),i=c+(e<<2)|0,x[h>>2]=i;e=hb-16|0;hb=e;c=ql(e,b+8|0,d);d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){BF(d);d=x[c>>2]+4|0;x[c>>2]=d;continue}break}Id(c);hb=e+16|0;zd(a,b);dP(b);a=x[b>>2];if(a){DF(x[b+16>>2],a,vz(b))}}hb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function mS(a){var b=0,c=0,d=0,e=0,f=0;b=hb-32|0;hb=b;e=b,f=ac(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=ac(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=ac(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=ac(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Pe(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Yu(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}hb=b+32|0;c=x[a>>2];b=c-52|0;lb=x[a+4>>2]-(c>>>0<52)|0;return b}function yH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-208|0;hb=f;x[f+204>>2]=c;c=f+160|0;Tb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((xH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if($B(a)){break b}}c=xH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){mb[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}hb=f+208|0;return e}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-80|0;hb=d;e=Nf(d+48|0);x[23420]=0;g=Q(823,b|0,e|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(824,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[23420]=0;U(178,d|0,b|0,g|0);f=x[23420];x[23420]=0;if((f|0)==1){break a}f=jc(d+24|0,d);bd(e+8|0,f);zb(f);zb(d);d:{if(!(g&1)|c>>>0<2){break d}x[23420]=0;Q(176,b|0,1)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);S(a|0);p()}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;e=Nf(d+48|0);x[23420]=0;c=Q(744,b|0,e|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(745,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[23420]=0;c=ac(c);U(178,d|0,b|0,c|0);f=x[23420];x[23420]=0;if((f|0)==1){break a}f=jc(d+24|0,d);bd(e+8|0,f);zb(f);zb(d);d:{c=c&1;if(!c){break d}x[23420]=0;Q(176,b|0,2-c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);hb=d+80|0;return}a=P()|0;Md(e);S(a|0);p()}function J5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=ak(b),x[i>>2]=j;c=hb-16|0;hb=c;g=a;d=Vd(a);a:{if(d){f=ic(g);while(1){a=d;d=a+16|0;if(bt(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!bt(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ic(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=hb-16|0;hb=a;b=ic(g);b=rh(c,wc(40),sh(a+8|0,b));Jb(Rc(x[b>>2]+16|0,x[e>>2])+12|0);i=ic(b),j=1,v[i+4|0]=j;hb=a+16|0;Yg(g,x[c+12>>2],f,x[c>>2]);b=Zd(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[ic(c)+4|0]){bm(a+16|0)}Ib(a)}h=1}Xg(e+8|0,x[gc(c,b)>>2],h);hb=c+16|0;a=ud(x[e+8>>2]);hb=e+16|0;return a+12|0}function ML(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-16|0;hb=d;x[d+12>>2]=b;if(b>>>0<4294967280){a:{if(nm(a)>>>0>=b>>>0){break a}i=d,j=Bd(x[a+4>>2],y[a+11|0]),x[i+8>>2]=j;e=wi(x[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(nm(a)|0)){break a}f=Bd(x[a+4>>2],y[a+11|0]);b:{c:{if((e|0)==10){g=x[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(nm(a)>>>0<e>>>0){b=wc(b);break d}x[23420]=0;b=T(51,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break d}_(V(0)|0)|0;$();break b}c=y[a+11|0];h=Sf(c);g=rd(a);c=Bd(x[a+4>>2],c)}b=He(b,g,c+1|0);if(h){Ib(g)}if((e|0)!=10){Af(a,e+1|0);Sd(a,f);xd(a,b);break b}we(a,f)}}hb=d+16|0;return}Bf();p()}function gP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function S9(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Qs(a+484344|0);Df(a+1298308|0);oA(a+1298320|0);Df(a+1298332|0);Gc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}EU(b);b=b+160|0;continue}}d=x[b>>2];if(d){Ib(St(d))}x[b>>2]=0;b=b+4|0;continue}}}else{mm(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function Ffa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0;c=hb-16|0;hb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{k=(D(b,f)+a|0)+i|0;g=Ph(E(Fd(B[Rp(j,a,b)>>2],E(-1))*E(128)));d:{if(E(F(g))<E(2147483648)){h=~~g;break d}h=-2147483648}l=k,m=OR(h),v[l|0]=m;a=a+1|0;continue}}}aa(17155,8885,27,9412);p()}aa(17105,8885,28,9412);p()}hb=c+16|0}function _A(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=hb-16|0;hb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;bh(b,Wd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=qe(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){ZA(b,32);hb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=Ve(e+14|0,e+12|0);i=Cb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Wb(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function Z5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=hb-96|0;hb=d;x[d+88>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=f;x[d+48>>2]=c;x[d+52>>2]=e;a=$d(d+40|0);c=x[d+60>>2];x[d+24>>2]=x[d+56>>2];x[d+28>>2]=c;x[23420]=0;c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;c=x[a+4>>2];x[d+8>>2]=x[a>>2];x[d+12>>2]=c;U(886,d- -64|0,d+16|0,d+8|0);a=x[23420];x[23420]=0;a:{b:{if((a|0)!=1){a=x[Tf(d+32|0,d+88|0)>>2];x[23420]=0;b=+xa(887,d- -64|0,+b,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}zb(d- -64|0);se(d+88|0);hb=d+96|0;return+b}a=P()|0;break a}a=P()|0;zb(d- -64|0)}se(d+88|0);S(a|0);p()}function DL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=hb-16|0;hb=h;v[h+15|0]=b;v[h+14|0]=10;bh(g,y[Wb(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=qe(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Cb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[Cb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Cb(j,b),p=i,w[o>>1]=p}o=m,p=Wd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;hb=h+16|0}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;f=c;e=hb-16|0;hb=e;g=b;d=Vd(b);a:{if(d){c=ic(g);while(1){b=d;d=b+16|0;if(PL(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!PL(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ic(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=hb-16|0;hb=b;d=ic(g);d=rh(e,wc(28),sh(b+8|0,d));i=x[d>>2];x[23420]=0;R(801,i+16|0,f|0);f=x[23420];x[23420]=0;b:{if((f|0)!=1){j=ic(d),k=1,v[j+4|0]=k;hb=b+16|0;break b}a=P()|0;OL(d);S(a|0);p()}Yg(g,x[e+12>>2],c,x[e>>2]);b=Zd(e);OL(e);i=1}c=h+8|0;Xg(c,x[gc(e,b)>>2],i);hb=e+16|0;eP(a,c);hb=h+16|0}function wD(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];d=Gg(c,x[a+4>>2]);if(d>>>0<b>>>0){f=hb-32|0;hb=f;c=b-d|0;b=x[Fb(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=hb-16|0;hb=d;b=_q(d,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){kc(b);hb=d+16|0}else{vl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Fb(a);d=ar(f+8|0,br(a,Gg(x[a>>2],e)+c|0),Gg(x[a>>2],x[a+4>>2]),b);b=hb-16|0;hb=b;x[b>>2]=x[d+8>>2];e=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=(c<<3)+e;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){vl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}Id(b);hb=b+16|0;zd(a,d);$q(d)}hb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+(b<<3)|0)}}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,j=0,k=0,l=0;c=hb-16|0;hb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){f=x[a+4>>2];e=x[b+4>>2];if((f|0)!=(e|0)){break b}x[c+12>>2]=d;x[c+8>>2]=d;h=x[Hb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;e=x[Hb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){a=0;if((b|0)==(h|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{g=Ph(E(Fd(B[Rp(j,a,b)>>2],E(-1))*E(32768)));d:{if(E(F(g))<E(2147483648)){d=~~g;break d}d=-2147483648}d=Xc(d);k=PR(i,f,a,b),l=d,w[k>>1]=l;a=a+1|0;continue}}}aa(17155,8885,27,9412);p()}aa(17105,8885,28,9412);p()}hb=c+16|0}function D2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=hb+-64|0;hb=d;f=d+16|0;h=hb-16|0;hb=h;i=mO(h+8|0);while(1){if((j|0)==12){hb=h+16|0}else{g=hb+-64|0;hb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=gJ(hJ(g+8|0,32));break a}e=G(c);e=hJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=gJ(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}hb=g- -64|0;l=Cb(f,j),m=c,x[l>>2]=m;j=j+1|0;continue}break}f=xO(d,f,CO(f));sO(a,f);km(f);hb=d- -64|0;d=sx(a+120|0,a,b);v[d+20|0]=1;x[23420]=0;R(1019,a|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){a=P()|0;zn(d);S(a|0);p()}return a|0}function E0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;if(GH(0,d+24|0)){Ur(x[115896],12532);p()}b=Bk(d+16|0,x[d+24>>2],x[d+28>>2]);g=rH(d+8|0,x[d+32>>2]/1e3|0);c=hb-32|0;hb=c;a=hb-16|0;hb=a;f=hb-16|0;hb=f;b=Bk(f+8|0,Wia(x[b>>2],x[b+4>>2],1e6,0),lb);e=x[b+4>>2];b=x[b>>2];hb=f+16|0;x[a+8>>2]=b;x[a+12>>2]=e;b=x[a+12>>2];x[c+16>>2]=x[a+8>>2];x[c+20>>2]=b;hb=a+16|0;e=x[c+16>>2];b=x[c+20>>2];a=x[g+4>>2];x[c+8>>2]=x[g>>2];x[c+12>>2]=a;b=x[c+12>>2]+b|0;a=x[c+8>>2];e=e+a|0;a=Bk(c+24|0,e,a>>>0>e>>>0?b+1|0:b);b=x[a+4>>2];a=x[a>>2];hb=c+32|0;a=Bk(d+40|0,a,b);c=x[a+4>>2];a=x[a>>2];hb=d+48|0;lb=c;return a|0}function X_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-48|0;hb=f;x[f+40>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;ad(a,c);x[23420]=0;a=T(1069,a|0)|0;b=x[23420];x[23420]=0;b:{if((b|0)!=1){Zb(f+24|0);c:{if(e){Hh(f+24|0,a);break c}Gh(f+24|0,a)}g=f,h=Yd(f+24|0),x[g+16>>2]=h;while(1){g=f,h=mh(f+24|0),x[g+8>>2]=h;if(!Lh(f+16|0,f+8|0)){c=x[f+40>>2];xb(f+24|0);break a}a=v[x[f+16>>2]];x[23420]=0;Q(20,f+40|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){Be(f+16|0);continue}break}c=P()|0;xb(f+24|0);break b}c=P()|0;Zb(f+24|0)}S(c|0);p()}hb=f+48|0;return c|0}function RK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;Bh(e+8|0,b);f=hb-16|0;hb=f;Lg(f+8|0,x[e+8>>2],x[e+12>>2]);c=x[f+12>>2];b=x[f+8>>2];g=hb-16|0;hb=g;k=g,l=Db(a),x[k+8>>2]=l;h=b;a=c;b=hb-16|0;hb=b;i=x[g+8>>2];c=i;d=x[c+12>>2];c=x[c+8>>2];a:{if((d|0)<0){break a}j=x[i+4>>2];if(!d&j>>>0<c>>>0|d){break a}x[b+8>>2]=j-c;x[b+12>>2]=0-(d+(c>>>0>j>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;d=MB(b+8|0,b);if((Zy(x[d>>2],x[d+4>>2])|0)!=(a|0)){break a}Hi(h,a+h|0,c+x[i>>2]|0);c=x[g+8>>2];h=c;d=a+x[c+8>>2]|0;c=x[c+12>>2];x[h+8>>2]=d;x[h+12>>2]=a>>>0>d>>>0?c+1|0:c}hb=b+16|0;hb=g+16|0;hb=f+16|0;hb=e+16|0}function oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;pd(b,0);Th(d,1,a);c=d+16|0;Fc(c,d);ze(b+43|0,c);xb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;gq(b,+((y[a+60|0]^8)-120|0)/192);v[d+16|0]=y[a+61|0];v[d|0]=64;f=b,g=y[Wb(c,d)|0]<<2,w[f+30>>1]=g;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}hb=d+32|0}function g_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=LF(b);wk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;vk(k,a);Pi(i,k);Jc(k);Gh(k,a);Pi(h,k);Jc(k);l=d,m=Vi(a),x[l>>2]=m;l=e,m=Wi(a),x[l>>2]=m;Ng(k,a);Ac(f,k);xb(k);Hh(k,a);Pi(g,k);Jc(k);a=uk(a);break a}a=KF(b);wk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;vk(k,a);Pi(i,k);Jc(k);Gh(k,a);Pi(h,k);Jc(k);l=d,m=Vi(a),x[l>>2]=m;l=e,m=Wi(a),x[l>>2]=m;Ng(k,a);Ac(f,k);xb(k);Hh(k,a);Pi(g,k);Jc(k);a=uk(a)}x[j>>2]=a;hb=k+16|0}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){if(hh(119304647)>>>0<b>>>0){Tc();p()}b=D(b,36);c=wc(b);x[a>>2]=c;x[a+4>>2]=c;f=Fb(a),g=b+c|0,x[f>>2]=g;d=hb-16|0;hb=d;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=b+c;b=x[d+4>>2];e=x[d+8>>2];while(1){if((b|0)==(e|0)){kc(d);hb=d+16|0}else{c=Tb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}return a|0}function Oo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);b:{c:{d:{while(1){d=sc(c);Cx(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;e:{if((b|0)!=1){x[23420]=0;R(71,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(70,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(e);hb=e+16|0;break a}a=P()|0;yb(e);S(a|0);p()}}function BT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);b:{c:{d:{while(1){d=sc(c);zx(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break d}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;e:{if((b|0)!=1){x[23420]=0;R(71,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(70,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(e);hb=e+16|0;break a}a=P()|0;yb(e);S(a|0);p()}}function n_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-16|0;hb=k;a:{if(a){a=OF(b);wk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;vk(k,a);Ac(i,k);xb(k);Gh(k,a);Ac(h,k);xb(k);l=d,m=Vi(a),v[l|0]=m;l=e,m=Wi(a),v[l|0]=m;Ng(k,a);Ac(f,k);xb(k);Hh(k,a);Ac(g,k);xb(k);a=uk(a);break a}a=NF(b);wk(k,a);b=x[k>>2];v[c|0]=b;v[c+1|0]=b>>>8;v[c+2|0]=b>>>16;v[c+3|0]=b>>>24;vk(k,a);Ac(i,k);xb(k);Gh(k,a);Ac(h,k);xb(k);l=d,m=Vi(a),v[l|0]=m;l=e,m=Wi(a),v[l|0]=m;Ng(k,a);Ac(f,k);xb(k);Hh(k,a);Ac(g,k);xb(k);a=uk(a)}x[j>>2]=a;hb=k+16|0}function as(a,b,c){var d=0,e=0;d=a,e=aj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=aj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function K2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Ro(c,a,1);ux(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;kc(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Fb(a);c=Lv(e+8|0,Mv(a,fh(x[a>>2],x[a+4>>2])+1|0),fh(x[a>>2],x[a+4>>2]),c);ux(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;ux(x[b>>2]-16|0,d);x[b>>2]=x[b>>2]-16;continue}break}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;x[c+8>>2]=b;ps(b);continue}break}a=x[c>>2];if(a){Po(c);Ib(a)}hb=e+32|0}function lN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-16|0;hb=c;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}d=c+8|0;f=a+1074312|0;Ab(d,f,21);e=a;a=y[b+821|0];a=my(e,y[b+828|0],Bb(x[x[c+8>>2]>>2],x[c+12>>2])?a:a+16>>>2|0);Ab(d,f,45);b:{if(!(!Bb(x[x[c+8>>2]>>2],x[c+12>>2])|y[b+828|0]!=3)){d=y[b+821|0];c:{if(!(!d|d>>>0>=y[b+829|0])){a=y[b+832|0];e=d+1|0;break c}v[b+832|0]=a;e=1}v[b+821|0]=e;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}Ab(c+8|0,f,47);if(!Bb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}v[b+831|0]=a}if(a){g=b,h=Xb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[g+684>>2]=h}hb=c+16|0}function ega(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=ak(b),x[i>>2]=j;f=z[b>>1];d=hb-16|0;hb=d;g=a;c=Vd(a);a:{if(c){b=ic(g);while(1){a=c;c=z[a+14>>1];if(lo(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!lo(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ic(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=hb-16|0;hb=a;c=ic(g);f=rh(d,wc(20),sh(a+8|0,c));c=x[f>>2];h=z[x[e>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=ic(f),j=1,v[i+4|0]=j;hb=a+16|0;Yg(g,x[d+12>>2],b,x[d>>2]);a=Zd(d);cl(d);h=1}Xg(e+8|0,x[gc(d,a)>>2],h);hb=d+16|0;a=Vp(x[e+8>>2]);hb=e+16|0;return a+2|0}function QQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;Yj(a+8|0,0);e=x[b+4>>2];if(e){Oq(a,e);$k(d+8|0,x[b>>2]);lm(d,x[b>>2],x[b+4>>2]);c=hb-32|0;hb=c;f=x[a+4>>2];e=x[d+8>>2];h=x[d+12>>2];b=x[d>>2];k=x[d+4>>2];g=f+OQ(e,h,b,k)|0;x[a+4>>2]=g;a:{b:{if(!f){i=g-1|0;break b}i=g-1|0;if((i^f-1)>>>0>31){break b}x[c+24>>2]=e;x[c+28>>2]=h;j=x[a>>2];break a}j=x[a>>2];x[j+((g>>>0>=33?i>>>5|0:0)<<2)>>2]=0;x[c+24>>2]=e;x[c+28>>2]=h}Ao(c+16|0,j,f);e=x[c+28>>2];x[c>>2]=x[c+24>>2];x[c+4>>2]=e;PQ(c+8|0,c,b,k,x[c+16>>2],x[c+20>>2]);hb=c+32|0}hb=d+16|0;return a|0}function kp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);a:{b:{c:{while(1){d=sc(c);Cx(f+8|0,d,Eb(c)+d|0,x[b>>2]);if(!x[f+12>>2]){break c}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(60,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(c);hb=f+32|0;break a}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(57,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(e);hb=e+16|0;return}a=P()|0;xb(e);S(a|0);p()}function C6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);a:{b:{c:{while(1){d=sc(c);Cx(f+8|0,d,Eb(c)+d|0,y[b|0]);if(!x[f+12>>2]){break c}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break b}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;d:{if((b|0)!=1){x[23420]=0;R(60,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}break b}break b}xb(c);hb=f+32|0;break a}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(57,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(e);hb=e+16|0;return}a=P()|0;xb(e);S(a|0);p()}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=w[f>>1];x[(e<<2)+b>>2]=g+((D(w[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function kZ(a){a=a|0;if(y[467264]){return x[116815]}if(!y[468368]){a=468080;while(1){a=Jb(a)+12|0;if((a|0)!=468368){continue}break}v[468368]=1}md(468080,88072);md(468092,88104);md(468104,88140);md(468116,88164);md(468128,88188);md(468140,88204);md(468152,88224);md(468164,88244);md(468176,88272);md(468188,88312);md(468200,88344);md(468212,88380);md(468224,88416);md(468236,88432);md(468248,88448);md(468260,88464);md(468272,88188);md(468284,88480);md(468296,88496);md(468308,88512);md(468320,88528);md(468332,88544);md(468344,88560);md(468356,88576);v[467264]=1;x[116815]=468080;return 468080}function t8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Dz(c,a);Qx(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Fb(a);c=bg(e+8|0,Tg(a,vc(x[a>>2],x[a+4>>2])+1|0),vc(x[a>>2],x[a+4>>2]),c);Qx(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Qx(x[b>>2]-4|0,d);x[b>>2]=x[b>>2]-4;continue}break}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;hg(b);continue}break}a=x[c>>2];if(a){vz(c);Ib(a)}hb=e+32|0}function Yg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[ic(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(qh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!qh(d)){Zp(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Yp(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(qh(d)){Yp(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;Zp(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=Fb(a);x[a>>2]=x[a>>2]+1}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb+-64|0;hb=c;f=wO(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10465];d=c+32|0;x[d+8>>2]=x[10464];x[d+12>>2]=e;e=x[10463];x[d>>2]=x[10462];x[d+4>>2]=e;iz(d,h*+(b>>>0));qO(c+48|0,C[c+32>>3],C[c+40>>3]);d=dd(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Wk(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;by(f,0,g,c);hb=c- -64|0;return f|0}function mk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){gn(e,f,CD(f));qd(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;x[23420]=0;b=T(155,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;hb=e+16|0;return a&(-1<<b^-1)}ha(b|0,30320,156);p()}function dm(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function OI(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);b:{c:{d:{while(1){d=sc(c);jx(f+8|0,d,Eb(c)+d|0,z[b>>1]);if(!x[f+12>>2]){break d}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;e:{if((b|0)!=1){x[23420]=0;R(71,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(70,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(e);hb=e+16|0;break a}a=P()|0;yb(e);S(a|0);p()}}function iJ(a,b){var c=0,d=0,e=0,f=0;a:{e=hb-16|0;hb=e;f=hb-32|0;hb=f;c=Qe(f+16|0,1,0);b:{c:{d:{while(1){d=sc(c);YI(f+8|0,d,Eb(c)+d|0,y[b|0]);if(!x[f+12>>2]){break d}d=If(Eb(c));x[23420]=0;R(58,c|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){continue}break}break c}b=x[f+8>>2];d=sc(c);x[23420]=0;R(59,c|0,b-d|0);b=x[23420];x[23420]=0;e:{if((b|0)!=1){x[23420]=0;R(71,e|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break e}break c}break c}xb(c);hb=f+32|0;break b}a=P()|0;xb(c);S(a|0);p()}x[23420]=0;R(70,a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(e);hb=e+16|0;break a}a=P()|0;yb(e);S(a|0);p()}}function UH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Ne(a)){ec(a,31);return 0}g=a,h=Ne(a),v[g+1375|0]=h;d=$i(a);b=$i(a);$i(a);g=a,h=$i(a),x[g+1112>>2]=h;$i(a);c=Ne(a);x[a+1116>>2]=c;if(!Yw(a,a+1120|0,c)){ec(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function yX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=hb-32|0;hb=k;m=x[c>>2];l=x[c+8>>2];c=x[c+4>>2];x[k+8>>2]=c;x[k+12>>2]=l;x[k+24>>2]=c;x[k+28>>2]=l;x[k+20>>2]=m;x[k+16>>2]=d;x[23420]=0;c=x[k+20>>2];x[k>>2]=x[k+16>>2];x[k+4>>2]=c;a=Ja(998,a|0,b|0,k|0)|0;b=x[23420];x[23420]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23420]=0;ia(885,10307,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}$();a=-255}hb=k+32|0;break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}return a|0}function hX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=hb+-64|0;hb=g;Xm(g+16|0,c);x[23420]=0;c=g+28|0;R(101,c|0,d|0);d=x[23420];x[23420]=0;b:{c:{d:{if((d|0)==1){break d}x[23420]=0;c=g+40|0;R(101,c|0,e|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}x[23420]=0;c=g+52|0;R(101,c|0,f|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}Kv(g+8|0,g+16|0);x[23420]=0;X(102,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}_D(g+16|0);hb=g- -64|0;break a}a=P()|0;while(1){c=yb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;_D(g+16|0)}S(a|0);p()}}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=hb-16|0;hb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=v[f|0];x[(e<<2)+b>>2]=((D(v[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function cU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function y5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{b:{c:{if((d|0)==1){break c}x[23420]=0;Y(903,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[23420]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;X(915,c+16|0,d|0,c|0,1);b=x[23420];x[23420]=0;if((b|0)==1){break c}a=c+16|0;b=Wf(Ic(a));xb(a);break b}_(V(0)|0)|0;b=0;x[23420]=0;X(889,5496,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=c+32|0;return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function sn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;v[a|0]=0;a:{d=x[x[b>>2]-12>>2]+b|0;b:{if(Jg(d)){d=x[d+72>>2];if(d){Jq(d)}c:{if(c){break c}c=x[x[b>>2]-12>>2]+b|0;if(!(x[c+4>>2]&4096)){break c}d=e+24|0;ad(d,c);x[23420]=0;f=T(18,d|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}Zb(e+24|0);c=xm(e+16|0,b);d=Bc(e+8|0);while(1){d:{if(!dp(c,d)){break d}g=Ek(x[c>>2]);if(!jh(x[f+8>>2],1,g)){break d}Jl(c);continue}break}if(!Yi(c,d)){break c}hk(x[x[b>>2]-12>>2]+b|0,6)}h=a,i=Jg(x[x[b>>2]-12>>2]+b|0),v[h|0]=i;break b}hk(d,4)}hb=e+32|0;return a}a=P()|0;Zb(e+24|0);S(a|0);p()}function GH(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[463588]){f=463589,g=Ca()|0,v[f|0]=g;v[463588]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[463589]){break c}d=+Ba();break a}x[115896]=28;return-1}d=+Ha()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}e=-2147483648;a=0}x[b>>2]=a;x[b+4>>2]=e;c=(d-(+(Wia(a,e,1e3,0)>>>0)+ +(lb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function mw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;ad(g,b);x[23420]=0;b=T(1086,g|0)|0;g=x[23420];x[23420]=0;a:{if((g|0)==1){break a}x[23420]=0;X(1098,b|0,81808,81840,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;b=T(1087,f+8|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;c=T(1099,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break a}x[d>>2]=c;x[23420]=0;c=T(1096,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[e>>2]=c;x[23420]=0;R(1097,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}Zb(f+8|0);hb=f+16|0;return}a=P()|0;Zb(f+8|0);S(a|0);p()}function bh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=vc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=hb-16|0;hb=c;b=Nh(c,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){kc(b);hb=c+16|0}else{bv(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Fb(a);c=bg(e+8|0,Tg(a,vc(x[a>>2],d)+b|0),vc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=ql(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){bv(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Id(b);hb=f+16|0;zd(a,c);ag(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function fD(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=Cb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Up(x[a>>2],x[c>>2])?c:a;continue}}hb=b+16|0;return x[a>>2]-36|0}function ae(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a=gh(a,-1,-1);a:{b:{if(Rd(y[sn(c+24|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23420]=0;R(95,c+8|0,d|0);d=x[23420];x[23420]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}_(V(0)|0)|0;e=1;rn(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}$()}hk(x[x[b>>2]-12>>2]+b|0,e)}hb=c+32|0;return}V(0)|0;Ub()}p()}function YY(a){a=a|0;if(y[467256]){return x[116813]}if(!y[468064]){a=467776;while(1){a=Jb(a)+12|0;if((a|0)!=468064){continue}break}v[468064]=1}id(467776,4995);id(467788,4986);id(467800,10734);id(467812,10482);id(467824,5222);id(467836,11510);id(467848,5079);id(467860,5570);id(467872,8788);id(467884,8771);id(467896,8779);id(467908,8798);id(467920,9965);id(467932,13104);id(467944,8861);id(467956,7632);id(467968,5222);id(467980,9654);id(467992,10370);id(468004,10746);id(468016,9151);id(468028,6424);id(468040,5453);id(468052,13022);v[467256]=1;x[116813]=467776;return 467776}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=hb-48|0;hb=e;d=x[a+8>>2];c=x[a>>2];x[23420]=0;d=W(144,c|0,d|0,1)|0;c=x[23420];x[23420]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}x[23420]=0;Y(451,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}x[23420]=0;d=T(194,a|0)|0;c=x[23420];x[23420]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}x[23420]=0;c=Q(452,a|0,e+8|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break c}d:{if(!c){break d}c=y[e+8|0];if(c>>>0>63){break d}pc(vS(x[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}zb(a);hb=e+48|0;return}b=P()|0;zb(a);S(b|0);p()}function zJ(a,b){var c=0,d=0;c=x[a>>2];x[a>>2]=b;if(c){x[23420]=0;Y(768,c|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){a=x[c+4>>2];if(a){if(x[a>>2]){d=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;hg(b);continue}break}x[a+4>>2]=d;b=x[a>>2];ti(a);Ib(b)}Ib(a)}x[c+4>>2]=0;AM(c+1298408|0);zy(c+1298344|0);xb(c+1298332|0);yb(c+1298320|0);xb(c+1298308|0);yy(c+1298304|0);xy(c+1298300|0);_s(c+1298264|0);My(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=Rs(b-160|0);if((a|0)!=(b|0)){continue}break}tz(c+484360|0);tM(c+484344|0);tc(c+480248|0);break a}V(0)|0;Ub();p()}Ib(c)}}function qw(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;g=f+8|0;ad(g,b);x[23420]=0;b=T(18,g|0)|0;g=x[23420];x[23420]=0;a:{if((g|0)==1){break a}x[23420]=0;X(1084,b|0,81808,81840,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}x[23420]=0;b=T(1069,f+8|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;c=T(1085,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break a}v[d|0]=c;x[23420]=0;c=T(1082,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}v[e|0]=c;x[23420]=0;R(1083,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}Zb(f+8|0);hb=f+16|0;return}a=P()|0;Zb(f+8|0);S(a|0);p()}function D$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-32|0;hb=c;a:{b:{c:{if(uc(b,-1)){break c}i=c,j=wn(b),v[i+23|0]=j;if(y[a+44|0]){d=-1;if((fk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Mr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((fk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((fk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Ew(b);break a}d=-1}hb=c+32|0;return d|0}function wX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=hb-16|0;hb=c;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[23420]=0;Y(903,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break d}e=x[a+24>>2];b=qc(c+8|0,b);x[23420]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;YE(923,e,c,f,d);d=x[23420];x[23420]=0;b=1;if((d|0)!=1){break c}}_(V(0)|0)|0;x[23420]=0;X(889,8544,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break b}$();b=0}hb=c+16|0;break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}return b|0}function NK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=li(a,b,c,d);v[a+4260|0]=e;x[a>>2]=46244;c=Qb(a+4264|0);d=Qb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=Cb(b,0),g=1056964608,x[f>>2]=g;f=Cb(b,1),g=1036831949,x[f>>2]=g;f=Cb(b,2),g=1038174126,x[f>>2]=g;f=Cb(b,3),g=1065353216,x[f>>2]=g;f=Cb(b,4),g=1061158912,x[f>>2]=g;f=Cb(b,5),g=1059082943,x[f>>2]=g;f=Cb(b,6),g=1061997773,x[f>>2]=g;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;tc(d);tc(c);vf(a);S(b|0);p()}function PM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}d=x[b+104>>2];if(!d){break a}if(!Td(x[d>>2],x[d+20>>2])){break a}f=z[d+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+33232|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+d>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+d>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[d+20>>2];c=b+c|0;b=lk(f);hc(e+8|0,g+D(c,b)|0,b);b=x[e+8>>2];f=Kb(b,x[e+12>>2]);while(1){if((b|0)==(f|0)){lj(d,a)}else{v[b|0]=y[b|0]^-1;b=b+1|0;continue}break}}hb=e+16|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){h=x[b+12>>2]+i|0;e=v[h|0];e=((D(v[h+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function z$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=y[a+52|0];a:{if(uc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=uc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=wn(x[a+48>>2]),v[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(Mr(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Kr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function N_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+24>>2]=b;a:{if(!(x[c+4>>2]&1)){c=mb[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;ad(a,c);x[23420]=0;a=T(1087,a|0)|0;b=x[23420];x[23420]=0;b:{if((b|0)!=1){Zb(f+8|0);c:{if(e){Hh(f+8|0,a);break c}Gh(f+8|0,a)}g=f,h=Yd(f+8|0),x[g>>2]=h;while(1){a=yk(f+8|0);b=x[f>>2];if(!Pb(b,a)){c=x[f+24>>2];Jc(f+8|0);break a}a=x[b>>2];x[23420]=0;Q(1102,f+24|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){Ce(f);continue}break}c=P()|0;Jc(f+8|0);break b}c=P()|0;Zb(f+8|0)}S(c|0);p()}hb=f+32|0;return c|0}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=hb-16|0;hb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){h=(x[b+12>>2]<<1)+i|0;e=w[h>>1];e=e+((D(w[h+2>>1]-e|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Rb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;hb=b+16|0}function T5(a){a=a|0;var b=0;b=7934;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21473;break a}b=7967;break a}b=17373;break a;case 0:b=4972;break a;case 9:b=7990;break a;case 10:b=8004;break a;case 11:b=5349;break a;case 12:b=5369;break a;case 19:b=8016;break a;case 20:b=7948;break a;case 21:b=12688;break a;case 22:b=12011;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5980;break a}b=7901}return Wf(b)|0}function No(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Sf(y[a+11|0])){c=y[b+11|0];if(!Sf(c)){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return}d=rd(b);b=Bd(x[b+4>>2],c);c=hb-16|0;hb=c;a:{if(b>>>0<=10){we(a,b);a=He(a,d,b);v[c+15|0]=0;sd(a+b|0,c+15|0);break a}f=a;a=Mf(y[a+11|0]);Lt(f,10,b-10|0,a,0,a,b,d)}hb=c+16|0;return}d=rd(b);b=Bd(x[b+4>>2],y[b+11|0]);c=hb-16|0;hb=c;e=QA(x[a+8>>2]);b:{if(e>>>0>b>>>0){e=x[a>>2];Sd(a,b);a=He(e,d,b);v[c+15|0]=0;sd(a+b|0,c+15|0);break b}f=a;a=x[a+4>>2];Lt(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}hb=c+16|0}}function Hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=hb-32|0;hb=f;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=D(Dg(x[x[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Db(x[a+4>>2]);c:{if(d){e=gc(f+24|0,e);d=f+16|0;Rh(d);e=x[e>>2];x[23420]=0;X(589,a|0,e|0,c|0,d|0);c=x[23420];x[23420]=0;if((c|0)!=1){break c}a=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(a|0)|0;$();break b}c=gc(f+8|0,aB(e,c));e=x[gc(f,Db(x[a+4>>2]))>>2];d=x[c>>2];c=x[a>>2];c=D(Is(d,Db(c)),6)+c|0;if(Pb(d,e)){Nd(a,zL(c+D(Is(e,d),6)|0,x[a+4>>2],c))}Db(c)}x[a+12>>2]=b}hb=f+32|0;return}S(a|0);p()}function xX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[23420]=0;Y(903,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}c=x[a+24>>2];e=qc(d+8|0,b);x[23420]=0;b=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=b;b=ZE(c,d,1);e=x[23420];x[23420]=0;c=lb;if((e|0)!=1){break c}}_(V(0)|0)|0;x[23420]=0;X(889,8575,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break b}$();b=0;c=0}hb=d+16|0;a=c;break a}b=P()|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)!=1){S(b|0);p()}V(0)|0;Ub();p()}ib=a;return b|0}function u5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;a:{b:{c:{if((e|0)==1){break c}x[23420]=0;Y(903,b|0);e=x[23420];x[23420]=0;if((e|0)==1){break c}e=x[a+24>>2];b=qc(d+8|0,b);x[23420]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;X(920,e|0,d|0,(c|0)!=0|0,1);c=x[23420];x[23420]=0;b=1;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,9897,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}hb=d+16|0;return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function k7(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+24620>>2];b=Hc(Xia(Wia(b,b>>31,3840,0),lb,1e3,0),lb);x[a+4316>>2]=b;x[23420]=0;x[c+12>>2]=0;U(859,a+4264|0,b|0,c+12|0);b=x[23420];x[23420]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[23420]=0;x[c+12>>2]=0;U(859,a+4276|0,b|0,c+12|0);b=x[23420];x[23420]=0;if((b|0)!=1){break d}b=V(91780)|0;break c}x[c+12>>2]=0;b=c+12|0;KK(a+4288|0,b);x[c+12>>2]=0;KK(a+4300|0,b);break b}b=V(91780)|0}if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;x[a+4316>>2]=0;$()}hb=c+16|0;return}S(b|0);p()}function fP(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;zz(a+48|0);zz(a+68|0);zz(a+88|0);mt(a+492|0);mt(a+524|0);Em(a,0,0);Dm(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;Ut(a,b);b=a+108|0;d=fA(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function L$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=hb-32|0;hb=c;a:{b:{c:{if(qn(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((fk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Mr(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((fk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((fk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=qn(b)?0:b;break a}d=-1}hb=c+32|0;return d|0}function t5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=hb-16|0;hb=e;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{b:{c:{if((d|0)==1){break c}x[23420]=0;Y(903,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(e+8|0,b);x[23420]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Xa(922,d|0,e|0,+c,1);d=x[23420];x[23420]=0;b=1;if((d|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,5887,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}hb=e+16|0;return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Xr(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=hb-240|0;hb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((mb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((mb[b|0](l,i)|0)>=0){break e}if((mb[b|0](l-f|0,i)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=EH(c,d);Yr(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}DH(h,k);Uw(i,b,e,g)}hb=h+240|0}function gR(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Ft(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=Ft(a);a=a+34|0;if(b){continue}break}}return d}function G$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;d=y[a+52|0];a:{if(qn(b)){if(d){break a}b=x[a+48>>2];e=a,f=qn(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Mr(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((Kr(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}hb=c+32|0;return b|0}function hr(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a=Jb(a);a:{b:{c:{switch(b|0){case 0:x[23420]=0;b=Q(1,d|0,15680)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}Gb(a,b);yb(b);break b;case 1:x[23420]=0;b=Q(1,d|0,15705)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 2:x[23420]=0;b=Q(1,d|0,15653)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 3:break c;default:break b}}x[23420]=0;b=Q(1,d|0,15627)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}Gb(a,b);yb(b)}hb=d+16|0;return}b=P()|0;yb(a);S(b|0);p()}function W9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(fn(a)>>>0>=b>>>0){break a}h=d,i=Eb(a),x[h+8>>2]=i;e=Hl(x[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(fn(a)|0)){break a}f=1;c=fn(a);g=Eb(a);b:{c:{if((e|0)==1){b=a;c=x[a>>2];break c}b=e+1|0;d:{if(c>>>0<e>>>0){b=qi(b);break d}x[23420]=0;b=T(1175,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break d}_(V(0)|0)|0;$();break b}f=Se(a);c=sc(a)}di(b,c,Eb(a)+1|0);if(f){Ib(c)}if((e|0)!=1){Af(a,e+1|0);Sd(a,g);xd(a,b);break b}we(a,g)}}hb=d+16|0;return}Bf();p()}function UA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(aq(y[a+1|0]),c)|0}return c}function Ws(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-16|0;hb=c;x[c+12>>2]=b;if(b>>>0<4294967280){a:{if(Sc(a)>>>0>=b>>>0){break a}h=c,i=Eb(a),x[h+8>>2]=i;d=wi(x[Yc(c+12|0,c+8|0)>>2]);if((d|0)==(Sc(a)|0)){break a}f=Eb(a);b:{c:{if((d|0)==10){g=1;b=a;e=x[a>>2];break c}b=d+1|0;d:{if(Sc(a)>>>0<d>>>0){b=wc(b);break d}x[23420]=0;b=T(51,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){break d}_(V(0)|0)|0;$();break b}g=Se(a);e=sc(a)}b=He(b,e,Eb(a)+1|0);if(g){Ib(e)}if((d|0)!=10){Af(a,d+1|0);Sd(a,f);xd(a,b);break b}we(a,f)}}hb=c+16|0;return}Bf();p()}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=hb-16|0;hb=g;h=z[c>>1];i=c;e=hb-16|0;hb=e;f=b;d=Vd(b);a:{if(d){c=ic(f);while(1){b=d;d=z[b+14>>1];if(tl(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!tl(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ic(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=hb-16|0;hb=b;d=ic(f);d=rh(e,wc(16),sh(b+8|0,d));wj(x[d>>2]+14|0,z[i>>1]);k=ic(d),l=1,v[k+4|0]=l;hb=b+16|0;Yg(f,x[e+12>>2],c,x[e>>2]);b=Zd(e);cl(e);j=1}c=g+8|0;Xg(c,x[gc(e,b)>>2],j);hb=e+16|0;eP(a,c);hb=g+16|0}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){c=hb-16|0;hb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;d=x[Hb(c+12|0,c+8|0)>>2];hb=c+16|0;if(b>>>0>d>>>0){Tc();p()}b=D(b,9);c=wc(b);x[a>>2]=c;x[a+4>>2]=c;e=Fb(a),f=b+c|0,x[e>>2]=f;c=hb-16|0;hb=c;x[c>>2]=a;d=x[a+4>>2];x[c+4>>2]=d;x[c+8>>2]=b+d;b=x[c+4>>2];d=x[c+8>>2];while(1){if((b|0)==(d|0)){kc(c);hb=c+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}return a|0}function DC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=hb-16|0;hb=f;x[f+8>>2]=e;x[f+12>>2]=d;Df(a);Ws(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Hb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=qu(rr(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Hb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[Nc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Nc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}hb=f+16|0}function Nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=z[nl(x[a>>2],x[a+4>>2],b)>>1];a:{b:{if(!oq(a,b)){break b}c=x[a+24>>2];d=Db(x[c+484360>>2]);x[f+8>>2]=d;h=Db(x[c+484364>>2]);while(1){if(!Pb(d,h)){break b}e=0;i=fl(x[d>>2],x[d+4>>2]);while(1){if((e|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(e|0))|z[bc(x[d>>2],e)>>1]!=(g|0)){break c}c=oR(x[a+24>>2]+484344|0,g);if((c|0)==65535){break c}j=nl(x[a>>2],x[a+4>>2],b),k=c,w[j>>1]=k;break a}e=e+1|0;continue}break}d=x[uz(f+8|0)>>2];continue}}c=g}hb=f+16|0;return c&65535}function w8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=hb-48|0;hb=e;d=x[a+28>>2];Ym(x[x[d>>2]-12>>2]+d|0,0);d=x[x[b>>2]+4>>2];if(d){g=x[a+28>>2];f=x[a+12>>2];h=d;d=x[a+8>>2]+d|0;f=h>>>0>d>>>0?f+1|0:f;d=gh(e+32|0,d,f);f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;Hj(g,e)}d=e+16|0;ae(d,x[a+28>>2]);pz(x[a+28>>2],c,x[x[b>>2]+8>>2]);b=x[b>>2];c=Zm(d,Kb(x[a+32>>2],x[b>>2]),z[b+12>>1]);x[23420]=0;Q(848,a|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){Sb(c);hb=e+48|0;break a}a=P()|0;Sb(c);S(a|0);p()}}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{b:{c:{if((d|0)==1){break c}x[23420]=0;Y(903,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break c}d=x[a+24>>2];b=qc(c+8|0,b);x[23420]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+qa(913,d|0,c|0,1);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,5924,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}hb=c+16|0;return+e}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function HM(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Ab(e+8|0,a+1074312|0,3);if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Ab(e+8|0,a+1074312|0,3);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=Ts(a,x[f+1075080>>2],d);if(!a){break a}mb[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}hb=e+16|0}function D5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;a:{b:{c:{if((c|0)==1){break c}x[23420]=0;Y(903,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break c}c=x[a+24>>2];b=qc(d+8|0,b);x[23420]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=W(909,c|0,d|0,1)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,9928,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}hb=d+16|0;return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function k4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-32|0;hb=c;a:{f=a+36|0;b=x[f>>2];d=x[a+40>>2];b:{if(Pb(b,d)){Bc(c+24|0);break b}b=c+8|0;Dn(b,a);x[23420]=0;b=T(961,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[c+24>>2]=b;Vf(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}b=(g=f,h=x[c+24>>2],i=Pb(b,d),i?g:h);a=x[a+8>>2];c:{if((a|0)==-1){g=c,h=Db(x[b>>2]),x[g+8>>2]=h;a=Db(x[b+4>>2]);while(1){b=x[c+8>>2];if(!Pb(b,a)){break c}e=e+C[b>>3];JI(c+8|0);continue}}e=C[bl(x[b>>2],a)>>3]}Ik(c+24|0);hb=c+32|0;return+e}a=P()|0;Vf(c+8|0);S(a|0);p()}function $w(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=hb-32|0;hb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];XH(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);XH(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+70080>>2];i=B[d+70092>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+70088>>2];d=5-a<<2;m=B[d+70080>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}hb=e+32|0}function oQ(a,b,c,d,e){var f=0;f=y[(y[a+3|0]&15)+26864|0];v[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:c=y[a+5|0];c=D(c&240,10)|c&15;v[a+5|0]=c;f=c&255;c=z[d>>1];if(!(f|(c|0)==65535)){v[a+5|0]=c;v[a+3|0]=12;w[d>>1]=65535}xc(e,b);return;case 1:w[d>>1]=y[a+5|0];x[e>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;e=x[a+28>>2];Ym(x[x[e>>2]-12>>2]+e|0,0);e=x[x[b>>2]+4>>2];if(e){h=x[a+28>>2];g=x[a+12>>2];i=e;e=x[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=gh(f+32|0,e,g);g=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=g;g=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=g;Hj(h,f)}e=f+16|0;ae(e,x[a+28>>2]);iL(d,x[a+28>>2],c);b=x[b>>2];c=Zm(e,Kb(x[a+32>>2],x[b>>2]),z[b+12>>1]);x[23420]=0;Q(848,a|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){Sb(c);hb=f+48|0;return}a=P()|0;Sb(c);S(a|0);p()}function v8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=hb-48|0;hb=f;e=x[a+28>>2];Ym(x[x[e>>2]-12>>2]+e|0,0);e=x[x[b>>2]+4>>2];if(e){h=x[a+28>>2];g=x[a+12>>2];i=e;e=x[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=gh(f+32|0,e,g);g=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=g;g=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=g;Hj(h,f)}e=f+16|0;ae(e,x[a+28>>2]);fL(c,x[a+28>>2],d);b=x[b>>2];c=Zm(e,Kb(x[a+32>>2],x[b>>2]),z[b+12>>1]);x[23420]=0;Q(848,a|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){Sb(c);hb=f+48|0;return}a=P()|0;Sb(c);S(a|0);p()}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=x[b+8>>2]>>>21&2040;e=(((D(w[e>>1],w[f+39714>>1])+D(w[e-2>>1],w[f+39712>>1])|0)+D(w[e+2>>1],w[f+39716>>1])|0)+D(w[e+4>>1],w[f+39718>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function zk(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Rd(y[sn(e+8|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[23420]=0;b=W(94,d|0,b|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}_(V(0)|0)|0;d=1;rn(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[23420]=0;Z(93);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)==1){break b}S(a|0);p()}$()}hk(x[x[a>>2]-12>>2]+a|0,d);hb=e+16|0;return a}V(0)|0;Ub()}p()}function WK(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Kx(a);c=Fd(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;Ds(a);return;case 3:v[a+4240|0]=c>=E(.5);Ds(a);return;case 4:b=hb-16|0;hb=b;e=b,f=Mh(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[vj(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Jx(a)}C[a+4256>>3]=c;break;default:break a}}}function q_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-416|0;hb=h;d=h+416|0;x[h+12>>2]=d;c=hb-144|0;hb=c;x[c+28>>2]=c+132;i=c+32|0;SF(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;g=vc(e,x[h+12>>2]);f=hb-16|0;hb=f;i=ai(f+8|0,x[a+8>>2]);a=uG(e,c+12|0,g,c+16|0);$h(i);hb=f+16|0;if((a|0)==-1){Jr(12451);p()}x[h+12>>2]=(a<<2)+e;hb=c+144|0;c=x[h+12>>2];a=hb-16|0;hb=a;x[a+8>>2]=b;while(1){if((c|0)!=(e|0)){XG(a+8|0,x[e>>2]);e=e+4|0;continue}break}hb=a+16|0;hb=d;return x[a+8>>2]}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=mk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Tq(c+4|0,mk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Tq(c+4|0,d-e|0);break b}VC(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}VC(a,e,0,b)}d=x[a+1072>>2];continue}break}hb=c+16|0}function qI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{b:{c:{a=x[a+32>>2];e=ts(a);d:{if(!e){if(ss(a)>>>0<=b>>>0){break d}a=_j(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;x[23420]=0;b=Q(54,d|0,5961)|0;c=x[23420];x[23420]=0;e:{if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break e}c=P()|0;ca(a|0)}S(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}hb=d+16|0;return}p()}function mM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=vc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=hb-32|0;hb=f;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){nC(a,b,h);break b}c=Fb(a);c=bg(f+8|0,Tg(a,vc(x[a>>2],d)+b|0),vc(x[a>>2],x[a+4>>2]),c);g=hb-16|0;hb=g;b=ql(g,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Lp(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Id(b);hb=g+16|0;zd(a,c);ag(c)}hb=f+32|0;break a}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}sy(a);hb=e+16|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-208|0;hb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;wM(a+946304|0);d=e+48|0;Tb(d,0,160);d=CM(d);x[23420]=0;f=a+906300|0;U(775,f|0,f+4e4|0,d|0);f=x[23420];x[23420]=0;a:{if((f|0)!=1){Rs(d);d=he(e+24|0,b);x[23420]=0;f=x[d+12>>2];x[e+8>>2]=x[d+8>>2];x[e+12>>2]=f;x[e+16>>2]=x[d+16>>2];f=x[d+4>>2];x[e>>2]=x[d>>2];x[e+4>>2]=f;a=W(776,a|0,e|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){a=P()|0;break a}zb(b);hb=e+208|0;return a|0}a=P()|0;Rs(d)}zb(b);S(a|0);p()}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Hb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=mk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Tq(c+4|0,mk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Tq(c+4|0,d-e|0);break b}UC(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}UC(a,e,0,b)}d=x[a+1072>>2];continue}break}hb=c+16|0}function u9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-48|0;hb=d;c=d+24|0;sj(c,b,1819307379);bd(a+40|0,c);zb(c);sj(c,b,1953721961);bd(a+60|0,c);zb(c);sj(c,b,543520099);bd(a+120|0,c);zb(c);sj(c,b,1414744396);x[23420]=0;c=Q(348,c|0,13612)|0;e=x[23420];x[23420]=0;a:{if((e|0)!=1){b:{if(c){x[23420]=0;U(725,d|0,d+24|0,2);c=x[23420];x[23420]=0;if((c|0)==1){break b}Dt(a+140|0,d);_d(d)}x[23420]=0;U(726,d|0,b|0,1634890872);b=x[23420];x[23420]=0;if((b|0)!=1){break a}}}a=P()|0;zb(d+24|0);S(a|0);p()}bd(a+80|0,d);zb(d);zb(d+24|0);hb=d+48|0}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;pd(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=x[b+8>>2]>>>21&2040;e=(((D(v[e|0],w[f+39714>>1])+D(v[e-1|0],w[f+39712>>1])|0)+D(v[e+1|0],w[f+39716>>1])|0)+D(v[e+2|0],w[f+39718>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function Ii(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;wf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;hb=f+16|0}function tV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;pd(b,0);Th(d,1,a+33|0);e=d+16|0;Fc(e,d);ze(b+43|0,e);xb(e);f=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=f;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[d+16|0]=y[a+56|0];v[d|0]=64;h=b,i=y[Wb(e,d)|0]<<2,w[h+30>>1]=i;e=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=e;g=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?e?f:g:g;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function my(a,b,c){var d=0,e=0;e=hb-16|0;hb=e;Ab(e+8|0,a+1074312|0,21);a:{if(Bb(x[x[e+8>>2]>>2],x[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=v[c+33440|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=VL(On(a))+-64|0;break a}d=v[(c>>>1&31)+31952|0];if(z[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=v[a+33312|0];break a;case 0:d=(a>>>0>=32?255:0)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=v[a+33376|0]}a=d;hb=e+16|0;return a}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=hb-608|0;hb=f;b=hb-16|0;hb=b;d=f+8|0;xR(b+8|0,d);c=x[b+12>>2];ld(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){cd(a,x[b+12>>2])}hb=b+16|0;c=(c|0)==(e|0);if(!c){wR(d)}b=-1;a:{if(!c){break a}b=0;if(!yR(f+8|0)){break a}b=-1;if(!Uf(a,1024)){break a}b=0;d=hb-1024|0;hb=d;c=hb-16|0;hb=c;hA(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){cd(a,x[c+12>>2])}hb=c+16|0;if((e|0)==(g|0)){b=iA(d,0)>>>0<17}hb=d+1024|0}hb=f+608|0;return b|0}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+24>>2];g=x[a+20>>2];h=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;i=x[a+8>>2];j=x[a+12>>2];while(1){if(d){k=((((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=w[(e<<1)+k>>1];e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],g);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f);Rb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;PN(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;kc(c);hb=c+16|0;return}f=hb-32|0;hb=f;g=Fb(a);h=f+8|0;d=$y(x[a>>2],x[a+4>>2])+1|0;c=hb-16|0;hb=c;x[c+12>>2]=d;a:{e=hh(613566756);if(d>>>0<=e>>>0){d=az(a);if(d>>>0<e>>>1>>>0){x[c+8>>2]=d<<1;e=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;break a}Tc();p()}c=SN(h,e,$y(x[a>>2],x[a+4>>2]),g);PN(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;RN(a,c);QN(c);hb=f+32|0}function r4(a){a=a|0;var b=0,c=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){a=x[a+24>>2];b=x[a+24>>2];c=z[b+1074448>>1];a:{if(c>>>0>=kj(Yb(x[b+484360>>2],y[b+484376|0]))>>>0){a=z[x[a+24>>2]+1074446>>1];break a}a=x[a+24>>2];b=z[bc(x[Yb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];a=zm(x[a+484344>>2],x[a+484348>>2],b)?b:-1}return a|0}_(V(0)|0)|0;x[23420]=0;X(889,9658,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Nf(c+48|0);x[23420]=0;e=Q(577,b|0,d|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(578,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[23420]=0;U(178,c|0,b|0,(e>>>0>=9?e-8|0:0)|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);S(a|0);p()}b=jc(c+24|0,c);bd(d+8|0,b);zb(b);zb(c);gl(a,d)}Md(d);hb=c+80|0}function cu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=hb-16|0;hb=g;x[g+12>>2]=0;x[g+8>>2]=a;i=hb-16|0;hb=i;b=fc(i+8|0,x[g+8>>2],x[g+12>>2]);e=hb-16|0;hb=e;d=117;x[e+12>>2]=117;c=x[b+4>>2];a:{if(!c){c=x[b>>2];break a}f=32-c|0;x[e+8>>2]=f;d=x[b>>2];j=x[d>>2];h=f;f=x[Hb(e+8|0,e+12|0)>>2];x[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=x[e+12>>2];c=d+4|0;x[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Tb(h,0,c);f=d&31;x[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+x[b>>2]|0;x[h>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-f^-1)}hb=e+16|0;hb=i+16|0;hb=g+16|0;return a}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Nf(c+48|0);x[23420]=0;e=Q(456,b|0,d|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(457,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}}break c}e=z[d+2>>1]|z[d+4>>1]<<16;x[23420]=0;U(178,c|0,b|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);S(a|0);p()}b=jc(c+24|0,c);bd(d+8|0,b);zb(b);zb(c);oS(a,d)}Md(d);hb=c+80|0}function _5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Vj(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Vj(E(E(c>>>0)*E(1.1892070770263672)));e=Vj(E(E(d>>>0)*E(1.1892070770263672)));h=Vj(E(E(e>>>0)*E(1.1892070770263672)));f=Vj(E(E(c+e>>>0)*E(.11546666920185089)));g=Vj(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=Cb(b,0),j=c-f|0,x[i>>2]=j;i=Cb(b,1),j=e-f|0,x[i>>2]=j;i=Cb(b,2),j=d-g|0,x[i>>2]=j;i=Cb(b,3),j=h-g|0,x[i>>2]=j;i=Cb(b,4),j=f,x[i>>2]=j;i=Cb(b,5),j=g,x[i>>2]=j;hK(a);fK(a)}function LM(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?(b&240?-16:15)&b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}f=x[a+480208>>2]&4096;g=b&240;if(!(!c|(g|0)!=240)){if(!f){break b}b=0-(c<<1)|0;break c}if(f){break b}if(g){if(c?e&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));ge(d+12|0,0,256);x[a>>2]=x[d+12>>2]}hb=d+16|0}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+12>>2]=b;a:{if(Ps(a)>>>0>=b>>>0){e=x[a>>2];g=ik(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Hb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=xL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Wx(a,b-g|0,c);break a}vL(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){Qs(a);d=x[a>>2];Ps(a);Ib(d);h=Fb(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}d=uL(a,b);if(hh(82595524)>>>0<d>>>0){Tc();p()}e=tL(d);x[a>>2]=e;x[a+4>>2]=e;h=Fb(a),i=e+D(d,52)|0,x[h>>2]=i;Wx(a,b,c)}hb=f+16|0}function n9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=hb-32|0;hb=f;a=Qb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[23420]=0;e=W(144,g|0,e|0,8)|0;g=x[23420];x[23420]=0;if((g|0)==1){break c}if(e){x[23420]=0;U(821,f|0,b|0,c|0);e=x[23420];x[23420]=0;if((e|0)==1){break e}x[23420]=0;R(822,a|0,f|0);e=x[23420];x[23420]=0;if((e|0)==1){break d}Md(f);e=NQ(x[a+4>>2]);yi(f,x[e>>2],x[e+4>>2]);if(x[f>>2]!=(d|0)){continue}}break}hb=f+32|0;break a}b=P()|0;break b}b=P()|0;Md(f);break b}b=P()|0}_d(a);S(b|0);p()}}function OX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,x[b+8>>2],e)){ew(b,c,d);return}a:{if(Kg(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];mb[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function $O(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function mG(a,b,c,d){var e=0,f=0,g=0;f=hb-16|0;hb=f;a:{b:{if((a|0)!=(b|0)){c:{g=x[115896];x[115896]=0;Ad();d=lG(a,f+12|0,d);e=lb;d:{a=x[115896];if(a){if(x[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}x[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}x[115896]=g;if(x[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){x[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){x[c>>2]=4;a=2147483647;break a}a=d;break a}}x[c>>2]=4;a=0;break a}a=-2147483648}hb=f+16|0;return a}function D9(a){a=a|0;var b=0,c=0;b=32048;a=Qb(a);a:{b:{while(1){c:{if((b|0)==32624){b=32624;break c}d:{c=x[a+4>>2];if(!uc(x[a>>2],c)){if(!ej(x[b+8>>2],x[Jn(c)>>2])){break d}}x[23420]=0;R(799,a|0,b+8|0);c=x[23420];x[23420]=0;if((c|0)!=1){break d}break b}b=b+12|0;continue}break}while(1){if((b|0)==32672){break a}e:{c=x[a+4>>2];f:{if(!uc(x[a>>2],c)){if(!ej(x[b+8>>2],x[Jn(c)>>2])){break f}}x[23420]=0;R(799,a|0,b+8|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;tc(a);S(b|0);p()}}function C4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;e=Qb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=x[a+24>>2];if(z[d+480188>>1]<=b>>>0){break a}x[23420]=0;R(957,c|0,(d+(b<<5)|0)+480289|0);d=x[23420];x[23420]=0;if((d|0)!=1){d=x[a+24>>2];x[23420]=0;U(958,c+16|0,d|0,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break e}x[23420]=0;R(171,e|0,c+16|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}b=b+1|0;xb(c+16|0);xb(c);continue}break}b=P()|0;break b}b=P()|0;break c}b=P()|0;xb(c+16|0)}xb(c)}Ke(e);S(b|0);p()}hb=c+32|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,26);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;f=x[a+24>>2];g=x[a+20>>2];h=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;i=x[a+8>>2];j=x[a+12>>2];while(1){if(d){k=(((x[b+12>>2]&2147483647)<<1|x[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){x[(e<<2)+b>>2]=v[e+k|0]<<8;e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],g);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f);Rb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function iaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Jb(a);a=0;a:{b:{c:{d:{while(1){d=x[b>>2];if(vd(d,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Hd(d,0);break e}x[23420]=0;Q(755,f|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}d=Hd(x[b>>2],a)}x[23420]=0;R(756,e|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;Q(755,f|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break d}a=a+1|0;xb(e);continue}break}a=P()|0;break a}a=P()|0;xb(e);break a}hb=e+16|0;return}a=P()|0}xb(f);S(a|0);p()}function SC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=y[a+8|0];h=x[a>>2];e=x[a+4>>2];f=Ic(b);a=Eb(b);b=hb-16|0;hb=b;x[b+8>>2]=a;x[b+12>>2]=e;a=h;g=x[Hb(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=y[f|0];v[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){v[b+7|0]=0;Ql(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}v[b+6|0]=32;Ql(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:v[(x[b+12>>2]+h|0)-1|0]=0;break;default:break c}}hb=b+16|0}function rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-80|0;hb=c;d=Nf(c+48|0);x[23420]=0;e=Q(612,b|0,d|0)|0;f=x[23420];x[23420]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(613,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[23420]=0;U(178,c|0,b|0,e|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}a=P()|0;Md(d);S(a|0);p()}b=jc(c+24|0,c);bd(d+8|0,b);zb(b);zb(c);gl(a,d)}Md(d);hb=c+80|0}function Aq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Se(a)){if(!Se(b)){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return}d=Ic(b);b=Eb(b);c=hb-16|0;hb=c;a:{if(b>>>0<=10){we(a,b);a=He(a,d,b);v[c+15|0]=0;sd(a+b|0,c+15|0);break a}f=a;a=y[a+11|0];Xo(f,10,b-10|0,a,0,a,b,d)}hb=c+16|0;return}d=Ic(b);b=Eb(b);c=hb-16|0;hb=c;e=ll(a);b:{if(e>>>0>b>>>0){e=x[a>>2];Sd(a,b);a=He(e,d,b);v[c+15|0]=0;sd(a+b|0,c+15|0);break b}f=a;a=x[a+4>>2];Xo(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}hb=c+16|0}}function MW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=Jb(a);a=0;a:{b:{c:{d:{while(1){d=x[b>>2];if(vd(d,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Hd(d,0);break e}x[23420]=0;Q(87,f|0,c|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break b}d=Hd(x[b>>2],a)}x[23420]=0;R(141,e|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;Q(87,f|0,e|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break d}a=a+1|0;yb(e);continue}break}a=P()|0;break a}a=P()|0;yb(e);break a}hb=e+16|0;return}a=P()|0}yb(f);S(a|0);p()}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-32|0;hb=c;pd(b,0);Th(c,1,a);d=c+16|0;Fc(d,c);ze(b+43|0,d);xb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+16|0]=y[a+15|0];v[c|0]=64;e=b,f=y[Wb(d,c)|0]<<2,w[e+30>>1]=f;hb=c+32|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;g=x[a+32>>2];j=x[a+28>>2];k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=w[(x[b+12>>2]<<1)+i>>1];f=f+j|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+g|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function Wl(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=hb-32|0;hb=d;a=Qb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[23420]=0;c=W(144,e|0,c|0,8)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}if(c){x[23420]=0;R(606,d|0,b|0);c=x[23420];x[23420]=0;if((c|0)==1){break e}x[23420]=0;R(607,a|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break d}Md(d);c=NQ(x[a+4>>2]);yi(d,x[c>>2],x[c+4>>2]);if(x[d>>2]!=1413891155){continue}}break}hb=d+32|0;break a}b=P()|0;break b}b=P()|0;Md(d);break b}b=P()|0}_d(a);S(b|0);p()}}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){if(hh(715827882)>>>0<b>>>0){Tc();p()}d=D(b,6);c=wc(d);x[a>>2]=c;x[a+4>>2]=c;f=Fb(a),g=c+d|0,x[f>>2]=g;d=hb-16|0;hb=d;c=mq(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){kc(c);hb=d+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[c+4>>2]=b;continue}break}}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function il(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}zo(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Ag(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function O3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{if((d|0)==1){break a}x[23420]=0;Y(973,c|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[23420]=0;b=Wa(974,d|0,E(e),b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}_(V(0)|0)|0;x[23420]=0;X(889,10245,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);d=x[a+4>>2];x[23420]=0;R(435,d|0,b|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;kc(a);hb=c+16|0;break a}b=P()|0;kc(a);S(b|0);p()}return}d=hb-32|0;hb=d;c=Fb(a);c=nk(d+8|0,Vm(a,vd(x[a>>2],x[a+4>>2])+1|0),vd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[23420]=0;R(435,e|0,b|0);b=x[23420];x[23420]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;lr(a,c);Hv(c);hb=d+32|0;break b}a=P()|0;Hv(c);S(a|0);p()}}function zO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=gt(b);x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);hz(a,2048);g=hb-16|0;hb=g;f=_q(g,a,2048);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){kc(f);hb=g+16|0}else{x[d>>2]=0;x[d+4>>2]=0;d=d+8|0;x[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=gt(M(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*si(c)/(h*c)}k=Pe(x[a>>2],e),l=c*.011841342921061943,C[k>>3]=l;e=e+1|0;continue}break}}function pI(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;a:{b:{c:{a=x[a+32>>2];c=ts(a);d:{if(!c){if(ss(a)>>>0<=b>>>0){break d}c=(y[_j(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;x[23420]=0;b=Q(54,d|0,5961)|0;c=x[23420];x[23420]=0;e:{if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break e}c=P()|0;ca(a|0)}S(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}hb=d+16|0;return c|0}p()}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=hb-16|0;hb=b;e=x[a+40>>2];f=x[a+36>>2];i=x[a+16>>2];g=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=g;g=x[a+32>>2];j=x[a+28>>2];k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){h=v[x[b+12>>2]+i|0]<<8;f=f+j|0;x[c>>2]=x[c>>2]+D(h,f>>12);e=e+g|0;x[c+4>>2]=x[c+4>>2]+D(e>>12,h);Rb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=e;x[a+20>>2]=f>>12;x[a+36>>2]=f;x[a+24>>2]=e>>12;hb=b+16|0}function d_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=hb-16|0;hb=h;d=Eb(a);e=fn(a);g=qe(b,c);a:{if(!g){break a}b:{f=sc(a);if(f>>>0<=b>>>0){f=(Eb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){JF(a,e,(d+g|0)-e|0,d,d)}e=sc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}xd(e,x[b>>2]);b=b+4|0;e=e+4|0;continue}}b=rG(h,b,c);c=sc(b);d=Eb(b);x[23420]=0;W(1122,a|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){Jc(b);break a}a=P()|0;Jc(b);S(a|0);p()}xd(e,0);Kh(a,d+g|0)}hb=h+16|0;return a|0}function Q5(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{b:{if(!a){a=Wf(21473);break b}x[23420]=0;c=Q(54,b|0,a|0)|0;a=x[23420];x[23420]=0;c:{d:{if((a|0)!=1){x[23420]=0;R(888,b+16|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break d}d=b+16|0;a=Wf(Ic(d));xb(d);xb(c);break b}a=V(0)|0;break c}a=V(0)|0;xb(c)}_(a|0)|0;a=0;x[23420]=0;X(889,10874,0,0,0);c=x[23420];x[23420]=0;if((c|0)==1){break a}$()}hb=b+32|0;return a|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Pd(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=1080;x[b>>2]=a;x[b+8>>2]=0;c=hb-16|0;hb=c;if(x[a>>2]!=-1){a:{d=gc(c,mf(c+8|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){xd(a,1);x[23420]=0;Y(1081,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break b}x[a>>2]=-1}break a}_(V(0)|0)|0;xd(a,0);x[23420]=0;Z(93);a=x[23420];x[23420]=0;c:{if((a|0)==1){a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){break c}V(0)|0;Ub()}p()}S(a|0);p()}}hb=c+16|0;hb=b+16|0;return x[a+4>>2]-1|0}function uE(a,b,c,d){var e=0,f=0,g=0;e=hb-80|0;hb=e;f=Nf(e+48|0);x[23420]=0;d=Q(d|0,b|0,f|0)|0;g=x[23420];x[23420]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[23420]=0;T(c|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[23420]=0;U(178,e|0,b|0,ac(c)|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}a=P()|0;Md(f);S(a|0);p()}b=jc(e+24|0,e);bd(f+8|0,b);zb(b);zb(e);gl(a,f)}Md(f);hb=e+80|0}function jI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-32|0;hb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;d=Q(54,d+8|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=fm(C[yg(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;hb=d+32|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-32|0;hb=d;pd(b,0);bB(d,a+1|0);c=d+16|0;Fc(c,d);ze(b+43|0,c);xb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);e=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(e){x[b+8>>2]=e+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,x[b+8>>2]);hb=d+32|0}function Zn(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+27664|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function iy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=z[e>>1];i=f+2|0;if((i|0)<(c|0)){j=z[e+2>>1];f=sp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=z[d>>1];if(sp(b,g&65535,i)){break a}while(1){b:{f=e;w[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=z[e>>1];j=d+2|0;if((j|0)<(c|0)){l=z[e+2>>1];d=sp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!sp(b,g&65535,i)){continue}}break}w[f>>1]=i}}function cM(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=D(b,104)+a|0;e=c+484380|0;if(!Td(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){mm(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;il(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}hb=d+32|0;return f>>>0>61536}function aP(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=D(e,g);i=x[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function A4(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;e=Qb(a);Qd(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[23420]=0;R(169,e|0,GI(d,b)|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((GI(b,x[c+28>>2])|0)<=(a|0)){hb=c+32|0;return}b=x[b+(a<<3)>>2];x[23420]=0;b=Q(54,c+8|0,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){x[23420]=0;R(171,e|0,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break b}xb(b);a=a+1|0;continue}break}a=P()|0;break a}a=P()|0;xb(b);break a}a=P()|0}Ke(e);S(a|0);p()}function Az(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;f=a+14|0;c=x[a>>2];e=x[a+4>>2];if(uc(c,e)){b=c}else{w[c>>1]=0;nf(c+2|0,b);g=d,h=hm(Db(x[a>>2]),1),x[g+8>>2]=h;while(1){e=Db(x[a+4>>2]);c=x[d+8>>2];if(Pb(c,e)){g=c,h=z[Ve(c,hm(c,-1))>>1],w[g>>1]=h;nf(c+2|0,b);XP(d+8|0);continue}else{e=x[a+4>>2];b=x[a>>2]}break}}nf(f,qe(b,e)-1&255);nf(a+13|0,y[a+14|0]);nf(a+16|0,qe(x[a>>2],x[a+4>>2])-1&255);nf(a+15|0,y[a+16|0]);if(y[a+17|0]!=255){nf(a+17|0,qe(x[a>>2],x[a+4>>2])-1&255)}hb=d+16|0}function $C(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;g=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=x[b+84>>2];if(c>>>0<=15){d=x[e>>2]}else{x[f+12>>2]=c-16;d=x[Yc(e,f+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)|!y[b+794|0]){break a}d=c;c=x[b+104>>2];b:{if(!(!_C(d,c)|x[e>>2]!=x[c+12>>2])){e=1;d=x[b+84>>2];if((d|0)==x[c+16>>2]){break b}}e=0;d=x[b+84>>2];if((d|0)!=x[c+8>>2]){break a}}h=a,i=D((x[c>>2]-d|0)+(e?112:48)|0,lk(z[c+34>>1]))+g|0,x[h+4>>2]=i}hb=f+16|0}function gJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){e=vy(x[a>>2]);c=lb;f=x[a+36>>2];if((c|0)==(f|0)&A[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=x[a+8>>2];b=(e&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=vy(x[a>>2]);c=lb;f=x[a+28>>2];if((c|0)==(f|0)&A[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=x[a+8>>2];b=(d&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function Ar(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((qo(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=_F(i,b,f);h=sc(f);x[23420]=0;h=W(1105,a|0,h|0,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break a}Jc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((qo(a,c,b)|0)!=(b|0)){break b}}pq(e);j=a}hb=i+16|0;return j|0}a=P()|0;Jc(f);S(a|0);p()}function rda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=hb-48|0;hb=f;tq(f+8|0,c);x[23420]=0;c=f+20|0;R(528,c|0,d|0);d=x[23420];x[23420]=0;b:{c:{d:{if((d|0)==1){break d}x[23420]=0;c=f+32|0;R(528,c|0,e|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}Cv(f,f+8|0);x[23420]=0;X(282,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}LP(f+8|0);hb=f+48|0;break a}a=P()|0;while(1){c=xb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;LP(f+8|0)}S(a|0);p()}}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=vU(c,a);DA(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;kc(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Fb(a);c=tU(e+8|0,uU(a,uq(x[a>>2],x[a+4>>2])+1|0),uq(x[a>>2],x[a+4>>2]),c);DA(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;DA(x[b>>2]-28|0,d);x[b>>2]=x[b>>2]-28;continue}break}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];sU(c);hb=e+32|0}function QW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=hb-48|0;hb=f;Oo(f+8|0,c);x[23420]=0;c=f+20|0;R(127,c|0,d|0);d=x[23420];x[23420]=0;b:{c:{d:{if((d|0)==1){break d}x[23420]=0;c=f+32|0;R(127,c|0,e|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}Cv(f,f+8|0);x[23420]=0;X(102,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}ir(f+8|0);hb=f+48|0;break a}a=P()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;ir(f+8|0)}S(a|0);p()}}function gk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=vU(c,a);xB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;kc(a);hb=c+16|0;return}e=hb-32|0;hb=e;c=Fb(a);c=tU(e+8|0,uU(a,uq(x[a>>2],x[a+4>>2])+1|0),uq(x[a>>2],x[a+4>>2]),c);xB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;f=x[a>>2];d=x[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;xB(x[b>>2]-28|0,d);x[b>>2]=x[b>>2]-28;continue}break}nc(a,b);nc(a+4|0,c+8|0);nc(Fb(a),yc(c));x[c>>2]=x[c+4>>2];sU(c);hb=e+32|0}function fI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){zx(a,b,c,d);return}g=d;i=D(e,e);k=D(i,e);j=D(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;x[a>>2]=c;return}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4856|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-32|0;hb=c;e=c+8|0;f=Qb(e+8|0);x[23420]=0;d=T(190,b|0)|0;g=x[23420];x[23420]=0;a:{b:{if((g|0)==1){break b}x[23420]=0;U(232,e|0,b|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break b}d=x[e>>2];x[23420]=0;Q(176,b|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break a}}a=P()|0;dc(f);S(a|0);p()}Eu(c,e);x[23420]=0;U(410,a|0,x[c>>2],x[c+4>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){Oc(c+8|0);hb=c+32|0;return}a=P()|0;Oc(c+8|0);S(a|0);p()}function xL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=hb-16|0;hb=c;d=x[b>>2];f=x[b+4>>2];e=ck(d,f);a:{if(e>>>0<=ju(a)>>>0){g=f;h=x[a>>2];i=ck(h,x[a+4>>2]);j=i>>>0>=e>>>0;if(!j){x[c+12>>2]=d;x[c+12>>2]=x[c+12>>2]+D(i,6);g=x[c+12>>2]}d=zL(d,g,h);if(!j){Yx(a,g,f,e-ck(x[a>>2],x[a+4>>2])|0);break a}Nd(a,d);break a}yL(a);au(a,LA(a,e));Yx(a,d,f,e)}hb=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];wL(a+24|0,b+24|0);Aq(a+36|0,b+36|0);return a}function wf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function mQ(a){var b=0,c=0;a:{if(Ob(a+60|0,13667,4)){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=qQ(a+20|0)}return c}function J1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;e=Io(a);x[e>>2]=60140;a=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=a;a=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=yc(e);c=hb-16|0;hb=c;d=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=d;d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;d=LI(c);b=Qm(b);v[b+8|0]=0;x[b+4>>2]=d;x[b>>2]=60540;Qb(b+12|0);x[b>>2]=60304;d=x[a+4>>2];x[b+24>>2]=x[a>>2];x[b+28>>2]=d;d=x[a+12>>2];x[b+32>>2]=x[a+8>>2];x[b+36>>2]=d;hb=c+16|0;hb=a+16|0;return e|0}function by(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-48|0;hb=e;a:{if(!c){b=dd(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;by(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=dd(x[a>>2],c);ni(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;by(a,b|c,f,e)}hb=e+48|0}function jW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=WS(rd(b),Bd(x[b+4>>2],y[b+11|0]),rd(c),Bd(x[c+4>>2],y[c+11|0]));if((e|0)!=-1){f=d,g=Ei(b),x[f+16>>2]=g;f=d,g=Di(d+16|0,e),x[f+24>>2]=g;f=d,g=Di(d+24|0,1),x[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=_u(b),x[f>>2]=g;e=Gf(d+8|0,d);LC(b,x[c>>2],x[e>>2]);break b}if(!ol(x[b+4>>2],y[b+11|0])){break b}if(CS(rd(b),Bd(x[b+4>>2],y[b+11|0]),rd(c),Bd(x[c+4>>2],y[c+11|0]))){break b}Jb(a);break a}Rc(a,b)}hb=d+48|0}function x4(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=E(0);x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){a=x[x[a+24>>2]+24>>2];if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=a+D(b,872)|0;c=E(E(y[a+1075834|0])*E(.0078125));e=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(e+E(c*c))))}return E(c)}_(V(0)|0)|0;x[23420]=0;X(889,9279,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return E(E(0))}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function r2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Mh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Ih(m,l,e,f);h=x[g>>2];n=g,o=Hc(Xia(Wia(h,h>>31,d,k),lb,65536,0),lb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;cJ(a,c);hb=c+16|0}function qM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=x[c>>2];c=x[c+4>>2];h=x[a+96>>2];i=x[a+100>>2];a:{if(!(h|i)){b=x[e+4>>2];d=x[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=x[e+4>>2];d=x[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;x[e>>2]=f-d;x[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=j;x[a+100>>2]=0;lb=x[e+4>>2];return x[e>>2]}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=hb-16|0;hb=c;a:{d=Mh(E(B[a+24>>2]*E(65536)));if((d|0)==65536){break a}i=x[b+4>>2];j=x[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=x[b+4>>2];m=x[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Ih(m,l,e,f);h=x[g>>2];n=g,o=Hc(Xia(Wia(h,h>>31,d,k),lb,65536,0),lb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;XI(a,c);hb=c+16|0}function Av(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){b=hb-16|0;hb=b;a=qD(b,a);c=x[a+4>>2];x[23420]=0;Y(158,c|0);c=x[23420];x[23420]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;kc(a);hb=b+16|0;break a}b=P()|0;kc(a);S(b|0);p()}return}c=hb-32|0;hb=c;b=Fb(a);b=oD(c+8|0,pD(a,Zq(x[a>>2],x[a+4>>2])+1|0),Zq(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[23420]=0;Y(158,d|0);d=x[23420];x[23420]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;nD(a,b);ov(b);hb=c+32|0;break b}a=P()|0;ov(b);S(a|0);p()}}function qJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!b){a=a+120|0;zn(a);g=mJ(a,x[d+12>>2]),h=0,v[g+20|0]=h;break a}e=hb-16|0;hb=e;x[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;zn(b);g=sx(b,a,x[e+12>>2]),h=1,v[g+20|0]=h;break b}f=hb-16|0;hb=f;x[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;zn(a);a=mJ(a,x[f+12>>2]);$d(a+12|0);v[a+20|0]=2;break c}b=hb-16|0;hb=b;x[b+12>>2]=c;c=a+120|0;zn(c);g=sx(c,a,x[b+12>>2]),h=3,v[g+20|0]=h;hb=b+16|0}hb=f+16|0}hb=e+16|0}hb=d+16|0}function QR(a,b,c,d){var e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!cf(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){e=cf(a,f+14|0);if(e){g=y[f+14|0];w[c>>1]=g<<1|1;v[b|0]=g>>>7;w[c>>1]=y[c|0]}if(!e){break a}if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}hb=f+16|0}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=ak(b),x[i>>2]=j;g=z[b>>1];c=hb-16|0;hb=c;f=a;d=Vd(a);a:{if(d){b=ic(f);while(1){a=d;d=z[a+16>>1];if(lo(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!lo(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ic(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){SS(c,f,e);Yg(f,x[c+12>>2],b,x[c>>2]);a=Zd(c);RS(c);h=1}Xg(e+8|0,x[gc(c,a)>>2],h);hb=c+16|0;a=ud(x[e+8>>2]);hb=e+16|0;return a+4|0}function nL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;i=e,j=ak(b),x[i>>2]=j;g=z[b>>1];c=hb-16|0;hb=c;f=a;d=Vd(a);a:{if(d){b=ic(f);while(1){a=d;d=z[a+16>>1];if(Gs(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Gs(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ic(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){SS(c,f,e);Yg(f,x[c+12>>2],b,x[c>>2]);a=Zd(c);RS(c);h=1}Xg(e+8|0,x[gc(c,a)>>2],h);hb=c+16|0;a=ud(x[e+8>>2]);hb=e+16|0;return a+4|0}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-32|0;hb=d;pd(b,0);Th(d,1,a+33|0);c=d+16|0;Fc(c,d);ze(b+43|0,c);xb(c);e=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=e;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+16|0]=y[a+54|0];v[d|0]=64;g=b,h=y[Wb(c,d)|0]<<2,w[g+30>>1]=h;f=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=f;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}hb=d+32|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;el(d,2,a+2|0);e=d+16|0;Fc(e,d);Dc(b+492|0,e);f=b+236|0;g=c+1|0;xb(e);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;DL(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);DL(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);hb=d+32|0}else{h=bc(f,c),i=y[(a+c|0)+31|0]+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function $G(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]){break b}if(!Jg(b)|!(x[b+4>>2]&8192)){break b}if(qH()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23420]=0;b=T(1055,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23420]=0;Y(1056,a+b|0);a=x[23420];x[23420]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break a}}return}V(0)|0;Ub();p()}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=hb-16|0;hb=e;f=ff(a,c);ae(e,x[a+28>>2]);h=a;a:{if(!f){c=0;if(gd(a,5)){break a}}c=0;d=hb-32|0;hb=d;g=x[a+28>>2];pk(g,d+24|0);i=d,j=Vc(x[d+24>>2],x[d+28>>2]),x[i+16>>2]=j;x[d+12>>2]=256;Pj(b,x[Hb(d+16|0,d+12|0)>>2]);a=x[b>>2];while(1){if(vc(a,x[b+4>>2])>>>0<=c>>>0){hb=d+32|0}else{x[d+16>>2]=0;mp(g,d+16|0);a=x[b>>2];i=Cb(a,c),k=B[d+16>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}af(h,c);hb=e+16|0}function lf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Wia(b,c,h,i);i=lb;j=h;h=Wia(d,e,f,g);e=j+h|0;d=lb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Wia(g,e,c,d);g=j+i|0;c=lb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Wia(h,0,i,0);b=lb;c=0;d=Wia(h,c,l,d);b=b+d|0;c=lb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Wia(i,m,k,e)+b|0;e=lb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;x[g+8>>2]=h;x[g+12>>2]=h>>>0<i>>>0?c+1|0:c;x[g>>2]=f;x[g+4>>2]=d}function jG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[115896];x[115896]=0;Ad();a=rw(a,e+12|0,d);d=lb;g=x[115896];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[115896]=h;if((b|0)!=x[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a&65535}function hl(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]){break b}if(!Jg(b)|!(x[b+4>>2]&8192)){break b}if(qH()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[23420]=0;b=T(21,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[23420]=0;R(15,a+b|0,1);a=x[23420];x[23420]=0;if((a|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break a}}return}V(0)|0;Ub();p()}function a8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a>>2]=44072;b=Qb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Tb(a+4248|0,0,48);x[23420]=0;Z(765);c=x[23420];x[23420]=0;a:{if((c|0)==1){break a}e=a,f=xM(),x[e+4296>>2]=f;Ds(a);Cs(a);x[23420]=0;R(853,a+44|0,2);c=x[23420];x[23420]=0;if((c|0)==1){break a}ki(a);return a|0}c=P()|0;dc(b);vf(a);S(c|0);p()}function U1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d+4>>2]=1;g=d,h=wc(56),x[g+8>>2]=h;c=hb-16|0;hb=c;e=Io(x[d+8>>2]);x[e>>2]=60640;f=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=f;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;b=Qm(yc(e));x[b>>2]=61004;Qb(b+4|0);v[b+20|0]=0;x[b+16>>2]=0;x[b>>2]=60804;e=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=e;e=x[c+12>>2];x[b+32>>2]=x[c+8>>2];x[b+36>>2]=e;v[b+40|0]=0;hb=c+16|0;b=a;a=Ko(d);Jo(b,yc(a),a);Rm(d);hb=d+16|0}function JW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=RD(rd(b),Bd(x[b+4>>2],y[b+11|0]),rd(c),Bd(x[c+4>>2],y[c+11|0]));if((e|0)!=-1){f=d,g=Ei(b),x[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=Ei(b),x[f+8>>2]=g;f=d,g=Di(d+8|0,e),x[f+16>>2]=g;e=Gf(d+24|0,d+16|0);LC(b,x[c>>2],x[e>>2]);break b}e=ol(x[b+4>>2],y[b+11|0]);if(!e){break b}if((QD(rd(b),Bd(x[b+4>>2],y[b+11|0]),rd(c),Bd(x[c+4>>2],y[c+11|0]))|0)!=(e-1|0)){break b}Jb(a);break a}Rc(a,b)}hb=d+48|0}function Ay(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=x[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=y[b+813|0];if(c){v[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Qj(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(Bb(x[x[d+8>>2]>>2],x[d+12>>2])|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}hb=d+16|0}function U3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;if((c|0)!=1){a=x[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(kj(Yb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[bc(x[Yb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c|0}_(V(0)|0)|0;x[23420]=0;X(889,9693,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function JM(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=x[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=y[b+814|0];if(c){v[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Qj(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}Ab(d+8|0,a+1074312|0,7);if(Bb(x[x[d+8>>2]>>2],x[d+12>>2])|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}hb=d+16|0}function yq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=hb-16|0;hb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((qo(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Qe(i,b,f);g=sc(f);x[23420]=0;g=W(22,a|0,g|0,b|0)|0;h=x[23420];x[23420]=0;if((h|0)==1){break a}xb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((qo(a,c,b)|0)!=(b|0)){break b}}pq(e);j=a}hb=i+16|0;return j|0}a=P()|0;xb(f);S(a|0);p()}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){if(hh(178956970)>>>0<b>>>0){Tc();p()}c=D(b,24);b=wc(c);x[a>>2]=b;x[a+4>>2]=b;f=Fb(a),g=b+c|0,x[f>>2]=g;b=hb-16|0;hb=b;x[b>>2]=a;d=x[a+4>>2];x[b+4>>2]=d;x[b+8>>2]=c+d;c=x[b+4>>2];d=x[b+8>>2];a:{while(1){if((c|0)==(d|0)){break a}x[23420]=0;Y(529,c|0);e=x[23420];x[23420]=0;if((e|0)!=1){c=c+24|0;x[b+4>>2]=c;continue}break}a=P()|0;kc(b);S(a|0);p()}kc(b);hb=b+16|0}return a|0}function Ot(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function qL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=vc(d,x[a+4>>2]);if(c>>>0<=127){f=hb-32|0;hb=f;c=128-c|0;e=x[Fb(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Vx(a,c,b);break a}e=Fb(a);d=bg(f+8|0,Tg(a,vc(x[a>>2],d)+c|0),vc(x[a>>2],x[a+4>>2]),e);g=hb-16|0;hb=g;c=ql(g,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){Hs(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}Id(c);hb=g+16|0;zd(a,d);ag(d)}hb=f+32|0;return}if((c|0)!=128){Nd(a,d+512|0)}}function gG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[115896];x[115896]=0;Ad();a=rw(a,e+12|0,d);d=lb;d:{g=x[115896];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[115896]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}hb=e+16|0;lb=a;return b}function TE(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;x[23420]=0;Y(902,a|0);j=x[23420];x[23420]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[23420]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}b=Wf(Ic(i));xb(i);break b}}_(V(0)|0)|0;b=0;x[23420]=0;X(889,g|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=i+16|0;return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function pE(a,b,c,d,e,f){var g=0;a:{g=hb-48|0;hb=g;Xm(g+8|0,c);x[23420]=0;c=g+20|0;R(f|0,c|0,d|0);d=x[23420];x[23420]=0;b:{c:{d:{if((d|0)==1){break d}x[23420]=0;c=g+32|0;R(101,c|0,e|0);d=x[23420];x[23420]=0;if((d|0)==1){break d}Cv(g,g+8|0);x[23420]=0;X(102,a|0,b|0,x[g>>2],x[g+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}ir(g+8|0);hb=g+48|0;break a}a=P()|0;while(1){c=yb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;ir(g+8|0)}S(a|0);p()}}function SE(a,b,c,d,e,f,g){var h=0,i=0;h=hb-16|0;hb=h;x[23420]=0;Y(902,a|0);i=x[23420];x[23420]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[23420]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=x[23420];x[23420]=0;if((b|0)==1){break c}b=Wf(Ic(h));xb(h);break b}}_(V(0)|0)|0;b=0;x[23420]=0;X(889,f|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}hb=h+16|0;return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function LC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;x[d+16>>2]=c;x[d+24>>2]=b;i=d,j=Ei(a),x[i+8>>2]=j;b=d+24|0;c=$j(b,d+8|0);b=$j(d+16|0,b);a:{if(Bd(x[a+4>>2],y[a+11|0])>>>0>=c>>>0){if((b|0)==-1){GA(a,rd(a),c);break a}e=hb-16|0;hb=e;x[e+12>>2]=b;if(b){g=Bd(x[a+4>>2],y[a+11|0]);h=rd(a);f=g-c|0;x[e+8>>2]=f;b=x[Hb(e+12|0,e+8|0)>>2];b:{if((f|0)==(b|0)){b=f;break b}c=c+h|0;rj(c,b+c|0,f-b|0)}GA(a,h,g-b|0)}hb=e+16|0;break a}om();p()}hb=d+32|0}function DN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=hb-16|0;hb=d;j=d,k=ak(b),x[j>>2]=k;c=hb-16|0;hb=c;g=Hy(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=hb-16|0;hb=e;b=ic(a);h=rh(c,wc(28),sh(e+8|0,b));b=x[h>>2];f=x[d>>2];i=x[f+4>>2];f=x[f>>2];x[b+24>>2]=0;x[b+16>>2]=f;x[b+20>>2]=i;j=ic(h),k=1,v[j+4|0]=k;hb=e+16|0;Yg(a,x[c+12>>2],g,x[c>>2]);b=Zd(c);cl(c);e=1}Xg(d+8|0,x[gc(c,b)>>2],e);hb=c+16|0;a=ud(x[d+8>>2]);hb=d+16|0;return a+8|0}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;jm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=$d(c+8|0);x[23420]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=wg(154,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23420];x[23420]=0;a:{if((d|0)!=1){d=Qb(a);a=x[c+52>>2];e=x[c+48>>2];x[23420]=0;U(656,b|0,d|0,Wc(e,a)>>>5|0);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;ui(d);zb(b);break a}zb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0}dc(c+48|0);S(a|0);p()}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;jm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=$d(c+8|0);x[23420]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=wg(154,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23420];x[23420]=0;a:{if((d|0)!=1){d=Qb(a);a=x[c+52>>2];e=x[c+48>>2];x[23420]=0;U(657,b|0,d|0,Wc(e,a)>>>2|0);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;tc(d);zb(b);break a}zb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0}dc(c+48|0);S(a|0);p()}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;jm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=$d(c+8|0);x[23420]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=wg(154,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23420];x[23420]=0;a:{if((d|0)!=1){d=Qb(a);a=x[c+52>>2];e=x[c+48>>2];x[23420]=0;U(658,b|0,d|0,Wc(e,a)>>>8|0);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;yt(d);zb(b);break a}zb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0}dc(c+48|0);S(a|0);p()}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb+-64|0;hb=c;jm(c+48|0,b);ke(c+16|0,x[c+48>>2],x[c+52>>2]);b=$d(c+8|0);x[23420]=0;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;b=wg(154,c+24|0,x[c+16>>2],x[c+20>>2],c);d=x[23420];x[23420]=0;a:{if((d|0)!=1){d=Qb(a);a=x[c+52>>2];e=x[c+48>>2];x[23420]=0;U(659,b|0,d|0,Wc(e,a)>>>4|0);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;dl(d);zb(b);break a}zb(b);dc(c+48|0);hb=c- -64|0;return}a=P()|0}dc(c+48|0);S(a|0);p()}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=x[b+12>>2]+i|0;e=v[f|0];e=((D(v[f+1|0]-e|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function eV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a:{b:{if(!Uf(a,7)){break b}c=0;if(!fC(a,17646)){break a}if(!Uf(a,1)){break b}c=-1;if(!cd(a,Cq(a))){break a}c=hb-16|0;hb=c;f=d+8|0;uo(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){Cu(f)}c=-1;if(!e){break a}c=0;if(!TB(y[d+8|0],y[d+9|0])){break a}c=Ge(a,b,SB(d+8|0),lb);break a}c=-1}hb=d+16|0;return c|0}function j_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;d=Eb(a);e=Sc(a);g=oi(b,c);a:{if(!g){break a}b:{if(!As(a,b)){if(e-d>>>0<g>>>0){Sl(a,e,(d+g|0)-e|0,d,d,0,0)}e=sc(a)+d|0;while(1){if((b|0)==(c|0)){break b}sd(e,b);b=b+1|0;e=e+1|0;continue}}b=Yf(f,b,c);c=Ic(b);d=Eb(b);x[23420]=0;W(1016,a|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){xb(b);break a}a=P()|0;xb(b);S(a|0);p()}v[f+15|0]=0;sd(e,f+15|0);Kh(a,d+g|0)}hb=f+16|0;return a|0}function C0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Sw(cb(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}hb=e+32|0;return g|0}function vea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;pd(b,0);bB(d,a+1|0);c=d+16|0;Fc(c,d);ze(b+43|0,c);xb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;xc(b+8|0,c);xc(b+4|0,x[b+8>>2]);hb=d+32|0}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;d=z[a+30>>1];if(d){b=Sx(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!eh(x[c+4>>2],y[c+11|0])){No(nL(a,e+14|0),c);break a}b=Tx(a,e+14|0);if(!zg(b,yf(a))){break a}c=hb-16|0;hb=c;b=x[gc(c,b)>>2];d=hb-16|0;hb=d;f=Wg(gc(d+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Fb(a);x[g>>2]=x[g>>2]-1;mL(x[ic(a)>>2],b);a=x[f>>2];hb=d+16|0;$t(ud(b));Ib(b);gc(c+8|0,a);hb=c+16|0}hb=e+16|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){f=(x[b+12>>2]<<1)+i|0;e=w[f>>1];e=e+((D(w[f+2>>1]-e|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Rb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function pC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Mc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){iC(a,b);break a}c=Fb(a);c=xj(e+8|0,yj(a,Mc(x[a>>2],d)+b|0),Mc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=Co(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){ev(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}Id(b);hb=f+16|0;zd(a,c);Fi(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<1)|0)}}function Pj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=vc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){sP(a,b);break a}c=Fb(a);c=bg(e+8|0,Tg(a,vc(x[a>>2],d)+b|0),vc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=ql(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){qP(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Id(b);hb=f+16|0;zd(a,c);ag(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function ws(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[23290]){b=ws(x[23290])}if(!x[23216]){break a}c=b|c;a=x[23216];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}mb[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;mb[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function pk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;Fh(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!g&(h|0)==(i|0)){hb=e+16|0}else{v[e+15|0]=0;Fh(a,e+15|0);c=x[b>>2];j=x[b+4>>2];f=y[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function Wf(a){var b=0,c=0,d=0;d=Np(qf(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=y[a|0];break b}if(a&3){while(1){b=y[a|0];v[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=x[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){x[c>>2]=b;b=x[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}v[c|0]=b;if(!(b&255)){break a}while(1){b=y[a+1|0];v[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function O0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;a:{if(!c){break a}g=ol(x[b+4>>2],y[b+11|0]);h=g-1|0;d=d<<24>>24;while(1){if((f|0)==(g|0)){break a}b:{if(!f|(f>>>0)%(c>>>0)){break b}if((f|0)==(h|0)){if(y[rd(b)|0]==(jf(43)&255)){break b}if(y[rd(b)|0]==(jf(45)&255)){break b}}i=e,j=Ei(b),x[i+8>>2]=j;i=e,j=Di(e+8|0,g-f|0),x[i+16>>2]=j;OH(b,x[Gf(e+24|0,e+16|0)>>2],1,jf(d))}f=f+1|0;continue}}Rc(a,b);hb=e+32|0}function oc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return oc(a,24)+(oc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=_r(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(9969,13048,1632,6791);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function UW(a,b){a=a|0;b=b|0;var c=0;a=Jb(a);a:{if(y[b+16|0]){x[23420]=0;Q(121,a|0,4906)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[23420]=0;Q(121,a|0,12398)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}}if(eh(x[a+4>>2],y[a+11|0])){x[23420]=0;Q(121,a|0,9959)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[23420]=0;Q(121,a|0,10991)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}}return}b=P()|0;yb(a);S(b|0);p()}function tt(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;e=d+16|0;KP(e,a,a+1|0,a+2|0,a+3|0);KP(d,b,b+1|0,b+2|0,b+3|0);hb=d+32|0;a=y[x[e>>2]];b=y[x[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=v[x[e+4>>2]];b=v[x[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=x[e+12>>2];g=x[d+12>>2];a=y[x[d+8>>2]];b=y[x[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=y[f|0]<y[g|0]}}}return c}function Qw(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[115922]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[115896]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function JL(a,b,c,d,e,f,g,h){var i=0,j=0;i=hb-16|0;hb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Hb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Wd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}hb=i+16|0}function Z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=hb-48|0;hb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=fc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=Ms(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ba(8)|0;x[23420]=0;b=Q(54,b+16|0,7975)|0;c=x[23420];x[23420]=0;b:{if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0)}S(c|0);p()}hb=b+48|0;return a|0}p()}function R8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=ck(x[b>>2],x[b+4>>2]);if(c){au(a,c);Yx(a,x[b>>2],x[b+4>>2],c)}x[a+20>>2]=x[b+20>>2];c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;x[23420]=0;c=Q(833,a+24|0,b+24|0)|0;d=x[23420];x[23420]=0;b:{c:{if((d|0)!=1){x[23420]=0;Q(53,a+36|0,b+36|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}x[a+48>>2]=x[b+48>>2];break a}b=P()|0;break b}b=P()|0;tc(c)}ek(a);S(b|0);p()}}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=hb-4096|0;hb=c;jm(a,b);a:while(1){if(Wc(x[a>>2],x[a+4>>2])>>>12>>>0>f>>>0){g=f<<12;b=0;d=0;while(1)if((b|0)==2048){h=g|2048;b=0;while(1){e=x[a>>2];if((b|0)!=2048){e=Kb(e,b+h|0);i=Kb(c,b<<1);d=y[e|0]+d|0;v[i|0]=d;b=b+1|0;continue}break}ah(c,UP(c),_g(Db(e),g));f=f+1|0;continue a}else{e=Kb(x[a>>2],b+g|0);h=Kb(c,b<<1|1);d=y[e|0]+d|0;v[h|0]=d;b=b+1|0;continue}}break}hb=c+4096|0}function Ki(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Wc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){hE(a,b);break a}c=Fb(a);c=Dl(e+8|0,Al(a,Wc(x[a>>2],d)+b|0),Wc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=Nv(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){ug(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}Id(b);hb=f+16|0;zd(a,c);Cl(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,b+d|0)}}function _K(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;d=Sc(a);a:{b:{c:{f=oi(b,c);if(d>>>0<f>>>0){if(As(a,b)){break c}g=d;h=f-d|0;d=Eb(a);Sl(a,g,h,d,0,d,0)}d=sc(a);while(1){if((b|0)==(c|0)){break b}sd(d,b);b=b+1|0;d=d+1|0;continue}}b=Yf(e,b,c);c=Ic(b);d=Eb(b);x[23420]=0;U(56,a|0,c|0,d|0);c=x[23420];x[23420]=0;if((c|0)!=1){xb(b);break a}a=P()|0;xb(b);S(a|0);p()}v[e+15|0]=0;sd(d,e+15|0);Kh(a,f)}hb=e+16|0;return a|0}function Efa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=hb-32|0;hb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;hS(h,b);i=g,j=Db(x[g+16>>2]),x[i+8>>2]=j;h=Kf(h);while(1){b=x[g+8>>2];if(Pb(b,h)){b=z[Vp(b)>>1];if(b>>>0<=z[a+480190>>1]){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Wg(g+8|0);continue}else{yA(g+16|0)}break}}hb=g+32|0}function c5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[23420]=0;Y(927,a|0);f=x[23420];x[23420]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[23420]=0;b=Sa(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11156,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function ZN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=hb-16|0;hb=e;j=e,k=ak(b),x[j>>2]=k;c=hb-16|0;hb=c;f=ez(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=hb-16|0;hb=b;d=ic(a);g=rh(c,wc(36),sh(b+8|0,d));d=x[g>>2]+16|0;h=x[e>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Qb(d+8|0);j=ic(g),k=1,v[j+4|0]=k;hb=b+16|0;Yg(a,x[c+12>>2],f,x[c>>2]);b=Zd(c);cO(c);d=1}Xg(e+8|0,x[gc(c,b)>>2],d);hb=c+16|0;a=ud(x[e+8>>2]);hb=e+16|0;return a+8|0}function AX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[23420]=0;m=a;a=b;b=0;a=Ka(997,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=x[23420];x[23420]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23420]=0;ia(885,8745,g|0,h|0,i|0,j|0,k|0,l|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}return a|0}function zS(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=vc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){HA(a,b);break a}c=Fb(a);c=bg(e+8|0,Tg(a,vc(x[a>>2],d)+b|0),vc(x[a>>2],x[a+4>>2]),c);f=hb-16|0;hb=f;b=ql(f,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){vm(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}Id(b);hb=f+16|0;zd(a,c);ag(c)}hb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function t1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-32|0;hb=e;a:{if(!c){break a}f=Eb(b);g=f-1|0;h=d<<24>>24;d=0;while(1){if((d|0)==(f|0)){break a}b:{if(!d|(d>>>0)%(c>>>0)){break b}if((d|0)==(g|0)){if(y[Nc(b,0)|0]==(jf(43)&255)){break b}if(y[Nc(b,0)|0]==(jf(45)&255)){break b}}i=e,j=Yd(b),x[i+8>>2]=j;i=e,j=Di(e+8|0,f-d|0),x[i+16>>2]=j;ex(b,x[Gf(e+24|0,e+16|0)>>2],1,jf(h))}d=d+1|0;continue}}Rc(a,b);hb=e+32|0}function kE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Qb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23420]=0;a=W(144,g|0,a|0,8)|0;g=x[23420];x[23420]=0;if((g|0)==1){break c}if(!a){break d}x[23420]=0;U(e|0,f|0,b|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;R(d|0,h|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;break b}a=P()|0;Md(f);break b}hb=f+32|0;break a}a=P()|0}_d(h);S(a|0);p()}}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=fg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;a:{b:{d=b-d|0;b=x[Fb(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){sz(a,d,c);break c}b=Fb(a);b=rt(e+8|0,Mp(a,fg(x[a>>2],f)+d|0),fg(x[a>>2],x[a+4>>2]),b);x[23420]=0;U(712,b|0,d|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}PO(a,b);qz(b)}hb=e+32|0;break a}a=P()|0;qz(b);S(a|0);p()}return}if(b>>>0<d>>>0){RO(a,e+(b<<5)|0)}}function KN(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function xda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=_c(c+8|0,16,1,1,0);x[c+4>>2]=0;pd(a,0);zc(b);a:{b:{if(Hq(b,13604)){$c(b,12);if(!to(b)){yo(d,2)}$c(b,24);break b}if(yh(b,13476)){zc(b);x[c+4>>2]=4;e=1;break a}Dh(d,8)}e=0}f=a,g=(df(b)>>>0)/(D(y[d|0],aq(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=kg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=uj(x[a>>2],z[a+34>>1]),x[f>>2]=g;Tb(d,0,x[Hb(c+4|0,c)>>2])}hb=c+16|0;return(b|0)!=0|0}function hG(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[115896];x[115896]=0;Ad();a=rw(a,e+12|0,d);d=lb;g=x[115896];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[115896]=h;if((b|0)!=x[e+12>>2]){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}hb=e+16|0;return a}function X1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-48|0;hb=e;x[e+40>>2]=c;x[e+44>>2]=d;a=fc(e+32|0,a,b);b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;a:{a=Ms(3,e+8|0,e+40|0);if(a+1>>>0>=3){b=ba(8)|0;x[23420]=0;c=Q(54,e+16|0,7975)|0;a=x[23420];x[23420]=0;b:{if((a|0)!=1){a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=P()|0;ca(b|0)}S(a|0);p()}hb=e+48|0;return a|0}p()}function Uo(a,b,c,d,e){var f=0,g=0,h=0;a:{f=hb-32|0;hb=f;h=Qb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[23420]=0;a=W(144,g|0,a|0,e|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break c}if(!a){break d}x[23420]=0;R(d|0,f|0,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){x[23420]=0;R(c|0,h|0,f|0);a=x[23420];x[23420]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;break b}a=P()|0;Md(f);break b}hb=f+32|0;break a}a=P()|0}_d(h);S(a|0);p()}}function ST(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=mk(a,7),v[f|0]=g;d=mk(a,1);e=mk(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;ST(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function gF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(1073741806-b>>>0>=c>>>0){j=sc(a);k=1073741807;if(b>>>0<=536870886){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=Hl(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=qi(k);if(e){di(c,j,e)}if(g){di(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;di((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Ib(j)}xd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Sd(b,a);xd(c+(a<<2)|0,0);hb=i+16|0;return}Bf();p()}function A0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[td(e+12|0,td(e+8|0,e+4|0))>>2];b=He(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=wn(d),v[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}hb=e+16|0;return f|0}function g5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23420]=0;Y(927,a|0);e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[23420]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11301,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Ob(c+24|0,b,7)){break b}$b(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d|0}function vs(a,b){var c=0,d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;c=Vd(a);d=ic(a);f=hb-16|0;hb=f;while(1){if(c){g=bt(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[gc(f+8|0,d)>>2];hb=f+16|0;a:{if(Pb(c,Kf(a))){if(!bt(b,ud(c))){break a}}c=Kf(a)}if(!uc(c,Kf(a))){b=x[gc(e+8|0,c)>>2];c=hb-16|0;hb=c;d=Wg(gc(c+8|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Fb(a);x[d>>2]=x[d>>2]-1;mL(x[ic(a)>>2],b);hb=c+16|0;bm(ud(b));Ib(b)}hb=e+16|0}function lQ(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Cb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=$o(x[a>>2],x[c>>2])?c:a;continue}}hb=b+16|0;a=x[a>>2];lb=a>>31;return a}function f5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[23420]=0;Y(927,a|0);e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[23420]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11337,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Ff(d,x[a+4>>2]);if(c>>>0<b>>>0){d=hb-32|0;hb=d;a:{b:{c=b-c|0;b=x[Fb(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){mC(a,c);break c}b=Fb(a);b=eB(d+8|0,fB(a,Ff(x[a>>2],e)+c|0),Ff(x[a>>2],x[a+4>>2]),b);x[23420]=0;R(455,b|0,c|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}dB(a,b);eu(b)}hb=d+32|0;break a}a=P()|0;eu(b);S(a|0);p()}return}if(b>>>0<c>>>0){kC(a,d+D(b,20)|0)}}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:nh(a,0,c);return;case 1:nh(a,1,c);return;case 2:nh(a,2,c);return;case 3:nh(a,3,c);return;case 4:nh(a,4,c);return;case 5:nh(a,5,c);return;case 6:rN(a,23552,c);return;case 7:rN(a,24576,c);return;case 8:nh(a,6,c);return;case 9:nh(a,7,c);return;case 10:nh(a,8,c);return;case 11:nh(a,9,c);return;case 12:nh(a,10,c);return;case 13:nh(a,11,c);return;default:break a}}Jb(a)}function ex(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;x[g+8>>2]=b;j=g,k=Yd(a),x[j>>2]=k;b=$j(g+8|0,g);h=hb-16|0;hb=h;a:{f=Eb(a);if(b>>>0<=f>>>0){if(c){e=Sc(a);b:{if(e-f>>>0>=c>>>0){e=sc(a);if((b|0)==(f|0)){break b}i=b+e|0;rj(i+c|0,i,f-b|0);break b}Sl(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}eq(b+e|0,c,d);b=c+f|0;Kh(a,b);v[h+15|0]=0;sd(b+e|0,h+15|0)}hb=h+16|0;break a}om();p()}Yd(a);hb=g+16|0}function y3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[23420]=0;b=Q(54,h|0,8118)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}d=P()|0;xb(b);break b}Lk(a,b,4);c=ox(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}d=P()|0;ca(a|0)}S(d|0)}p()}function jg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Zc(42956,d+14|0)>>1];e=x[a>>2];c=Mc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=hb-32|0;hb=e;b=b-c|0;c=x[Fb(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){vo(a,b,f);break b}c=Fb(a);c=xj(e+8|0,yj(a,Mc(x[a>>2],g)+b|0),Mc(x[a>>2],x[a+4>>2]),c);AC(c,b,f);zd(a,c);Fi(c)}hb=e+32|0;break a}if(b>>>0<c>>>0){Nd(a,e+(b<<1)|0)}}hb=d+16|0}function j3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=hb-16|0;hb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;x[23420]=0;b=Q(54,h|0,8118)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}d=P()|0;xb(b);break b}Lk(a,b,4);c=qx(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=h+16|0;return c|0}d=P()|0;ca(a|0)}S(d|0)}p()}function a5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23420]=0;Y(927,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[23420]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,6621,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function _4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[23420]=0;Y(927,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[23420]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,6675,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function PE(a,b,c,d){var e=0,f=E(0);x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(!(v[a+1075081|0]&1)){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}_(V(0)|0)|0;x[23420]=0;X(889,c|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return E(0)}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function lZ(a){a=a|0;if(y[467248]){return x[116811]}if(!y[467768]){a=467600;while(1){a=Jb(a)+12|0;if((a|0)!=467768){continue}break}v[467768]=1}md(467600,87732);md(467612,87760);md(467624,87788);md(467636,87820);md(467648,87860);md(467660,87896);md(467672,87924);md(467684,87960);md(467696,87976);md(467708,87992);md(467720,88008);md(467732,88024);md(467744,88040);md(467756,88056);v[467248]=1;x[116811]=467600;return 467600}function Es(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function QH(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function QE(a,b,c,d){var e=0,f=E(0);x[23420]=0;Y(902,a|0);e=x[23420];x[23420]=0;if((e|0)!=1){a=x[x[a+24>>2]+24>>2];a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=a+D(b,872)|0;if(v[a+1075081|0]&1){break a}f=E(E(y[a+d|0])*E(.0078125))}return f}_(V(0)|0)|0;x[23420]=0;X(889,c|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return E(0)}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function xx(a,b,c,d,e){var f=0,g=0;a:{if(!cs(b)){break a}f=x[a+484344>>2];if(!oe(f,x[a+484348>>2],b&65535)){break a}b=_b(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=ed(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function Ge(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;g=Hg(a);a:{b:{if(!b){i=e,j=Hg(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}f=x[b+4>>2];h=x[b>>2];x[e+8>>2]=h;x[e+12>>2]=f;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Nq(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}hb=e+16|0;return a}function m0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[td(e+12|0,td(e+8|0,e+4|0))>>2];di(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=mb[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}hb=e+16|0;return g|0}function f7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a>>2]=45136;c=Qb(a+4256|0);b=a+4208|0;e=Cb(b,0),f=1056964608,x[e>>2]=f;e=Cb(b,1),f=1017370378,x[e>>2]=f;e=Cb(b,2),f=1028670828,x[e>>2]=f;e=Cb(b,3),f=1059760811,x[e>>2]=f;e=Cb(b,4),f=1017370378,x[e>>2]=f;e=Cb(b,5),f=1065353216,x[e>>2]=f;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;tc(c);vf(a);S(b|0);p()}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=ck(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;d=b-d|0;b=x[Fb(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){RA(a,d,c);break a}b=Fb(a);b=NS(e+8|0,LA(a,ck(x[a>>2],f)+d|0),ck(x[a>>2],x[a+4>>2]),b);MS(b,d,c);c=b+4|0;KS(x[a>>2],x[a+4>>2],c);nc(a,c);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2];LS(b)}hb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,e+D(b,6)|0)}}function Y4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23420]=0;Y(927,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[23420]=0;ta(f|0,d|0,b|0,+c);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11536,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function OH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=hb-16|0;hb=g;x[g+8>>2]=b;j=g,k=Ei(a),x[j>>2]=k;b=$j(g+8|0,g);h=hb-16|0;hb=h;a:{f=Bd(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=nm(a);b:{if(e-f>>>0>=c>>>0){e=rd(a);if((b|0)==(f|0)){break b}i=b+e|0;rj(i+c|0,i,f-b|0);break b}_x(a,e,(c+f|0)-e|0,f,b,c);e=x[a>>2]}eq(b+e|0,c,d);b=c+f|0;Tt(a,b);v[h+15|0]=0;sd(b+e|0,h+15|0)}hb=h+16|0;break a}om();p()}Ei(a);hb=g+16|0}function N4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23420]=0;Y(927,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[23420]=0;ta(f|0,d|0,b|0,+c);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11474,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function L4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[23420]=0;Y(927,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[23420]=0;ta(f|0,d|0,b|0,+c);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,10925,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function cX(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;b=Vb(c,16590);x[23420]=0;U(108,c+16|0,a|0,b|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){yb(b);a=0;b=0;while(1){d=x[c+16>>2];if(!(b>>>0<=3&vd(d,x[c+20>>2])>>>0>b>>>0)){yl(c+16|0);hb=c+32|0;return a|0}x[23420]=0;d=T(109,Hd(d,b)|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;yl(c+16|0);break a}a=P()|0;yb(b)}S(a|0);p()}function HK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=hb-32|0;hb=d;x[d+16>>2]=c;x[d+24>>2]=b;i=d,j=Yd(a),x[i+8>>2]=j;c=d+24|0;b=$j(c,d+8|0);c=$j(d+16|0,c);a:{if(Eb(a)>>>0>=b>>>0){if((c|0)==-1){BK(a,b);break a}f=a;e=hb-16|0;hb=e;x[e+12>>2]=c;if(c){g=Eb(f);h=sc(f);c=g-b|0;x[e+8>>2]=c;a=x[Hb(e+12|0,e+8|0)>>2];b:{if((c|0)==(a|0)){a=c;break b}b=b+h|0;rj(b,a+b|0,c-a|0)}Fx(f,h,g-a|0)}hb=e+16|0;break a}om();p()}hb=d+32|0}function PH(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){ec(a,21);return-1}if(x[a+1396>>2]<=9){Hk(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Ll(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){ec(a,21)}return c}aa(7484,13048,1793,5711);p()}function Zw(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!Zr(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}ec(a,32);return 0}aa(15575,13048,1564,5997);p()}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;c=ff(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!gd(a,5)){break b}break a}d=x[c+8>>2]}g=x[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=hb-16|0;hb=d;x[d+8>>2]=0;mp(g,d+8|0);B[b>>2]=B[d+8>>2];hb=d+16|0;break c}e=hb-32|0;hb=e;x[e+28>>2]=0;x[e+24>>2]=d;x[e+20>>2]=4;wr(e+8|0,g,e+28|0,x[Hb(e+24|0,e+20|0)>>2]);x[b>>2]=0;hb=e+32|0}e=c}af(a,e);hb=f+16|0}function b2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;TI(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+16>>2];k=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Ih(k,j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}hb=c+16|0}function ZY(a){a=a|0;if(y[467240]){return x[116809]}if(!y[467592]){a=467424;while(1){a=Jb(a)+12|0;if((a|0)!=467592){continue}break}v[467592]=1}id(467424,5201);id(467436,5208);id(467448,5174);id(467460,5182);id(467472,5165);id(467484,5215);id(467496,5192);id(467508,9650);id(467520,9856);id(467532,11152);id(467544,12720);id(467556,5464);id(467568,10656);id(467580,6548);v[467240]=1;x[116809]=467424;return 467424}function R3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;if((c|0)!=1){a=x[x[a+24>>2]+24>>2];c=0;a:{if(!cs(b)){break a}d=x[a+484344>>2];if(!oe(d,x[a+484348>>2],b&65535)){break a}c=x[_b(d,b)+12>>2]}return c|0}_(V(0)|0)|0;x[23420]=0;X(889,6585,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function mV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+12>>2]=-1;if(ng(a,d+8|0)){x[d+4>>2]=y[d+8|0];f=x[Hb(d+4|0,d+12|0)>>2];c=hb+-64|0;hb=c;e=c+40|0;Ef(e,a,f);g=x[c+40>>2];a=c+8|0;Qf(a,3,xe(e),g);x[23420]=0;R(210,c+24|0,a|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){fc(c,b,11);a=c+24|0;pl(c,a);xb(a);Oc(c+40|0);hb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;Oc(c+40|0);S(a|0);p()}}hb=d+16|0;return e|0}function jO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-32|0;hb=d;x[a+4>>2]=0;a:{if(b){b:{if(pt(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=ao(d+16|0);x[23420]=0;f=Q(681,a|0,b|0)|0;g=x[23420];x[23420]=0;if((g|0)==1){break a}x[23420]=0;R(682,e|0,f|0);f=x[23420];x[23420]=0;if((f|0)==1){break a}x[e+4>>2]=b;wt(a,e);Je(e)}$k(d+8|0,x[a>>2]);av(x[d+8>>2],x[d+12>>2],b,y[c|0])}hb=d+32|0;return}a=P()|0;Je(e);S(a|0);p()}function CE(a,b,c,d,e,f){var g=0,h=0;g=hb-256|0;hb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;Cr(h|1,10479,f,x[b+4>>2]);f=Ad();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=Mg(d,24,f,h,g)+d|0;f=Ti(d,e,b);h=g+16|0;ad(h,b);x[23420]=0;ia(1103,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23420];x[23420]=0;a:{if((d|0)!=1){Zb(g+16|0);a=Ar(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);hb=g+256|0;break a}a=P()|0;Zb(g+16|0);S(a|0);p()}return a}function EE(a,b,c,d,e,f){var g=0,h=0;g=hb-112|0;hb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;Cr(h|1,10479,f,x[b+4>>2]);f=Ad();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=Mg(d,24,f,h,g)+d|0;f=Ti(d,e,b);h=g+16|0;ad(h,b);x[23420]=0;ia(1100,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[23420];x[23420]=0;a:{if((d|0)!=1){Zb(g+16|0);a=yq(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);hb=g+112|0;break a}a=P()|0;Zb(g+16|0);S(a|0);p()}return a}function Bea(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;v[b+15|0]=128;a=wm(a,127,b+15|0);x[23420]=0;v[b+14|0]=64;d=W(530,a+12|0,127,b+14|0)|0;c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){x[23420]=0;v[b+13|0]=0;Q(605,a+24|0,b+13|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;hb=b+16|0;return a|0}b=P()|0;break a}b=P()|0;dc(d)}dc(a);S(b|0);p()}function fu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=Kb(a,0);e=(y[f|0]&15)<<8|y[Kb(a,1)|0];c=0;a:{if(!e|(e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=z[(d<<1)+32672>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(z[(d<<1)+32670>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}v[b|0]=c;e=y[f|0]&16;d=Kb(a,2);v[b+1|0]=e|y[d|0]>>>4;v[b+3|0]=y[d|0]&15;g=b,h=y[Kb(a,3)|0],v[g+5|0]=h}function l5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=c;c=x[Tf(e+16|0,e+24|0)>>2];x[23420]=0;f=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=f;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;fa(896,a+8|0,e|0,c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=FI(a);b=EI(a+88|0);c=DI(a+92|0);x[a>>2]=61368;x[b>>2]=61480;x[c>>2]=61560;se(e+24|0);hb=e+32|0;return a|0}a=P()|0;se(e+24|0);S(a|0);p()}function e5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[23420]=0;R(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11166,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function P4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[23420]=0;R(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,12637,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function NN(a,b,c){a:{switch(b|0){case 0:oh(a,0,c);return;case 1:oh(a,1,c);return;case 2:oh(a,2,c);return;case 3:oh(a,3,c);return;case 4:oh(a,4,c);return;case 5:oh(a,5,c);return;case 6:BN(a,23552,c);return;case 7:BN(a,24576,c);return;case 8:oh(a,6,c);return;case 9:oh(a,7,c);return;case 10:oh(a,8,c);return;case 11:oh(a,9,c);return;case 12:oh(a,10,c);return;case 13:oh(a,11,c);return;default:break a}}Jb(a)}function K4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[23420]=0;R(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,12120,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[23420]=0;R(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11015,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Xo(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(-18-b>>>0>=c>>>0){j=sc(a);k=-17;if(b>>>0<=2147483622){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=wi(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=wc(k);if(e){He(c,j,e)}if(g){He(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){He((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Ib(j)}xd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Sd(b,a);v[i+7|0]=0;sd(a+c|0,i+7|0);hb=i+16|0;return}Bf();p()}function W4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[23420]=0;ra(e|0,c|0,+b);c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11574,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);d=x[23420];x[23420]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[23420]=0;R(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,9214,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function O4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[23420]=0;d=+sa(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11492,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Lt(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=hb-16|0;hb=i;if(-18-b>>>0>=c>>>0){j=rd(a);k=-17;if(b>>>0<=2147483622){x[i+8>>2]=b<<1;x[i+12>>2]=b+c;k=wi(x[Yc(i+12|0,i+8|0)>>2])+1|0}c=wc(k);if(e){He(c,j,e)}if(g){He(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){He((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Ib(j)}xd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Sd(b,a);v[i+7|0]=0;sd(a+c|0,i+7|0);hb=i+16|0;return}Bf();p()}function uy(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;oM(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(mb[x[x[b>>2]+136>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function Z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[23420]=0;d=+sa(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11555,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function T4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[23420]=0;ra(e|0,c|0,+b);c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7695,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);d=x[23420];x[23420]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function R4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[23420]=0;ra(e|0,c|0,+b);c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7643,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);d=x[23420];x[23420]=0;if((d|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function M4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[23420]=0;d=+sa(e|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,10945,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Mf(v[b|0]),h=x[x[a>>2]+52>>2],mb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[td(e+12|0,e+8|0)>>2];He(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}hb=e+16|0;return f|0}function kaa(a){a=a|0;var b=0;a=Jb(a);x[23420]=0;R(45,a|0,4);b=x[23420];x[23420]=0;a:{b:{if((b|0)==1){break b}x[23420]=0;R(46,a|0,32);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(46,a|0,10);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(46,a|0,13);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(46,a|0,9);b=x[23420];x[23420]=0;if((b|0)!=1){break a}}b=P()|0;xb(a);S(b|0);p()}}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{c=x[b+4>>2];if(!c){break a}f=a+480190|0;w[d>>1]=z[f>>1];w[d+14>>1]=c-1;c=z[Zc(d,d+14|0)>>1];while(1){if(!c){break a}Ab(d,x[b>>2],c);b:{if(Bb(x[x[d>>2]>>2],x[d+4>>2])){break b}if(cM(a,c&65535)){e=Vb(d,21473);Dc(((c<<5)+a|0)+946304|0,e);xb(e)}if(c>>>0<2){break b}e=z[f>>1];if((e|0)!=(c|0)){break b}w[f>>1]=e-1}c=c-1|0;continue}}hb=d+16|0}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-32|0;hb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Wc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Hb(e+28|0,e+24|0)>>2];f=_g(Db(f),c);c=_g(_g(Db(x[b+12>>2]),c),g);b=x[d>>2];ah(f,c,b);hc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;mb[f|0](a,b,c,e+8|0)}hb=e+32|0}function w3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[23420]=0;b=Q(54,f|0,8118)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}e=P()|0;xb(b);break b}Lk(a,b,2);c=ox(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;ca(a|0)}S(e|0)}p()}function h3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;x[23420]=0;b=Q(54,f|0,8118)|0;c=x[23420];x[23420]=0;if((c|0)==1){break c}a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}e=P()|0;xb(b);break b}Lk(a,b,2);c=qx(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c|0}e=P()|0;ca(a|0)}S(e|0)}p()}function b5(a,b){a=a|0;b=b|0;var c=0,d=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[23420]=0;b=Q(d|0,c|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,6648,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Oe(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Vo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(aF(a,b)&3){case 0:c=Vo(C[b>>3],C[b+8>>3]);break a;case 1:c=-Wo(C[b>>3],C[b+8>>3],1);break a;case 2:c=-Vo(C[b>>3],C[b+8>>3]);break a;default:break b}}c=Wo(C[b>>3],C[b+8>>3],1)}a=c;hb=b+16|0;return a}function LW(a){a=a|0;var b=0;a=Jb(a);x[23420]=0;R(72,a|0,4);b=x[23420];x[23420]=0;a:{b:{if((b|0)==1){break b}x[23420]=0;R(50,a|0,32);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(50,a|0,10);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(50,a|0,13);b=x[23420];x[23420]=0;if((b|0)==1){break b}x[23420]=0;R(50,a|0,9);b=x[23420];x[23420]=0;if((b|0)!=1){break a}}b=P()|0;yb(a);S(b|0);p()}}function $4(a,b){a=a|0;b=b|0;var c=0,d=0;x[23420]=0;Y(927,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[23420]=0;b=Q(d|0,c|0,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,6699,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function sW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+4>>2]=1;i=f,j=wc(32),x[i+8>>2]=j;e=hb-16|0;hb=e;g=Io(x[f+8>>2]);x[g>>2]=42968;g=yc(g);b=wl(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;b=Qm(g);x[b>>2]=43104;wl(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;de(e);hb=e+16|0;b=a;a=Ko(f);Jo(b,yc(a),a);Rm(f);hb=f+16|0}function DE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-160|0;hb=f;x[f+152>>2]=37;x[f+156>>2]=0;g=f+152|0;Cr(g|1,10646,e,x[b+4>>2]);e=Ad();x[f>>2]=d;d=f+139|0;e=Mg(d,13,e,g,f)+d|0;g=Ti(d,e,b);h=f+16|0;ad(h,b);x[23420]=0;ia(1103,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[23420];x[23420]=0;a:{if((d|0)!=1){Zb(f+16|0);a=Ar(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);hb=f+160|0;break a}a=P()|0;Zb(f+16|0);S(a|0);p()}return a}function rI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Dg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[23420]=0;c=Q(54,c|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;ca(b|0)}S(a|0)}p()}function ht(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Db(x[c>>2]);x[e+8>>2]=d;f=Db(x[c+4>>2]);while(1){if(!Pb(d,f)){break a}g=d,h=oO(b,C[d>>3]),C[g>>3]=h;d=x[ft(e+8|0)>>2];continue}}}else{oO(b,C[Pe(x[c>>2],0)>>3]);d=d+1|0;continue}break}Zj(a,c);hb=e+16|0}function fC(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,7);ld(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Ob(c+24|0,b,7)){break b}cd(a,7);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d}function NE(a,b,c,d,e,f,g,h,i){var j=0;x[23420]=0;Y(902,a|0);j=x[23420];x[23420]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[23420]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,h|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;b=-1;a:{if(!Uf(a,8)){break a}b=hb-32|0;hb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=fc(b+8|0,b+24|0,8);ld(b+16|0,a,x[d>>2],x[d+4>>2]);b:{if(x[b+20>>2]!=8){break b}if(Ob(b+24|0,13979,8)){break b}cd(a,8);e=1}hb=b+32|0;b=0;if(!e){break a}b=-1;if(!Aj(a,c+8|0)){break a}b=0;if(!ac(x[c+12>>2])){break a}b=!(ac(x[c+8>>2])&-2139062144)}hb=c+16|0;return b|0}function no(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+12>>2]=c;a:{if(!Nb(x[b>>2],x[b+8>>2],c)){break a}xc(f+12|0,65535);jg(a,z[f+12>>1]);c=Db(x[a>>2]);x[f>>2]=c;h=Db(x[a+4>>2]);while(1){if(!Pb(c,h)){break a}a=f+11|0;if(!ng(b,a)){ug(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Re(f)>>2];continue}}hb=f+16|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-32|0;hb=d;Ye(d,2,a+6|0);e=d+16|0;Fc(e,d);Dc(b+492|0,e);f=b+236|0;g=c+1|0;xb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;Zx(a+180|0,b+48|0,0);Zx(a+228|0,b+88|0,2);Zx(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Hz(f)}hb=d+32|0}else{h=bc(f,c),i=y[(a+c|0)+38|0]+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function _ca(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Dz(c,a);rP(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=bg(d+8|0,Tg(a,vc(x[a>>2],x[a+4>>2])+1|0),vc(x[a>>2],x[a+4>>2]),c);rP(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;zd(a,c);ag(c);hb=d+32|0}function FE(a,b,c,d,e){var f=0,g=0,h=0;f=hb-80|0;hb=f;x[f+72>>2]=37;x[f+76>>2]=0;g=f+72|0;Cr(g|1,10646,e,x[b+4>>2]);e=Ad();x[f>>2]=d;d=f+59|0;e=Mg(d,13,e,g,f)+d|0;g=Ti(d,e,b);h=f+16|0;ad(h,b);x[23420]=0;ia(1100,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=x[23420];x[23420]=0;a:{if((d|0)!=1){Zb(f+16|0);a=yq(a,f+32|0,x[f+28>>2],x[f+24>>2],b,c);hb=f+80|0;break a}a=P()|0;Zb(f+16|0);S(a|0);p()}return a}function $2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23420]=0;U(996,d|0,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,10213,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function E_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-208|0;hb=a;f=Ad();x[a>>2]=e;g=a+176|0;i=Mg(g,20,f,9164,a);e=i+g|0;g=Ti(g,e,c);f=a+8|0;ad(f,c);x[23420]=0;f=T(1086,f|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Zb(a+8|0);h=f;f=a+16|0;aG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Ar(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);hb=a+208|0;return b|0}b=P()|0;Zb(a+8|0);S(b|0);p()}function zX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[23420]=0;a=Ia(999,a|0,b|0,c|0,d|0)|0;b=x[23420];x[23420]=0;a:{b:{if((b|0)==1){_(V(0)|0)|0;x[23420]=0;ia(885,11038,e|0,f|0,g|0,h|0,i|0,j|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}return a|0}function tI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Dg(a)|0)>(b|0)){break d}}b=ba(8)|0;x[23420]=0;c=Q(54,c|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=P()|0;ca(b|0)}S(a|0)}p()}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Og(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;bJ(a,c);hb=c+16|0}function nS(a){var b=0;a:{if(Ob(a,14120,3)|(y[a+3|0]-52&255)>>>0<252){break a}if(ac(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if(ac(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if(ac(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=ac(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function md(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=wG(b);c=fn(a);if(e>>>0<=c>>>0){f=sc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;x[g+d>>2]=x[b+g>>2];if(c){continue}break}}}Kh(a,e);xd((e<<2)+f|0,0);break a}d=a;a=Eb(a);gF(d,c,e-c|0,a,0,a,e,b)}}function k2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=hb-16|0;hb=c;g=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;_I(a,c);a:{if(B[a+24>>2]==E(1)){break a}d=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Rp(j,b,i);B[f>>2]=B[a+24>>2]*B[f>>2];b=b+1|0;continue}}}hb=c+16|0}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Og(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;ZI(a,c);hb=c+16|0}function gda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;w[b+12>>1]=0;w[b+14>>1]=1;tg(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=hb-16|0;hb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Gm(a)>>>0>=c>>>0){g=x[a>>2];f=Mc(g,x[a+4>>2]);x[d+8>>2]=f;Pt(g,x[Hb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){vo(a,c-f|0,e);break a}Nd(a,x[a>>2]+(c<<1)|0);break a}ZO(a);Pp(a,yj(a,c));vo(a,c,e)}hb=d+16|0;hb=b+16|0}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Og(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;WI(a,c);hb=c+16|0}function bR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=fc(c+8|0,c+24|0,8);mc(c+16|0,x[a>>2],x[a+8>>2],x[d>>2],x[d+4>>2]);d=0;b:{if(x[c+20>>2]!=8){break b}if(Ob(c+24|0,b,8)){break b}$b(a,8);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d|0}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=hb-16|0;hb=c;a:{if(B[a+24>>2]==E(1)){break a}g=x[b+4>>2];h=x[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=x[b+4>>2];j=x[b>>2];k=+B[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Og(j,i,d,e);C[f>>3]=C[f>>3]*k;d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;SI(a,c);hb=c+16|0}function si(a){var b=0,c=0;b=hb-16|0;hb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Wo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(aF(a,b)&3){case 0:a=Wo(C[b>>3],C[b+8>>3],1);break a;case 1:a=Vo(C[b>>3],C[b+8>>3]);break a;case 2:a=-Wo(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-Vo(C[b>>3],C[b+8>>3])}hb=b+16|0;return a}function d3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[23420]=0;e=+qa(992,d|0,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,5311,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function X4(a){a=a|0;var b=0,c=0,d=0;x[23420]=0;Y(927,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[23420]=0;c=+na(d|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,11592,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function fV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Nb(x[b>>2],x[b+8>>2],c)){c=df(b)}x[a>>2]=c;c=x[b>>2];a:{if(mb[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Ki(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(uc(c,a)){break a}ke(d+8|0,c,a);mc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}hb=d+16|0}function V4(a){a=a|0;var b=0,c=0,d=0;x[23420]=0;Y(927,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[23420]=0;c=+na(d|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7712,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function S4(a){a=a|0;var b=0,c=0,d=0;x[23420]=0;Y(927,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[23420]=0;c=+na(d|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7660,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function kr(a){var b=0,c=0;Mm(a,1,15263);x[23420]=0;b=ga(114)|0;c=x[23420];x[23420]=0;a:{if((c|0)==1){break a}x[a+12>>2]=b;x[23420]=0;b=ga(115)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}v[a+16|0]=b;x[23420]=0;b=ga(116)|0;c=x[23420];x[23420]=0;if((c|0)==1){break a}v[a+18|0]=0;v[a+17|0]=b;x[23420]=0;Y(117,a+20|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}return}b=P()|0;yb(a);S(b|0);p()}function ix(a,b,c){var d=0,e=0;d=hb-32|0;hb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=NI(b,4096);MI(a,b-c|0);c=x[a+16>>2];b=fc(d+16|0,Kb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;mb[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(mb[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}hb=d+32|0}function fG(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[115896];x[115896]=0;Ad();d=hb-16|0;hb=d;vw(d,a,e+12|0,0);f=MD(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[115896];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[115896]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return f}function EU(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){mb[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;Gc(a);b=hb-32|0;hb=b;a:{b:{d=_o(a);c=Wc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[23420]=0;c=fa(862,b+8|0,c|0,c|0,Fb(a)|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){zd(a,c);Cl(c);break c}_(V(0)|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break b}}hb=b+32|0;break a}V(0)|0;Ub();p()}}function vM(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){d=hb-16|0;hb=d;b=Db(x[c>>2]);x[d+8>>2]=b;f=Db(x[c+4>>2]);while(1){a:{b:{if(Pb(b,f)){while(1){a=x[b>>2];e=x[a>>2];if(!e){break b}a=x[x[e>>2]+8>>2];x[23420]=0;Y(a|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){continue}break}V(0)|0;Ub();p()}a=tc(c);hb=d+16|0;break a}Sb(a+20|0);Sb(a+8|0);Ib(a);b=x[Ce(d+8|0)>>2];continue}break}Ib(a)}}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;x[23420]=0;c=Q(54,e|0,8118)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Lk(a,b,1);c=qx(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;ca(a|0)}S(b|0)}p()}function CB(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if($B(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return mb[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=mb[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}pc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a:{b:{c:{if(!d){a=ba(8)|0;x[23420]=0;c=Q(54,e|0,8118)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Lk(a,b,1);c=ox(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=e+16|0;return c|0}b=P()|0;ca(a|0)}S(b|0)}p()}function TA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Nb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){d=hb-16|0;hb=d;if(Nb(x[a>>2],x[a+8>>2],b)){while(1){if((c|0)==4){c=x[d+12>>2]}else{v[d+11|0]=0;b:{if(b>>>0>c>>>0){ng(a,d+11|0);e=v[d+11|0];g=e>>>31|0;break b}e=0-g|0}v[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}hb=d+16|0;break a}c=pg(a);$b(a,b-4|0)}v[f|0]=c}function S6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);x[a>>2]=45744;b=Qb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[23420]=0;R(853,a+44|0,2);c=x[23420];x[23420]=0;if((c|0)!=1){ki(a);return a|0}c=P()|0;tc(b);vf(a);S(c|0);p()}function $7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=WS(Ic(b),Eb(b),Ic(c),Eb(c));if((e|0)!=-1){f=d,g=Yd(b),x[f+16>>2]=g;f=d,g=Di(d+16|0,e),x[f+24>>2]=g;f=d,g=Di(d+24|0,1),x[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=mh(b),x[f>>2]=g;e=Gf(d+8|0,d);HK(b,x[c>>2],x[e>>2]);break b}if(!Eb(b)){break b}if(CS(Ic(b),Eb(b),Ic(c),Eb(c))){break b}Jb(a);break a}Rc(a,b)}hb=d+48|0}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,15);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function ME(a,b,c,d,e,f,g){var h=0;x[23420]=0;Y(902,a|0);h=x[23420];x[23420]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[23420]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,f|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function IR(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function $z(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,14);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function hI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;d=Q(54,d|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,d);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=Mz(c*32768),w[e>>1]=f;hb=d+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function fia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(hh(1073741823)>>>0<=8191){Tc();p()}b=wc(32768);x[a>>2]=b;x[a+4>>2]=b;e=Fb(a),f=b+32768|0,x[e>>2]=f;b=hb-16|0;hb=b;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];d=x[b+8>>2];while(1){if((c|0)==(d|0)){kc(b);hb=b+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}return a|0}function W2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=hb-32|0;hb=b;c=fc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=Ms(a,b,0);if(a+1>>>0>=3){a=ba(8)|0;x[23420]=0;b=Q(54,b+8|0,7975)|0;c=x[23420];x[23420]=0;b:{if((c|0)!=1){a=rc(a,b);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}c=P()|0;xb(b);break b}c=P()|0;ca(a|0)}S(c|0);p()}hb=b+32|0;return a|0}p()}function O_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=hb-96|0;hb=a;f=Ad();x[a>>2]=e;g=a- -64|0;i=Mg(g,20,f,9164,a);e=i+g|0;g=Ti(g,e,c);f=a+8|0;ad(f,c);x[23420]=0;f=T(18,f|0)|0;h=x[23420];x[23420]=0;if((h|0)!=1){Zb(a+8|0);h=f;f=a+16|0;eG(h,a- -64|0,e,f);h=b;b=f+i|0;b=yq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);hb=a+96|0;return b|0}b=P()|0;Zb(a+8|0);S(b|0);p()}function dG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[115896];x[115896]=0;Ad();d=hb-16|0;hb=d;vw(d,a,e+12|0,1);f=Ev(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);hb=d+16|0;a=x[115896];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[115896]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}hb=e+16|0;return f}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=w[(x[b+12>>2]<<1)+i>>1];x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Rb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function nE(a,b,c,d,e){var f=0,g=0;a:{f=hb-80|0;hb=f;oA(b);g=f+56|0;Ef(g,a,c);a=x[f+56>>2];c=f+8|0;Qf(c,e,xe(g),a);x[23420]=0;R(210,f+24|0,c|0);a=x[23420];x[23420]=0;b:{c:{if((a|0)!=1){x[23420]=0;U(11,f+40|0,d|0,f+24|0);a=x[23420];x[23420]=0;if((a|0)==1){break c}a=f+40|0;Gb(b,a);yb(a);xb(f+24|0);Oc(f+56|0);hb=f+80|0;break a}a=P()|0;break b}a=P()|0;xb(f+24|0)}Oc(f+56|0);S(a|0);p()}}function g3(a,b){a=a|0;b=b|0;var c=0,d=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23420]=0;R(991,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,10759,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function tea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Wz(a,b);x[23420]=0;c=Q(610,a+12|0,b+12|0)|0;d=x[23420];x[23420]=0;b:{c:{if((d|0)!=1){x[23420]=0;Q(611,a+24|0,b+24|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=P()|0;break b}b=P()|0;dc(c)}dc(a);S(b|0);p()}}function m8(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[23420]=0;R(272,b+4|0,8);b=x[23420];x[23420]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=V(91780)|0;if((ib|0)==(da(91780)|0)){_(b|0)|0;Gc(x[a+20>>2]+4|0);$();return}S(b|0);p()}function Ri(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(Yi(a,f+8|0)){break b}h=Ek(x[a>>2]);g=4;if(!jh(x[d+8>>2],64,h)){break b}b=jn(d,h);while(1){c:{b=b-48|0;h=Jl(a);if(!dp(h,f+8|0)|(e|0)<2){break c}g=Ek(x[h>>2]);if(!jh(x[d+8>>2],64,g)){break a}e=e-1|0;b=jn(d,g)+D(b,10)|0;continue}break}g=2;if(!Yi(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=hb-16|0;hb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];j=x[a+12>>2];while(1){if(d){f=v[x[b+12>>2]+i|0]<<8;x[c>>2]=x[c>>2]+D(f,h);x[c+4>>2]=x[c+4>>2]+D(g,f);Rb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;hb=b+16|0}function yh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=fc(c+8|0,c+28|0,4);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Ob(c+28|0,b,4)){break b}$b(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d|0}function x0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Aq(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=sc(c)+Eb(c)|0;x[a+44>>2]=b;d=sc(c);on(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Eb(c);e=a,f=b+sc(c)|0,x[e+44>>2]=f;Ax(c,Sc(c));d=sc(c);Fw(a,d,Eb(c)+d|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){Or(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Or(a,b)}}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{e=Ee(a);b:{if(e>>>0>1){break b}c:{if(e){x[23420]=0;U(315,d|0,a|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){rm(b,d);dc(d);break c}a=V(30320)|0;if((ib|0)!=(da(30320)|0)){break a}_(a|0)|0;$();break b}if(!Nb(x[a>>2],x[a+8>>2],c)){break b}Ju(a,b,c)}f=Wc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}hb=d+16|0;return f|0}S(a|0);p()}function laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;a:{b:{e=RD(Ic(b),Eb(b),Ic(c),Eb(c));if((e|0)!=-1){f=d,g=Yd(b),x[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=Yd(b),x[f+8>>2]=g;f=d,g=Di(d+8|0,e),x[f+16>>2]=g;e=Gf(d+24|0,d+16|0);HK(b,x[c>>2],x[e>>2]);break b}e=Eb(b);if(!e){break b}if((QD(Ic(b),Eb(b),Ic(c),Eb(c))|0)!=(e-1|0)){break b}Jb(a);break a}Rc(a,b)}hb=d+48|0}function i5(a){a=a|0;var b=0;x[23420]=0;Y(927,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){mb[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Ib(b);x[a+20>>2]=0}Ib(a);return}_(V(0)|0)|0;x[23420]=0;X(889,5012,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function $m(a,b,c,d,e,f){var g=0;x[23420]=0;Y(902,a|0);g=x[23420];x[23420]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[23420]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,e|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function uea(a){a=a|0;var b=0,c=0,d=0,e=0;e=hb-16|0;hb=e;b=wc(2500);c=hb-2496|0;hb=c;JP(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}hb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[mf(e+8|0,b)>>2];hb=e+16|0;return a|0}function j0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[td(f+12|0,f+8|0)>>2];di(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}hb=f+16|0;return g|0}function ER(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=fc(c+8|0,c+24|0,5);mc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(Ob(c+24|0,b,5)){break b}$b(a,5);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d}function b3(a,b){a=a|0;b=+b;var c=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[23420]=0;b=+Va(993,c|0,+b);c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7524,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;if((c|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Y7(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function Y3(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-32|0;hb=c;a:{e=a+36|0;b=x[e>>2];d=x[a+40>>2];b:{if(Pb(b,d)){Bc(c+24|0);break b}b=c+8|0;Dn(b,a);x[23420]=0;b=T(961,b|0)|0;d=x[23420];x[23420]=0;if((d|0)==1){break a}x[c+24>>2]=b;Vf(c+8|0);d=x[a+40>>2];b=x[a+36>>2]}if(!Pb(b,d)){e=x[c+24>>2];b=x[e>>2]}a=Cn(b,x[e+4>>2]);Ik(c+24|0);hb=c+32|0;return a|0}a=P()|0;Vf(c+8|0);S(a|0);p()}function yI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[23420]=0;c=Q(54,c|0,7793)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}a=x[a+32>>2];e=a,f=Ie(b*65536),x[e+480240>>2]=f;up(a);hb=c+16|0;return}d=P()|0;ca(a|0)}S(d|0)}p()}function SG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Vb(d,c);x[23420]=0;U(1058,d+16|0,b|0,e|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){x[23420]=0;a=Q(1059,a|0,d+16|0)|0;c=x[23420];x[23420]=0;if((c|0)==1){break b}xb(d+16|0);xb(e);x[a>>2]=91052;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;hb=d+32|0;return a|0}c=P()|0;break a}c=P()|0;xb(d+16|0)}xb(e);S(c|0);p()}function LE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;x[23420]=0;c=Q(54,f|0,8118)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Lk(a,b,e);c=HE(a,c,e,d,59312,60084);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;ca(a|0)}S(b|0)}p()}function KE(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;a:{b:{c:{if(!d){a=ba(8)|0;x[23420]=0;c=Q(54,f|0,8118)|0;b=x[23420];x[23420]=0;if((b|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}b=P()|0;xb(c);break b}Lk(a,b,e);c=HE(a,c,e,d,58484,59256);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);hb=f+16|0;return c}b=P()|0;ca(a|0)}S(b|0)}p()}function AI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;x[23420]=0;c=Q(54,c|0,7772)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}a=x[a+32>>2];e=a,f=Ie(65536/b),x[e+480244>>2]=f;up(a);hb=c+16|0;return}d=P()|0;ca(a|0)}S(d|0)}p()}function sK(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function nI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;c=Q(54,c|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;hb=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function Z3(a){a=a|0;var b=0,c=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23420]=0;b=T(969,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7196,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function sx(a,b,c){var d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(c){kl(a,c);d=hb-16|0;hb=d;e=Nh(d,a,c);c=x[e+4>>2];f=x[e+8>>2];while(1){if((c|0)==(f|0)){kc(e);hb=d+16|0}else{x[c>>2]=0;Bc(c);c=c+4|0;x[e+4>>2]=c;continue}break}}c=0;e=0;d=hb-16|0;hb=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=rM(b);continue}break}x[f>>2]=e;Mn(f);hb=d+16|0;x[a+12>>2]=x[f>>2];return a}function Gx(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(mb[x[x[a>>2]+204>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(mb[x[x[a>>2]+196>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Mh(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(mb[x[x[a>>2]+208>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(mb[x[x[a>>2]+192>>2]](a)|0)){b=EK(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function l4(a){a=a|0;var b=0,c=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[23420]=0;c=+na(960,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){break b}}_(V(0)|0)|0;x[23420]=0;X(889,7596,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function iI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;c=Q(54,c|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;ca(b|0)}S(a|0)}p()}function lP(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a=Jb(a);d=Eb(b);x[23420]=0;R(45,a|0,d|0);d=x[23420];x[23420]=0;a:{if((d|0)!=1){e=c,f=Ns(b),x[e+8>>2]=f;e=c,f=Ls(b),x[e>>2]=f;while(1){if(!Lh(c+8|0,c)){break a}b=y[x[c+8>>2]];x[23420]=0;R(46,a|0,((b|0)==13?10:b)<<24>>24);b=x[23420];x[23420]=0;if((b|0)!=1){Be(c+8|0);continue}break}}b=P()|0;xb(a);S(b|0);p()}hb=c+16|0}function gI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;c=Q(54,c|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}hb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;ca(b|0)}S(a|0)}p()}function Ml(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+71520|0]}if(a>>>0<=511){return v[(a>>>5|0)+71520|0]+5|0}return v[(a>>>10|0)+71520|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+71520|0]+15|0}return v[(a>>>20|0)+71520|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+71520|0]+25|0}a=v[(a>>>30|0)+71520|0]+30|0}else{a=0}return a}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a:{b:{if((Nj(y[a+140|0])|0)!=1){break b}if((rJ(a)|0)!=(b|0)){break b}d=a+120|0;ms(y[d+20|0]);b=hb-16|0;hb=b;x[b+8>>2]=c+8;a=hb-16|0;hb=a;e=x[14175];x[a+8>>2]=x[14174];x[a+12>>2]=e;e=x[14173];x[a>>2]=x[14172];x[a+4>>2]=e;mb[x[hp(a,Nj(y[d+20|0]))>>2]](b+8|0,d);hb=a+16|0;hb=b+16|0;break a}qJ(a,1,b)}hb=c+16|0}function Qi(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=b;b=0;g=6;a:{b:{if(Lj(a,f+8|0)){break b}g=4;h=Dk(x[a>>2]);if(!Ck(d,64,h)){break b}b=hn(d,h);while(1){c:{b=b-48|0;h=pn(a);if(!Pr(h,f+8|0)|(e|0)<2){break c}g=Dk(x[h>>2]);if(!Ck(d,64,g)){break a}e=e-1|0;b=hn(d,g)+D(b,10)|0;continue}break}g=2;if(!Lj(h,f+8|0)){break a}}x[c>>2]=x[c>>2]|g}hb=f+16|0;return b}function IC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Ob(a,11012,2)){if(Ob(a,13621,2)){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=v[c+113|0];if((e|0)<-2){break a}f=y[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(y[c+369|0]<64){continue}break}}return d}function Br(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function qV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=-1;a:{if(!Uf(a,7)){break a}c=0;if(!fC(a,11632)){break a}c=hb-16|0;hb=c;cC(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){bC(d)}c=-1;if(!e){break a}c=0;if(!eC(y[d+1|0])){break a}c=Ge(a,b,dC(d),lb)}hb=d+16|0;return c|0}function Z6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a>>2]=45372;b=a+4208|0;e=Cb(b,0),f=1060320051,x[e>>2]=f;e=Cb(b,1),f=1041865114,x[e>>2]=f;e=Cb(b,2),f=1065353216,x[e>>2]=f;e=Cb(b,3),f=1049951732,x[e>>2]=f;e=Cb(b,4),f=1049951732,x[e>>2]=f;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;vf(a);S(b|0);p()}function wI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{b:{c:{if(b<0|b>1){a=ba(8)|0;x[23420]=0;c=Q(54,c|0,11610)|0;d=x[23420];x[23420]=0;if((d|0)==1){break c}a=rc(a,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}d=P()|0;xb(c);break b}e=x[a+32>>2]+1074456|0,f=Ie(b*256),x[e>>2]=f;hb=c+16|0;return}d=P()|0;ca(a|0)}S(d|0)}p()}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;c=ff(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!gd(a,5)){break b}break a}d=x[c+8>>2]}e=x[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:d=hb-32|0;hb=d;v[d+24|0]=0;Ui(d+8|0,d+24|0);kn(d+16|0,e,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+24|0];hb=d+32|0;break c;default:break d}}QS(e,b,d)}e=c}af(a,e);hb=f+16|0}function u8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=wc(64);x[23420]=0;e=T(790,c|0)|0;f=x[23420];x[23420]=0;a:{if((f|0)!=1){c=mf(d,e);e=x[c>>2];x[23420]=0;a=W(851,e|0,a|0,b|0)|0;b=x[23420];x[23420]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Bc(d+8|0);break b}a=P()|0;hg(c);break a}Tf(d+8|0,c)}hg(c);hb=d+16|0;return x[d+8>>2]}a=P()|0;Ib(c)}S(a|0);p()}function YL(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=pe(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=pe(a+902204|0,c&127)}mN(a,e,b,f,d,c&255)}}function B1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(c){if(hh(357913941)>>>0<c>>>0){Tc();p()}d=YD(c);x[a>>2]=d;x[a+4>>2]=d;f=Fb(a),g=d+D(c,12)|0,x[f>>2]=g;e=Hd(b,c);d=hb-16|0;hb=d;c=zt(d,a,c);x[23420]=0;U(1034,b|0,e|0,c+4|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){kc(c);hb=d+16|0;break a}a=P()|0;kc(c);S(a|0);p()}}return a|0}function Sn(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function gU(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=hb-16|0;hb=a;c=ba(16)|0;b=hb-16|0;hb=b;if(!y[463712]){v[463712]=1}fc(b+8|0,1,92868);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;hb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[23420]=0;a=XE(1060,c,8845,a,b);b=x[23420];x[23420]=0;if((b|0)!=1){ha(a|0,77204,1061);p()}a=P()|0;ca(c|0);S(a|0);p()}}function kG(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if((a|0)!=(b|0)){g=x[115896];x[115896]=0;Ad();d=lG(a,e+12|0,d);a=lb;f=x[115896];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}x[115896]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;d=0;a=0}hb=e+16|0;lb=a;return d}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Qb(a);a=Db(x[b>>2]);x[d+24>>2]=a;b=Db(x[b+4>>2]);a:{while(1){if(Pb(a,b)){yi(d,x[a>>2],x[a+4>>2]);if((ac(x[d>>2])|0)==(c|0)){so(d,a);x[23420]=0;R(338,e|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}zb(d)}a=x[um(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;zb(d);kd(e);S(a|0);p()}function r5(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Ib(us(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Ib(b);x[a+20>>2]=0}Ib(a);return}_(V(0)|0)|0;x[23420]=0;X(889,5039,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function GE(a,b,c){var d=0;d=hb-16|0;hb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;x[23420]=0;c=Q(54,d|0,10598)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;hb=d+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function BI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;x[23420]=0;c=Q(54,c|0,9265)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);hb=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function Fy(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;Xl(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!wd(a)){break a}ij(a,b,0)}}function zQ(a,b){var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=fc(c+8|0,c+28|0,4);ld(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=4){break b}if(Ob(c+28|0,b,4)){break b}cd(a,4);d=1}hb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}aa(17284,8981,413,13012);p()}aa(17263,8981,411,13012);p()}return d}function w$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){pc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){pc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function n5(a,b){a=a|0;b=b|0;var c=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Ib(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[23420]=0;X(889,5621,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function hL(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=hb-16|0;hb=c;d=0;a:{if(!Jg(x[x[a>>2]-12>>2]+a|0)){break a}x[c+12>>2]=0;bk(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}Pj(b,e);while(1){if((f|0)==(e|0)){d=Jg(x[x[a>>2]-12>>2]+a|0)}else{x[c+8>>2]=0;mp(a,c+8|0);g=Cb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;hb=c+16|0;return a}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=hb-16|0;hb=c;d=wc(223888);x[23420]=0;b=Q(757,d|0,b+1074376|0)|0;e=x[23420];x[23420]=0;a:{if((e|0)!=1){b=x[mf(c+8|0,b)>>2];hb=c+16|0;break a}a=P()|0;Ib(d);S(a|0);p()}x[a+4>>2]=b;b=Qb(a+8|0);x[23420]=0;Y(538,a|0);c=x[23420];x[23420]=0;if((c|0)!=1){return a|0}c=P()|0;je(b);bN(a+4|0);S(c|0);p()}function L6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=NK(a,b,c,d,e^1);x[b>>2]=45972;a=b+4208|0;f=Cb(a,0),g=1056964608,x[f>>2]=g;f=Cb(a,1),g=1065353216,x[f>>2]=g;f=Cb(a,2),g=1020054733,x[f>>2]=g;f=Cb(a,3),g=1065353216,x[f>>2]=g;f=Cb(a,4),g=1056964608,x[f>>2]=g;f=Cb(a,5),g=1048406533,x[f>>2]=g;f=Cb(a,6),g=1056964608,x[f>>2]=g;return b|0}function CI(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;x[23420]=0;c=Q(54,c|0,5809)|0;a=x[23420];x[23420]=0;if((a|0)==1){break c}a=rc(b,c);x[23420]=0;U(107,a|0,61592,906);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(c);break b}x[x[a+32>>2]+1074416>>2]=b;hb=c+16|0;return}a=P()|0;ca(b|0)}S(a|0)}p()}function kT(a){var b=0,c=0,d=0;a:{if(Ob(a+60|0,15354,4)|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;SM(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;kc(c);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=rt(d+8|0,Mp(a,fg(x[a>>2],x[a+4>>2])+1|0),fg(x[a>>2],x[a+4>>2]),c);SM(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;zd(a,c);GP(c);hb=d+32|0}function _z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=Qb(a);a=Db(x[b>>2]);x[d+24>>2]=a;b=Db(x[b+4>>2]);a:{while(1){if(Pb(a,b)){yi(d,x[a>>2],x[a+4>>2]);if(x[d>>2]==(c|0)){so(d,a);x[23420]=0;R(338,e|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}zb(d)}a=x[um(d+24|0)>>2];continue}break}hb=d+32|0;return}a=P()|0;zb(d);kd(e);S(a|0);p()}function Ss(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=hb-16|0;hb=e;a:{if(!b){break a}Ab(e+8|0,a+1074312|0,73);j=Bb(x[x[e+8>>2]>>2],x[e+12>>2])?c- -64|0:c;c=120;h=gj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=Qg(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}hb=e+16|0;return f}function Rn(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function oV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;Mu(e+8|0,c);c=y[d|0];x[23420]=0;R(231,e+20|0,c|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[23420]=0;X(102,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(e+8|0);hb=e+32|0;break a}a=P()|0;yb(e+8|0);break b}a=P()|0;Ah(e+8|0)}S(a|0);p()}}
function fw(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function Fu(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if(y[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function ap(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;ad(d,b);x[23420]=0;b=T(1087,d|0)|0;d=x[23420];x[23420]=0;a:{if((d|0)==1){break a}x[23420]=0;d=T(1096,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break a}x[c>>2]=d;x[23420]=0;R(1097,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}Zb(e+8|0);hb=e+16|0;return}a=P()|0;Zb(e+8|0);S(a|0);p()}function LI(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}a=x[a+12>>2];if(!a){break b}e=mb[a|0](b)|0;d=lb;if((d|0)<0){break b}if((mb[c|0](b,0,0,0)|0)<0){break a}if((mb[c|0](b,0,0,2)|0)<0){break a}f=mb[a|0](b)|0;a=lb;mb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Zy(f,a)}return g}mb[c|0](b,e,d,0)|0;return 0}function cp(a,b,c){var d=0,e=0,f=0;e=hb-16|0;hb=e;d=e+8|0;ad(d,b);x[23420]=0;b=T(1069,d|0)|0;d=x[23420];x[23420]=0;a:{if((d|0)==1){break a}x[23420]=0;d=T(1082,b|0)|0;f=x[23420];x[23420]=0;if((f|0)==1){break a}v[c|0]=d;x[23420]=0;R(1083,a|0,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}Zb(e+8|0);hb=e+16|0;return}a=P()|0;Zb(e+8|0);S(a|0);p()}function qk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;ms(y[h+20|0]);g=hb-16|0;hb=g;x[g+8>>2]=f+8;e=hb-16|0;hb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;mb[x[hp(e,Nj(y[h+20|0]))>>2]](g+8|0,h);hb=e+16|0;hb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];hb=f+16|0}function q5(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Ib(b);x[a+20>>2]=0;return}_(V(0)|0)|0;x[23420]=0;X(889,8818,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$()}return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-112|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;yT(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){xT(f)}c=-1;a:{if(!e){break a}c=0;if(!AT(d+8|0)){break a}c=Ge(a,b,zT(y[d+55|0]|y[d+56|0]<<8),lb)}hb=d+112|0;return c|0}function H9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;w[a>>1]=0;c=Qb(a+4|0);d=Qb(a+16|0);x[a+36>>2]=0;e=Jb(a+40|0);f=gg(a+52|0);Gc(c);w[a+28>>1]=65472;x[23420]=0;x[b+12>>2]=1065353216;R(794,c|0,b+12|0);g=x[23420];x[23420]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Gc(d);hb=b+16|0;return a|0}a=P()|0;TS(f);yb(e);tc(d);tc(c);S(a|0);p()}function o5(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return Wf(a)|0}_(V(0)|0)|0;x[23420]=0;X(889,12033,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();return 0}return Wf(21473)|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function GV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-512|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;GC(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){EC(f)}c=-1;a:{if(!e){break a}c=0;if(!IC(d+8|0)){break a}c=Ge(a,b,HC(y[d+118|0],y[d+119|0]),lb)}hb=d+512|0;return c|0}function QX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=hb+-64|0;hb=e;d=1;a:{if(Kg(a,b,0)){break a}d=0;if(!b){break a}b=Jy(b,91388,91436);d=0;if(!b){break a}d=e+8|0;Tb(d|4,0,52);x[e+56>>2]=1;x[e+20>>2]=-1;x[e+16>>2]=a;x[e+8>>2]=b;mb[x[x[b>>2]+28>>2]](b,d,x[c>>2],1);a=x[e+32>>2];if((a|0)==1){x[c>>2]=x[e+24>>2]}d=(a|0)==1}hb=e- -64|0;return d|0}function FN(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];lt(a,i>>>0>1&e&(b|0)==1,f+15|0);hb=f+16|0}function Dj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function ry(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;e=oi(b,c);a:{if(e>>>0<=_o(a)>>>0){f=c;g=x[a>>2];h=Wc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;x[d+12>>2]=x[d+12>>2]+h;f=x[d+12>>2]}b=Hi(b,f,g);if(!i){_t(a,f,c,e-Wc(x[a>>2],x[a+4>>2])|0);break a}Nd(a,b);break a}jB(a);rl(a,Al(a,e));_t(a,b,c,e)}hb=d+16|0}function jz(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=d+11|0;TQ(a,c);if(Ob(c,13428,4)){a=1}else{TQ(a,d+11|0);v[b|0]=1;a=0}c=hb-16|0;hb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Vb(c,a);x[23420]=0;a=T(608,b|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break b}xb(b)}hb=c+16|0;break a}a=P()|0;xb(b);S(a|0);p()}hb=d+16|0;return a|0}function wY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=hb-16|0;hb=g;k=ai(g+8|0,x[a+8>>2]);i=Ir(0,c,d-c|0,b?b:466956);$h(k);hb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function lW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){hc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;hc(e+24|0,x[d>>2],x[Hb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;mb[d|0](a,b,c+g|0,e+8|0)}hb=e+32|0}function Q3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[23420]=0;Y(902,a|0);f=x[23420];x[23420]=0;if((f|0)!=1){return xx(x[x[a+24>>2]+24>>2],b,c,d,e)|0}_(V(0)|0)|0;x[23420]=0;X(889,12276,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function KG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=mb[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((fk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=ws(x[a+32>>2])?-1:0}hb=b+16|0;return d|0}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;tq(e+8|0,c);x[23420]=0;R(528,e+20|0,d|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[23420]=0;X(282,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}NR(e+8|0);hb=e+32|0;break a}a=P()|0;xb(e+8|0);break b}a=P()|0;NR(e+8|0)}S(a|0);p()}}function P1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=hb-16|0;hb=e;g=x[d+4>>2];ix(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){hc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Hb(e+12|0,e+8|0)>>2];iq(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];ah(_g(Db(x[b+4>>2]),c),_g(_g(Db(x[b+4>>2]),c),i),h);iq(a,d,g,0,f)}hb=e+16|0}function M5(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;a=Qb(a);x[23420]=0;Y(892,b+16|0);c=x[23420];x[23420]=0;a:{b:{if((c|0)!=1){c=Db(x[b+16>>2]);d=Db(x[b+20>>2]);e=x[gc(b+8|0,a)>>2];x[23420]=0;U(893,c|0,d|0,e|0);c=x[23420];x[23420]=0;if((c|0)==1){break b}tc(b+16|0);hb=b+32|0;return}c=P()|0;break a}c=P()|0;tc(b+16|0)}Ke(a);S(c|0);p()}function ut(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;Wia(b,0,a,0);a=lb?0:D(a,b)}else{a=0}a:{if(!a){break a}x[23420]=0;b=T(705,a|0)|0;c=x[23420];x[23420]=0;b:{c:{if((c|0)==1){_(V(0)|0)|0;x[23420]=0;Z(17);c=x[23420];x[23420]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;Ub();p()}if(!b){break a}d=Tb(b,0,a)- -64|0}return d}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;Xm(e+8|0,c);x[23420]=0;R(101,e+20|0,d|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[23420]=0;X(102,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(e+8|0);hb=e+32|0;break a}a=P()|0;yb(e+8|0);break b}a=P()|0;Ah(e+8|0)}S(a|0);p()}}function P$(a){a=a|0;a:{x[23420]=0;T(1063,465976)|0;a=x[23420];x[23420]=0;b:{if((a|0)==1){break b}x[23420]=0;T(1063,466312)|0;a=x[23420];x[23420]=0;if((a|0)==1){break b}x[23420]=0;T(1064,466060)|0;a=x[23420];x[23420]=0;if((a|0)==1){break b}x[23420]=0;T(1064,466396)|0;a=x[23420];x[23420]=0;if((a|0)==1){break b}break a}V(0)|0;Ub();p()}}function Bu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-32|0;hb=e;LB(e+8|0,c);x[23420]=0;R(101,e+20|0,d|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[23420]=0;X(102,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(e+8|0);hb=e+32|0;break a}a=P()|0;yb(e+8|0);break b}a=P()|0;Ah(e+8|0)}S(a|0);p()}}function zfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb+-64|0;hb=c;b=-1;a:{if(!(mb[x[x[a>>2]+32>>2]](a,0,1084)|0)){break a}al(a,1080);d=c+60|0;MR(a,d);e=d;d=LR(c+40|0);b=0;if(!KR(e,d)){break a}al(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[d+4>>2]>=f>>>0}else{e=c+8|0;JR(a,e);b=b+1|0;f=nA(e)+f|0;continue}break}}hb=c- -64|0;return b|0}function dC(a){var b=0,c=0,d=0,e=0,f=0;d=y[a+9|0]|y[a+10|0]<<8;c=Wia(y[a+3|0],0,18,0);d=d+c|0;b=lb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=y[a+6|0]|y[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;lb=a;return b}function Aaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(hh(2147483647)>>>0<=2303){Tc();p()}b=dv(2304);x[a>>2]=b;x[a+4>>2]=b;f=Fb(a),g=b+4608|0,x[f>>2]=g;d=hb-16|0;hb=d;c=Gi(d,a,2304);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){kc(c);hb=d+16|0}else{ev(b);b=b+2|0;x[c+4>>2]=b;continue}break}return a|0}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);x[a>>2]=44880;c=Qb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);zs(a);return a|0}b=P()|0;tc(c);vf(a);S(b|0);p()}function P0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if(!(c&1024)){break a}f=e,g=Ei(b),x[f+8>>2]=g;c=ol(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[rd(b)|0]!=(jf(43)&255)){if(y[rd(b)|0]!=(jf(45)&255)){break b}}d=d+1|0;mI(e+8|0)}if(c>>>0>=d>>>0){break a}OH(b,x[Gf(e,e+8|0)>>2],d-c|0,jf(48))}Rc(a,b);hb=e+16|0}function xq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Db(x[b>>2]);g=Db(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Pb(d,g)){break a}f=hb-16|0;hb=f;yi(f+8|0,x[d>>2],x[d+4>>2]);h=ac(x[f+8>>2]);hb=f+16|0;if((c|0)==(h|0)){break a}d=x[um(e+8|0)>>2];continue}break}hb=e+16|0;if(uc(d,Db(x[b+4>>2]))){zh(a);return}so(a,d)}function s9(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=fc(b,b+16|0,15);mc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(Ob(b+16|0,8443,15)){break a}$b(a,15);c=1}hb=b+32|0;return c|0}function hR(a){var b=0,c=0,d=0,e=0,f=0;e=y[a+28|0]|y[a+29|0]<<8;b=Wia(y[a+30|0],0,37,0);c=lb;d=b;b=Wia(y[a+24|0]|y[a+25|0]<<8,0,192,0);d=d+b|0;c=lb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=y[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;lb=a;return b}function a4(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return kj(Yb(x[a+484360>>2],y[a+484376|0]))|0}_(V(0)|0)|0;x[23420]=0;X(889,6846,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-32|0;hb=d;KA(d+8|0,c);x[23420]=0;R(409,d+20|0,43212);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(d,d+8|0);x[23420]=0;X(102,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(d+8|0);hb=d+32|0;break a}a=P()|0;yb(d+8|0);break b}a=P()|0;Ah(d+8|0)}S(a|0);p()}}function Ud(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;Nm(b);f=mf(e+8|0,b);a:{d=a+8|0;b=x[d>>2];if(vc(b,x[a+12>>2])>>>0<=c>>>0){x[23420]=0;R(1160,d|0,c+1|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}b=x[d>>2]}a=Cb(b,c);b=x[a>>2];if(b){Sm(b);a=Cb(x[d>>2],c)}g=a,h=Zd(f),x[g>>2]=h;CF(f);hb=e+16|0;return}a=P()|0;CF(f);S(a|0);p()}function E1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!x[b+28>>2]){break a}e=0;if((mb[x[b+32>>2]](x[b+24>>2],c,0,0)|0)<0){break a}f=x[d+4>>2];c=x[d>>2];while(1){b:{if(!f){break b}e=mb[x[b+28>>2]](x[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}hc(a,x[d>>2],e)}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;hc(c+8|0,b,10);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function Fp(a){var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Db(x[a>>2]);e=a;f=Db(x[a+4>>2]);a=hb-16|0;hb=a;x[a+8>>2]=d;while(1){if(Pb(d,f)){b=b+C[d>>3];d=x[ft(a+8|0)>>2];continue}break}hb=a+16|0;a=Db(x[e>>2]);x[c+8>>2]=a;b=-b;e=Db(x[e+4>>2]);while(1){if(Pb(a,e)){b=b+C[a>>3];C[a>>3]=b;a=x[ft(c+8|0)>>2];continue}else{hb=c+16|0}break}}function yK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Hc(b,b>>31);x[a+4272>>2]=b;x[23420]=0;x[c+12>>2]=0;U(859,a+4256|0,b<<1,c+12|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;x[a+4272>>2]=0;$()}x[a+4276>>2]=0;x[a+4268>>2]=0;hb=c+16|0;return}S(b|0);p()}function pd(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;mm(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Vb(c,21473);ze(a+43|0,b);xb(b);OP(a);hb=c+16|0}function $3(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){a=x[x[a+24>>2]+24>>2];return et(x[a+484344>>2],x[a+484348>>2])|0}_(V(0)|0)|0;x[23420]=0;X(889,6914,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function rL(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Hb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=op(v[Kb(a,f)|0]);h=op(v[Kb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}hb=e+16|0;return a}function RI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a>>2];a:{if(!b){break a}c=x[a+8>>2];if(!c){break a}d=x[a+12>>2];if(!d){break a}e=mb[d|0](b)|0;a=lb;f=a;if((a|0)<0){break a}a=0;b:{if((mb[c|0](b,0,0,0)|0)<0){break b}a=0;if((mb[c|0](b,0,0,2)|0)<0){break b}mb[d|0](b)|0;a=lb;a=(a|0)>0|(a|0)>=0}g=a;mb[c|0](b,e,f,0)|0}return g|0}function Cy(a,b,c){var d=0,e=0,f=0;d=Jb(a);a=Eb(b);x[23420]=0;R(47,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){a=65533;f=v[Xf(b,e)|0];if((f|0)>=-96){a=x[((f&255)<<2)+c>>2]}x[23420]=0;R(48,d|0,a|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;Jc(d);S(a|0);p()}function BW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;c=hb-16|0;hb=c;b=hb-16|0;hb=b;x[b+4>>2]=1;g=b,h=wc(24),x[g+8>>2]=h;e=Io(x[b+8>>2]);x[e>>2]=61060;FD(yc(e),x[d>>2],x[d+4>>2]);e=c+8|0;f=Ko(b);Jo(e,yc(f),f);Rm(b);hb=b+16|0;qg(a,e);de(e);hb=c+16|0;hb=d+16|0}function nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb+-64|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;lS(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){kS(f)}c=-1;a:{if(!e){break a}c=0;if(!nS(d+8|0)){break a}c=Ge(a,b,mS(d+8|0),lb)}hb=d- -64|0;return c|0}function Uw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=hb-240|0;hb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((mb[b|0](a,f)|0)>=0){if((mb[b|0](a,e)|0)>=0){break a}}j=f;f=(mb[b|0](f,e)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}DH(g,h);hb=g+240|0}function Sl(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=hb-16|0;hb=h;i=-17;if(-17-b>>>0>=c>>>0){j=sc(a);if(b>>>0<=2147483622){x[h+8>>2]=b<<1;x[h+12>>2]=b+c;i=wi(x[Yc(h+12|0,h+8|0)>>2])+1|0}c=wc(i);if(e){He(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){He((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Ib(j)}xd(a,c);Af(a,i);hb=h+16|0;return}Bf();p()}function PF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=x[b>>2];h=x[a>>2];e=x[ic(a)>>2]==1108;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:4;g=Mt(e?0:h,f);if(g){if(!e){Zd(a)}x[d+4>>2]=1073;e=le(d+8|0,g,d+4|0);a=MF(a,e);Pc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);hb=d+16|0;return}tw();p()}function EV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=hb-48|0;hb=d;c=hb-16|0;hb=c;f=d+8|0;xC(c+8|0,f);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(g|0);if(!e){wC(f)}c=-1;a:{if(!e){break a}c=0;if(!zC(d+8|0)){break a}c=Ge(a,b,yC(y[d+43|0]),lb)}hb=d+48|0;return c|0}function bS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;e=qe(b,c);a:{if(e>>>0<=ti(a)>>>0){f=c;g=x[a>>2];h=vc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;x[d+12>>2]=x[d+12>>2]+(h<<2);f=x[d+12>>2]}b=Hi(b,f,g);if(!i){uA(a,f,c,e-vc(x[a>>2],x[a+4>>2])|0);break a}Nd(a,b);break a}tA(a);kl(a,Tg(a,e));uA(a,b,c,e)}hb=d+16|0}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-576|0;hb=d;c=hb-16|0;hb=c;iT(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){hT(d)}c=-1;a:{if(!e){break a}c=0;if(!kT(d)){break a}c=Ge(a,b,jT(z[d+34>>1],z[d+36>>1]),lb)}hb=d+576|0;return c|0}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Wc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=hb-32|0;hb=e;b=b-d|0;d=x[Fb(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){Bo(a,b,c);break a}d=Fb(a);d=Dl(e+8|0,Al(a,Wc(x[a>>2],f)+b|0),Wc(x[a>>2],x[a+4>>2]),d);HS(d,b,c);zd(a,d);Cl(d)}hb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,b+e|0)}}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;c=ff(a,c);ae(f,x[a+28>>2]);a:{if(!c){e=0;if(gd(a,5)){break a}}h=x[a+28>>2];g=hb-16|0;hb=g;e=Jb(g);x[23420]=0;fa(404,b|0,h|0,e|0,d|0)|0;b=x[23420];x[23420]=0;b:{if((b|0)!=1){yb(e);hb=g+16|0;break b}a=P()|0;yb(e);S(a|0);p()}e=c}af(a,e);hb=f+16|0}function w1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;a:{if(!(c&1024)){break a}f=e,g=Yd(b),x[f+8>>2]=g;b:{if(!Eb(b)){break b}if(y[Nc(b,0)|0]!=(jf(43)&255)){if(y[Nc(b,0)|0]!=(jf(45)&255)){break b}}d=d+1|0;mI(e+8|0)}c=Eb(b);if(c>>>0>=d>>>0){break a}ex(b,x[Gf(e,e+8|0)>>2],d-c|0,jf(48))}Rc(a,b);hb=e+16|0}function f3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}_(V(0)|0)|0;x[23420]=0;X(889,12897,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}f=x[a+8>>2];c=x[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(uc(b,-1)){on(a,f,c-1|0,e);return Ew(b)|0}g=wn(b);if(!(x[a+48>>2]&16)){d=-1;if(!uc(g,v[c-1|0])){break a}}on(a,f,c-1|0,e);v[x[a+12>>2]]=g;d=b}return d|0}function PL(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;fc(d+8|0,rd(b),Bd(x[b+4>>2],y[b+11|0]));b=x[d+8>>2];e=x[d+12>>2];c=hb-16|0;hb=c;f=Bd(x[a+4>>2],y[a+11|0]);x[c+12>>2]=f;x[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=Tl(rd(a),b,x[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}hb=c+16|0;hb=d+16|0;return a>>>31|0}function Jk(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=hb-16|0;hb=f;x[f+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=hb-32|0;hb=c;d=qc(c+24|0,x[a>>2]);e=x[f+8>>2];g=x[e+4>>2];e=x[e>>2];x[c+16>>2]=e;x[c+20>>2]=g;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=e;x[c+12>>2]=g;d=Lc(d,h,c+8|0);hb=c+32|0;if(!d){break a}b=a}hb=f+16|0;return b}a=a+8|0;continue}}function JC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<3){if(!b){break a}if(!Nb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){d=z[c+14>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){ng(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11081,8981,136,14045);p()}hb=c+16|0;return d&65535}function yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{e=Nb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}xc(d+12|0,65535);jg(a,z[d+12>>1]);c=Db(x[a>>2]);x[d>>2]=c;a=Db(x[a+4>>2]);while(1){if(!Pb(c,a)){break a}f=d+8|0;if(!Go(b,f)){vm(f)}w[c>>1]=x[d+8>>2];c=x[Re(d)>>2];continue}}hb=d+16|0;return e|0}function k6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=46992;b=a+4208|0;e=Cb(b,0),f=1056880300,x[e>>2]=f;e=Cb(b,1),f=1050733080,x[e>>2]=f;e=Cb(b,2),f=1056964608,x[e>>2]=f;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;vf(a);S(b|0);p()}function d6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a>>2]=47224;b=a+4208|0;e=Cb(b,0),f=1065353216,x[e>>2]=f;e=Cb(b,1),f=1065353216,x[e>>2]=f;e=Cb(b,2),f=1051372203,x[e>>2]=f;e=Cb(b,3),f=0,x[e>>2]=f;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;vf(a);S(b|0);p()}function l_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=hb-16|0;hb=d;i=x[b>>2];h=x[a>>2];e=x[ic(a)>>2]==1108;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g?g:1;g=Mt(e?0:h,f);if(g){if(!e){Zd(a)}x[d+4>>2]=1073;e=le(d+8|0,g,d+4|0);a=MF(a,e);Pc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];hb=d+16|0;return}tw();p()}function j5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[f+8>>2]=d;d=x[Tf(f,f+8|0)>>2];x[23420]=0;ja(900,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){a=FI(a);b=EI(a+88|0);c=DI(a+92|0);x[a>>2]=61368;x[b>>2]=61480;x[c>>2]=61560;se(f+8|0);hb=f+16|0;return a|0}a=P()|0;se(f+8|0);S(a|0);p()}function JF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=hb-16|0;hb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=sc(a);if(b>>>0<=536870886){x[f+8>>2]=b<<1;x[f+12>>2]=b+c;g=Hl(x[Yc(f+12|0,f+8|0)>>2])+1|0}c=qi(g);if(e){di(c,h,e)}if((d|0)!=(e|0)){i=e<<2;di(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Ib(h)}xd(a,c);Af(a,g);hb=f+16|0;return}Bf();p()}function uf(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a:{if(A[b+8>>2]<c>>>0){x[23420]=0;X(1025,17201,9012,392,6342);a=x[23420];x[23420]=0;if((a|0)==1){break a}p()}x[d+8>>2]=x[b+8>>2];e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=x[d+4>>2];x[a>>2]=x[d>>2];x[a+4>>2]=b;x[a+8>>2]=x[d+8>>2];x[a+12>>2]=c;hb=d+16|0;return}V(0)|0;Ub();p()}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-1968|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;JB(c+8|0,f);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){IB(f)}c=-1;a:{if(!d){break a}c=0;if(!KB(e+8|0)){break a}c=Ge(a,b,1024,0)}hb=e+1968|0;return c|0}function OB(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=Gi(c,a,1);wj(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=xj(d+8|0,yj(a,Mc(x[a>>2],x[a+4>>2])+1|0),Mc(x[a>>2],x[a+4>>2]),c);wj(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;zd(a,c);Fi(c);hb=d+32|0}function N8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+e;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[23420]=0;R(832,b|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=P()|0;Id(d);S(a|0);p()}Id(d);hb=d+16|0}function B8(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=Nh(c,a,1);Hs(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=bg(d+8|0,Tg(a,vc(x[a>>2],x[a+4>>2])+1|0),vc(x[a>>2],x[a+4>>2]),c);Hs(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;zd(a,c);ag(c);hb=d+32|0}function x7(a){a=a|0;var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;x[x[a+20>>2]+148>>2]=-1;uo(c+8|0,a+4228|0);d=x[a+20>>2];e=x[c+12>>2];b=x[c+8>>2];x[23420]=0;U(871,d+4|0,b|0,Kb(b,e)|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;Gc(x[a+20>>2]+4|0);$()}hb=c+16|0;return}S(b|0);p()}function kj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(uc(x[a>>2],b)){a=0}else{b=qj(b);e=qj(x[a>>2]);c=hb-16|0;hb=c;x[c+8>>2]=b;while(1){a:{if(!zg(b,e)){break a}d=hb-16|0;hb=d;x[d+8>>2]=b;f=XO(d+8|0);hb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[XO(c+8|0)>>2];continue}break}hb=c+16|0;a=yB(Db(x[a>>2]),b)}return a&65535}function L7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;EA(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);EA(e,b);Tb(x[d+8>>2]+c|0,0,33-c|0);$b(a,x[d+28>>2]);hb=d+32|0;return c|0}function Yf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=hb-16|0;hb=f;a:{e=oi(b,c);if(e>>>0<4294967280){b:{if(jq(e)){we(d,e);break b}g=wi(e)+1|0;h=wc(g);xd(d,h);Af(d,g);Sd(d,e);d=h}while(1){if((b|0)!=(c|0)){sd(d,b);d=d+1|0;b=b+1|0;continue}break}v[f+15|0]=0;sd(d,f+15|0);hb=f+16|0;break a}Bf();p()}return a|0}function PI(a){var b=0,c=0,d=0,e=0;b=hb-32|0;hb=b;if(!y[a+20|0]){while(1){if(!(mb[x[x[a>>2]+40>>2]](a)|0)){MI(a,65536);c=fc(b+16|0,Kb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;mb[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}hb=b+32|0}function JX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Kg(a,x[b+8>>2],e)){ew(b,c,d);return}a:{if(!Kg(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function J9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;if(!wd(x[a+1298300>>2])){d=x[a+24620>>2];e=hb-16|0;hb=e;b=wc(536);x[23420]=0;d=Q(789,b|0,d|0)|0;f=x[23420];x[23420]=0;a:{if((f|0)!=1){b=x[mf(e+8|0,d)>>2];hb=e+16|0;break a}a=P()|0;Ib(b);S(a|0);p()}x[c+8>>2]=b;b=a+1298300|0;a=c+8|0;uM(b,Zd(a));xy(a)}hb=c+16|0}function HO(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{ij(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Xh(a+8|0,18,b+15|0);Pt(a+26|0,18,29034);v[b+14|0]=255;Xh(a+62|0,256,b+14|0);Sg(x[a>>2],x[a+4>>2],65535,261,1);Sg(x[a>>2],x[a+4>>2],65535,260,0);hb=b+16|0}function B9(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;v[d+15|0]=b;b=y[a+11|0];a:{b:{c:{if(!Sf(b)){c=10;b=Mf(b);if((b|0)==10){break c}we(a,b+1|0);c=a;break a}b=x[a+4>>2];c=QA(x[a+8>>2])-1|0;if((b|0)!=(c|0)){break b}}_x(a,c,1,c,c,0);b=c}c=x[a>>2];Sd(a,b+1|0)}a=b+c|0;sd(a,d+15|0);v[d+14|0]=0;sd(a+1|0,d+14|0);hb=d+16|0}function ds(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(!(c&32)){break a}g=d,h=Yd(b),x[g+8>>2]=h;g=d,h=mh(b),x[g>>2]=h;while(1){if(!Lh(d+8|0,d)){break a}c=x[d+8>>2];f=jf(97);e=v[c|0];b:{if((f|0)>(e|0)){break b}if((jf(122)|0)<(e|0)){break b}g=c,h=(jf(65)-f|0)+e|0,v[g|0]=h}Be(d+8|0);continue}}Rc(a,b);hb=d+16|0}function KC(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(b>>>0<5){if(!b){break a}if(!Nb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){d=x[c+12>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){ng(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}aa(11081,8981,136,14045);p()}hb=c+16|0;return d}function $r(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;a:{if(!(c&32)){break a}g=d,h=Ei(b),x[g+8>>2]=h;g=d,h=_u(b),x[g>>2]=h;while(1){if(!Lh(d+8|0,d)){break a}c=x[d+8>>2];f=jf(97);e=v[c|0];b:{if((f|0)>(e|0)){break b}if((jf(122)|0)<(e|0)){break b}g=c,h=(jf(65)-f|0)+e|0,v[g|0]=h}Be(d+8|0);continue}}Rc(a,b);hb=d+16|0}function eL(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=Px(a);b=zj(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23420]=0;b=fa(857,c+8|0,b|0,b|0,Fb(a)|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){zd(a,b);bL(b);break b}_(V(0)|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;Ub();p()}function dL(a){var b=0,c=0,d=0;c=hb-32|0;hb=c;a:{d=ti(a);b=vc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[23420]=0;b=fa(858,c+8|0,b|0,b|0,Fb(a)|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){zd(a,b);ag(b);break b}_(V(0)|0)|0;x[23420]=0;Z(17);a=x[23420];x[23420]=0;if((a|0)==1){break a}}hb=c+32|0;return}V(0)|0;Ub();p()}function nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=hb-32|0;hb=e;c=hb-16|0;hb=c;f=e+8|0;VB(c+8|0,f);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;d=(d|0)==(g|0);if(!d){Du(f)}c=-1;a:{if(!d){break a}c=0;if(!LT(e+8|0)){break a}c=Ge(a,b,72,0)}hb=e+32|0;return c|0}function hN(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;f=-2147483648;f=!c|!(v[c+15|0]&1)?f:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){f=z[d+28>>1];break b}if((f|0)==-2147483648){break a}}Ip(b,f,a);Ab(e+8|0,a+1074312|0,10);if(!Bb(x[x[e+8>>2]>>2],x[e+12>>2])|x[a+480208>>2]&16384){break a}x[b+88>>2]=x[b+88>>2]&-257}hb=e+16|0}function _2(a,b){a=a|0;b=b|0;var c=0;x[23420]=0;Y(902,a|0);c=x[23420];x[23420]=0;if((c|0)!=1){x[x[x[a+24>>2]+24>>2]+480272>>2]=b;return 1}_(V(0)|0)|0;x[23420]=0;X(889,5745,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-608|0;hb=d;c=hb-16|0;hb=c;HQ(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){GQ(d)}c=-1;a:{if(!e){break a}c=0;if(!JQ(d)){break a}c=Ge(a,b,IQ(z[d+34>>1]),lb)}hb=d+608|0;return c|0}function cy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=H(c,.999);h=c*3.141592653589793;i=gt(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=si(g)*gt(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Mz(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function MQ(a){var b=0,c=0;a:{if(Ob(a,3868,4)|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=tl(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function tE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;Oo(f+8|0,c);x[23420]=0;R(e|0,f+20|0,d|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(f,f+8|0);x[23420]=0;X(102,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(f+8|0);hb=f+32|0;break a}a=P()|0;yb(f+8|0);break b}a=P()|0;Ah(f+8|0)}S(a|0);p()}}function qE(a,b,c,d,e){var f=0;a:{f=hb-32|0;hb=f;BT(f+8|0,c);x[23420]=0;R(e|0,f+20|0,d|0);c=x[23420];x[23420]=0;b:{c:{if((c|0)!=1){ok(f,f+8|0);x[23420]=0;X(102,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[23420];x[23420]=0;if((a|0)==1){break c}Ah(f+8|0);hb=f+32|0;break a}a=P()|0;yb(f+8|0);break b}a=P()|0;Ah(f+8|0)}S(a|0);p()}}function e3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:883;return}_(V(0)|0)|0;x[23420]=0;X(889,12927,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function Yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;IA(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);IA(e,b);Tb(x[d+8>>2]+c|0,0,4896-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function JQ(a){var b=0;a:{if(Ob(a+44|0,14002,4)|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;oP(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);oP(e,b);Tb(x[d+8>>2]+c|0,0,263-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function Tx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=hb-16|0;hb=d;h=z[b>>1];c=Vd(a);e=ic(a);f=hb-16|0;hb=f;while(1){if(c){g=Gs(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[gc(f+8|0,e)>>2];hb=f+16|0;a:{if(Pb(c,Kf(a))){if(!Gs(z[b>>1],z[ud(c)>>1])){break a}}c=Kf(a)}a=x[gc(d+8|0,c)>>2];hb=d+16|0;return a}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=Pu(c,a,1);aR(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=eB(d+8|0,fB(a,Ff(x[a>>2],x[a+4>>2])+1|0),Ff(x[a>>2],x[a+4>>2]),c);aR(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;dB(a,c);eu(c);hb=d+32|0}function m4(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return A[x[x[a+24>>2]+24>>2]+1074420>>2]/1e4|0}_(V(0)|0)|0;x[23420]=0;X(889,9232,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function ky(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;f=x[b+656>>2];e=0;a:{if(!f){break a}f=Uu(f,c);e=a+1074312|0;Ab(d+8|0,e,31);a=0;if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){Ab(d,e,93);a=Bb(x[x[d>>2]>>2],x[d+4>>2])^1}if(!(v[UL(b,c)+6|0]&1)){e=0;if(!(v[f+12|0]&1)|a){break a}}e=uc(x[f>>2],x[f+4>>2])^1}hb=d+16|0;return e}function jU(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=_T(c,a,1);ZT(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+48;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=XT(d+8|0,YT(a,lq(x[a>>2],x[a+4>>2])+1|0),lq(x[a>>2],x[a+4>>2]),c);ZT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+48;WT(a,c);VT(c);hb=d+32|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Fz(c,a,1);rz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=rt(d+8|0,Mp(a,fg(x[a>>2],x[a+4>>2])+1|0),fg(x[a>>2],x[a+4>>2]),c);rz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;PO(a,c);qz(c);hb=d+32|0}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Pu(c,a,1);gB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=eB(d+8|0,fB(a,Ff(x[a>>2],x[a+4>>2])+1|0),Ff(x[a>>2],x[a+4>>2]),c);gB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;dB(a,c);eu(c);hb=d+32|0}function UZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!Se(f)){b=x[f+4>>2];x[a>>2]=x[f>>2];x[a+4>>2]=b;x[a+8>>2]=x[f+8>>2];break a}d=x[f>>2];b:{c:{c=x[f+4>>2];d:{if(Gr(c)){we(a,c);break d}if(c>>>0>=1073741808){break c}e=Hl(c)+1|0;b=qi(e);xd(a,b);Af(a,e);Sd(a,c);a=b}di(a,d,c+1|0);break b}Bf();p()}}}function x_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=x[20511];x[g+24>>2]=x[20510];x[g+28>>2]=h;h=x[20509];x[g+16>>2]=x[20508];x[g+20>>2]=h;h=x[20507];x[g+8>>2]=x[20506];x[g+12>>2]=h;h=x[20505];x[g>>2]=x[20504];x[g+4>>2]=h;h=a;a=g+32|0;b=Jj(h,b,c,d,e,f,g,a);hb=a;return b|0}function qga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c>>2]=x[a+8>>2];d=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+d;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[23420]=0;Y(216,b|0);a=x[23420];x[23420]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=P()|0;Id(c);S(a|0);p()}Id(c);hb=c+16|0}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=Oh(d,b);x[23420]=0;U(754,d+16|0,b|0,c|0);e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){x[23420]=0;U(55,a|0,d+16|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}xb(d+16|0);xb(b);hb=d+32|0;return}c=P()|0;break a}c=P()|0;xb(d+16|0)}xb(b);S(c|0);p()}function jga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;gu(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);gu(e,b);Tb(x[d+8>>2]+c|0,0,22-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;vA(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);vA(e,b);Tb(x[d+8>>2]+c|0,0,40-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Fb(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);Qz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=nk(d+8|0,Vm(a,vd(x[a>>2],x[a+4>>2])+1|0),vd(x[a>>2],x[a+4>>2]),c);Qz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;eQ(a,c);dQ(c);hb=d+32|0}function MN(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=zt(c,a,1);Qo(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=nk(d+8|0,Vm(a,vd(x[a>>2],x[a+4>>2])+1|0),vd(x[a>>2],x[a+4>>2]),c);Qo(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;lr(a,c);LN(c);hb=d+32|0}function wp(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;v[d+15|0]=b;a:{b:{c:{if(!Se(a)){c=10;b=y[a+11|0];if((b|0)==10){break c}we(a,b+1|0);c=a;break a}c=ll(a);b=x[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}Sl(a,c,1,c,c,0,0);b=c}c=x[a>>2];Sd(a,b+1|0)}a=b+c|0;sd(a,d+15|0);v[d+14|0]=0;sd(a+1|0,d+14|0);hb=d+16|0}function uV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;Ou(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Ou(e,b);Tb(x[d+8>>2]+c|0,0,65-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function sf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Eb(a)|(c-b|0)<5){break a}Er(b,c);e=c-4|0;c=Ic(a);g=c+Eb(a)|0;b:{while(1){c:{a=v[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>x[e>>2]-1>>>0){break a}}x[d>>2]=4}}function qK(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=hb-16|0;hb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=Ph(E(B[Xp(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}hb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;xc(a+4224|0,b)}function Wea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-1120|0;hb=d;c=hb-16|0;hb=c;eR(c+8|0,d+8|0);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!gR(d+8|0)){break a}c=Ge(a,b,fR(x[d+1112>>2]),lb)}hb=d+1120|0;return c|0}function _W(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Iv(c,a);Qo(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=nk(d+8|0,Vm(a,vd(x[a>>2],x[a+4>>2])+1|0),vd(x[a>>2],x[a+4>>2]),c);Qo(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;lr(a,c);Hv(c);hb=d+32|0}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=hb-32|0;hb=d;e=hb-16|0;hb=e;f=e,g=Lb(c&65535),w[f+14>>1]=g;c=d+16|0;OI(c,e+14|0);hb=e+16|0;Ui(d+8|0,c);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function VV(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=qD(c,a);mv(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;kc(a);hb=c+16|0;return}d=hb-32|0;hb=d;c=Fb(a);c=oD(d+8|0,pD(a,Zq(x[a>>2],x[a+4>>2])+1|0),Zq(x[a>>2],x[a+4>>2]),c);mv(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;nD(a,c);ov(c);hb=d+32|0}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-224|0;hb=d;c=hb-16|0;hb=c;qT(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!sT(d)){break a}c=Ge(a,b,rT(y[d+216|0],y[d+217|0]),lb)}hb=d+224|0;return c|0}function KW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;b=Om(d,b);x[23420]=0;U(142,d+16|0,b|0,c|0);e=x[23420];x[23420]=0;a:{b:{if((e|0)!=1){x[23420]=0;U(4,a|0,d+16|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);hb=d+32|0;return}c=P()|0;break a}c=P()|0;yb(d+16|0)}yb(b);S(c|0);p()}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb+-64|0;hb=d;c=hb-16|0;hb=c;ou(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){iu(d)}c=-1;a:{if(!e){break a}c=0;if(!mQ(d)){break a}c=Ge(a,b,lQ(d),lb)}hb=d- -64|0;return c|0}function _x(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;h=-17;if(-17-b>>>0>=c>>>0){i=rd(a);if(b>>>0<=2147483622){x[g+8>>2]=b<<1;x[g+12>>2]=b+c;h=wi(x[Yc(g+12|0,g+8|0)>>2])+1|0}c=wc(h);if(e){He(c,i,e)}if((d|0)!=(e|0)){He((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Ib(i)}xd(a,c);Af(a,h);hb=g+16|0;return}Bf();p()}function L1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(y[b+40|0]){break a}if(!x[b+28>>2]){v[b+40|0]=1;break a}d=x[c+4>>2];f=x[c>>2];while(1){b:{if(d){e=mb[x[b+28>>2]](x[b+24>>2],f,d)|0;if(e){break b}v[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}hc(a,x[c>>2],d)}function ul(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=WM(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return VM(a,b,c,e);case 1:break b;default:break a}}f=VM(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=WM(x[a+720>>2],x[a+1272>>2],e)}return f}function ZK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[23420]=0;x[c+12>>2]=0;U(859,a+4208|0,b<<1,c+12|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;x[a+4220>>2]=0;$()}x[a+4224>>2]=0;hb=c+16|0;return}S(b|0);p()}function Ds(a){var b=0,c=0,d=0;b=Ej(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=Zo(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Ej(d+c)*.5}else{b=0}C[a+4248>>3]=b}Cs(a)}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-192|0;hb=d;c=hb-16|0;hb=c;zq(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){cT(d)}c=-1;a:{if(!e){break a}c=0;if(!eT(d)){break a}c=Ge(a,b,dT(d),lb)}hb=d+192|0;return c|0}function Jm(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-hd((hd(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-hd(e+(hd(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Tb(a,0,b<<3)}}function yY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;x[e>>2]=c;a=hw(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}hb=f+16|0;return b|0}function p2(a,b){a=a|0;b=b|0;var c=0,d=0;a=Jb(a);c=Eb(b);x[23420]=0;R(72,a|0,c|0);c=x[23420];x[23420]=0;if((c|0)!=1){a:{b:{while(1){if(Eb(b)>>>0<=d>>>0){break b}c=v[Xf(b,d)|0];x[23420]=0;R(50,a|0,jf(c)|0);c=x[23420];x[23420]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;yb(a);S(b|0);p()}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-80|0;hb=d;c=hb-16|0;hb=c;ES(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){JA(d)}c=-1;a:{if(!e){break a}c=0;if(!vP(d)){break a}c=Ge(a,b,uP(d),lb)}hb=d+80|0;return c|0}function LU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!Nb(x[b>>2],x[b+8>>2],c<<1)){break a}xc(d+12|0,65535);jg(a,z[d+12>>1]);c=Db(x[a>>2]);x[d>>2]=c;a=Db(x[a+4>>2]);while(1){if(!Pb(c,a)){break a}Hu(b,d+8|0);e=c,f=Lb(z[d+8>>1]),w[e>>1]=f;c=x[Re(d)>>2];continue}}hb=d+16|0}function Cr(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function Cia(a,b){a=a|0;b=b|0;var c=0;pu(a,b);Of(b);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;return}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;return}v[b+3|0]=20;v[b+5|0]=a&15|160;return}v[b+3|0]=0}}function ot(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[115904]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Bw(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Bw(a)}Zd(b)}return a}function mfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-128|0;hb=d;c=hb-16|0;hb=c;rR(c+8|0,d);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;e=(e|0)==(f|0);if(!e){qR(d)}c=-1;a:{if(!e){break a}c=0;if(!sR(d)){break a}c=Ge(a,b,256,0)}hb=d+128|0;return c|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Db(x[b>>2]);g=Db(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Pb(d,g)){break a}f=hb-16|0;hb=f;JS(f+8|0,d);hb=f+16|0;if(z[f+8>>1]==(c|0)){break a}d=x[um(e+8|0)>>2];continue}break}hb=e+16|0;if(uc(d,Db(x[b+4>>2]))){zh(a);return}so(a,d)}function CL(a){var b=0,c=0;a:{if(Ob(a,14036,4)){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function uB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=hb-32|0;hb=f;x[f+8>>2]=c;g=f,h=df(b),x[g+28>>2]=h;c=f+8|0;Ef(c,b,x[Hb(c,f+28|0)>>2]);b=xe(c);x[23420]=0;ea(224,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){Oc(f+8|0);hb=f+32|0;return}a=P()|0;Oc(f+8|0);S(a|0);p()}function bq(a){var b=0,c=0;b=hb-32|0;hb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;Bz(c,c+512|0,b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;Bz(a,UP(a),b);hb=b+32|0}function Tv(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=D(32-G(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(A[(e<<2)+25600>>2]<=d>>>0)|0)){break a}}b:{if(d>>>0<=99999999){c=Pw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+D(d,-1e8)|0;c=(e>>>0)/1e4|0;c=Zi(Zi(tH(b,d),c),e+D(c,-1e4)|0)}f=0}x[a+4>>2]=f;x[a>>2]=c}function y$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Jb(a);d=Bd(x[b+4>>2],y[b+11|0]);e=Bd(x[c+4>>2],y[c+11|0]);b=rd(b);x[23420]=0;X(90,a|0,b|0,d|0,d+e|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){b=rd(c);x[23420]=0;W(91,a|0,b|0,e|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break a}}b=P()|0;yb(a);S(b|0);p()}}function o7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-3|0){case 0:c=Ph(c);if(c==B[Cb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(Ph(E(c*E(4)))*E(.25))}d=Cb(a+4208|0,b),e=c,B[d>>2]=e;Gx(a)}}function Wx(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];a=x[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}x[23420]=0;R(832,b|0,c|0);e=x[23420];x[23420]=0;if((e|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=P()|0;kc(d);S(a|0);p()}kc(d);hb=d+16|0}function NU(a){a=a|0;var b=0,c=0,d=0;c=hb-32|0;hb=c;b=255;a:{if(jj(x[a>>2],x[a+4>>2])>>>0<=49){b=wz(c,x[a+12>>2]);x[23420]=0;R(276,a|0,b|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}Yk(b);zi(a,jj(x[a>>2],x[a+4>>2])-1&255);b=jj(x[a>>2],x[a+4>>2])-1|0}hb=c+32|0;return b&255}a=P()|0;Yk(b);S(a|0);p()}function J6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Fd(c,E(0));a:{b:{switch(b-1|0){case 0:c=Ph(c);if(c==B[Cb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(Ph(E(c*E(4)))*E(.25))}d=Cb(a+4208|0,b),e=c,B[d>>2]=e;Gx(a)}}function z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;ad(a,b);x[23420]=0;U(65,d+8|0,b|0,c|0);e=x[23420];x[23420]=0;a:{if((e|0)==1){break a}Zb(d+8|0);b=x[b+24>>2];if(b){x[23420]=0;U(66,d|0,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)==1){break a}Zb(d)}hb=d+16|0;return}b=P()|0;Zb(a);S(b|0);p()}function vf(a){a=a|0;var b=0,c=0;x[a>>2]=44304;b=x[a+12>>2];if(x[b>>2]==(a|0)){x[b>>2]=x[a+4>>2]}b=x[a+20>>2];if(b){x[b>>2]=0;x[a+20>>2]=0}b=x[a+4>>2];if(b){x[b+8>>2]=x[a+8>>2]}c=x[a+8>>2];if(c){x[c+4>>2]=b}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;SK(a+44|0);return a|0}function EN(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=x[b+48>>2]+1|0;x[b+52>>2]=e;a:{if(A[_b(x[a+484344>>2],z[b+70>>1])+12>>2]>e>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;Ab(d+8|0,a+1074312|0,63);if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}hb=d+16|0}function vq(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;a:{b:{while(1){h=g&255;if(h>>>0>3){break b}if(!Dq(b,c,h>>>0>1)){uh(b,d);uh(c,e);g=g+1|0;continue}break}v[f+15|0]=0;lt(a,0,f+15|0);break a}g=a;a=y[b|0];if(Ai(a)>>>0>Ai(y[d|0])>>>0){uh(b,d);uh(c,e);a=y[b|0]}lt(g,a,c);v[b|0]=0;v[c|0]=0}hb=f+16|0}function r8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);x[a>>2]=43836;b=Qb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];CU(a+4260|0,80,150,80,255);x[23420]=0;R(853,a+44|0,2);c=x[23420];x[23420]=0;if((c|0)!=1){ki(a);return a|0}c=P()|0;tc(b);vf(a);S(c|0);p()}function c4(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return Dg(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23420]=0;X(889,7039,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function b4(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return ts(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23420]=0;X(889,6748,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=pc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);yp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Wz(c+223848|0,b+223848|0);x[23420]=0;Q(758,c+223860|0,b+223860|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){return c|0}b=P()|0;dc(a);S(b|0);p()}function _3(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return ss(x[x[a+24>>2]+24>>2])|0}_(V(0)|0)|0;x[23420]=0;X(889,7398,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function TK(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function LX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Kg(a,x[b+8>>2],0)){dw(b,c,d);return}e=x[a+12>>2];f=a+16|0;dF(x[f>>2],x[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){dF(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function t4(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return+iM(x[x[a+24>>2]+24>>2])}_(V(0)|0)|0;x[23420]=0;X(889,10041,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function aw(a,b,c){var d=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){return x[x[x[a+24>>2]+24>>2]+c>>2]}_(V(0)|0)|0;x[23420]=0;X(889,b|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function OE(a,b,c){var d=0;x[23420]=0;Y(902,a|0);d=x[23420];x[23420]=0;if((d|0)!=1){return z[x[x[a+24>>2]+24>>2]+c>>1]}_(V(0)|0)|0;x[23420]=0;X(889,b|0,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function qO(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=sr(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Wk(e,b,+n());return}a:{if(!bf(b)){break a}d=F(c)<O;if(b<0){c=d?c:1;break a}if(d){break a}Wk(a,b,bf(c)?N:c);return}b=sr(b);g=si(c);Wk(a,b*Oe(c),g*b)}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Eb(a),x[f>>2]=g;e=x[Hb(d+12|0,d)>>2];x[d+4>>2]=e;a=Tl(Ic(a),b,x[Hb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}hb=d+16|0;return a|0}om();p()}function Ig(a,b){var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);wf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;hb=d+16|0}function NB(a,b,c){var d=0,e=0,f=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Hb(d+28|0,d+8|0)>>2];if(!Nb(e,f,c)){c=df(a)}e=d+8|0;zq(e,b);f=fc(d+16|0,x[d+8>>2],c);mc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);zq(e,b);Tb(x[d+8>>2]+c|0,0,192-c|0);$b(a,x[d+28>>2]);hb=d+32|0}function gL(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=hb-16|0;hb=c;if(Jg(x[x[a>>2]-12>>2]+a|0)){w[c+14>>1]=0;Lf(a,c+14|0);e=z[c+14>>1];Pj(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;mp(a,c+8|0);f=Cb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=Jg(x[x[a>>2]-12>>2]+a|0)}hb=c+16|0;return d}function QP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=hb-16|0;hb=e;x[e+12>>2]=6553600;i=e,j=ac(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=hq(f*+A[Hb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=ac(c),x[i+4>>2]=j;i=e,j=hq(f*+A[Hb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;bo(a,h,Hb(b,g));hb=e+16|0}function Mk(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;px(c,b);x[23420]=0;R(1006,c+16|0,c|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){x[23420]=0;U(1007,a|0,0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Jc(c+16|0);yb(c);hb=c+32|0;return}b=P()|0;break a}b=P()|0;Jc(c+16|0)}yb(c);S(b|0);p()}function vw(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-160|0;hb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;ci(f,0,0);EG(e,f,d,1);d=x[e+8>>2];f=x[e+12>>2];g=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=f;x[a>>2]=g;x[a+4>>2]=h;hb=e+160|0}function Yl(a,b,c){var d=0,e=0;a=Jb(a);d=Eb(b);x[23420]=0;R(47,a|0,d|0);d=x[23420];x[23420]=0;if((d|0)!=1){a:{while(1){if(Eb(b)>>>0>e>>>0){d=x[(y[Xf(b,e)|0]<<2)+c>>2];x[23420]=0;R(48,a|0,d|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;Jc(a);S(b|0);p()}function P3(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}_(V(0)|0)|0;x[23420]=0;X(889,7560,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return 0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function J3(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}_(V(0)|0)|0;x[23420]=0;X(889,10789,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return-1}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function CT(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Bv(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function aD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-hd((hd(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-hd((hd(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=fh(x[b+4>>2],x[b+8>>2]);if(c){nO(a,c);d=x[b+4>>2];e=x[b+8>>2];b=hb-16|0;hb=b;a=Ro(b,a,c);x[23420]=0;U(1008,d|0,e|0,a+4|0);c=x[23420];x[23420]=0;a:{if((c|0)!=1){kc(a);hb=b+16|0;break a}b=P()|0;kc(a);S(b|0);p()}}}function By(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Qj(a,b,b+700|0,c<<2,0)}}function rK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[23420]=0;x[c+12>>2]=0;U(859,a+4208|0,b<<2,c+12|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;x[a+4240>>2]=0;$()}x[a+4244>>2]=0;hb=c+16|0;return}S(b|0);p()}function Kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;Df(b);x[d+12>>2]=0;a:{if(!bk(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(Fh(a,d+11|0)){wp(b,v[d+11|0]);e=e+1|0;continue}break}e=0}hb=d+16|0;return e|0}function r_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=hb-128|0;hb=c;x[c+12>>2]=c+116;d=x[a+8>>2];a=c+16|0;SF(d,a,c+12|0,e,f,g);e=x[c+12>>2];d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if((a|0)!=(e|0)){cH(d+8|0,v[a|0]);a=a+1|0;continue}break}hb=d+16|0;hb=c+128|0;return x[d+8>>2]}function Sy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=hb-16|0;hb=f;g=x[b+480180>>2];a:{if(g&64671904){b=y[(d&15)+43744|0];v[a+2|0]=0;w[a>>1]=b;break a}Ab(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;jo(h,(i=Bb(x[x[f+8>>2]>>2],x[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}hb=f+16|0}function mB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;x[e+8>>2]=c;f=e,g=df(b),x[f+28>>2]=g;c=e+8|0;Ef(c,b,x[Hb(c,e+28|0)>>2]);b=xe(c);x[23420]=0;X(323,a|0,b|0,x[e+8>>2],d|0);a=x[23420];x[23420]=0;if((a|0)!=1){Oc(e+8|0);hb=e+32|0;return}a=P()|0;Oc(e+8|0);S(a|0);p()}function TX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;a:{e=x[b>>2];if(wd(e)){if(!De(c)){VJ(c,17588);e=x[b>>2]}b=x[b+4>>2];mb[x[x[b>>2]+24>>2]](d,b,e);x[23420]=0;Q(755,c|0,d|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}xb(d)}Rc(a,c);hb=d+16|0;return}a=P()|0;xb(d);S(a|0);p()}function IM(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}Qj(a,b,b+700|0,c,0)}}function hS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a=gg(a);b=b+236|0;e=fq(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[23420]=0;U(488,c|0,a|0,c+14|0);d=x[23420];x[23420]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}hb=c+16|0;return}b=P()|0;yA(a);S(b|0);p()}function _9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Rd(y[b+24|0])){a=gg(a);c=qj(x[b>>2]);d=yf(b);x[23420]=0;U(761,a|0,c|0,d|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}x[23420]=0;Q(760,a+12|0,b+12|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=P()|0;$M(a);S(b|0);p()}function Xl(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!mj(y[f+31|0])){break a}e=y[f+34|0];if((e-1&255)>>>0>249){break a}e=x[(D(e,160)+a|0)+906140>>2];if(!e){break a}mb[x[x[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function Rz(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!Td(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}mm(b);b=fo(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Ag(b)){break a}if(x[a>>2]!=(d|0)){Wq(b+68|0)}pc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function $R(a,b,c){var d=0,e=0,f=0;f=hb-16|0;hb=f;e=Eb(a);d=Sc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=sc(a);if(e){rj(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=rj(d,b,c);c=c+e|0;Kh(a,c);v[f+15|0]=0;sd(b+c|0,f+15|0);break a}Xo(a,d,(c+e|0)-d|0,e,0,0,c,b)}hb=f+16|0;return a}function lL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(ti(a)>>>0>=b>>>0){f=x[a>>2];e=vc(f,x[a+4>>2]);x[d+8>>2]=e;kL(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Vx(a,b-e|0,c);break a}Nd(a,x[a>>2]+(b<<2)|0);break a}tA(a);kl(a,Tg(a,b));Vx(a,b,c)}hb=d+16|0}function eI(a,b,c,d,e){var f=0;a:{if((e|0)==10){YI(a,b,c,d);break a}f=d>>>0<e>>>0?1:D(e,e)>>>0>d>>>0?2:3;if((f|0)>(c-b|0)){x[a+4>>2]=61;x[a>>2]=c;break a}c=b+f|0;b=c;while(1){f=d&255;d=(f|0)/(e|0)|0;b=b-1|0;v[b|0]=y[(f-D(d,e)|0)+4856|0];if(d&255){continue}break}x[a+4>>2]=0;x[a>>2]=c}}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-32|0;hb=e;x[e+24>>2]=d;c=ff(a,c);ae(e+8|0,x[a+28>>2]);f=a;a:{if(!c){d=0;if(gd(a,5)){break a}}d=x[a+28>>2];a=0;pC(b,x[e+24>>2]);while(1){if(A[e+24>>2]>a>>>0){OO(d,bc(x[b>>2],a));a=a+1|0;continue}break}d=c}af(f,d);hb=e+32|0}function kV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;a:{if(!Nb(x[b>>2],x[b+8>>2],c<<1)){break a}xc(d+12|0,65535);jg(a,z[d+12>>1]);c=Db(x[a>>2]);x[d>>2]=c;a=Db(x[a+4>>2]);while(1){if(!Pb(c,a)){break a}Hu(b,d+8|0);w[c>>1]=z[d+8>>1];c=x[Re(d)>>2];continue}}hb=d+16|0}function bp(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;ad(d,a);x[23420]=0;a=T(1086,d|0)|0;d=x[23420];x[23420]=0;a:{b:{if((d|0)==1){break b}x[23420]=0;X(1098,a|0,81808,81834,b|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Zb(c+8|0);hb=c+16|0;break a}a=P()|0;Zb(c+8|0);S(a|0);p()}return b}function rJ(a){var b=0,c=0,d=0,e=0;d=hb-16|0;hb=d;b=a+120|0;ms(y[b+20|0]);c=hb-16|0;hb=c;x[c+8>>2]=d+8;a=hb-16|0;hb=a;e=x[14171];x[a+8>>2]=x[14170];x[a+12>>2]=e;e=x[14169];x[a>>2]=x[14168];x[a+4>>2]=e;b=mb[x[hp(a,Nj(y[b+20|0]))>>2]](c+8|0,b)|0;hb=a+16|0;hb=c+16|0;hb=d+16|0;return b}function Qc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;lb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function Hr(a,b,c,d){var e=0,f=0;e=hb-160|0;hb=e;f=-1;x[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;x[e+144>>2]=a;e=Tb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1068;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+144;a:{if((b|0)<0){x[115896]=61;break a}v[a|0]=0;f=yH(e,c,d,1042,1043)}hb=e+160|0;return f}function p5(a){a=a|0;var b=0;x[23420]=0;Y(902,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return x[a+16>>2]}_(V(0)|0)|0;x[23420]=0;X(889,5651,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)!=1){$();return-1}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function dK(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;cK(a+60|0);cK(a+52|0);vp(a+49956|0);vp(a+58148|0);vp(a+66340|0);vp(a+74532|0);Tb(a+228|0,0,32768);Tb(a+32996|0,0,512);Tb(a+33508|0,0,16384)}function Yaa(a,b){a=a|0;b=b|0;var c=0;a:{x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=Mc(x[b>>2],x[b+4>>2]);if(c){Pp(a,c);QO(a,x[b>>2],x[b+4>>2],c)}x[23420]=0;Q(3,a+12|0,b+12|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=P()|0;od(a);S(b|0);p()}}function I4(a){a=a|0;var b=0;x[23420]=0;Y(927,a|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[23420]=0;X(889,11832,a|0,0,0);a=x[23420];x[23420]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;if((b|0)!=1){S(a|0);p()}V(0)|0;Ub();p()}function El(a,b){x[a>>2]=0;x[a+4>>2]=0;x[a+20>>2]=0;w[a+16>>1]=65535;x[a+8>>2]=0;x[a+12>>2]=0;x[a+24>>2]=11;x[a+28>>2]=b;Qb(a+32|0);Qb(a+44|0);x[a+72>>2]=0;x[a+76>>2]=0;x[a+64>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;x[a+80>>2]=0;x[a+84>>2]=0;x[a+88>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;return a}function Si(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=d;g=ai(e+8|0,b);b=hb-16|0;hb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=Hr(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Ld(d);x[h>>2]=a;if(!a){break a}f=Hr(a,d,c,x[b+12>>2])}hb=b+16|0;$h(g);hb=e+16|0;return f}function Daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+12>>2]=b;a:{if(_o(a)>>>0>=b>>>0){f=x[a>>2];e=Wc(f,x[a+4>>2]);x[d+8>>2]=e;Xh(f,x[Hb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Bo(a,b-e|0,c);break a}Nd(a,x[a>>2]+b|0);break a}jB(a);rl(a,Al(a,b));Bo(a,b,c)}hb=d+16|0}function Ph(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function EJ(a,b){var c=0;c=hb-32|0;hb=c;fi(c,b);x[23420]=0;U(1010,c+16|0,0,c|0);b=x[23420];x[23420]=0;a:{b:{if((b|0)!=1){x[23420]=0;R(1011,a|0,c+16|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Jc(c+16|0);xb(c);hb=c+32|0;return}b=P()|0;break a}b=P()|0;Jc(c+16|0)}xb(c);S(b|0);p()}function tW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[23420]=0;X(161,e+8|0,b|0,e+28|0,e+24|0);c=x[23420];x[23420]=0;if((c|0)!=1){c=e+16|0;pv(c,x[e+8>>2],x[e+12>>2]);qg(a,c);de(c);de(e+8|0);de(b);hb=e+32|0;return}a=P()|0;de(b);S(a|0);p()}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;Df(b);e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,1,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;break a}a=P()|0;Oc(d+40|0);S(a|0);p()}}function sO(a,b){var c=0,d=0,e=0,f=0;c=hb-96|0;hb=c;JP(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;hb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function VC(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Gd(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function QG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=ls(a);x[a+32>>2]=b;x[a>>2]=77492;b=d+8|0;Nr(b,a);x[23420]=0;b=T(1065,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){Zb(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=nn(b),v[f+44|0]=g;hb=d+16|0;return}b=P()|0;Zb(d+8|0);En(a);S(b|0);p()}function OG(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;a=bH(a);x[a+32>>2]=b;x[a>>2]=77860;b=d+8|0;Nr(b,a);x[23420]=0;b=T(1066,b|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){Zb(d+8|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=nn(b),v[f+44|0]=g;hb=d+16|0;return}b=P()|0;Zb(d+8|0);Qr(a);S(b|0);p()}function L0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=rs(c);x[a>>2]=76952;x[d>>2]=76972;x[a+60>>2]=77012;x[a>>2]=76992;x[a+4>>2]=0;e=c;c=a+8|0;An(e,c);x[a>>2]=76952;x[d>>2]=76972;x[23420]=0;Q(80,c|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}a=P()|0;Gk(d);S(a|0);p()}function Kq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=hb-16|0;hb=f;x[f+12>>2]=c;c=f+12|0;xc(c,256);xc(c,65535);h=z[f+12>>1];jg(a,h);c=0;while(1){if((c|0)==(h|0)){hb=f+16|0}else{g=y[b+c|0];i=nl(x[a>>2],x[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,w[i>>1]=j;c=c+1|0;continue}break}}function dS(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Ie(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){xc(e+12|0,10);a=D(y[x[e+12>>2]+26640|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Ie(733.8401379310345/f*1e4);break a}a=Ie(f/.264*1e4)}hb=e+16|0;return a}function bt(a,b){var c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;ue(d+8|0,b);b=x[d+8>>2];e=x[d+12>>2];c=hb-16|0;hb=c;f=Eb(a);x[c+12>>2]=f;x[c+8>>2]=e;g=Hb(c+12|0,c+8|0);a=Tl(Ic(a),b,x[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}hb=c+16|0;hb=d+16|0;return a>>>31|0}function ZS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Ef(d,a,32);a=x[c+40>>2];e=c+8|0;Qf(e,2,xe(d),a);x[23420]=0;R(210,c+24|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){Fm(c,b);a=c+24|0;pl(c,a);xb(a);Oc(c+40|0);hb=c- -64|0;break a}a=P()|0;Oc(c+40|0);S(a|0);p()}}function Ur(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=ba(16)|0;if(!y[468945]){v[468945]=1}a=fc(c+8|0,a,93168);x[23420]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=W(1044,d|0,c|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){ha(a|0,91088,1045);p()}a=P()|0;ca(d|0);S(a|0);p()}function pl(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;d=Ic(b);e=c,f=Eb(b),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;ah(d,d+x[Hb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Eb(b),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;b=x[Hb(c+12|0,c+8|0)>>2];v[c+7|0]=0;Ql(b+d|0,a+d|0,c+7|0);hb=c+16|0}function Te(a){var b=0,c=0;b=hb-32|0;hb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;BC(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];hb=b+32|0}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-160|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;LQ(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){KQ(e)}if(a){d=MQ(b+8|0)}hb=b+160|0;return d|0}function l8(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Wc(b,x[c+8>>2])|0)!=8){break b}if(Ob(b,9458,4)){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}Nx(a,a)}Es(a)}function Gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-624|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;qU(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){pU(e)}if(a){d=rU(b+8|0)}hb=b+624|0;return d|0}function sR(a){var b=0;a:{if(Ob(a,15324,4)|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function UB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;Df(b);e=d+40|0;Ef(e,a,c);a=x[d+40>>2];f=d+8|0;Qf(f,3,xe(e),a);x[23420]=0;R(210,d+24|0,f|0);e=x[23420];x[23420]=0;if((e|0)!=1){e=b;b=d+24|0;Ac(e,b);xb(b);Oc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;Oc(d+40|0);S(a|0);p()}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,2,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;ym(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;break a}a=P()|0;Oc(d+40|0);S(a|0);p()}}function uU(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=b;c=hb-16|0;hb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);hb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=zB(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}Tc();p()}function eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-32|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;gu(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){CT(e)}if(a){d=DT(b+8|0)}hb=b+32|0;return d|0}function OK(a){a=a|0;var b=0,c=0;c=hb-16|0;hb=c;b=x[x[a+16>>2]+1074404>>2];x[23420]=0;x[c+12>>2]=0;U(859,a+4208|0,D(b,254)|0,c+12|0);b=x[23420];x[23420]=0;a:{if((b|0)==1){b=V(91780)|0;if((ib|0)!=(da(91780)|0)){break a}_(b|0)|0;$()}x[a+4220>>2]=0;hb=c+16|0;return}S(b|0);p()}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;d=-1;c=hb-16|0;hb=c;e=b+8|0;yu(c+8|0,e);f=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(f|0)==(g|0);if(!a){wS(e)}if(a){d=xS(b+8|0)}hb=b+16|0;return d|0}function CS(a,b,c,d){var e=0,f=0,g=0;if(!b|!d){a=-1}else{e=a;f=e+b|0;d=c+d|0;while(1){a:{b=c;b:{if((e|0)!=(f|0)){while(1){if((b|0)==(d|0)){break b}g=v[b|0];b=b+1|0;if(!uc(v[e|0],g)){continue}break}b=e}else{b=f}break a}e=e+1|0;continue}break}a=(b|0)==(f|0)?-1:b-a|0}return a}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,1,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;ze(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;break a}a=P()|0;Oc(d+40|0);S(a|0);p()}}function oU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb+-64|0;hb=d;e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,2,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;Dc(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;break a}a=P()|0;Oc(d+40|0);S(a|0);p()}}function ZR(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!Td(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}xc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Ag(a)){break a}pc(x[a+20>>2],x[b+20>>2],uj(x[a>>2],z[a+34>>1]))}}function YT(a,b){var c=0,d=0,e=0;d=hb-16|0;hb=d;x[d+12>>2]=b;c=hb-16|0;hb=c;x[c+12>>2]=89478485;x[c+8>>2]=2147483647;e=Hb(c+12|0,c+8|0);hb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=UT(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[Yc(d+8|0,d+12|0)>>2]}hb=d+16|0;return b}Tc();p()}function LD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-32|0;hb=e;g=x[b+8>>2];f=x[b>>2];Lg(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;mb[c|0](e+24|0,f,g,e+8|0);Lg(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];hb=e+32|0}function GU(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function C1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-32|0;hb=e;Lg(e+24|0,b,c);b=qg(e+16|0,d);x[23420]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;wg(157,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[23420];x[23420]=0;if((a|0)!=1){de(d);hb=e+32|0;return}a=P()|0;de(d);S(a|0);p()}function zh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;b=hb-16|0;hb=b;x[b+4>>2]=1;f=b,g=wc(16),x[f+8>>2]=g;c=Io(x[b+8>>2]);x[c>>2]=42728;f=Qm(yc(c)),g=42860,x[f>>2]=g;c=d+8|0;e=Ko(b);Jo(c,yc(e),e);Rm(b);hb=b+16|0;qg(a,c);de(c);hb=d+16|0;x[a+8>>2]=0;$d(a+12|0);return a}function v$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function uJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=qf(e);b:{c:{if((Eb(c)|0)==(d|0)){x[23420]=0;d=W(347,c|0,e|0,d|0)|0;e=x[23420];x[23420]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;Ub();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function tn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Zia(a,b,10,0);f=lb;e=Wia(d,f,246,0)+a|0;c=c-1|0;v[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function UC(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Gd(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Dn(c,a);if(x[b>>2]){Gc(b);a=x[b>>2];Kt(b);Ib(a);d=Fb(b),e=0,x[d>>2]=e;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Fb(c);d=Fb(b),e=x[a>>2],x[d>>2]=e;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Vf(c);hb=c+16|0}function naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=hb+-64|0;hb=c;d=c+40|0;Ef(d,a,32);a=x[c+40>>2];e=c+8|0;Qf(e,1,xe(d),a);x[23420]=0;R(210,c+24|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=c+24|0;Dc(b,a);xb(a);Oc(c+40|0);hb=c- -64|0;break a}a=P()|0;Oc(c+40|0);S(a|0);p()}}function fe(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Um(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;a:{if(!b){b=0;break a}d=b;b=G(b);wf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+x[c+8>>2]|0;e=e+(x[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=x[c>>2];b=x[c+4>>2]}x[a>>2]=d;x[a+4>>2]=b;x[a+8>>2]=f;x[a+12>>2]=e;hb=c+16|0}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a=FP(d,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[23420]=0;R(708,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=P()|0;Id(a);S(b|0);p()}Id(a);hb=d+16|0}function K7(a){a=a|0;var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){aa(6014,8916,88,7318);p()}hb=b+16|0;return a|0}function zs(a){var b=0,c=0,d=E(0);b=a+4232|0;c=y[b|0];if(c>>>0>=5){v[b|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-me(E(2),E(-E((b&255)+1|0))));break a}d=me(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function XB(a,b,c){var d=0,e=0,f=0;d=hb+-64|0;hb=d;e=d+40|0;Ef(e,a,c);a=x[d+40>>2];f=d+8|0;Qf(f,3,xe(e),a);x[23420]=0;R(210,d+24|0,f|0);e=x[23420];x[23420]=0;if((e|0)!=1){e=b;b=d+24|0;Dc(e,b);xb(b);Oc(d+40|0);hb=d- -64|0;return!c|(a|0)!=0}a=P()|0;Oc(d+40|0);S(a|0);p()}function Wv(a,b,c,d,e){var f=0,g=0;a:{f=hb+-64|0;hb=f;g=f+40|0;Ef(g,a,e);a=x[f+40>>2];e=f+8|0;Qf(e,d,xe(g),a);x[23420]=0;R(210,f+24|0,e|0);a=x[23420];x[23420]=0;if((a|0)!=1){fc(f,b,c);a=f+24|0;pl(f,a);xb(a);Oc(f+40|0);hb=f- -64|0;break a}a=P()|0;Oc(f+40|0);S(a|0);p()}}function AU(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=hb-16|0;hb=b;f=Kb(a,31),g=0,v[f|0]=g;v[b+15|0]=0;c=ii(a,$n(a),b+15|0);v[b+14|0]=0;c=oi(a,c);Ql(c+a|0,$n(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Kb(a,d);if((y[e|0]-127&255)>>>0<=160){v[e|0]=32}d=d+1|0;continue}break}hb=b+16|0}function pQ(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=Db(x[a>>2]);x[c+8>>2]=b;e=Db(x[a+4>>2]);while(1){a:{d=Pb(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Re(c+8|0)>>2];continue}break}hb=c+16|0;return d^1}function RC(a,b,c){var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}Ao(d+8|0,a,e);av(x[d+8>>2],x[d+12>>2],b,c);hb=d+16|0}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+8>>2]=b;a:{if(vc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!wd(b)){break a}x[23420]=0;R(434,a|0,c+8|0);a=x[23420];x[23420]=0;d=b;if((a|0)!=1){break a}a=P()|0;hg(c+8|0);S(a|0);p()}hg(c+8|0);hb=c+16|0;return d|0}function xE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=e+12|0;xc(c,d);xc(c,65535);f=z[e+12>>1];jg(a,f);c=0;while(1){if((c|0)==(f|0)){hb=e+16|0}else{d=y[b+c|0];g=nl(x[a>>2],x[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,w[g>>1]=h;c=c+1|0;continue}break}}function sj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Db(x[b>>2]);f=Db(x[b+4>>2]);e=hb-16|0;hb=e;x[e+8>>2]=d;while(1){a:{if(!Pb(d,f)){break a}if($T(c,x[d>>2],x[d+4>>2])){break a}d=x[um(e+8|0)>>2];continue}break}hb=e+16|0;if(uc(d,Db(x[b+4>>2]))){zh(a);return}so(a,d)}function dU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[_e(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[_e(d+13|0,d+12|0)|0]}hb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function Wo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function Saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=ff(a,c);ae(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!gd(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:bi(d,b);break c;default:break d}}QS(d,b,c)}d=f}af(a,d);hb=e+16|0}function E$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Mf(v[b|0]),e=x[x[a>>2]+52>>2],mb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=fk(b,1,c,x[a+32>>2])}return c|0}function wh(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function rA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=nm(a);e=Bd(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=rd(a);He(d+e|0,b,c);b=c+e|0;Tt(a,b);v[f+15|0]=0;sd(b+d|0,f+15|0);break a}Lt(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function _1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;x[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Vb(d+8|0,x[a>>2]);x[23420]=0;Q(1026,d+24|0,c|0)|0;e=x[23420];x[23420]=0;if((e|0)!=1){xb(c);a=a+4|0;continue}break}a=P()|0;xb(c);S(a|0);p()}hb=d+32|0}function d0(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){on(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=Mf(v[a|0])}return d|0}function UN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=hb-16|0;hb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Ic(d);Yf(b,a,Eb(d)+a|0);break c}NN(e,c,d);x[23420]=0;U(43,a|0,b|0,e|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Jc(e)}hb=e+16|0;break a}a=P()|0;Jc(e);S(a|0);p()}}function Kr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Nw(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function iD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=rd(c);Yf(b,a,Bd(x[c+4>>2],y[c+11|0])+a|0);break c}GL(d,c);x[23420]=0;U(43,a|0,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Jc(d)}hb=d+16|0;break a}a=P()|0;Jc(d);S(a|0);p()}}function dT(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;lb=a;return b}function vC(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;ad(d,a);x[23420]=0;a=T(18,d|0)|0;d=x[23420];x[23420]=0;a:{if((d|0)==1){break a}x[23420]=0;a=Q(19,a|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}Zb(c+8|0);hb=c+16|0;return a}a=P()|0;Zb(c+8|0);S(a|0);p()}function sz(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a=Fz(d,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[23420]=0;R(708,b|0,c|0);f=x[23420];x[23420]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=P()|0;kc(a);S(b|0);p()}kc(a);hb=d+16|0}function hO(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=93688;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function Hk(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=_r(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Bj(a,b){var c=0,d=0,e=0,f=0,g=0;g=x[a+8>>2];while(1){if((b|0)!=(e|0)){d=x[a>>2];if(d){c=x[a+4>>2]}else{x[a>>2]=8;c=g;d=x[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;x[a+12>>2]=c}d=8;c=y[c|0]}x[a>>2]=d-1;x[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function kA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=hb-1024|0;hb=e;d=hb-16|0;hb=d;hA(d+8|0,e);f=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){$b(a,x[d+12>>2])}hb=d+16|0;if((f|0)==(g|0)){h=iA(e,c)>>>0<=b>>>0}hb=e+1024|0;return h}function _da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-208|0;hb=b;d=-1;c=hb-16|0;hb=c;jQ(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){iQ(b)}if(a){d=kQ(b)}hb=b+208|0;return d|0}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-160|0;hb=b;d=-1;c=hb-16|0;hb=c;nT(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){mT(b)}if(a){d=oT(b)}hb=b+160|0;return d|0}function C7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=jt(a+8|0,d);x[23420]=0;Q(869,a+20|0,c|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=P()|0;Sb(b);S(a|0);p()}function tJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Jb(a);d=qf(b);e=Eb(c);x[23420]=0;X(1015,a|0,b|0,d|0,d+e|0);b=x[23420];x[23420]=0;a:{if((b|0)!=1){b=Ic(c);x[23420]=0;W(1016,a|0,b|0,e|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break a}}b=P()|0;xb(a);S(b|0);p()}}function rG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=qe(b,c);if(e>>>0<1073741808){b:{if(Gr(e)){we(d,e);break b}f=Hl(e)+1|0;g=qi(f);xd(d,g);Af(d,f);Sd(d,e);d=g}while(1){if((b|0)!=(c|0)){xd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}xd(d,0);break a}Bf();p()}return a}function i8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0),f=0,g=E(0);d=hb-16|0;hb=d;f=d,g=E(E(mb[x[x[a>>2]+48>>2]](a,b))+c),B[f+12>>2]=g;c=E(0);e=B[d+12>>2];a:{if(!(e<E(0))){c=E(1);if(!(e>E(1))){break a}}B[d+12>>2]=c}mb[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);hb=d+16|0}function ez(a,b,c,d){var e=0,f=0,g=0;e=Vd(a);a:{if(e){f=ic(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Vk(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Vk(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ic(a);f=a}x[b>>2]=a;return f}function GM(a,b,c,d){var e=0,f=0,g=0;v[c+851|0]=y[c+851|0]|64;e=a?y[c+813|0]:0;g=(d|0)<0?e:0-e|0;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(F(f)<2147483648){e=~~f;break a}e=-2147483648}x[c+852>>2]=g+(e+x[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;v[c+813|0]=(a^b)-a}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+8>>2];a:{if(f>>>0<=c>>>0){c=x[d>>2];b=0;break a}x[e+12>>2]=f-c;x[e+8>>2]=x[d+4>>2];c=x[b+4>>2]+c|0;f=c;b=x[Hb(e+12|0,e+8|0)>>2];g=c+b|0;c=x[d>>2];Hi(f,g,c)}hc(a,c,b);hb=e+16|0}function Hy(a,b,c,d){var e=0,f=0,g=0;e=Vd(a);a:{if(e){f=ic(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(Kn(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Kn(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ic(a);f=a}x[b>>2]=a;return f}function Gp(a,b,c,d){var e=0,f=0,g=0;a:{e=Xk(a,b);if((e|0)==255){break a}g=x[a>>2];if(Uj(g)){break a}f=Hd(a+318|0,e);e=FO(e);if(v[Kb(f,10)|0]&1|d){Sg(g,x[a+4>>2],b,e- -64|0,EO(c,y[Kb(f,2)|0]))}if(d){break a}Sg(x[a>>2],x[a+4>>2],b,e+67|0,EO(c,y[Kb(f,3)|0]))}}function rE(a,b,c,d){var e=0,f=0;a:{e=hb+-64|0;hb=e;f=e+40|0;Ef(f,a,d);a=x[e+40>>2];d=e+8|0;Qf(d,c,xe(f),a);x[23420]=0;R(210,e+24|0,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=e+24|0;ze(b,a);xb(a);Oc(e+40|0);hb=e- -64|0;break a}a=P()|0;Oc(e+40|0);S(a|0);p()}}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;Df(b);v[c+15|0]=0;a:{if(!Fh(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(Fh(a,c+14|0)){wp(b,v[c+14|0]);e=e+1|0;continue}break}d=0}hb=c+16|0;return d|0}function D6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);x[a>>2]=46468;b=a+4208|0;e=Cb(b,0),f=1017370378,x[e>>2]=f;e=Cb(b,1),f=0,x[e>>2]=f;x[23420]=0;R(853,a+44|0,2);b=x[23420];x[23420]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;vf(a);S(b|0);p()}function CV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=hb-48|0;hb=b;d=-1;c=hb-16|0;hb=c;sC(c+8|0,b);e=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(e|0)==(f|0);if(!a){rC(b)}if(a){d=tC(b)}hb=b+48|0;return d|0}function s$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function V1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=hb-16|0;hb=c;x[c+4>>2]=1;e=c,f=wc(52),x[e+8>>2]=f;d=x[c+8>>2];x[23420]=0;Q(1033,d|0,b|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){b=a;a=Ko(c);Jo(b,yc(a),a);Rm(c);hb=c+16|0;break a}a=P()|0;Rm(c);S(a|0);p()}}function Qe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=hb-16|0;hb=e;a:{if(b>>>0<4294967280){b:{if(jq(b)){we(d,b);break b}f=wi(b)+1|0;g=wc(f);xd(d,g);Af(d,f);Sd(d,b);d=g}c=eq(d,b,c);v[e+15|0]=0;sd(b+c|0,e+15|0);hb=e+16|0;break a}Bf();p()}return a|0}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;v[c+40|0]=b;b=c+40|0;Mq(c+16|0,b);d=x[c+16>>2];Mq(c+8|0,b);b=Yf(c+24|0,d,x[c+8>>2]+1|0);x[23420]=0;Q(711,a|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=P()|0;xb(b);S(a|0);p()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;w[c+40>>1]=b;b=c+40|0;sl(c+16|0,b);d=x[c+16>>2];sl(c+8|0,b);b=Yf(c+24|0,d,x[c+8>>2]+2|0);x[23420]=0;Q(711,a|0,b|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){xb(b);hb=c+48|0;return}a=P()|0;xb(b);S(a|0);p()}function BU(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;Df(b);e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,2,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;Ac(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;return}a=P()|0;Oc(d+40|0);S(a|0);p()}function mC(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;a=Pu(c,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[23420]=0;Y(216,b|0);e=x[23420];x[23420]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=P()|0;kc(a);S(b|0);p()}kc(a);hb=c+16|0}function Nw(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){mb[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function fU(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[_e(d+15|0,d+14|0)|0]}a=e;hb=d+16|0;return a&255}function Oea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;b=4;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Lm(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function s2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[b+8>>2];e=x[b+4>>2];f=x[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=x[(a<<2)+f>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function AA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jS(a,b);$c(a,ac(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);iS(a,d);a:{b=ac(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!$c(a,b)){break a}CA(a,c);return}Tb(c,0,80)}function qf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!y[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}FC(a,d,c)}function G1(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;if(!y[a+8|0]){Ki(a+12|0,x[a+4>>2]);ke(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;mb[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}hb=b+32|0;return x[a+12>>2]}function ZB(a,b,c){var d=0,e=0;d=hb+-64|0;hb=d;e=d+40|0;Ef(e,a,c);a=x[d+40>>2];c=d+8|0;Qf(c,3,xe(e),a);x[23420]=0;R(210,d+24|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){a=d+24|0;ym(b,a);xb(a);Oc(d+40|0);hb=d- -64|0;return}a=P()|0;Oc(d+40|0);S(a|0);p()}function w7(a,b){a=a|0;b=b|0;var c=0,d=0;b=hb-16|0;hb=b;a:{b:{d=x[a+20>>2];c=x[d+4>>2];if((Wc(c,x[d+8>>2])|0)!=7){break b}if(Ob(c,9458,4)){break b}c=Db(c);d=Db(x[x[a+20>>2]+8>>2]);uo(b+8|0,a+4228|0);ah(c,d,x[b+8>>2]);break a}Nx(a,a)}zs(a);hb=b+16|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;ad(g,d);x[23420]=0;b=T(1086,g|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(g);VF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;Zb(g);S(a|0);p()}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;ad(g,d);x[23420]=0;b=T(1086,g|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(g);UF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;Zb(g);S(a|0);p()}function jE(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;x[b>>2]=0;v[c+15|0]=0;Fh(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){hb=c+16|0}else{v[c+15|0]=0;Fh(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function kQ(a){var b=0;a:{if(Ob(a,14840,4)){break a}if(Lb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Lb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Lb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Lb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function zH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=zH(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function rr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=hb-16|0;hb=f;d=Sc(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=sc(a);He(d+e|0,b,c);b=c+e|0;Kh(a,b);v[f+15|0]=0;sd(b+d|0,f+15|0);break a}Xo(a,d,(c+e|0)-d|0,e,e,0,c,b)}hb=f+16|0;return a|0}function _F(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(Gr(b)){we(d,b);break b}e=Hl(b)+1|0;f=qi(e);xd(d,f);Af(d,e);Sd(d,b);d=f}e=b;f=d;while(1){x[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}xd((b<<2)+d|0,0);break a}Bf();p()}return a}function B_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;ad(g,d);x[23420]=0;b=T(18,g|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(g);YF(a,f+24|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;Zb(g);S(a|0);p()}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=hb-16|0;hb=g;x[g+8>>2]=b;ad(g,d);x[23420]=0;b=T(18,g|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(g);XF(a,f+16|0,g+8|0,c,e,b);hb=g+16|0;return x[g+8>>2]}a=P()|0;Zb(g);S(a|0);p()}function XD(a,b,c,d){var e=0,f=0,g=0;a:{if((c|0)==(d|0)){break a}b:{d=d-c|0;if((d|0)>(b-a|0)){break b}f=1-d|0;g=y[c|0];while(1){e=b-a|0;if((d|0)>(e|0)){break b}a=Tp(a,f+e|0,g);if(!a){break b}if(!Tl(a,c,d)){break a}a=a+1|0;continue}}a=b}return a}function VO(a,b,c){var d=0,e=0,f=0,g=0;f=x[b+4>>2];e=b+4|0;Jp(x[a>>2],c,e);g=x[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){wj(x[d>>2],z[c>>1]);x[d>>2]=x[d>>2]+2;c=c+2|0;continue}break}nc(a,e);nc(a+4|0,d);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2];return f}function T9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{if(!Se(a)){c=1;d=y[a+11|0];if((d|0)==1){break c}we(a,d+1|0);c=a;break a}c=ll(a)-1|0;d=x[a+4>>2];if((c|0)!=(d|0)){break b}}JF(a,c,1,c,c);d=c}c=x[a>>2];Sd(a,d+1|0)}a=(d<<2)+c|0;xd(a,b);xd(a+4|0,0)}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;f=ff(a,c);ae(e,x[a+28>>2]);a:{b:{if(!f){c=-1;if(!gd(a,5)){break b}break a}c=x[f+8>>2]}d=x[a+28>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){bk(d,b);break c}pG(d,b,c)}d=f}af(a,d);hb=e+16|0}function GT(a,b,c){var d=0,e=0,f=0,g=0;f=x[b+4>>2];e=b+4|0;Jp(x[a>>2],c,e);g=x[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){tk(x[d>>2],y[c|0]);x[d>>2]=x[d>>2]+1;c=c+1|0;continue}break}nc(a,e);nc(a+4|0,d);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2];return f}function rO(a){var b=0,c=0,d=0,e=0,f=0;b=hb-16|0;hb=b;c=a;d=x[a>>2];f=fh(d,x[a+4>>2]);a=Db(d);x[b+8>>2]=a;e=+(f>>>0);c=Db(x[c+4>>2]);while(1){if(Pb(a,c)){C[a>>3]=C[a>>3]/e;C[a+8>>3]=C[a+8>>3]/e;a=x[co(b+8|0)>>2];continue}else{hb=b+16|0}break}}function rD(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function mi(a){var b=0,c=0,d=0,e=0;b=Ee(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=Ee(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=(e|0)<0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function SB(a){var b=0,c=0,d=0,e=0;b=y[a+2|0];c=b+(y[a+5|0]|y[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=y[a+3|0]|y[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;lb=a;return b}function jA(a,b,c){var d=0;d=hb-16|0;hb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=Db(x[a>>2]);c=Db(x[a+4>>2]);a=hb-16|0;hb=a;x[a+8>>2]=b;while(1){if(Pb(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Re(a+8|0)>>2];continue}break}hb=a+16|0;hb=d+16|0}function Vo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Ub(){var a=0;a=x[23293];x[23420]=0;Z(a|0);a=x[23420];x[23420]=0;a:{if((a|0)!=1){x[23420]=0;Z(1176);a=x[23420];x[23420]=0;if((a|0)!=1){break a}}_(V(0)|0)|0;x[23420]=0;Z(1176);a=x[23420];x[23420]=0;if((a|0)!=1){break a}V(0)|0;Ub()}p()}function FC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=hb-16|0;hb=d;b:{c:{if(!b){b=a;a=Ic(c);Yf(b,a,Eb(c)+a|0);break c}NN(d,b,c);x[23420]=0;R(49,a|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}Jc(d)}hb=d+16|0;break a}a=P()|0;Jc(d);S(a|0);p()}}function wN(a,b){var c=0,d=0;d=hb-16|0;hb=d;c=x[a+104>>2];a:{if(!c){break a}c=x[c>>2];if(!c){break a}x[a+76>>2]=c;x[a+88>>2]=x[a+88>>2]&-131|128;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Hb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}hb=d+16|0}function zK(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function bD(a){var b=0,c=0;a:{if(Ob(a,14021,4)){break a}if(Ob(a+8|0,13942,4)){break a}b=ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=(ac(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function ZF(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;g=gc(e+8|0,x[x[b>>2]-12>>2]+b|0),h=b,x[g+4>>2]=h;f=c;zk(x[e+12>>2],c,d);b=hb-16|0;hb=b;x[b+12>>2]=x[x[e+12>>2]+4>>2];x[b+8>>2]=0;c=x[Le(b+8|0,b+12|0)>>2];hb=b+16|0;hc(a,f,c);hb=e+16|0}function tda(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=fc(b+8|0,b+24|0,6);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(Ob(b+24|0,3856,6)){break a}$b(a,6);d=1}hb=b+32|0;return d|0}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;ad(a,d);x[23420]=0;b=T(1086,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(a);TF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=P()|0;Zb(a);S(b|0);p()}function sQ(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=qQ(a+20|0)}return c}function sE(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;x[e+12>>2]=c;c=e+12|0;xc(c,d);xc(c,65535);d=z[e+12>>1];jg(a,d);c=0;while(1){if((c|0)==(d|0)){hb=e+16|0}else{f=y[b+c|0];g=nl(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;KA(e,c);Ui(d+8|0,e);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Oo(e,c);Ui(d+8|0,e);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function gfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;kp(e,c);Ui(d+8|0,e);x[23420]=0;X(282,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){Sb(d+16|0);hb=d+32|0;break a}a=P()|0;Sb(d+16|0);S(a|0);p()}}function ce(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;tq(e,c);Ui(d+8|0,e);x[23420]=0;X(282,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){Sb(d+16|0);hb=d+32|0;break a}a=P()|0;Sb(d+16|0);S(a|0);p()}}function PN(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function PA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Qb(a+8|0);x[23420]=0;d=T(190,b|0)|0;e=x[23420];x[23420]=0;b:{if((e|0)==1){break b}x[23420]=0;U(232,a|0,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)==1){break b}break a}a=P()|0;dc(c);S(a|0);p()}}function DM(a,b){a=zM(a);zM(a+368680|0);if(b){yM(a,1);return}if(!y[462552]){DM(93848,1);v[462552]=1}Vn(224960,290496,a+131112|0);Vn(290496,356032,a+196648|0);Vn(356032,421568,a+262184|0);Vn(93872,224960,a+24|0);pc(a+327720|0,421568,40960)}function Aha(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;v[b+30|0]=0;w[b+28>>1]=0;c=fc(b+8|0,b+28|0,3);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=3){break a}if(Ob(b+28|0,14593,3)){break a}$b(a,3);d=1}hb=b+32|0;return d|0}function uv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;Lg(e+8|0,b,c);x[23420]=0;Na(159,a|0,x[e+8>>2],x[e+12>>2]);b=x[23420];x[23420]=0;if((b|0)!=1){x[a+8>>2]=0;qg(a+12|0,d);de(d);hb=e+16|0;return a|0}a=P()|0;de(d);S(a|0);p()}function qia(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!pB(a,b+16|0)){break a}c=0;if(!RT(b+16|0)){break a}if(!Ob(b+16|0,14007,4)){c=-1;if(!cd(a,4)){break a}}c=-1;if(!Aj(a,b+8|0)){break a}c=!Ob(b+8|0,13983,4)}hb=b+32|0;return c|0}function kU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;LB(e,c);Ui(d+8|0,e);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function SD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Xm(e,c);Ui(d+8|0,e);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function Pv(a,b){var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;w[b>>1]=0;v[c+15|0]=0;Fh(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){hb=c+16|0}else{v[c+15|0]=0;Fh(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function AV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=hb-32|0;hb=d;e=d+16|0;Mu(e,c);Ui(d+8|0,e);x[23420]=0;X(102,a|0,b|0,x[d+8>>2],x[d+12>>2]);a=x[23420];x[23420]=0;if((a|0)!=1){cc(d+16|0);hb=d+32|0;break a}a=P()|0;cc(d+16|0);S(a|0);p()}}function z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=hb-16|0;hb=a;x[a+8>>2]=b;ad(a,d);x[23420]=0;b=T(18,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){Zb(a);WF(f+20|0,a+8|0,c,e,b);hb=a+16|0;return x[a+8>>2]}b=P()|0;Zb(a);S(b|0);p()}function sG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;if(d>>>0<4294967280){a:{if(jq(d)){we(a,c);break a}f=wi(d)+1|0;d=wc(f);xd(a,d);Af(a,f);Sd(a,c);a=d}a=He(a,b,c);v[e+15|0]=0;sd(a+c|0,e+15|0);hb=e+16|0;return}Bf();p()}function dN(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;kv(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function vN(a,b){var c=0,d=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c){break a}d=x[c>>2];if(!d){break a}x[a+76>>2]=d;x[a>>2]=0;x[a+4>>2]=d-1;c=x[a+88>>2];x[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}x[a+84>>2]=d;x[a+80>>2]=0}}function ci(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function t2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[b+8>>2];d=x[b+4>>2];e=x[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Rp(e,a,b),g=0,x[f>>2]=g;b=b+1|0;continue}}break}}function pN(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=c&15;if(e){v[b+824|0]=e}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;Ab(d+8|0,a+1074312|0,80);if(!(!e|!Bb(x[x[d+8>>2]>>2],x[d+12>>2]))){v[b+824|0]=y[b+824|0]<<2}hb=d+16|0}function Oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=hb-16|0;hb=c;while(1){a:{d=x[a>>2];if(vc(d,x[a+4>>2])>>>0>e>>>0){Om(c,x[Cb(d,e)>>2]+40|0);d=$p(c,b);yb(c);if(!d){break a}f=x[Cb(x[a>>2],e)>>2]}hb=c+16|0;return f|0}e=e+1|0;continue}}function wO(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){nO(a,b);d=hb-16|0;hb=d;c=Ro(d,a,b);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){kc(c);hb=d+16|0}else{Wk(b,0,0);b=b+16|0;x[c+4>>2]=b;continue}break}}return a}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;IA(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,4896)}return a|0}function r7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Ob(b,9458,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;zs(a)}}function c8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Ob(b,9458,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;Es(a)}}function Ti(a,b,c){c=x[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-32|0;hb=d;Mk(d,c);c=d+16|0;x[c>>2]=b;Rc(c+4|0,d);x[23420]=0;R(1009,a+4|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){ps(d+16|0);xb(d);hb=d+32|0;return}a=P()|0;ps(d+16|0);xb(d);S(a|0);p()}function Ef(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Qb(a+8|0);x[23420]=0;U(232,a|0,b|0,c|0);c=x[23420];x[23420]=0;a:{if((c|0)!=1){a=x[a>>2];x[23420]=0;Q(176,b|0,a|0)|0;a=x[23420];x[23420]=0;if((a|0)!=1){break a}}a=P()|0;dc(d);S(a|0);p()}}function M$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((mb[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=fk(b,4,c,x[a+32>>2])}return c|0}function dM(a){var b=0,c=0,d=0;c=hb-544|0;hb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Jz(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}pc(b+112|0,a,538);b=b+872|0;continue}}hb=c+544|0}function Jz(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;x[a>>2]=0;x[a+4>>2]=0;e=a,f=RP(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=lb;return a}function Iy(a,b,c){var d=0,e=0;d=Vd(a);a:{if(d){e=ic(a);while(1){a=d;d=y[a+16|0];if(Ln(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!Ln(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ic(a);e=a}x[b>>2]=a;return e}function zV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Ou(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,65)}return a|0}function WO(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Gi(e,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){kc(g);iB(b,f,h);hb=e+16|0}else{wj(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function UD(){var a=0,b=0,c=0;b=hb-16|0;hb=b;a=Vb(b,14812);a:{if(!Eb(a)){break a}c=1;if((sg(a,14489)|0)!=-1){break a}if((sg(a,16618)|0)!=-1){break a}if((sg(a,13555)|0)!=-1){break a}c=(sg(a,13598)|0)!=-1}xb(a);hb=b+16|0;return c|0}function OD(a){var b=0;if(!(Ob(a,13199,8)|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function Fea(a,b){a=a|0;b=b|0;var c=0;b=hb-32|0;hb=b;c=-1;a:{if(!pB(a,b+16|0)){break a}c=0;if(!WQ(b+16|0)){break a}c=-1;if(!Aj(a,b+8|0)){break a}c=0;if(!x[b+12>>2]){break a}a=x[b+8>>2];c=(a&2139062143)==(a|0)}hb=b+32|0;return c|0}function nQ(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=x[a+4>>2];f=e>>>8|0;d=x[a>>2];e=(e&255)<<24|d>>>8;d=(((d^y[b|0])&255)<<3)+21496|0;g=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function bia(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Iq((a<<1)+b|0);a=a+1|0;continue}break}break a}ou(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function aV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){ug(a+b|0);a=a+1|0;continue}break}break a}hc(c+8|0,b,120);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function _f(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[Cb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function HT(a,b,c,d){var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Bl(e,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){kc(g);iB(b,f,h);hb=e+16|0}else{tk(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function tB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=ik(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=Pf(e,c);if(!Pb(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return($g(a,d&65535,b)?d:-1)&65535}function pfa(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;w[b+30>>1]=0;c=fc(b+8|0,b+30|0,2);mc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=2){break a}if(Ob(b+30|0,13463,2)){break a}$b(a,2);d=1}hb=b+32|0;return d|0}function TL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Hc(Xia(Wia(d,d>>31,g,h),lb,256,0),lb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Cq(a){var b=0,c=0,d=0,e=0;c=hb-16|0;hb=c;b=hb-16|0;hb=b;Mq(b+8|0,c+15|0);d=x[b+12>>2];ld(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){cd(a,x[b+12>>2])}hb=b+16|0;hb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;EA(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){FA(b)}return a|0}function qu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=hb-16|0;hb=f;if(b){e=Sc(a);d=Eb(a);g=d+b|0;if(e-d>>>0<b>>>0){Sl(a,e,g-e|0,d,d,0,0)}e=d;d=sc(a);eq(e+d|0,b,c);Kh(a,g);v[f+15|0]=0;sd(d+g|0,f+15|0)}hb=f+16|0;return a|0}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-32|0;hb=d;e=of(x[b>>2],x[b+4>>2]);c=BP(d+8|0,c);x[23420]=0;X(680,a|0,b|0,e-1&65535,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){Je(c);hb=d+32|0;return}a=P()|0;Je(c);S(a|0);p()}function Xia(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Zia(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;lb=(g^lb)-((a>>>0<f>>>0)+g|0)|0;return b}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;AO(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){jz(b)}return a|0}function CN(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[Yc(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=Tz(c&255),x[e+44>>2]=f}hb=d+16|0}function qd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=hb-16|0;hb=e;g=x[b+8>>2];f=x[b>>2];x[e+8>>2]=c;x[e+12>>2]=d;h=x[x[f>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[h|0](a,f,g,e);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];hb=e+16|0}function qC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;sC(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){rC(b)}return a|0}function Ku(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;cC(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){bC(b)}return a|0}function Et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;XQ(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){YQ(b)}return a|0}function Uz(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));lb=e|(d&65280|c&255);return a}function Os(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43820;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43672;break a;case 2:c=43668;break a;case 1:break b;case 0:break c}}c=43664;break a}c=43660}x[a>>2]=x[c>>2]}function Jd(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function ZD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=hb-16|0;hb=d;c=nm(a);e=Bd(x[a+4>>2],y[a+11|0]);f=e+1|0;if((c|0)==(e|0)){_x(a,c,f-c|0,c,c,0)}c=rd(a);eq(c+e|0,1,b);Tt(a,f);v[d+15|0]=0;sd(c+f|0,d+15|0);hb=d+16|0;return a|0}function Ep(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[b-8>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-fe(f*C[Pe(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=Cb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[a+480180>>2]=b;Pz(c,cq(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;Os(a+8|0,cq(a));hb=c+16|0}function wE(a,b,c,d,e){var f=0;f=hb-32|0;hb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=MB(f+24|0,f+8|0);b=f+16|0;a=bE(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;hb=f+32|0;return x[a>>2]}function uN(a,b,c,d){var e=0;a=Xc(Qn(a,z[c+70>>1],x[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=Rk(c)-x[c+16>>2]|0;if((d|0)<2){break a}e=a;a=w[(D(b,872)+c|0)+1390>>1];a=Xc(((e-a|0)/(d|0)|0)+a|0)}w[(D(b,872)+c|0)+1390>>1]=a}function mJ(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){rl(a,b);d=hb-16|0;hb=d;b=Bl(d,a,b);c=x[b+4>>2];e=x[b+8>>2];while(1){if((c|0)==(e|0)){kc(b);hb=d+16|0}else{c=c+1|0;x[b+4>>2]=c;continue}break}}return a}function _ea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){ug(a+b|0);a=a+1|0;continue}break}break a}hB(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function Dt(a,b){var c=0,d=0,e=0;if(x[a>>2]){zU(a);c=x[a>>2];zB(a);Ib(c);d=Fb(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Fb(b);d=Fb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function uQ(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+32622>>1]-z[(c<<1)+32622>>1]|0)/5;a=y[Wb(d+15|0,d+14|0)|0]}hb=d+16|0;return a&255}function l7(a){a=a|0;var b=0;mb[x[x[a>>2]+128>>2]](a);Gx(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=mb[x[x[a>>2]+192>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}
function jZ(a){a=a|0;if(y[467280]){return x[116819]}if(!y[468440]){a=468416;while(1){a=Jb(a)+12|0;if((a|0)!=468440){continue}break}v[468440]=1}md(468416,88592);md(468428,88604);v[467280]=1;x[116819]=468416;return 468416}function _r(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!Zw(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=Ne(a)}return b}aa(15532,13048,1578,5390);p()}function ZM(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Fb(a);c=ic(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=ic(b);x[b>>2]=c;x[c>>2]=0;e=Fb(b),f=0,x[e>>2]=f}return a}function XY(a){a=a|0;if(y[467272]){return x[116817]}if(!y[468408]){a=468384;while(1){a=Jb(a)+12|0;if((a|0)!=468408){continue}break}v[468408]=1}id(468384,13705);id(468396,13684);v[467272]=1;x[116817]=468384;return 468384}function $v(a,b,c,d,e){var f=0,g=0,h=0;f=hb-16|0;hb=f;g=qg(f+8|0,d);x[23420]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=wg(e,a,b,c,f);b=x[23420];x[23420]=0;if((b|0)!=1){de(d);hb=f+16|0;return a}a=P()|0;de(d);S(a|0);p()}function rS(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function ks(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=hb-16|0;hb=c;d=x[b>>2];b=vc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){hb=c+16|0}else{x[c+8>>2]=0;e=Bc(c+8|0);f=Cb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function VM(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function Ij(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);e=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){$b(a,x[d+12>>2])}hb=d+16|0;a=(e|0)==(f|0);if(!a){Tb(b,0,c)}return a}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=hb-16|0;hb=d;c=-1;a:{if(!Aj(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(Bm(8880)|0)&e>>>0>255&e>>>0<260)){break a}c=Ge(a,b,e>>>0<259?80:76,0)}hb=d+16|0;return c|0}function JO(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function Ip(a,b,c){var d=0;d=hb-16|0;hb=d;Ab(d+8|0,c+1074312|0,102);a:{if(!Bb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b;hb=d+16|0}function pz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:OO(a,b);return;default:break a}}d=hb-32|0;hb=d;x[d+28>>2]=c;w[d+24>>1]=0;x[d+12>>2]=2;wr(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);w[b>>1]=z[d+24>>1];hb=d+32|0}function eT(a){var b=0;a:{b:{if(Ob(a,13682,4)){if(Ob(a,16099,4)){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function Wia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;lb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function Ty(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!Uc(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[bc(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function cL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Jf(a+12|0,d);if(b){if(b>>>0>=2097152){ig();p()}d=wc(b<<11)}else{d=0}x[a>>2]=d;c=d+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<11)|0,x[e>>2]=f;return a|0}function Xw(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!Zr(a)){break a}if(!(v[a+1375|0]&1)){continue}break}ec(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function DH(a,b){var c=0,d=0,e=0;c=hb-256|0;hb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;pc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;pc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}hb=c+256|0}function oO(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function Do(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;if(c>>>0<4294967280){a:{if(jq(c)){we(a,c);break a}e=wi(c)+1|0;f=wc(e);xd(a,f);Af(a,e);Sd(a,c);a=f}a=He(a,b,c);v[d+15|0]=0;sd(a+c|0,d+15|0);hb=d+16|0;return}Bf();p()}function yp(a,b){a=pc(a,b,88);x[a+88>>2]=x[b+88>>2];pc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];pc(a+672|0,b+672|0,52);Ly(a+724|0,b+724|0);Ly(a+732|0,b+732|0);Ly(a+740|0,b+740|0);pc(a+748|0,b+748|0,123);return a}function un(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function iP(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function c_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fn(a);e=Eb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=sc(a);di(d+(e<<2)|0,b,c);b=c+e|0;Kh(a,b);xd(d+(b<<2)|0,0);return a|0}gF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Vl(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((vc(e,x[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=B[Cb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function MS(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;x[d>>2]=x[a+8>>2];e=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+e;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Yt(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}Id(d);hb=d+16|0}function kk(a){xc(a+16|0,x[a>>2]);xc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function jS(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;lS(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){kS(b)}return a}function cB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;tT(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){uT(b)}return a}function _O(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=Gi(e,a,d);d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if(Pb(b,c)){wj(x[a+4>>2],z[b>>1]);b=Re(d+8|0);x[a+4>>2]=x[a+4>>2]+2;b=x[b>>2];continue}break}hb=d+16|0;kc(a);hb=e+16|0}function MC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Nb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ng(a,c+15|0);d=v[c+15|0]}hb=c+16|0;a=d;break a}aa(11081,8981,136,14045);p()}return a}function w9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(ti(a)>>>0<b>>>0){if(hh(1073741823)>>>0<b>>>0){break a}d=Fb(a);e=a;a=bg(c+8|0,b,vc(x[a>>2],x[a+4>>2]),d);zd(e,a);ag(a)}hb=c+32|0;return}Tc();p()}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(az(a)>>>0<b>>>0){if(hh(613566756)>>>0<b>>>0){break a}d=Fb(a);e=a;a=SN(c+8|0,b,$y(x[a>>2],x[a+4>>2]),d);RN(e,a);QN(a)}hb=c+32|0;return}Tc();p()}function ny(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;ZL(a+24648|0);dM(a)}function eS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Gm(a)>>>0<b>>>0){if(hh(2147483647)>>>0<b>>>0){break a}d=Fb(a);e=a;a=xj(c+8|0,b,Mc(x[a>>2],x[a+4>>2]),d);zd(e,a);Fi(a)}hb=c+32|0;return}Tc();p()}function XG(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=mb[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!qn(b)){break a}x[a>>2]=0}return a|0}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Fj(a)>>>0<b>>>0){if(hh(357913941)>>>0<b>>>0){break a}d=Fb(a);e=a;a=nk(c+8|0,b,vd(x[a>>2],x[a+4>>2]),d);eQ(e,a);dQ(a)}hb=c+32|0;return}Tc();p()}function Ht(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;jR(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){$z(b)}}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=Gg(x[b>>2],x[b+4>>2]);if(c){hz(a,c);d=hb-16|0;hb=d;e=x[b>>2];f=x[b+4>>2];b=_q(d,a,c);Zt(e,f,b+4|0);kc(b);hb=d+16|0}return a|0}function Faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Tm(a)>>>0<b>>>0){if(hh(536870911)>>>0<b>>>0){break a}d=Fb(a);e=a;a=ar(c+8|0,b,Gg(x[a>>2],x[a+4>>2]),d);zd(e,a);$q(a)}hb=c+32|0;return}Tc();p()}function y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(Fj(a)>>>0<b>>>0){if(hh(357913941)>>>0<b>>>0){break a}d=Fb(a);e=a;a=nk(c+8|0,b,vd(x[a>>2],x[a+4>>2]),d);lr(e,a);LN(a)}hb=c+32|0;return}Tc();p()}function py(a,b){var c=0;c=x[b+24>>2];x[a+24628>>2]=c?c>>>0>=512?512:c:1;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}pc(a+24604|0,b,40);_L(a,c)}function p9(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;a:{if(!Aj(a,b+8|0)){break a}c=0;if(!HL(x[b+8>>2],x[b+12>>2])){break a}a=wQ(a,b);if(!a){vm(b)}c=-1;if(!a){break a}c=FL(x[b>>2])}a=c;hb=b+16|0;return a|0}function nD(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;mv(x[d>>2]-36|0,c);x[d>>2]=x[d>>2]-36;continue}break}nc(a,d);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function lr(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;Qo(x[d>>2]-12|0,c);x[d>>2]=x[d>>2]-12;continue}break}nc(a,d);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function dw(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function dB(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;gB(x[d>>2]-20|0,c);x[d>>2]=x[d>>2]-20;continue}break}nc(a,d);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);ae(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!gd(a,5)){break b}break a}d=x[c+8>>2]}pz(x[a+28>>2],b,d);f=c}a=af(a,f);hb=e+16|0;return a|0}function T7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;a=Oj(a);if(a){d=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=d;e=x[x[a>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=d;a=mb[e|0](a,c)|0}else{a=1}hb=c+16|0;return a|0}function PO(a,b){var c=0,d=0,e=0;e=x[a>>2];c=x[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;rz(x[d>>2]-32|0,c);x[d>>2]=x[d>>2]-32;continue}break}nc(a,d);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function iA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=CD(a);a:while(1){if((a|0)!=(e|0)){f=ud(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[Kb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=hb-16|0;hb=f;c=ff(a,c);ae(f,x[a+28>>2]);a:{b:{if(!c){e=-1;if(!gd(a,5)){break b}break a}e=x[c+8>>2]}mb[d|0](x[a+28>>2],b,e);g=c}af(a,g);hb=f+16|0}function UV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!cD(a,c+8|0)){break a}d=0;if(!bD(c+8|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<ac(x[c+12>>2])-8>>>0){break a}}d=1}hb=c+48|0;return d|0}function RP(a){a=a*4294967296;if(F(a)<0x8000000000000000){lb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}lb=-2147483648;return 0}function Jv(a,b,c){var d=0,e=0;d=rd(a);a=Bd(x[a+4>>2],y[a+11|0]);e=rd(b);b=Bd(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=XD(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function yd(a,b){var c=0,d=0;c=hb-16|0;hb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Nb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ng(a,c+15|0);d=y[c+15|0]}hb=c+16|0;break a}aa(11081,8981,136,14045);p()}return d}function SM(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){ry(d,x[c+4>>2],x[c+8>>2])}pc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Du(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function Oi(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);e=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){$b(a,x[d+12>>2])}hb=d+16|0;if((e|0)!=(f|0)){Tb(b,0,c)}}function Gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Qb(a);d=gg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[23420]=0;R(720,a|0,1);b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}b=P()|0;gO(d);lO(a);S(b|0);p()}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;jm(a,b);b=Db(x[a>>2]);x[c+8>>2]=b;a=Db(x[a+4>>2]);while(1){if(Pb(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[Be(c+8|0)>>2];continue}else{hb=c+16|0}break}}function LO(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Zn(d);KO(x[c>>2])}b=b+1|0;continue}break}}function Kaa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){ug(a+b|0);a=a+1|0;continue}break}break a}AO(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Dia(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){ug(a+b|0);a=a+1|0;continue}break}break a}ou(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function tf(a,b,c,d,e){var f=0;f=hb-256|0;hb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Tb(f,b&255,c?d:256);if(!c){while(1){hf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}hf(a,f,d)}hb=f+256|0}function nR(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){ug(a+b|0);a=a+1|0;continue}break}break a}jR(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function v6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=hb-16|0;hb=f;b=Hc(Xia(Wia(d,d>>31,b,0),lb,1e3,0),lb);x[a+16>>2]=0;x[a+12>>2]=b+c;pK(a,e);b=x[a+12>>2];x[f+12>>2]=0;lL(a,b,f+12|0);hb=f+16|0}function pS(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;hB(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function oT(a){var b=0;a:{if(Ob(a,3873,4)|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(Ob(a+71|0,13543,4)|y[a+75|0]!=1|y[a+76|0]){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function kda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if((b|0)>=0){d=2147483647;a=pt(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[Yc(c+12|0,c+8|0)>>2]}hb=c+16|0;return d|0}Tc();p()}function d4(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}Yf(a,x[b+24>>2],d);break a}if(c&8){Yf(a,x[b+12>>2],x[b+20>>2]);break a}Jb(a)}}function be(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ld(b)}return c}function Wh(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;Lm(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)|0}function Ufa(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],2)){a=0;while(1){if((a|0)!=2){ug(a+b|0);a=a+1|0;continue}break}break a}sl(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(c){Vb(d,c);break a}Jb(d)}x[23420]=0;U(11,a|0,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(d);hb=d+16|0;return}a=P()|0;xb(d);S(a|0);p()}function en(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-32|0;hb=c;a:{if(_o(a)>>>0<b>>>0){if(hh(-1)>>>0<b>>>0){break a}d=Fb(a);e=a;a=Dl(c+8|0,b,Wc(x[a>>2],x[a+4>>2]),d);zd(e,a);Cl(a)}hb=c+32|0;return}Tc();p()}function Tfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){if(hh(1073741823)>>>0<b>>>0){Tc();p()}c=QC(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=(b<<2)+c|0,x[d>>2]=e;HA(a,b)}return a|0}function SF(a,b,c,d,e,f){var g=0,h=0,i=0;g=hb-16|0;hb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){uh(g+13|0,g+14|0)}h=c,i=($a(b|0,Wc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;hb=g+16|0}function If(a){var b=0,c=0,d=0,e=0;b=hb-16|0;hb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Hb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Hb(b+12|0,b+8|0)>>2]}hb=b+16|0;return c}function FU(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){ug(a+b|0);a=a+1|0;continue}break}break a}Lm(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function xV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){if(hh(214748364)>>>0<b>>>0){Tc();p()}c=jC(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=D(b,20)+c|0,x[d>>2]=e;mC(a,b)}return a|0}function oR(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!oe(d,x[a+4>>2],b)){break a}d=tB(a,x[Pf(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=Pf(c,b);xL(Pf(c,d),a);c=d}return c|0}function lX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=hb-16|0;hb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;mb[f|0](a,b,d,8);hb=d+16|0}function Pg(a,b){var c=0,d=0,e=0;c=Eb(a);a:{if((c|0)!=(Eb(b)|0)){break a}d=Ic(a);b=Ic(b);if(!Se(a)){while(1){e=!c;if(!c|y[d|0]!=y[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Tl(d,b,c)}return e}function B0(a,b){a=a|0;b=b|0;var c=0;a=ls(a);x[a>>2]=76272;c=Jb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[23420]=0;R(81,a|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}b=P()|0;xb(c);En(a);S(b|0);p()}function uP(a){var b=0,c=0,d=0;d=y[a+64|0]|y[a+65|0]<<8;b=y[a+70|0]|y[a+71|0]<<8;a=b+(y[a+72|0]|y[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;lb=a;return c}function gM(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(mb[x[x[b>>2]+116>>2]](b)|0)){break a}mb[x[x[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function bK(a){var b=0,c=0,d=E(0);if(!a){return E(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}d=E(Ej(b-+(a|0)))}else{d=E(0)}return d}function Naa(a){a=a|0;var b=0;b=hb-16|0;hb=b;a:{if(dq(a,10157)){tJ(b,17392,a);a=Ic(b);x[23420]=0;R(40,44,a|0);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;xb(b);S(a|0);p()}hb=b+16|0;return}p()}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;EJ(d,c);a=x[a+1298464>>2];x[23420]=0;U(353,a|0,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(d);hb=d+16|0;return}a=P()|0;yb(d);S(a|0);p()}function HB(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){vm((a<<2)+b|0);a=a+1|0;continue}break}break a}wu(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Gk(a){a=a|0;var b=0;x[a>>2]=77468;x[23420]=0;R(69,a|0,0);b=x[23420];x[23420]=0;if((b|0)!=1){Zb(a+28|0);Ib(x[a+32>>2]);Ib(x[a+36>>2]);Ib(x[a+48>>2]);Ib(x[a+60>>2]);return a|0}V(0)|0;Ub();p()}function EQ(a){var b=0,c=0,d=0;d=y[a+32|0]|y[a+33|0]<<8;b=y[a+34|0]|y[a+35|0]<<8;a=b+(y[a+36|0]|y[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;lb=a;return c}function E7(a){a=a|0;var b=0,c=0,d=0;b=hb-32|0;hb=b;a:{if(ti(a)>>>0<=12){if(hh(1073741823)>>>0<=12){break a}c=Fb(a);d=a;a=bg(b+8|0,13,vc(x[a>>2],x[a+4>>2]),c);zd(d,a);ag(a)}hb=b+32|0;return}Tc();p()}function $W(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Bd(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){om();p()}b=rd(b);x[e+8>>2]=d-c;Do(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function Ru(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){ug(a+b|0);a=a+1|0;continue}break}break a}hc(c+8|0,b,256);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function BR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;HR(c+8|0,b);d=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;if((d|0)!=(e|0)){IR(b)}}function sT(a){var b=0,c=0,d=0;a:{if(Ob(a,21462,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function pO(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function Kd(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function aj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Uv(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=x[a>>2];c=x[a+4>>2]-f|0;d=x[e>>2]+D(g,(c|0)/(d|0)|0)|0;x[e>>2]=d;if((c|0)>0){pc(d,f,c)}nc(a,e);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function tQ(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;tT(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){uT(b)}return a}function pB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;oB(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){PT(b)}return a}function nU(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;nu(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){wB(b)}return a}function ku(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function cD(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Vq(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Wq(b)}return a}function PD(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;ND(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){Bv(b)}return a}function JR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;HR(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){IR(b)}return a}function E8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);ae(e,x[a+28>>2]);a:{b:{if(!c){d=-1;if(!gd(a,5)){break b}break a}d=x[c+8>>2]}pz(x[a+28>>2],b,d);f=c}af(a,f);hb=e+16|0}function Aj(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;Lm(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){vl(b)}return a}function $Q(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;XQ(c+8|0,b);d=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;a=(d|0)==(e|0);if(!a){YQ(b)}return a}function rB(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Xb(128/(D(x[Le(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[_e(c+7|0,c+6|0)|0];hb=c+16|0;return a|b<<4&240}function Au(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function wH(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Mj(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}function vh(a,b){var c=0;c=x[a>>2];a=Pd(b);b=x[c+8>>2];if(vc(b,x[c+12>>2])>>>0>a>>>0){c=x[Cb(b,a)>>2]!=0}else{c=0}if(!c){a=Nl(ba(4)|0);x[a>>2]=92236;ha(a|0,92372,1057);p()}return x[Cb(b,a)>>2]}function aK(a,b){var c=0,d=0,e=0,f=0;if(a>E(.9999989867210388)){d=0}else{a=E(a*a);c=+a;e=32768/(1-c);f=c;c=Oe(31415.926535897932/+b);d=fm(e*(1-(f*c+M(+E(a+a)*(1-c)-+E(a*a)*(1-c*c)))))}return d}function _H(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function ZQ(a){var b=0,c=0,d=0,e=0;lb=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function qy(a,b){var c=0;a=ZP(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function yj(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(2147483647);if(d>>>0<=b>>>0){a=Gm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function qr(a,b,c,d,e,f){var g=0,h=0;Jf(a+12|0,d);if(b){if(b>>>0>=f>>>0){ig();p()}d=wc(D(b,e))}else{d=0}x[a>>2]=d;c=d+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;g=yc(a),h=d+D(b,e)|0,x[g>>2]=h;return a}function jP(a,b){var c=0;c=y[a+800|0];a:{if(c){break a}c=xi(y[a+797|0]-w[a+770>>1]|0);if(!b|(c<<24)-16777216>>24<0){break a}a=x[a+656>>2];if(!a){break a}c=y[Kb(a+108|0,c-1|0)|0]}return c&255}function ij(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Xk(a,b);if((d|0)==255){break a}Tj(a,b);Gp(a,b,0,0);if(!c){break a}e=bc(a+26|0,d),f=65535,w[e>>1]=f;a=Kb(a+62|0,b);v[a|0]=y[a|0]|128}}function hF(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=82056;d=a+8|0;while(1){b=x[a+8>>2];if(vc(b,x[a+12>>2])>>>0>c>>>0){b=x[Cb(b,c)>>2];if(b){Sm(b)}c=c+1|0;continue}break}xb(a+152|0);FF(d);return a|0}function Tg(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(1073741823);if(d>>>0<=b>>>0){a=ti(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function BJ(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=wc(1298472);x[23420]=0;c=T(1013,b|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){b=x[mf(a+8|0,c)>>2];hb=a+16|0;return b|0}a=P()|0;Ib(b);S(a|0);p()}function pD(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(119304647);if(d>>>0<=b>>>0){a=nv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function mA(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[g|0](a,b,f,e);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];hb=e+16|0}function lR(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=(Zo(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;JN(c+8|0,127);a=ho(C[c+8>>3]);hb=c+16|0;return a}function fB(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(214748364);if(d>>>0<=b>>>0){a=lC(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function br(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(536870911);if(d>>>0<=b>>>0){a=Tm(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function Vm(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(357913941);if(d>>>0<=b>>>0){a=Fj(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function Mv(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(268435455);if(d>>>0<=b>>>0){a=mr(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function Mp(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(134217727);if(d>>>0<=b>>>0){a=go(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function LA(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(715827882);if(d>>>0<=b>>>0){a=ju(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function zu(a,b){var c=0,d=0;c=hb-16|0;hb=c;yu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function xu(a,b){var c=0,d=0;c=hb-16|0;hb=c;uo(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function vt(a){var b=0;a:{if(Ob(a,13443,4)|y[a+4|0]){break a}if(Lb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Lb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Lb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function uL(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(82595524);if(d>>>0<=b>>>0){a=Ps(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function ng(a,b){var c=0,d=0;c=hb-16|0;hb=c;Mq(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function lD(a,b){var c=0,d=0;c=hb-16|0;hb=c;ND(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function dR(a,b){var c=0,d=0;c=hb-16|0;hb=c;vA(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function dD(a,b){var c=0,d=0;c=hb-16|0;hb=c;Vq(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function bU(a,b){var c=0,d=0;c=hb-16|0;hb=c;Nu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function _v(a,b,c){var d=0;d=hb-16|0;hb=d;hc(d+8|0,b,c);b=x[d+12>>2];mc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){$b(a,x[d+12>>2])}hb=d+16|0;return(b|0)==(c|0)}function WB(a,b){var c=0,d=0;c=hb-16|0;hb=c;VB(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function UM(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=_q(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{TM(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function U2(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;EJ(c,b);a=x[a+1298464>>2];x[23420]=0;U(353,a|0,1,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){yb(c);hb=c+16|0;return}a=P()|0;yb(c);S(a|0);p()}function TT(a,b){var c=0,d=0;c=hb-16|0;hb=c;nu(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Sq(a,b){var c=0,d=0;c=hb-16|0;hb=c;sl(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function NT(a,b){var c=0,d=0;c=hb-16|0;hb=c;ou(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function MT(a,b){var c=0,d=0;c=hb-16|0;hb=c;oB(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function Ks(a){var b=0;x[23420]=0;a=T(767,a|0)|0;b=x[23420];x[23420]=0;a:{if((b|0)==1){_(V(0)|0)|0;x[23420]=0;Z(17);b=x[23420];x[23420]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;Ub();p()}function Go(a,b){var c=0,d=0;c=hb-16|0;hb=c;Bh(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function FS(a,b){var c=0,d=0;c=hb-16|0;hb=c;ES(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=hb-16|0;hb=d;e=z[a+28>>1];w[d+8>>1]=e;f=d,g=(vc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+10>>1]=g;a=oL(a,b,c,d+8|0);hb=d+16|0;return a|0}function CG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function AR(a,b){var c=0,d=0;c=hb-16|0;hb=c;zR(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){$b(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function $B(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function kw(a,b,c,d,e,f,g,h,i){var j=0;j=hb-16|0;hb=j;xg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;hb=j+16|0}function UO(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;v[a+16|0]=0;c=wz(b,x[a+12>>2]);x[23420]=0;R(707,a|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){Yk(c);hb=b+32|0;return}a=P()|0;Yk(c);S(a|0);p()}function Sz(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Fb(a);c=bg(d+8|0,Tg(a,vc(x[a>>2],x[a+4>>2])+1|0),vc(x[a>>2],x[a+4>>2]),c);Lp(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;zd(a,c);ag(c);hb=d+32|0}function Cw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+D(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((D(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function uF(a,b){var c=0,d=0;d=hb-32|0;hb=d;c=Fb(a);c=Dl(d+8|0,Al(a,Wc(x[a>>2],x[a+4>>2])+1|0),Wc(x[a>>2],x[a+4>>2]),c);tk(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;zd(a,c);Cl(c);hb=d+32|0}function nP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function cn(a,b){var c=0,d=0,e=0;a:{c=wG(b);if(c>>>0<1073741808){b:{if(Gr(c)){we(a,c);break b}d=Hl(c)+1|0;e=qi(d);xd(a,e);Af(a,d);Sd(a,c);a=e}di(a,b,c);xd((c<<2)+a|0,0);break a}Bf();p()}}function x$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Ot(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;pc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function lg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb+-64|0;hb=c;d=Xx(c+8|0,a);x[23420]=0;U(189,a|0,b|0,d|0);a=x[23420];x[23420]=0;if((a|0)!=1){Pk(d);hb=c- -64|0;return}a=P()|0;Pk(d);S(a|0);p()}function ej(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function OS(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Tl(a,c,x[Hb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}hb=e+16|0;return c}function Gb(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(Sf(y[a+11|0])){Ib(x[a>>2])}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];we(b,0);v[c+15|0]=0;sd(b,c+15|0);hb=c+16|0;return a}function _S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;Lf(a,c+14|0);e=z[c+14>>1];mM(b,e);while(1){if((d|0)==(e|0)){sy(b);hb=c+16|0}else{bk(a,Cb(x[b>>2],d));d=d+1|0;continue}break}}function K5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=TJ(f,b,c,d,0,0,0,0,e);hb=f+16|0;return a|0}function Jx(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Mn(d)|b<<15;continue}break}C[c+4280>>3]=E(E(b|0)*E(-4.656612873077393e-10))}function D_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-16|0;hb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=Kj(h,b,c,d,e,f,g+8|0,a);hb=a;return b|0}function zn(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(!pJ(y[a+20|0])){x[23420]=0;R(1018,b+8|0,a|0);c=x[23420];x[23420]=0;if((c|0)==1){break a}}v[a+20|0]=255;hb=b+16|0;return}V(0)|0;Ub();p()}function y2(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=x[14179];x[c+8>>2]=x[14178];x[c+12>>2]=d;d=x[14177];x[c>>2]=x[14176];x[c+4>>2]=d;mb[x[hp(c,Nj(y[b+20|0]))>>2]](a,b);hb=c+16|0}function rha(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Xh(b,12,c);break a}oB(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function gs(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Zu(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Zu(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function ch(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;x[23420]=0;b=T(181,a|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}return y[a+c|0]}ha(b|0,25912,156);p()}function Mh(a){var b=0;a=Ph(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function Al(a,b){var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=b;d=b;b=hh(-1);if(d>>>0<=b>>>0){a=_o(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[Yc(c+8|0,c+12|0)>>2]}hb=c+16|0;return b}Tc();p()}function y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=hb-16|0;hb=e;f=1;g=x[c>>2];if(g>>>0<Wc(a,b)>>>0){a=Zm(e,Kb(a,g),z[c+12>>1]);b=Vv(d,a);Sb(a);f=b^1}hb=e+16|0;return f|0}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;zS(b,c);c=Nb(x[a>>2],x[a+8>>2],c<<2);if(c){yS(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0;return c|0}function sda(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;hD(b,4,c);break a}Bh(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function bg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Jf(a+12|0,d);if(b){d=qi(b)}else{d=0}x[a>>2]=d;c=d+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<2)|0,x[e>>2]=f;return a|0}function _J(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=ZJ(f,b,c,d,e,0,0,0,0);hb=f+16|0;return+c}function vW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=mb[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function hs(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0;a=d&4095}else{c=c+15|0;d=Mn(a);continue}break}return a}function fz(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=qh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function Fv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;d=Eb(b);if(d>>>0<c>>>0){om();p()}b=Ic(b);x[e+8>>2]=d-c;Do(a,b+c|0,x[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function FW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wD(b,c);c=Nb(x[a>>2],x[a+8>>2],c<<3);if(c){vD(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0;return c|0}function yN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;YP(b,c);if(Nb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];hc(d+8|0,c,ph(c,x[b+4>>2])<<8);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function EW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Wc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Ki(c,a)}return!d|0}function vo(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=Gi(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{wj(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function nC(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=Nh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{Lp(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Vx(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=Nh(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{Hs(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function VL(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Hb(b+12|0,b+8|0)>>2]<=c>>>0){hb=b+16|0;a=d&127}else{c=c+15|0;d=Mn(a);continue}break}return a}function JS(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function tC(a){var b=0,c=0;a:{if(Ob(a,14017,3)){break a}b=y[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(y[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function sY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+82128>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function jha(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;ZS(b,c);YS(a,c);hb=c+32|0}function gm(a){var b=0,c=0;b=x[23176];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>nb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[23176]=a;return b}x[115896]=48;return-1}function af(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!b){b=1;if(gd(a,5)){break a}ae(c,x[a+28>>2])}x[a>>2]=x[a>>2]|134217728;x[a+20>>2]=x[a+20>>2]+1;b=0}hb=c+16|0;return b|0}function Zj(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Fb(b);d=Fb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function Wga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);ae(e,x[a+28>>2]);a:{if(!c){f=0;if(gd(a,5)){break a}}XS(x[a+28>>2],b,d,0);f=c}af(a,f);hb=e+16|0}function Bo(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=Bl(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{tk(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function Ac(a,b){var c=0,d=0;c=hb-16|0;hb=c;if(Se(a)){Ib(x[a>>2])}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];we(b,0);v[c+15|0]=0;sd(b,c+15|0);hb=c+16|0;return a}function p6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Fd(c,E(0));d=a+4208|0;if((b|0)==12){c=E(Ph(E(c*E(3)))/E(3));b=12}e=Cb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function a9(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-32|0;hb=d;c=-1;a:{if(!PD(a,d+8|0)){break a}c=0;if(!CL(d+8|0)|(x[d+16>>2]!=x[b>>2]|x[b+4>>2]?b:0)){break a}c=1}hb=d+32|0;return c|0}function WD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function $N(a,b,c,d){var e=0,f=0;e=hb-16|0;hb=e;while(1){if(c){f=Vk(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[gc(e+8|0,d)>>2];hb=e+16|0;return a}function us(a){var b=0;b=x[a+24>>2];x[23420]=0;Y(768,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){Ke(a+68|0);Vf(a+36|0);ns(a+32|0);cj(a+24|0);bj(a+4|0);return se(a)}V(0)|0;Ub();p()}function aia(a,b){a=a|0;b=b|0;if(!MT(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function N1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;ix(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+8|0,d+12|0)>>2]}hb=d+16|0;return c|0}function lM(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;jM(c,b+80|0);x[23420]=0;U(11,a|0,0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){xb(c);hb=c+16|0;return}a=P()|0;xb(c);S(a|0);p()}function YX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;mb[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=uc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);hb=d+16|0;return a|0}function Sda(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;b=-1;a:{if(!Aj(a,c+8|0)){break a}b=0;if(!_P(c+8|0)){break a}b=-1;if(!Uf(a,4)){break a}b=xQ(a)>>>31|0}hb=c+16|0;return b|0}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=hb-16|0;hb=e;c=ff(a,c);ae(e,x[a+28>>2]);a:{if(!c){f=0;if(gd(a,5)){break a}}iL(d,x[a+28>>2],b);f=c}af(a,f);hb=e+16|0}function zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;a:{if(a){mb[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}pM(d,9055,10750,140,42);ID(a,d,b,a,c)}hb=d+16|0}function oq(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];d=x[a+4>>2];if(Mc(c,d)>>>0>b>>>0){a=x[a+24>>2];b=nl(c,d,b);a=oe(x[a+484344>>2],x[a+484348>>2],z[b>>1])}else{a=0}return a|0}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+8>>2]=b;while(1){if(Pb(b,c)){x[d+4>>2]=x[b>>2];Zz(a,d+4|0);b=x[Ce(d+8|0)>>2];continue}else{hb=d+16|0}break}}
function wQ(a,b){var c=0,d=0;c=hb-16|0;hb=c;Bh(c+8|0,b);b=x[c+12>>2];ld(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){cd(a,x[c+12>>2])}hb=c+16|0;return(b|0)==(d|0)}function og(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=ch(x[d>>2],x[d+4>>2],a);return((ch(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|ch(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function ne(a,b){var c=0;a:{c=qf(b);if((c|0)==(Eb(a)|0)){x[23420]=0;a=W(347,a|0,b|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;Ub();p()}function RA(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;a=mq(d,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){kc(a);hb=d+16|0}else{Yt(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function Ju(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;Ki(b,c);if(Nb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];hc(d+8|0,c,Wc(c,x[b+4>>2]));qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function DT(a){var b=0;a:{if(Ob(a,16536,4)){break a}if(ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Lb(y[a+8|0]|y[a+9|0]<<8)}return b}function wfa(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=wc(1);x[23420]=0;Z(31);c=x[23420];x[23420]=0;if((c|0)!=1){b=x[mf(a+8|0,b)>>2];hb=a+16|0;return b|0}a=P()|0;Ib(b);S(a|0);p()}function Fh(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;v[c+24|0]=0;Ui(c+8|0,c+24|0);kn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];v[b|0]=y[c+24|0];hb=c+32|0;return(a|0)==1|0}function Dl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;Jf(a+12|0,d);if(b){d=wc(b)}else{d=0}x[a>>2]=d;c=c+d|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=b+d|0,x[e>>2]=f;return a|0}function zia(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Lm(c+8|0,b);b=x[c+12>>2];mc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){$b(a,x[c+12>>2])}hb=c+16|0}function qY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+82128>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function aX(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;iD(b,0,a);x[23420]=0;a=T(113,b|0)|0;c=x[23420];x[23420]=0;if((c|0)!=1){xb(b);hb=b+16|0;return a|0}a=P()|0;xb(b);S(a|0);p()}function Xe(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=yU(b,c),x[e+12>>2]=f;c=b;b=AB(d+4|0);ah(c,c+b|0,a);e=Kb(a,b),f=0,v[e|0]=f;AU(a);hb=d+16|0}function TC(a,b,c){var d=0,e=0;a:{b:{if(jq(c)){we(a,c);break b}if(c>>>0>=4294967280){break a}d=wi(c)+1|0;e=wc(d);xd(a,e);Af(a,d);Sd(a,c);a=e}He(a,b,c+1|0);return}Bf();p()}function wW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=mb[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function haa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],16);a:{if(!d){gC(b);break a}Nu(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function UE(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;x[23420]=0;c=T(c|0,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){break a}b=P()|0;ca(a|0);S(b|0);p()}return}ha(c|0,b|0,906);p()}function Qv(a,b,c,d,e){var f=0;a:{f=Ks(4332);if(f){x[23420]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break a}}return f}a=P()|0;Ib(f);S(a|0);p()}function Kl(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function sP(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=Nh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);hb=c+16|0}else{qP(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function rY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+82128>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function iC(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=Gi(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);hb=c+16|0}else{ev(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function hE(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=Bl(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);hb=c+16|0}else{ug(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function HA(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=Nh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);hb=c+16|0}else{vm(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function EF(a,b){var c=0,d=0;c=hb-16|0;hb=c;a=Nh(c,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){kc(a);hb=c+16|0}else{BF(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function mo(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=Nb(x[a>>2],x[a+8>>2],4);a:{if(!d){BS(b);break a}Bh(c+8|0,b);qd(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0;return d|0}function Z9(a,b){a=a|0;b=b|0;var c=0;a=gg(a);c=qj(x[b>>2]);b=yf(b);x[23420]=0;U(762,a|0,c|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}b=P()|0;aN(a);S(b|0);p()}function Ft(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function $H(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;wD(b,c);if(Nb(x[a>>2],x[a+8>>2],c<<3)){vD(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function cea(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-48|0;hb=c;d=-1;a:{if(!tQ(a,c)){break a}d=0;if(!sQ(c)){break a}d=Ge(a,b,rQ(y[c+31|0],y[c+33|0]),lb)}hb=c+48|0;return d|0}function AC(a,b,c){var d=0;d=hb-16|0;hb=d;a=Co(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){wj(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}Id(a);hb=d+16|0}function xl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=qf(b);d=nm(a);if(c>>>0<=d>>>0){GA(a,rj(rd(a),b,c),c);break a}e=a;a=Bd(x[a+4>>2],y[a+11|0]);Lt(e,d,c-d|0,a,0,a,c,b)}}function vQ(a,b){var c=0;c=hb-32|0;hb=c;cR(c+24|0,a);ue(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Lc(x[c+24>>2],x[c+28>>2],c+8|0);hb=c+32|0;return a}function iW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function Tj(a,b){var c=0,d=0,e=0;a:{c=Xk(a,b);if((c|0)==255){break a}if(Uj(x[a>>2])){break a}d=Kb(a+8|0,c);e=y[d|0]&223;v[d|0]=e;Sg(x[a>>2],x[a+4>>2],b,it(c)|176,e)}}function HS(a,b,c){var d=0;d=hb-16|0;hb=d;a=Nv(d,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){tk(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}Id(a);hb=d+16|0}function BA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;zS(b,c);if(Nb(x[a>>2],x[a+8>>2],c<<2)){yS(d+8|0,x[b>>2],x[b+4>>2]);qd(d,a,x[d+8>>2],x[d+12>>2])}hb=d+16|0}function xW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Hb(d+12|0,d+8|0)>>2]}hb=d+16|0;return c|0}function w_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=sc(a);return Jj(g,h,c,d,e,f,b,b+(Eb(a)<<2)|0)|0}function mP(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function Zz(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Fb(a)>>2]){c=hb-16|0;hb=c;a=Nh(c,a,1);Lp(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0;return}Sz(a,b)}function U8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;c=ff(a,c);ae(d,x[a+28>>2]);a:{if(!c){e=0;if(gd(a,5)){break a}}_S(x[a+28>>2],b);e=c}af(a,e);hb=d+16|0}function SS(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;b=ic(b);a=rh(a,wc(32),sh(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Jb(b+4|0);e=ic(a),f=1,v[e+4|0]=f;hb=d+16|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ix(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function I0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;a=Sw(Qa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);hb=e+16|0;lb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function fH(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=Mf(b),d=x[x[a>>2]+52>>2],mb[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return Mf(b)}function Zea(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Vb(a,10157);x[23420]=0;Y(35,b|0);c=x[23420];x[23420]=0;if((c|0)!=1){xb(b);hb=a+16|0;return}a=P()|0;xb(b);S(a|0);p()}function Xha(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Xh(a,6,c);break a}hB(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function HP(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;Jz(a+112|0,48e3);x[a+668>>2]=0;Iz(a+724|0);Iz(a+732|0);Iz(a+740|0);Sh(a+788|0);return a}function Gea(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Xh(a,5,c);break a}yu(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function T$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=hb-16|0;hb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=SG(a,e,b);x[a>>2]=77148;hb=e+16|0;return a|0}function Om(a,b){a=a|0;b=b|0;var c=0;if(!Sf(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}TC(a,x[b>>2],x[b+4>>2]);return a|0}function Kp(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function GX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;x[d+12>>2]=x[c>>2];a=mb[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}hb=d+16|0;return a|0}function Am(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Xh(a,4,c);break a}Bh(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function AB(a){var b=0,c=0;a:{c=Cb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=Up(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function rM(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){qM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}x[a+112>>2]=b+1;a=qM(a);return a}function pP(a,b){var c=0;c=x[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function bk(a,b){var c=0;c=hb-32|0;hb=c;x[c+24>>2]=0;Kv(c+8|0,c+24|0);kn(c+16|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+20>>2];x[b>>2]=x[c+24>>2];hb=c+32|0;return(a|0)==4}function Zp(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){Ol(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;Ol(a,b)}function Yp(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){Ol(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;Ol(a,b)}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-80|0;hb=d;c=-1;a:{if(!nU(a,d+8|0)){break a}c=0;if(!iR(d+8|0)){break a}c=Ge(a,b,hR(d+8|0),lb)}hb=d+80|0;return c|0}function RD(a,b,c,d){var e=0,f=0;e=-1;a:{if(!b){break a}f=a+b|0;b=a;while(1){if((b|0)==(f|0)){break a}if(Tp(c,d,y[b|0])){b=b+1|0;continue}break}e=b-a|0}return e}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=hb-16|0;hb=c;d=c,e=vi(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[vj(c+12|0,c+8|0,43824)>>2],x[d+36>>2]=e;np(a);hb=c+16|0}function Zr(a){var b=0;a:{if((Ne(a)|0)!=79){break a}if((Ne(a)|0)!=103){break a}if((Ne(a)|0)!=103){break a}b=(Ne(a)|0)==83}if(!b){ec(a,30);return 0}return UH(a)}function Qu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;hC(a,c);break a}sl(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function Maa(a,b){a=a|0;b=b|0;a=Bc(a);v[a+534|0]=0;x[a+4>>2]=0;x[23420]=0;R(713,a|0,b|0);b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}b=P()|0;oj(a);S(b|0);p()}function MI(a,b){var c=0,d=0;d=a+4|0;c=Wc(x[d>>2],x[a+8>>2]);a=x[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=If(c);if(a>>>0<=b>>>0){break a}}b=NI(a,65536)}Ki(d,b)}}function Hfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qb(a+8|0);x[23420]=0;U(232,a|0,b|0,c|0);a=x[23420];x[23420]=0;if((a|0)!=1){break a}a=P()|0;dc(d);S(a|0);p()}}function C_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=mb[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Ic(a);return Kj(g,h,c,d,e,f,b,Eb(a)+b|0)|0}function C3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=ip(d,a);CJ(a,c);x[23420]=0;R(69,b|0,1);a=x[23420];x[23420]=0;if((a|0)==1){a=P()|0;Zb(d);S(a|0);p()}}function jT(a,b){var c=0;c=Wia(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+lb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;lb=a;return b}function iV(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ng(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=XB(a,b,x[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function em(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function aC(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ng(a,c+8|0)){x[c+4>>2]=y[c+8|0];d=UB(a,b,x[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0;return d|0}function X7(a){a=a|0;var b=0,c=0,d=0;b=hb-16|0;hb=b;VK(b+8|0,a,0);c=x[b+12>>2];if(c){a=x[a+20>>2];x[a+148>>2]=-1;d=a+4|0;a=x[b+8>>2];ry(d,a,Kb(a,c))}hb=b+16|0}function LT(a){var b=0;if(!(Ob(a,17667,8)|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function Fd(a,b){var c=0,d=0,e=E(0);c=hb-16|0;hb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=xf(a),B[d+4>>2]=e;a=B[Xp(c+4|0,c+12|0,c+8|0)>>2];hb=c+16|0;return a}function DJ(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function q$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function nk(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=YD(b)}else{d=0}x[a>>2]=d;c=d+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+D(b,12)|0,x[e>>2]=f;return a}function ld(a,b,c,d){var e=0,f=0,g=0;e=hb-16|0;hb=e;f=x[b+12>>2];x[e+8>>2]=c;x[e+12>>2]=d;g=x[x[b>>2]+28>>2];x[e>>2]=c;x[e+4>>2]=d;mb[g|0](a,b,f,e);hb=e+16|0}function kD(a){var b=0;if(!(Ob(a,15339,4)|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function iK(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function eB(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=jC(b)}else{d=0}x[a>>2]=d;c=d+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+D(b,20)|0,x[e>>2]=f;return a}function Mz(a){var b=0;a=fe(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function t$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function qda(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-48|0;hb=d;c=-1;a:{if(!tQ(a,d)){break a}c=0;if(!DP(d)){break a}c=Ge(a,b,CP(y[d+47|0]),lb)}hb=d+48|0;return c|0}function oA(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(Sf(y[a+11|0])){c=x[a>>2];v[b+15|0]=0;sd(c,b+15|0);Sd(a,0);break a}v[b+14|0]=0;sd(a,b+14|0);we(a,0)}hb=b+16|0}function VP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;while(1){if((b|0)==(c|0)){hb=d+16|0}else{x[d+12>>2]=x[b>>2];Zz(a,d+12|0);b=b+4|0;continue}break}}function Me(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[ic(a)>>2];x[23420]=0;Y(a|0,c|0);a=x[23420];x[23420]=0;if((a|0)==1){break a}}return}V(0)|0;Ub();p()}function M2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=x[c>>2];x[d>>2]=x[a>>2];Oh(d+4|0,a+4|0);x[c>>2]=x[c>>2]+16;a=a+16|0;continue}break}}function $b(a,b){a=a|0;b=b|0;var c=0;c=Nb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=mb[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function xj(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=dv(b)}else{d=0}x[a>>2]=d;c=d+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<1)|0,x[e>>2]=f;return a}function xM(){var a=0,b=0,c=0,d=0;a=hb-16|0;hb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=vy(93720);continue}break}x[b>>2]=d;Mn(b);hb=a+16|0;return x[b>>2]}function wc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Ld(a);if(b){break a}b=x[117237];if(b){mb[b|0]();continue}break}ha(Pl(ba(4)|0)|0,91780,25);p()}return b|0}function rt(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=EP(b)}else{d=0}x[a>>2]=d;c=d+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<5)|0,x[e>>2]=f;return a}function eA(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=a;c=c&65535;while(1){if(!(!Pb(a,b)|(c|0)==z[a>>1])){a=x[Re(d+8|0)>>2];continue}break}hb=d+16|0;return a}function ar(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=tD(b)}else{d=0}x[a>>2]=d;c=d+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<3)|0,x[e>>2]=f;return a}function _aa(a,b){a=a|0;b=b|0;a=Qb(a);v[a+16|0]=0;x[a+12>>2]=b;x[23420]=0;Y(706,a|0);b=x[23420];x[23420]=0;if((b|0)!=1){return a|0}b=P()|0;tz(a);S(b|0);p()}function Us(a,b){var c=0,d=0,e=E(0);c=hb-16|0;hb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Xp(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;hb=c+16|0}function NS(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=IS(b)}else{d=0}x[a>>2]=d;c=d+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+D(b,6)|0,x[e>>2]=f;return a}function Lv(a,b,c,d){var e=0,f=0;Jf(a+12|0,d);if(b){d=cE(b)}else{d=0}x[a>>2]=d;c=d+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;e=yc(a),f=d+(b<<4)|0,x[e>>2]=f;return a}function kW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function jD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=x[b>>2];d=(mb[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0;a=x[b>>2];fc(c,d,(mb[x[x[a>>2]+24>>2]](a)|0)-x[b+8>>2]|0)}function dj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function ax(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+64640>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function _h(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function QD(a,b,c,d){var e=0;if(!d){return-1}b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(!Tp(c,d,y[b|0])){continue}break}e=b-a|0}return e}function Np(a,b){var c=0,d=0;a:{if(!a){break a}c=Wia(a,0,b,0);d=lb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Ld(c);if(!(!a|!(y[a-4|0]&3))){Tb(a,0,c)}return a}function Ni(a,b,c,d,e){a:{e=Ks(e);if(e){x[23420]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=x[23420];x[23420]=0;if((a|0)==1){break a}}return e}a=P()|0;Ib(e);S(a|0);p()}function DU(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function yW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function pG(a,b,c){var d=0;d=hb-32|0;hb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;wr(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);x[b>>2]=x[d+24>>2];hb=d+32|0}function Oh(a,b){a=a|0;b=b|0;var c=0;if(!Se(b)){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}TC(a,x[b>>2],x[b+4>>2]);return a|0}function vn(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Ld(b)}return c}function f6(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=Xy(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;jK(a);iK(a)}function Wg(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!qh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=aS(c)}x[a>>2]=b;return a}function Ob(a,b,c){var d=0,e=0;a:{while(1){d=y[a|0];e=y[b|0];if((d|0)!=(e|0)){break a}b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break}return 0}return d-e|0}function yl(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;cc(b);continue}break}x[a+4>>2]=c;b=x[a>>2];Fj(a);Ib(b)}}function rx(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;ps(b);continue}break}x[a+4>>2]=c;b=x[a>>2];mr(a);Ib(b)}}function rm(a,b){var c=0,d=0,e=0;jB(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Fb(b);d=Fb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function jY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function ZP(a,b){var c=0,d=0,e=0;tA(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Fb(b);d=Fb(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function UR(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;zb(b);continue}break}x[a+4>>2]=c;b=x[a>>2];Kt(a);Ib(b)}}function UQ(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;Ct(b);continue}break}x[a+4>>2]=c;b=x[a>>2];SQ(a);Ib(b)}}function Ts(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Rj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[(D(b,160)+a|0)+906140>>2]}return d}function Ke(a){var b=0,c=0;if(x[a>>2]){c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Sb(b);continue}break}x[a+4>>2]=c;b=x[a>>2];Fj(a);Ib(b)}}function K$(a,b){a=a|0;b=b|0;var c=0,d=0;b=yw(b);x[a+36>>2]=b;c=a,d=Hg(b),x[c+44>>2]=d;c=a,d=nn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Jr(5524);p()}}function C$(a,b){a=a|0;b=b|0;var c=0,d=0;b=Dw(b);x[a+36>>2]=b;c=a,d=Hg(b),x[c+44>>2]=d;c=a,d=nn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Jr(5524);p()}}function $c(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(mb[x[x[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}x[a+8>>2]=b;c=1}return c|0}function rT(a,b){var c=0;c=Wia(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+lb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;lb=a;return b}function Zv(a,b,c,d){var e=0;e=ba(8)|0;x[23420]=0;a=Q(d|0,e|0,a|0)|0;d=x[23420];x[23420]=0;if((d|0)!=1){ha(a|0,c|0,b|0);p()}a=P()|0;ca(e|0);S(a|0);p()}function QS(a,b,c){var d=0;d=hb-32|0;hb=d;x[d+28>>2]=c;v[d+24|0]=0;x[d+12>>2]=1;wr(d+16|0,a,d+24|0,x[Hb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+24|0];hb=d+32|0}function F3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;HI(i,b,c,d,e,f,g);Rc(a,h+20|0);bm(i);hb=h+32|0}function An(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Tb(a+32|0,0,40);lH(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function sN(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=Qn(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function lv(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Nb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Xh(a,3,c);break a}kv(c+8|0,a);qd(c,b,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function u1(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Oh(a,b);x[23420]=0;Q(53,a+12|0,c|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){break a}b=P()|0;xb(a);S(b|0);p()}}function jea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!$Q(a,d)){break a}c=0;if(!FQ(d)){break a}c=Ge(a,b,EQ(d),lb)}hb=d+96|0;return c|0}function gv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function bY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Kea(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-96|0;hb=d;c=-1;a:{if(!$Q(a,d)){break a}c=0;if(!_Q(d)){break a}c=Ge(a,b,ZQ(d),lb)}hb=d+96|0;return c|0}function Df(a){var b=0,c=0;b=hb-16|0;hb=b;a:{if(Se(a)){c=x[a>>2];v[b+15|0]=0;sd(c,b+15|0);Sd(a,0);break a}v[b+14|0]=0;sd(a,b+14|0);we(a,0)}hb=b+16|0}function sU(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Md(b);continue}break}c=x[a>>2];if(c){yc(a);Ib(c)}}function sL(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Pk(b);continue}break}c=x[a>>2];if(c){yc(a);Ib(c)}}function qz(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Yk(b);continue}break}c=x[a>>2];if(c){Po(a);Ib(c)}}function ov(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Yq(b);continue}break}c=x[a>>2];if(c){yc(a);Ib(c)}}function iM(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function eu(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;zb(b);continue}break}c=x[a>>2];if(c){yc(a);Ib(c)}}function YJ(a,b){a=a|0;b=b|0;var c=0,d=0;d=hb-16|0;hb=d;c=FJ(wc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=48972;a=x[mf(d+8|0,c)>>2];hb=d+16|0;return a|0}function RQ(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;Ct(b);continue}break}c=x[a>>2];if(c){yc(a);Ib(c)}}function PX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,x[b+8>>2],f)){fw(b,c,d,e);return}a=x[a+8>>2];mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function LN(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Sb(b);continue}break}c=x[a>>2];if(c){Po(a);Ib(c)}}function Hv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;cc(b);continue}break}c=x[a>>2];if(c){Po(a);Ib(c)}}function nz(a,b,c){var d=0,e=0,f=0;d=Xk(a,b);if((d|0)!=255){e=bc(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=Kb(a,b),f=255,v[e|0]=f;e=Kb(a,c),f=d,v[e|0]=f}}function _E(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Yx(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=mq(e,a,d);c=c-b|0;if((c|0)>0){pc(x[a+4>>2],b,c);x[a+4>>2]=x[a+4>>2]+D((c>>>0)/6|0,6)}kc(a);hb=e+16|0}function Yia(a,b,c){var d=0;d=b>>31;a=a^d;Uia(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);lb=kb;a=d^jb;b=a-d|0;lb=(d^lb)-((a>>>0<d>>>0)+d|0)|0;return b}function S$(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;mb[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function PT(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function DO(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function mD(a){a=a|0;var b=0;a=Jb(a);x[23420]=0;T(162,a+12|0)|0;b=x[23420];x[23420]=0;if((b|0)!=1){Bc(a+32|0);return a|0}b=P()|0;yb(a);S(b|0);p()}function bC(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function G4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=hb-32|0;hb=h;i=h+8|0;HI(i,b,c,d,e,f,g);Rc(a,i);bm(i);hb=h+32|0}function A6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Fd(c,E(0));if((b|0)==1){d=1;c=Ph(c)}e=Cb(a+4208|0,d),f=c,B[e>>2]=f;qK(a)}}function jL(a){var b=0;b=hb-16|0;hb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[Xp(b+12|0,b+8|0,b+4|0)>>2];hb=b+16|0;return a}function gp(a,b){var c=0;a:{if(!$H(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Lf(a,b){a=a|0;b=b|0;var c=0;c=hb-32|0;hb=c;w[c+24>>1]=0;ok(c+8|0,c+24|0);kn(c+16|0,a,x[c+8>>2],x[c+12>>2]);w[b>>1]=z[c+24>>1];hb=c+32|0}function Bw(a){var b=0,c=0;b=hb-16|0;hb=b;c=-1;a:{if(Nw(a)){break a}if((mb[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}hb=b+16|0;return c}function kN(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function gQ(a){a=a|0;var b=0,c=0;w[a+34>>1]=0;b=hb-16|0;hb=b;v[b+15|0]=0;c=a+43|0;Ql(c,c+22|0,b+15|0);hb=b+16|0;x[a+20>>2]=0;pd(a,0);return a|0}function fk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=CB(a,e,d);break a}a=CB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Wz(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=Wc(x[b>>2],x[b+4>>2]);if(c){rl(a,c);_t(a,x[b>>2],x[b+4>>2],c)}return a|0}function Q8(a,b){a=a|0;b=b|0;var c=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);c=vc(x[b>>2],x[b+4>>2]);if(c){kl(a,c);uA(a,x[b>>2],x[b+4>>2],c)}return a|0}function Ji(a,b,c){if(a>>>0<b>>>0){pc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;v[a|0]=y[b|0];c=c-1|0;if(c){continue}break}}}function mc(a,b,c,d,e){var f=0,g=0;f=hb-16|0;hb=f;x[f+8>>2]=d;x[f+12>>2]=e;g=x[x[b>>2]+28>>2];x[f>>2]=d;x[f+4>>2]=e;mb[g|0](a,b,c,f);hb=f+16|0}function gj(a){var b=0,c=0;b=hb-16|0;hb=b;Ab(b+8|0,a+1074312|0,7);if(Bb(x[x[b+8>>2]>>2],x[b+12>>2])){c=qm(x[a+480180>>2])^1}hb=b+16|0;return c}function ffa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=pg(b);pg(b);break a}a=Eg(b);Eg(b)}while(1){if(a){if(a&1){$b(b,260)}a=a>>>1|0;continue}break}}function dz(a){var b=0,c=0;b=hb-16|0;hb=b;x[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Wg(c);a=a-1|0;continue}break}hb=b+16|0;return x[b+8>>2]}function _m(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){yc(a);Ib(b)}}function _R(a){var b=0;if(!(Ob(a,14859,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function Tia(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ng(a,c+8|0)){x[c+4>>2]=y[c+8|0];BU(a,b,x[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0}function O5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){wx(a,0,0,0,0,0,0,c,d);return}wx(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function JH(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function BQ(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}_c(a,8,1,0,10);return}b=16;if(e){break a}}b=8}_c(a,b,c&2|1,0,d^1)}function nV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;x[c+12>>2]=-1;if(ng(a,c+8|0)){x[c+4>>2]=y[c+8|0];ZB(a,b,x[Hb(c+4|0,c+12|0)>>2])}hb=c+16|0}function gE(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){Po(a);Ib(b)}}function et(a,b){var c=0,d=0;d=of(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!oe(a,b,d&65535)){continue}}break}return c&65535}function dQ(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){Po(a);Ib(b)}}function Zh(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function Km(a,b){var c=0;a=Qm(a);x[a>>2]=61196;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function GP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){Po(a);Ib(b)}}function vB(a,b){var c=0,d=0,e=0;c=hb-16|0;hb=c;w[c+14>>1]=1;d=c,e=fl(a,b),w[d+12>>1]=e;a=z[Ve(c+14|0,c+12|0)>>1];hb=c+16|0;return a-1&65535}function kz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];x[a>>2]=d<<8^x[((y[b|0]^d>>>24)<<2)+29036>>2];b=b+1|0;continue}break}return a}function D3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;II(h,b,c,d,e,f);Rc(a,g+20|0);bm(h);hb=g+32|0}function ye(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function xo(a,b){var c=0;a:{if(!b){break a}if(!Nb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=KC(a,b);break a}c=pg(a);$b(a,b-4|0)}return c}function Vu(a,b){var c=0;a:{if(!b){break a}if(!Nb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=JC(a,1);break a}c=Eg(a);$b(a,b-2|0)}return c}function uY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=hb-16|0;hb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Hb(a+12|0,a+8|0);hb=a+16|0;return x[b>>2]}function lH(a){var b=0,c=0;x[23420]=0;c=ga(1046)|0;b=x[23420];x[23420]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;Nm(a);return}V(0)|0;Ub();p()}function dF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=cw(x[d>>2],c)}mb[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Rk(a){var b=0,c=0,d=0;b=hb-16|0;hb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[Yc(a+20|0,b+12|0)>>2];hb=b+16|0;return D(a,c+d|0)}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=hb-16|0;hb=d;if(b>>>0>=117){Wp(12e3);p()}e=d+8|0;Ab(e,a,b);vg(e,c);hb=d+16|0;return a|0}function sg(a,b){var c=0,d=0,e=0;c=Ic(a);a=Eb(a);e=qf(b);d=0;a:{if(!e){break a}a=a+c|0;b=XD(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function raa(a){a=a|0;var b=0;b=x[a>>2];if(mb[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=mb[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Xz(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Fb(b),d=0,x[c>>2]=d;return a}function Xc(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[Le(b+8|0,td(b+12|0,b+4|0))>>1];hb=b+16|0;return a}function WS(a,b,c,d){var e=0;b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(Tp(c,d,y[b|0])){continue}break}e=b-a|0}return e}function Tz(a){a=50-(D(y[(a>>>4|0)+31376|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Hc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Em(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Wb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;hb=d+16|0}function Dm(a,b,c){var d=0,e=0,f=0;d=hb-16|0;hb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Wb(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;hb=d+16|0}function W7(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=x[a+20>>2];ke(b,x[c+4>>2],x[c+8>>2]);UK(a,fc(b+8|0,x[b>>2],x[b+4>>2]),0);hb=b+16|0}function Ow(a,b){var c=0;if(b>>>0<=99){return tH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Vr(sH(c,a),D(a,-100)+b|0)}return Zi(a,b)}function Oj(a){var b=0,c=0;b=Hm(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[(x[a+16>>2]+D(b,160)|0)+906300>>2]}return c}function JT(a){var b=0,c=0,d=0;c=hb-16|0;hb=c;b=c+8|0;lv(b,a);a=y[Kb(b,0)|0];d=y[Kb(b,1)|0];b=y[Kb(b,2)|0];hb=c+16|0;return a|d<<8|b<<16}function BE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function nA(a){var b=0;b=Lb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Lb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function cd(a,b){var c=0,d=0,e=0;c=Uf(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=mb[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function Oq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){Tc();p()}b=(b-1>>>5|0)+1|0;c=QC(b);x[a+4>>2]=0;x[a>>2]=c;d=Fb(a),e=b,x[d>>2]=e}function F0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=Ev(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function E4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=hb-32|0;hb=g;h=g+8|0;II(h,b,c,d,e,f);Rc(a,h);bm(h);hb=g+32|0}function Cl(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Ib(a)}}function s1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=xx(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+43728|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function P7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Uc(c&255))){WK(a,8,E(0))}a=Oj(a);if(a){mb[x[x[a>>2]+92>>2]](a,b,c,d,e)}}function $9(a,b){a=a|0;b=b|0;a=Ky(a);x[23420]=0;R(759,a|0,b|0);b=x[23420];x[23420]=0;if((b|0)==1){b=P()|0;zp(a);S(b|0);p()}return a|0}function yi(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function uaa(a,b){a=a|0;b=b|0;a=xu(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function ho(a){var b=0;a=fe(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function Pi(a,b){var c=0;if(Se(a)){c=x[a>>2];ll(a);Ib(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];we(b,0);xd(b,0)}function OR(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[Le(b+8|0,td(b+12|0,b+4|0))|0];hb=b+16|0;return a}function AE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function kl(a,b){var c=0,d=0,e=0;if(hh(1073741823)>>>0<b>>>0){Tc();p()}c=qi(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=(b<<2)+c|0,x[d>>2]=e}function Wr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function Q6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Fd(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Ph(c)}B[d>>2]=c;sK(a)}}function Pp(a,b){var c=0,d=0,e=0;if(hh(2147483647)>>>0<b>>>0){Tc();p()}c=dv(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=(b<<1)+c|0,x[d>>2]=e}function Jw(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return Mf(v[b|0])|0}function Jh(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Kc(c,d,(b>>31&a)+b|0)>>2]}function Cf(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=117){Wp(11965);p()}d=c+8|0;Ab(d,a,b);vg(d,0);hb=c+16|0;return a|0}function z0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=Mf(v[a|0])}else{a=-1}return a|0}function nO(a,b){var c=0,d=0,e=0;if(hh(268435455)>>>0<b>>>0){Tc();p()}c=cE(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=(b<<4)+c|0,x[d>>2]=e}function hz(a,b){var c=0,d=0,e=0;if(hh(536870911)>>>0<b>>>0){Tc();p()}c=tD(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=(b<<3)+c|0,x[d>>2]=e}function au(a,b){var c=0,d=0,e=0;if(hh(715827882)>>>0<b>>>0){Tc();p()}c=IS(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=D(b,6)+c|0,x[d>>2]=e}function Yr(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function IH(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14069,13048,1180,5695);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function xi(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[Le(b+8|0,td(b+12|0,b+4|0))|0];hb=b+16|0;return a}function baa(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;if(b>>>0>=250){Wp(12e3);p()}d=c+8|0;Ab(d,a,b);pm(d);hb=c+16|0;return a|0}function n$(a){a=a|0;var b=0,c=0;b=x[x[a>>2]>>2];c=x[b+8>>2];a=x[b+4>>2];b=x[b>>2]+(c>>1)|0;if(c&1){a=x[a+x[b>>2]>>2]}mb[a|0](b)}function HC(a,b){var c=0;c=Wia(b&255,0,1536,0);b=lb;a=Wia(a&255,0,25,0);c=a+c|0;b=lb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;lb=b;return a}function yE(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Nq(d+8|0,d);hb=d+16|0;return x[a>>2]}function vE(a,b,c,d){a=Qb(a);x[23420]=0;U(d|0,a|0,b|0,c|0);b=x[23420];x[23420]=0;if((b|0)!=1){return a}b=P()|0;tc(a);S(b|0);p()}function qN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=Qn(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function lY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function k0(a){a=a|0;var b=0;if((mb[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function i0(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(Jg(b)){b=x[b+72>>2];if(b){aH(b)}v[a|0]=1}return a|0}function gz(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(jj(c,x[a+484364>>2])>>>0<=b>>>0){return Yb(c,y[a+484376|0])}return pj(c,b)}function de(a){var b=0;a=x[a+4>>2];if(a){if(Sm(a)){a:{b=a+8|0;if(x[b>>2]){if((tv(b)|0)!=-1){break a}}mb[x[x[a>>2]+16>>2]](a)}}}}function ZU(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(Jg(b)){b=x[b+72>>2];if(b){Jq(b)}v[a|0]=1}return a|0}function Yw(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}pc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function XF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Fr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function UF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Dr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function $p(a,b){var c=0;c=Bd(x[a+4>>2],y[a+11|0]);if((c|0)==(Bd(x[b+4>>2],y[b+11|0])|0)){a=Tl(rd(a),rd(b),c)}else{a=1}return!a}function xY(a){a=a|0;var b=0;b=hb-16|0;hb=b;$h(ai(b+8|0,x[a+8>>2]));hb=b+16|0;a=x[a+8>>2];if(!a){return 1}return(lF(a)|0)==1|0}function lE(a,b,c){a=Ph(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function hq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function dY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function _B(a,b){var c=0;c=x[b+4>>2];if(c){hc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!uc(c,b)){ke(a,c,b);return}$d(a)}function VD(){var a=0,b=0,c=0;a=hb-16|0;hb=a;b=Vb(a,14812);if(Eb(b)){c=(sg(b,13706)|0)!=-1}else{c=0}xb(b);hb=a+16|0;return c|0}function NO(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Sd(b,a)}if(c){Sd(c,a)}if(d){Sd(d,a)}if(e){Sd(e,a)}}function Cs(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function AJ(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=jJ(wc(8));x[c+4>>2]=a;x[c>>2]=56728;a=x[mf(b+8|0,c)>>2];hb=b+16|0;return a|0}function qS(a,b){var c=0;c=hb-16|0;hb=c;a=Nh(c,a,1);io(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0}function gw(a,b){var c=0,d=0,e=0,f=0;c=qf(b);d=wc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=pc(yc(d),b,c+1|0),x[e>>2]=f}function al(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(mb[x[x[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}x[a+12>>2]=b;c=1}return c}function TD(a){a=a|0;var b=0;a=Jb(a);x[23420]=0;R(124,a|0,13501);b=x[23420];x[23420]=0;if((b|0)==1){b=P()|0;yb(a);S(b|0);p()}}function NX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,x[b+8>>2],0)){dw(b,c,d);return}a=x[a+8>>2];mb[x[x[a>>2]+28>>2]](a,b,c,d)}function Gq(a,b){return Up(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function fS(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;if((fl(x[a>>2],x[a+4>>2])|0)!=65535){OB(a,c+14|0)}hb=c+16|0}function YF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Fr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function VF(a,b,c,d,e,f){a=mb[x[x[a+8>>2]>>2]](a+8|0)|0;a=Dr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Ok(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;ay(a,c,d)}function GN(a){Qy(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=gg(a);gg(a+12|0);v[a+24|0]=1}function AT(a){var b=0;a:{if(Ob(a,3863,4)){break a}if(Ob(a+44|0,17659,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function $f(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Xn(a,d)}function rc(a,b){var c=0;a=Nl(a);x[a+4>>2]=0;x[a>>2]=49072;c=Ld(Eb(b)+1|0);x[a+4>>2]=c;if(c){pc(c,Ic(b),Eb(b)+1|0)}return a}function oK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=tc(b-24|0);if((c|0)!=(b|0)){continue}break}return vf(a)|0}function z7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Ug(E(Fd(c,E(0))*E(127))),v[d|0]=e;zs(a)}}function qQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function o8(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Ug(E(Fd(c,E(0))*E(255))),v[d|0]=e;Es(a)}}function mE(a,b){x[a>>2]=b;lH(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function aA(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);d=b+c|0;c=oi(b,d);if(c){rl(a,c);_t(a,b,d,c)}}function NL(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function ge(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function Eo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function tK(a,b,c){var d=0,e=0;d=Sc(a);if(d>>>0>=c>>>0){Fx(a,rj(sc(a),b,c),c);return}e=a;a=Eb(a);Xo(e,d,c-d|0,a,0,a,c,b)}function cP(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){$O(a,1);$O(a,0)}}function bP(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){aP(a,1);aP(a,0)}}function YG(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function OP(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function Mg(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;x[f+12>>2]=e;c=ai(f+8|0,c);a=Hr(a,b,d,x[f+12>>2]);$h(c);hb=f+16|0;return a}function MR(a,b){var c=0;c=hb-16|0;hb=c;a:{if(!Uf(a,4)){BS(b);break a}Bh(c+8|0,b);mA(c,a,x[c+8>>2],x[c+12>>2])}hb=c+16|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){Dx(x[c>>2],a);x[c>>2]=x[c>>2]+12;a=a+12|0;continue}break}}function ii(a,b,c){c=y[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function rl(a,b){var c=0,d=0,e=0;if(hh(-1)>>>0<b>>>0){Tc();p()}c=wc(b);x[a>>2]=c;x[a+4>>2]=c;d=Fb(a),e=b+c|0,x[d>>2]=e}function qX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return mb[a|0](h|b,c,d,e,b|f,g)|0}function iR(a){var b=0;if(!(Ob(a,13658,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function gt(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function gN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Xb(x[a>>2]+((D((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),x[e>>2]=f}}function Ne(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function bG(a,b,c){var d=0;d=hb-16|0;hb=d;x[d+12>>2]=c;b=ai(d+8|0,b);a=BG(a,9164,x[d+12>>2]);$h(b);hb=d+16|0;return a}function Baa(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=mf(b+8|0,Tb(wc(6668),0,6668));hb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Ai(a){var b=0;while(1){a:{if((b|0)!=46){if(y[b+43760|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function zU(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Md(b);continue}break}x[a+4>>2]=c}function z8(a){a=a|0;var b=0;b=hb-16|0;hb=b;if(!gd(a,4)){Ov(a)}a=x[gc(b+8|0,Db(x[a+48>>2]))>>2];hb=b+16|0;return a|0}function kP(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function i6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Fd(c,E(0));d=Cb(a+4208|0,b),e=c,B[d>>2]=e;jK(a)}}function c7(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Fd(c,E(0));d=Cb(a+4208|0,b),e=c,B[d>>2]=e;AK(a)}}function b6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Fd(c,E(0));d=Cb(a+4208|0,b),e=c,B[d>>2]=e;hK(a)}}function X6(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Fd(c,E(0));d=Cb(a+4208|0,b),e=c,B[d>>2]=e;wK(a)}}function Lo(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Yq(b);continue}break}x[a+4>>2]=c}function Ag(a){var b=0;mm(a);b=ut(x[a>>2],lk(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return uj(x[a>>2],z[a+34>>1])}function A8(a){a=a|0;var b=0;b=hb-16|0;hb=b;if(!gd(a,4)){Ov(a)}a=x[gc(b+8|0,Db(x[a+44>>2]))>>2];hb=b+16|0;return a|0}function yL(a){var b=0,c=0,d=0;if(x[a>>2]){Gc(a);b=x[a>>2];ju(a);Ib(b);c=Fb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function vi(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Hb(b+12|0,b+8|0)>>2];hb=b+16|0;return a}function tA(a){var b=0,c=0,d=0;if(x[a>>2]){Gc(a);b=x[a>>2];ti(a);Ib(b);c=Fb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function hh(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Hb(b+12|0,b+8|0);hb=b+16|0;return x[a>>2]}function bO(a){var b=0,c=0,d=0;if(x[a>>2]){Gc(a);b=x[a>>2];Tm(a);Ib(b);c=Fb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function ZO(a){var b=0,c=0,d=0;if(x[a>>2]){Gc(a);b=x[a>>2];Gm(a);Ib(b);c=Fb(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function GG(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function zd(a,b){var c=0;c=b+4|0;Jp(x[a>>2],x[a+4>>2],c);nc(a,c);nc(a+4|0,b+8|0);nc(Fb(a),yc(b));x[b>>2]=x[b+4>>2]}function pc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function FQ(a){var b=0;if(!(Ob(a+44|0,13667,4)|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function FH(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function CU(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function vK(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function oN(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function cH(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!uc(fH(c,b),-1)){break a}x[a>>2]=0}return a|0}function RL(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=rL(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function Qk(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function Fl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}uh(a,b);a=a+1|0;continue}}}function Er(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}nc(a,b);a=a+4|0;continue}}}function dP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function _P(a){if(Ob(a,13640,4)){a=0}else{a=(ac(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}return a}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=mb[x[x[b>>2]+8>>2]](b)|0;d=c,e=Wf(a?a:21473),x[d>>2]=e}}function nw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function at(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function Xi(a){a:{a=x[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function N$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=yw(b);x[a+36>>2]=b;c=a,d=nn(b),v[c+44|0]=d}function F$(a,b){a=a|0;b=b|0;var c=0,d=0;mb[x[x[a>>2]+24>>2]](a)|0;b=Dw(b);x[a+36>>2]=b;c=a,d=nn(b),v[c+44|0]=d}function Bm(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function zE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Cb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function xF(a,b){var c=0;c=hb-16|0;hb=c;a=Bl(c,a,1);tk(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;kc(a);hb=c+16|0}function vg(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function rQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;lb=b;return c}function pL(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Hb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function mu(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Hb(b+12|0,b+8|0)>>1];hb=b+16|0;return a}function lu(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=(D(a,b)>>>0)/255;ge(c+12|0,0,15);hb=c+16|0;return y[c+12|0]}function gd(a,b){var c=0;c=hb-16|0;hb=c;sk(c+8|0,a+24|0,b);a=Bb(x[x[c+8>>2]>>2],x[c+12>>2]);hb=c+16|0;return a}function Kg(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!ej(x[a+4>>2],x[b+4>>2])}function mp(a,b){var c=0;c=hb-32|0;hb=c;Bh(c+16|0,b);kn(c+24|0,a,x[c+16>>2],x[c+20>>2]);Bh(c+8|0,b);hb=c+32|0}function kM(a,b){var c=0;c=hb-16|0;hb=c;a=Dz(c,a);Lp(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;kc(a);hb=c+16|0}function hu(a){var b=0;b=hb-16|0;hb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Zc(b+14|0,b+12|0)|0];hb=b+16|0;return a}function bw(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=cw(x[e>>2],h)}mb[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function UL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Tk(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;x[e+8>>2]=c;fc(a,b,x[Hb(e+12|0,e+8|0)>>2]);hb=e+16|0}function ki(a){var b=0,c=0;x[x[a+20>>2]>>2]=a;c=x[a+12>>2];b=x[c>>2];x[a+4>>2]=b;if(b){x[b+8>>2]=a}x[c>>2]=a}function hH(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return Mf(v[b|0])}function WF(a,b,c,d,e){b=Ri(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function TF(a,b,c,d,e){b=Qi(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Qq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hb-16|0;hb=d;v[d+15|0]=0;Yf(a,b,ii(b,b+c|0,d+15|0));hb=d+16|0}function Pw(a,b){var c=0;if(b>>>0<=9999){return Ow(a,b)}c=a;a=(b>>>0)/1e4|0;return Zi(Ow(c,a),D(a,-1e4)+b|0)}function KO(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+28896|0]>>>z[a+68>>1]}function Caa(){var a=0;a=hb-16|0;hb=a;if(_a(a+12|0,4)|0){Ur(x[115896],12500);p()}hb=a+16|0;return x[a+12>>2]}function kga(a,b){a=a|0;b=b|0;if(!pS(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function hm(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=c+8|0;x[a>>2]=x[a>>2]+(b<<2);hb=c+16|0;return x[a>>2]}function Xx(a,b){a=Qb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Qb(a+24|0);Jb(a+36|0);x[a+48>>2]=b;return a}function XH(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Cm(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Hb(b+12|0,b+8|0)|0];hb=b+16|0;return a}function CR(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function aga(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Aj(a,b+8|0)){c=_R(b+8|0)}hb=b+16|0;return c|0}function _u(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,rd(a)+Bd(x[a+4>>2],y[a+11|0])|0)>>2];hb=b+16|0;return a}function _Q(a){var b=0;if(!(Ob(a,17654,4)|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function Zs(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Mn(a);continue}break}return a}function Uu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Bia(a,b){a=a|0;b=b|0;var c=0;b=hb-80|0;hb=b;c=-1;if(nU(a,b+8|0)){c=mU(b+8|0)}hb=b+80|0;return c|0}function z3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return NE(a,b,c,d,e,f,g,12767,982)|0}function ur(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=cw(x[d>>2],g)}mb[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function pu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Am(c+8|0,a);x[c+4>>2]=x[c+8>>2];fu(c+4|0,b);hb=c+16|0}function kO(a,b){var c=0;c=x[a+484344>>2];if(oe(c,x[a+484348>>2],b)){a=x[_b(c,b)+12>>2]}else{a=1}return a}function kF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function k3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return NE(a,b,c,d,e,f,g,12835,989)|0}function TU(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(Aj(a,b+8|0)){c=FB(b+8|0)}hb=b+16|0;return c|0}function Dk(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return mb[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function sM(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Pk(c);continue}break}x[a+4>>2]=b}function kC(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;zb(c);continue}break}x[a+4>>2]=b}function hfa(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){Pp(a,b);vo(a,b,c)}return a|0}function he(a,b){a=wl(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];wl(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function eO(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Je(c);continue}break}x[a+4>>2]=b}function cQ(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;bQ(c);continue}break}x[a+4>>2]=b}function SO(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Yk(c);continue}break}x[a+4>>2]=b}function Rb(a,b,c){var d=0;c=x[a+4>>2]+c|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function yV(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){kl(a,b);nC(a,b,c)}return a|0}function wm(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){rl(a,b);Bo(a,b,c)}return a|0}function aT(a,b,c){a=a|0;b=b|0;c=c|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){au(a,b);RA(a,b,c)}return a|0}function RT(a){a:{if(Ob(a,14026,4)){break a}if(Ob(a+8|0,14007,4)){break a}return 1}return!Ob(a,14007,4)}function JN(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function $X(){if(y[467148]){return x[116786]}ip(467140,LJ());v[467148]=1;x[116786]=467140;return 467140}function lF(a){var b=0,c=0;b=hb-16|0;hb=b;a=ai(b+8|0,a);c=x[x[115922]>>2];$h(a);hb=b+16|0;return c?4:1}function Vk(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function vP(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=Ob(a,17502,17)}else{a=1}return!a}function lB(a,b){if(b>>>0<=126){Te(((b<<5)+a|0)+480280|0);_n((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function jB(a){var b=0,c=0;if(x[a>>2]){Gc(a);Ib(x[a>>2]);b=Fb(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function bW(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;c=-1;if(Aj(a,b+8|0)){c=kD(b+8|0)}hb=b+16|0;return c|0}function Tb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function IW(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=-1;if(PD(a,b+8|0)){c=OD(b+8|0)}hb=b+32|0;return c|0}function Fq(a,b,c){var d=0;d=hb-16|0;hb=d;if(b){v[d+15|0]=0;_K(a+36|0,b,ii(b,b+c|0,d+15|0))}hb=d+16|0}function zM(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function xP(a){_d(a+140|0);zb(a+120|0);zb(a+100|0);zb(a+80|0);zb(a+60|0);zb(a+40|0);zb(a+20|0);zb(a)}function wq(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Sq(a,b+8|0)){c=Lb(z[b+8>>1])}hb=b+16|0;return c|0}function vl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function v1(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;YB(c+8|0,b);Qq(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function to(a){a=a|0;var b=0,c=0;b=hb-16|0;hb=b;if(Go(a,b+8|0)){c=ac(x[b+8>>2])}hb=b+16|0;return c|0}function US(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){TS(c+52|0);yb(c+40|0);tc(c+16|0);tc(c+4|0);Ib(c)}}function MV(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;Fm(c+8|0,b);Qq(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function LV(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Yj(a+8|0,0);Oq(a,127);RC(a,127,y[b|0]);return a|0}function LR(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;w[a+14>>1]=0;return a}function Cu(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function r1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ez(xx(x[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function eM(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21473}else{a=21473}return a}function Rc(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];KD(b);return a}function KS(a,b,c){var d=0;d=c;b=b-a|0;c=x[c>>2]+D((b|0)/-6|0,6)|0;x[d>>2]=c;if((b|0)>0){pc(c,a,b)}}function rfa(a,b){a=a|0;b=b|0;var c=0;b=hb-16|0;hb=b;c=-1;if(pB(a,b)){c=tR(b)}hb=b+16|0;return c|0}function mF(a,b,c,d,e){var f=0;f=hb-16|0;hb=f;e=ai(f+8|0,e);a=Ir(a,b,c,d);$h(e);hb=f+16|0;return a}function iO(a,b,c){var d=0;d=hb-16|0;hb=d;a=x[gc(d+8|0,$N(b,c,Vd(a),ic(a)))>>2];hb=d+16|0;return a}function Wu(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=ng(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)<<24>>24}function Q2(a,b){a=a|0;b=b|0;var c=0;b=Ic(b);c=x[a+4>>2];if(c){mb[c|0](b,x[a+8>>2]);return}xs(b,a)}function Ofa(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Sq(a,b+8|0);hb=b+16|0;return(a?z[b+8>>1]:0)<<16>>16}function N7(a,b,c){a=a|0;b=b|0;c=c|0;a=Oj(a);if(!a){return 0}return mb[x[x[a>>2]+100>>2]](a,b,c)|0}function Kn(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function r3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;mb[x[x[b>>2]+8>>2]](b,c);d=a;a=b+4|0;ip(d,a);CJ(a,c)}function dx(a,b,c){b=(D(D(bx(a),cx(a,b)),125)>>>0)/(dI(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function wr(a,b,c,d){var e=0;e=hb-16|0;hb=e;hc(e+8|0,c,d);ZF(a,b,x[e+8>>2],x[e+12>>2]);hb=e+16|0}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f)|0}function u0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function t0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function s0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function r0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function kn(a,b,c,d){var e=0;e=hb-16|0;hb=e;Lg(e+8|0,c,d);ZF(a,b,x[e+8>>2],x[e+12>>2]);hb=e+16|0}function di(a,b,c){if(c){while(1){x[a>>2]=x[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function JE(a,b,c){var d=0;d=hb-16|0;hb=d;c=Vb(d,c);a=rc(a,c);xb(c);x[a>>2]=b;hb=d+16|0;return a}function Gz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Di(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=x[a>>2];a=x[MA(c+8|0,b)>>2];hb=c+16|0;return a}function z2(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=x[mf(b+8|0,Zj(wc(12),a))>>2];hb=b+16|0;return a|0}function nt(a,b){b=Wia(a,a>>31,b,b>>31)+5e5|0;a=lb;return Hc(Xia(b,b>>>0<5e5?a+1|0:a,1e6,0),lb)}function kR(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function hv(a,b){a=eD(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];eD(a+12|0,x[b+12>>2],x[b+16>>2])}function _U(a,b){a=a|0;b=b|0;if(!zu(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function _$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function VU(a){a=a|0;var b=0;b=x[a+76>>2];if(uc(-1,b)){b=vC(a,32);x[a+76>>2]=b}return b<<24>>24}function Hga(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Go(a,b+8|0);hb=b+16|0;return E(a?B[b+8>>2]:E(0))}function HX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Kg(a,x[b+8>>2],f)){fw(b,c,d,e)}}function H4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return TE(a,b,c,d,e,f,10556,953)|0}function G3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return TE(a,b,c,d,e,f,10511,979)|0}function x9(a,b){a=a|0;b=b|0;mi(a);mi(a);a:{if(b>>>0>=60){$b(a,4);break a}mi(a)}return mi(a)|0}function vG(a){var b=0;b=x[115922];if(a){x[115922]=(a|0)==-1?466932:a}return(b|0)==466932?-1:b}function rU(a){var b=0;if(!(Ob(a,26180,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function nr(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function eU(a,b){return(Xb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Xb((D(a&15,b)>>>0)/15|0,1,15))&255}function bda(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){kl(a,b);sP(a,b)}return a|0}function aB(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[pT(c+8|0,0-b|0)>>2];hb=c+16|0;return a}function PS(a,b,c){var d=0;d=hb-16|0;hb=d;v[d+15|0]=0;fc(a,b,ii(b,b+c|0,d+15|0)-b|0);hb=d+16|0}function KH(a){var b=0;b=+((a&2097151)>>>0);return E(Dj(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function yk(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,sc(a)+(Eb(a)<<2)|0)>>2];hb=b+16|0;return a}function yC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;lb=a;return b}function ru(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Vb(c,b);Rc(d,a);xb(a);hb=c+16|0}function rg(a,b){a=a|0;b=b|0;var c=0,d=0;c=hb-16|0;hb=c;d=a;a=Vb(c,b);Rc(d,a);yb(a);hb=c+16|0}function kB(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);if(b){rl(a,b);hE(a,b)}return a|0}function aQ(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function Ql(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Lc(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=OS(a,b,x[c>>2],d)}else{a=1}return!a}function xQ(a){var b=0,c=0;b=hb-16|0;hb=b;if(wQ(a,b+8|0)){c=ac(x[b+8>>2])}hb=b+16|0;return c}function wG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function n0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return mb[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function iF(a){a=a|0;var b=0;x[a>>2]=82076;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Ib(b)}return a|0}function JV(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=ng(a,b+8|0);hb=b+16|0;return(a?y[b+8|0]:0)&255}function Afa(a){a=a|0;var b=0,c=0;b=hb-32|0;hb=b;c=a;a=zh(b+8|0);YR(c,a,0,0);zb(a);hb=b+32|0}function fx(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=WJ(d);b=b+1|0}fI(a,b,c,d,e)}function WQ(a){a:{if(Ob(a,17447,4)){break a}if(Ob(a+8|0,14064,4)){break a}return 1}return 0}function Py(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function PC(a,b){if((a&4088)>>>0>=520){b=Zu(0-_ia(b^1230262859,25)|0,4)^1247037516}return b}function Cg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){lB(a,c);b=b+1|0;continue}break}}function $ea(a){a=a|0;var b=0;b=hb-16|0;hb=b;a=Wh(a,b+8|0);hb=b+16|0;return+(a?C[b+8>>3]:0)}function zl(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[Cb(a+4208|0,b)>>2]}else{d=E(0)}return d}function wi(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function sv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+21476>>2]}else{b=9634}Vb(a,b)}function pK(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function hw(a,b,c){var d=0;d=hb-16|0;hb=d;c=ai(d+8|0,c);a=Qw(a,b);$h(c);hb=d+16|0;return a}function gH(a){var b=0;b=x[a>>2];if(b){if(!uc(hH(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function eD(a,b,c){var d=0;d=hb-16|0;hb=d;b=wl(d+8|0,b,c);GD(b,a);de(b);hb=d+16|0;return a}function _g(a,b){var c=0;c=hb-16|0;hb=c;x[c+8>>2]=a;a=x[MA(c+8|0,b)>>2];hb=c+16|0;return a}function Y5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;wx(a,b,c,d,e,0,0,f,g)}function CP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;lb=a;return b}function xw(a,b,c,d){var e=0;e=hb-16|0;hb=e;x[e+12>>2]=d;a=Hr(a,b,c,d);hb=e+16|0;return a}function sp(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function gK(a,b){a=a|0;b=b|0;var c=0;c=Eb(a);if(c>>>0<b>>>0){qu(a,b-c|0,0);return}BK(a,b)}function _ia(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function Ux(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function S7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Oj(a);if(a){mb[x[x[a>>2]+76>>2]](a,b,c,d)}}function R7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Oj(a);if(a){mb[x[x[a>>2]+84>>2]](a,b,c,d)}}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Oj(a);if(a){mb[x[x[a>>2]+88>>2]](a,b,c,d)}}function GJ(a){a=a|0;var b=0;x[a>>2]=49072;b=x[a+4>>2];if(b){Ib(b);x[a+4>>2]=0}return a|0}function Eg(a){var b=0;b=hb-16|0;hb=b;a=Sq(a,b+8|0);hb=b+16|0;return(a?z[b+8>>1]:0)&65535}function $T(a,b,c){var d=0;d=hb-16|0;hb=d;yi(d+8|0,b,c);hb=d+16|0;return x[d+8>>2]==(a|0)}function zv(){var a=0,b=0;a=hb-16|0;hb=a;b=mf(a+8|0,Qb(wc(12)));hb=a+16|0;return x[b>>2]}function rz(a,b){a=Zj(a,b);Rc(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function ms(a){if(pJ(a)){a=ba(4)|0;x[a>>2]=0;a=Nl(a);x[a>>2]=91304;ha(a|0,91340,25);p()}}function mh(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,sc(a)+Eb(a)|0)>>2];hb=b+16|0;return a}function cR(a,b){var c=0;c=hb-16|0;hb=c;Fm(c+8|0,b);PS(a,x[c+8>>2],x[c+12>>2]);hb=c+16|0}function Ls(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,Ic(a)+Eb(a)|0)>>2];hb=b+16|0;return a}function GA(a,b,c){var d=0;d=hb-16|0;hb=d;Tt(a,c);v[d+15|0]=0;sd(b+c|0,d+15|0);hb=d+16|0}function Fx(a,b,c){var d=0;d=hb-16|0;hb=d;Kh(a,c);v[d+15|0]=0;sd(b+c|0,d+15|0);hb=d+16|0}function FM(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function Ee(a){var b=0;b=hb-16|0;hb=b;a=ng(a,b+15|0);hb=b+16|0;return(a?y[b+15|0]:0)&255}function BM(a){a=Jb(a);Jb(a+12|0);Jb(a+24|0);Jb(a+36|0);Jb(a+48|0);x[a+60>>2]=0;return a}function As(a,b){var c=0;c=Ic(a);if(c>>>0<=b>>>0){a=Eb(a)+c>>>0>=b>>>0}else{a=0}return a}function zL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Ji(c,a,d)}return D((d|0)/6|0,6)+c|0}function xp(a,b,c){a=Rk(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function nW(a){a=a|0;var b=0;b=x[a+4>>2];return(mb[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function mt(a){var b=0;b=hb-16|0;hb=b;v[b+15|0]=0;Ql(a,$n(a),b+15|0);hb=b+16|0;return a}function ZG(a){var b=0;b=x[a>>2];if(b){if(!qn(Dk(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Xp(a,b,c){var d=E(0);d=B[a>>2];if(!Wt(d,B[b>>2])){b=Wt(B[c>>2],d)?c:a}return b}function XA(a){var b=0;b=Cz(a);while(1){if((a|0)!=(b|0)){AU(a);a=a+32|0;continue}break}}function U7(a,b){a=a|0;b=b|0;a=Oj(a);if(!a){return 1}return mb[x[x[a>>2]+68>>2]](a,b)|0}function Sm(a){var b=0;b=tv(a+4|0);if((b|0)==-1){mb[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function Sh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Nv(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function Cx(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=WJ(d);b=b+1|0}zx(a,b,c,d)}function AG(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;a=BG(a,11034,b);hb=c+16|0;return a}function rk(a,b,c){var d=0,e=0;d=hb-16|0;hb=d;e=d+8|0;sk(e,a+24|0,b);vg(e,c);hb=d+16|0}function Sk(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Ab(d,a,b);pm(d);hb=c+16|0;return a}function RW(){var a=0;a:{if(WD(19924737)){break a}if(VD()){break a}a=UD()^1}return a|0}function NR(a){var b=0;b=a+24|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Mu(a,b){a=a|0;b=b|0;var c=0;c=hb-16|0;hb=c;v[c+15|0]=b;iJ(a,c+15|0);hb=c+16|0}function LP(a){var b=0;b=a+36|0;while(1){b=xb(b-12|0);if((b|0)!=(a|0)){continue}break}}function HN(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;sk(d,a,b);pm(d);hb=c+16|0;return a}function HD(a,b){var c=0;c=hb-16|0;hb=c;b=qg(c+8|0,b);GD(b,a);de(b);hb=c+16|0;return a}function GB(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+26128|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function EO(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function Dc(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;Fm(d,a);pl(d,b);hb=c+16|0;return a}function xs(a,b){a=a|0;b=b|0;b=hb-16|0;hb=b;x[b>>2]=a;UJ(17676,b);ws(92720);hb=b+16|0}function uA(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=Nh(e,a,d);Zt(b,c,a+4|0);kc(a);hb=e+16|0}function nl(a,b,c){a=a|0;b=b|0;c=c|0;if(Mc(a,b)>>>0<=c>>>0){Su();p()}return(c<<1)+a|0}function hY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+80576>>2]}return b<<24>>24}function fY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+79040>>2]}return b<<24>>24}function aZ(a){a=a|0;a=468440;while(1){a=Jc(a-12|0);if((a|0)!=468416){continue}break}}function _t(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=Bl(e,a,d);Zt(b,c,a+4|0);kc(a);hb=e+16|0}function _Y(a){a=a|0;a=467768;while(1){a=Jc(a-12|0);if((a|0)!=467600){continue}break}}function Ys(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){ly(a,b,0);ly(a,b,1);ly(a,b,2)}}function Ut(a,b){var c=0;c=hb-16|0;hb=c;w[c+14>>1]=b;Pt(a+236|0,128,c+14|0);hb=c+16|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return EE(b,c,d,e,f,1)|0}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return EE(b,c,d,e,f,0)|0}function QO(a,b,c,d){var e=0;e=hb-16|0;hb=e;a=Gi(e,a,d);Zt(b,c,a+4|0);kc(a);hb=e+16|0}function OY(a){a=a|0;a=468408;while(1){a=xb(a-12|0);if((a|0)!=468384){continue}break}}function NY(a){a=a|0;a=468064;while(1){a=xb(a-12|0);if((a|0)!=467776){continue}break}}function N0(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function MY(a){a=a|0;a=467592;while(1){a=xb(a-12|0);if((a|0)!=467424){continue}break}}function MF(a,b){var c=0,d=0;Me(a,Zd(b));b=ic(b);c=ic(a),d=x[b>>2],x[c>>2]=d;return a}function M0(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function K_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return CE(b,c,d,e,f,1)|0}function KD(a){var b=0;while(1){if((b|0)!=3){x[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function Jp(a,b,c){var d=0;d=c;b=b-a|0;c=x[c>>2]-b|0;x[d>>2]=c;if((b|0)>0){pc(c,a,b)}}function I_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return CE(b,c,d,e,f,0)|0}function Hl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function F4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SE(a,b,c,d,e,12323,954)|0}function E3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return SE(a,b,c,d,e,12223,980)|0}function Bt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function $Y(a){a=a|0;a=468368;while(1){a=Jc(a-12|0);if((a|0)!=468080){continue}break}}function yg(a,b,c){var d=0;d=C[a>>3];if(!wP(d,C[b>>3])){b=wP(C[c>>3],d)?c:a}return b}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ME(a,b,c,d,e,9518,983)|0}function vj(a,b,c){var d=0;d=x[a>>2];if(!$o(d,x[b>>2])){b=$o(x[c>>2],d)?c:a}return b}function oe(a,b,c){if(zm(a,b,c)){a=Pf(a,c);a=Pb(x[a>>2],x[a+4>>2])}else{a=0}return a}function i3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ME(a,b,c,d,e,9590,990)|0}function df(a){a=a|0;var b=0;b=x[a>>2];return(mb[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function Yv(a,b){var c=0;while(1){if((b|0)!=(c|0)){ug(a+c|0);c=c+1|0;continue}break}}function Rh(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;Sh(a)}function Qz(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function Mn(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function IP(a,b,c,d,e,f){a=gc(a,b);gc(a+4|0,c);gc(a+8|0,d);gc(a+12|0,e);gc(a+16|0,f)}function AF(a,b){a:{if(!(y[a+120|0]|b>>>0>30)){v[a+120|0]=1;break a}a=qi(b)}return a}function yG(a){return(a|0)!=0&(a|0)!=88800&(a|0)!=88824&(a|0)!=466848&(a|0)!=466872}function y7(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function qg(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function nF(a){a=a|0;x[a>>2]=83160;if(x[a+8>>2]!=(Ad()|0)){xG(x[a+8>>2])}return a|0}function n8(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function jp(a){a=a|0;x[a+56>>2]=76808;x[a>>2]=76788;qs(a+4|0);Gk(a+56|0);return a|0}function gq(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Ie(Ej(b)*+(c>>>0)),x[d+24>>2]=e}function gf(a){a=a|0;x[a+60>>2]=76972;x[a>>2]=76952;qs(a+8|0);Gk(a+60|0);return a|0}function cx(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+63537|0]<<1}function cO(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ic(a)+4|0]){dO(b+16|0)}Ib(b)}}function RS(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ic(a)+4|0]){$t(b+16|0)}Ib(b)}}function Qd(a){var b=0;b=hb-16|0;hb=b;x[b+12>>2]=49240;bo(a,49136,b+12|0);hb=b+16|0}function OL(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ic(a)+4|0]){cc(b+16|0)}Ib(b)}}function H5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return RJ(a,b,c,d,0,0,0,0,e)|0}function vy(a){var b=0;b=hb-16|0;hb=b;gc(b+8|0,a+116|0);a=rM(a);hb=b+16|0;return a}function pr(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function pg(a){var b=0;b=hb-16|0;hb=b;a=Go(a,b+8|0);hb=b+16|0;return a?x[b+8>>2]:0}function nN(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function e8(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];Es(a);ZK(a)}function To(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function NH(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function N6(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];sK(a);rK(a)}function kL(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function fo(a,b){a=pc(a,b,34);w[a+34>>1]=z[b+34>>1];pc(a+36|0,b+36|0,68);return a}function Pt(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function DP(a){if((y[a+14|0]-53&255)>>>0>=252){a=Ob(a,15386,14)}else{a=1}return!a}function yf(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,Kf(a))>>2];hb=b+16|0;return a}function sX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=mb[a|0](b,c,d)|0;ib=lb;return a|0}function qj(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,Db(a))>>2];hb=b+16|0;return a}function gl(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;jc(a+8|0,b+8|0)}function Yd(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,sc(a))>>2];hb=b+16|0;return a}function UJ(a,b){var c=0;c=hb-16|0;hb=c;x[c+12>>2]=b;yH(92720,a,b,0,0);hb=c+16|0}function Ns(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,Ic(a))>>2];hb=b+16|0;return a}function Kf(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,ic(a))>>2];hb=b+16|0;return a}function Ei(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,rd(a))>>2];hb=b+16|0;return a}function tY(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+82128>>2]&b)!=0&c>>>0<=127}function rh(a,b,c){a=gc(a,b);b=x[c+4>>2];x[a+4>>2]=x[c>>2];x[a+8>>2]=b;return a}function rX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;mb[a|0](b,c,d,e,f)}function iE(){var a=0;a=hb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function hD(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function gg(a){var b=0,c=0;Bc(a+4|0);Yj(a+8|0,0);b=a,c=ic(a),x[b>>2]=c;return a}function Uh(a){return(zj(x[a>>2],x[a+4>>2])|0)!=(0-zj(x[a+12>>2],x[a+16>>2])|0)}function Rv(a,b){b=a+b|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function OZ(){var a=0,b=0,c=0;a=Od(468496);x[a>>2]=83160;b=a,c=Ad(),x[b+8>>2]=c}function oX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return mb[a|0](b,c,d,e)|0}function iZ(a){a=a|0;if(!y[467376]){cn(467364,83396);v[467376]=1}return 467364}function gZ(a){a=a|0;if(!y[467408]){cn(467396,83480);v[467408]=1}return 467396}function ey(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Fb(a)>>2]){kM(a,b);return}Sz(a,b)}function eo(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function eZ(a){a=a|0;if(!y[467312]){cn(467300,83324);v[467312]=1}return 467300}function cZ(a){a=a|0;if(!y[467344]){cn(467332,83360);v[467344]=1}return 467332}function a1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return oI(a-88|0,b,c,d,e)|0}function WY(a){a=a|0;if(!y[467360]){Vb(467348,13339);v[467360]=1}return 467348}function QY(a){a=a|0;if(!y[467328]){Vb(467316,13548);v[467328]=1}return 467316}function Iu(a,b){return Ie(Ej((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function FT(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Fb(a)>>2]){xF(a,b);return}uF(a,b)}function BC(a){var b=0;b=hb-16|0;hb=b;v[b+15|0]=0;Ql(a,Mo(a),b+15|0);hb=b+16|0}function ze(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;$u(d,a);pl(d,b);hb=c+16|0}function ym(a,b){var c=0,d=0;c=hb-16|0;hb=c;d=c+8|0;YB(d,a);pl(d,b);hb=c+16|0}function _i(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Ib(b)}function _X(a,b){a=a|0;b=b|0;a=Nl(a);x[a>>2]=91832;gw(a+4|0,Ic(b));return a|0}function Zi(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Vr(Vr(c,a),D(a,-100)+b|0)}function XN(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function Vy(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function UY(a){a=a|0;if(!y[467392]){Vb(467380,9155);v[467392]=1}return 467380}function UX(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[468944]){v[468944]=1}fc(a,c,93164)}function Sx(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function SY(a){a=a|0;if(!y[467296]){Vb(467284,5226);v[467296]=1}return 467284}function Rx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function MX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Kg(a,x[b+8>>2],0)){dw(b,c,d)}}function L9(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Fb(a)>>2]){kM(a,b);return}Sz(a,b)}function BP(a,b){a=QQ(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function xe(a){var b=0;b=hb-16|0;hb=b;Eu(b+8|0,a);hb=b+16|0;return x[b+8>>2]}function eG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[a>>2]+32>>2]](a,b,c,d)|0}function ak(a){var b=0;b=hb-16|0;hb=b;a=x[mf(b+8|0,a)>>2];hb=b+16|0;return a}function aG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[x[x[a>>2]+48>>2]](a,b,c,d)|0}function Xd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];$b(b,c);wv(a,b,d,c)}function WM(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function P6(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function HF(a){var b=0;b=hb-16|0;hb=b;x[b+8>>2]=a;hb=b+16|0;return x[b+8>>2]}function Db(a){var b=0;b=hb-16|0;hb=b;a=x[gc(b+8|0,a)>>2];hb=b+16|0;return a}function yO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);pO(a,b,0,0,b+-1,0)}function v3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,12724,984)|0}function q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,12798,986)|0}function pY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+80576>>2]}return b|0}function nY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+79040>>2]}return b|0}function mg(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function dI(a,b){a=a^-1;return x[(b&12)+63540>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function aS(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function W_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FE(b,c,d,e,1)|0}function WG(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function U$(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){TG(a,c);return}Vb(a,7838)}function T_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FE(b,c,d,e,0)|0}function Nz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function Mr(a,b,c,d,e,f,g,h){return mb[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function M_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return DE(b,c,d,e,1)|0}function MK(a){a=a|0;x[a>>2]=46244;tc(a+4276|0);tc(a+4264|0);return vf(a)|0}function J_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return DE(b,c,d,e,0)|0}function Bl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,9473,985)|0}function rv(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){Ji(c,a,d)}return c+d|0}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,9551,987)|0}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,9353,988)|0}function gh(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function XX(a,b,c){a=a|0;b=b|0;c=c|0;return uc(a,x[b+4>>2])&x[b>>2]==(c|0)}function Wj(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(yP(a)?b:a)&65535}function Vr(a,b){b=z[(b<<1)+75936>>1];v[a|0]=b;v[a+1|0]=b>>>8;return a+2|0}function B3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $m(a,b,c,d,9322,981)|0}function zD(a,b){a=a|0;b=b|0;a=Nl(a);x[a>>2]=91832;gw(a+4|0,b);return a|0}function yD(a,b){a=qg(a,b);x[a+8>>2]=x[b+8>>2];qg(a+12|0,b+12|0);return a}function rd(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Sf(y[a+11|0]),d?b:c}function qo(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+48>>2]](a,b,c)|0}function kt(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;return a}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=xo(a,b),x[d>>2]=e}function bd(a,b){a=HD(a,b);x[a+8>>2]=x[b+8>>2];HD(a+12|0,b+12|0);return a}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Vu(a,b),w[d>>1]=e}function _c(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function Zt(a,b,c){b=b-a|0;if((b|0)>0){pc(x[c>>2],a,b);x[c>>2]=b+x[c>>2]}}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+32>>2]](a,b,c)|0}function H7(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function DR(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function Ck(a,b,c){a=a|0;b=b|0;c=c|0;return mb[x[x[a>>2]+12>>2]](a,b,c)|0}function zw(a,b){var c=0;c=MG(a+4|0);x[a>>2]=77968;x[c>>2]=77988;An(c,b)}function rP(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function oH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;gh(a,-1,-1)}function Aw(a,b){var c=0;c=rs(a+4|0);x[a>>2]=77600;x[c>>2]=77620;An(c,b)}function xI(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function tc(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];ti(a);Ib(b)}return a}function sB(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function qc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=qf(b),x[c+4>>2]=d;return a}function nm(a){if(Sf(y[a+11|0])){a=QA(x[a+8>>2])-1|0}else{a=10}return a}function kd(a){var b=0;if(x[a>>2]){kC(a,x[a>>2]);b=x[a>>2];lC(a);Ib(b)}}function gea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;pE(a,b,c,d,e,127)}function fQ(a){var b=0;if(x[a>>2]){cQ(a,x[a>>2]);b=x[a>>2];Fj(a);Ib(b)}}function aU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function Yo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function Vw(a){return((kh(a)+(kh(a)<<8)|0)+(kh(a)<<16)|0)+(kh(a)<<24)|0}function Vf(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Kt(a);Ib(b)}return a}function Oia(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){va();p()}}function MO(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function IK(a){a=a|0;return E(E(E(B[Cb(a+4208|0,5)>>2]*E(198))+E(-99)))}function Fha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;pE(a,b,c,d,e,101)}function FO(a){if(a>>>0<=8){return y[a+29024|0]}return y[a+29015|0]|256}function xk(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function wz(a,b){a=Qb(a);Jb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function tR(a){if(Ob(a,13662,4)){a=1}else{a=Ob(a+8|0,13715,4)}return!a}function ig(){var a=0;a=Pl(ba(4)|0);x[a>>2]=91716;ha(a|0,91792,25);p()}function ew(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function dy(a,b){if(b){dy(a,x[b>>2]);dy(a,x[b+4>>2]);cc(b+16|0);Ib(b)}}function _y(a,b){if(b){_y(a,x[b>>2]);_y(a,x[b+4>>2]);bm(b+16|0);Ib(b)}}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $v(a,b,c,d,524)|0}function Xq(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function OA(a,b){if(b){OA(a,x[b>>2]);OA(a,x[b+4>>2]);$t(b+16|0);Ib(b)}}function NA(a,b){if(b){NA(a,x[b>>2]);NA(a,x[b+4>>2]);$t(b+16|0);Ib(b)}}function Ly(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function Dp(a,b){if(b){Dp(a,x[b>>2]);Dp(a,x[b+4>>2]);dO(b+16|0);Ib(b)}}function yJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){zn(c+120|0);Ib(c)}}function tX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;mb[a|0](b,c,d,e)}function pM(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function iw(a){a=a|0;if(x[a+8>>2]!=(Ad()|0)){xG(x[a+8>>2])}return a|0}function cr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $v(a,b,c,d,157)|0}function Xk(a,b){a=y[Kb(a+62|0,b)|0];return(a<<24>>24<0?-1:a&127)&255}function KT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return $v(a,b,c,d,319)|0}function KP(a,b,c,d,e){a=gc(a,b);gc(a+4|0,c);gc(a+8|0,d);gc(a+12|0,e)}function FX(a){a=a|0;if(!a){return 0}return(Jy(a,91388,91532)|0)!=0|0}function zP(a,b){a=Xz(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function su(a,b){var c=0;c=hb-16|0;hb=c;OC(c,a,64);SC(c,b);hb=c+16|0}function pX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mb[a|0](b,c,d)|0}function oS(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];jc(a+8|0,b+8|0)}function o$(a){a=a|0;var b=0;b=x[116788]+1|0;x[116788]=b;x[a+4>>2]=b}function VZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Oh(a,f)}function Il(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function BB(a,b){var c=0;c=hb-16|0;hb=c;OC(c,a,32);SC(c,b);hb=c+16|0}function wS(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function u3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return LE(a,b,c,d,4)|0}function s3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return LE(a,b,c,d,2)|0}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return KE(a,b,c,d,4)|0}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return KE(a,b,c,d,2)|0}function jM(a,b){var c=0;c=hb-16|0;hb=c;cA(c,1,b);Fc(a,c);hb=c+16|0}function Nq(a,b){return Yu(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function MB(a,b){return bE(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Kc(a,b,c){if(vc(a,b)>>>0<=c>>>0){Su();p()}return(c<<2)+a|0}function EM(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function wL(a,b){if((a|0)!=(b|0)){bS(a,x[b>>2],x[b+4>>2])}return a}function kY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function fd(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function eP(a,b){var c=0,d=0;c=gc(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function DF(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Ib(b)}}function zi(a,b){if(fg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function xm(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function vI(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function qv(a,b,c){a=qg(a,b);x[a+8>>2]=0;qg(a+12|0,c);de(c);de(b)}function pW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+12>>2]](a)|0}function oW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+16>>2]](a)|0}function fr(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+32>>2]](a,0,b)|0}function e6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,881,86224)|0}function dn(a,b){if(A[a+4>>2]<A[Fb(a)>>2]){xF(a,b);return}uF(a,b)}function YR(a,b,c,d){a=he(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function O$(a,b){a=a|0;b=b|0;if(!x[23420]){x[23420]=a;x[23421]=b}}function Ic(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Se(a),d?b:c}function EH(a,b){a=CH(a-1|0);if(!a){a=CH(b);a=a?a+32|0:0}return a}function zy(a){yb(a+48|0);yb(a+36|0);yb(a+24|0);yb(a+12|0);yb(a)}function xn(a,b,c){return PR(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function u6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,878,5048)|0}function sha(a,b){a=a|0;b=b|0;a=bu(a,b);x[a>>2]=91988;return a|0}function s8(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,852,4268)|0}function qW(a){a=a|0;a=x[a+4>>2];return mb[x[x[a>>2]+8>>2]](a)|0}function l6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,880,4276)|0}function kx(a,b,c){return Ih(x[a>>2],x[a+4>>2],b,x[a+12>>2]+c|0)}function kK(a){return E(E(B[Cb(a+4208|0,11)>>2]*E(19980))+E(20))}function hd(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function g7(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,873,4280)|0}function bga(a,b){a=a|0;b=b|0;a=bu(a,b);x[a>>2]=92040;return a|0}function bE(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function b8(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,860,4304)|0}function _6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,874,4276)|0}function T6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,875,4268)|0}function Qp(a,b,c){a=Lb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function FD(a,b,c){a=Qm(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=61196}function E6(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,877,4228)|0}function B7(a,b,c){a=a|0;b=b|0;c=c|0;return Ni(a,b,c,870,4236)|0}function yt(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Oz(a);Ib(b)}}function waa(a,b){a=a|0;b=b|0;a=sS(a,b);if(!a){rS(b)}return a|0}function vY(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return lF(a)|0}function ui(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];go(a);Ib(b)}}function tz(a){var b=0;if(x[a>>2]){TO(a);b=x[a>>2];go(a);Ib(b)}}function tr(a){var b=0;b=hb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function tM(a){var b=0;if(x[a>>2]){Qs(a);b=x[a>>2];Ps(a);Ib(b)}}function sw(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+12>>2]](a,b)|0}function se(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ys(b)}return a}function od(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Gm(a);Ib(b)}}function nM(a){var b=0;if(x[a>>2]){Lo(a);b=x[a>>2];nv(a);Ib(b)}}function lO(a){var b=0;if(x[a>>2]){fO(a);b=x[a>>2];Fj(a);Ib(b)}}function lK(a){return E(E(B[Cb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function ko(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];uS(a);Ib(b)}}function jl(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+28>>2]](a,b)|0}function je(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Tm(a);Ib(b)}}function jC(a){if(a>>>0>=214748365){ig();p()}return wc(D(a,20))}function fN(a,b){a=a|0;b=b|0;a=bu(a,b);x[a>>2]=91852;return a|0}function ek(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];ju(a);Ib(b)}}function dl(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];mr(a);Ib(b)}}function bQ(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Fj(a);Ib(b)}}function _d(a){var b=0;if(x[a>>2]){zU(a);b=x[a>>2];zB(a);Ib(b)}}function Yu(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function YD(a){if(a>>>0>=357913942){ig();p()}return wc(D(a,12))}function WP(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];nv(a);Ib(b)}}function W5(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Vg(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Tp(a,b,c){if(!b){return 0}return Ot(a,Mf(c<<24>>24),b)}function TN(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];az(a);Ib(b)}}function Lr(a,b){a=a|0;b=b|0;return mb[x[x[a>>2]+44>>2]](a,b)|0}function Jc(a){var b=0;if(Se(a)){b=x[a>>2];ll(a);Ib(b)}return a}function Gv(a){var b=0;b=hb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function Bs(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Px(a);Ib(b)}}function At(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];Fb(a);Ib(b)}}function AM(a){var b=0;if(x[a>>2]){Gc(a);b=x[a>>2];UT(a);Ib(b)}}function zA(a,b){a=a|0;b=b|0;a=Go(a,b);if(!a){vm(b)}return a|0}function yU(a,b){if(!b){return-1}b=Tp(a,b,0);return b?b-a|0:-1}function xv(a,b){a=a|0;b=b|0;a=sD(a,b);if(!a){rD(b)}return a|0}function tL(a){if(a>>>0>=82595525){ig();p()}return wc(D(a,52))}function oo(a,b){a=a|0;b=b|0;a=MT(a,b);if(!a){PT(b)}return a|0}function mv(a,b){a=Rc(a,b);jc(a+12|0,b+12|0);Tf(a+32|0,b+32|0)}function m_(a,b){a=a|0;b=b|0;XM(a,Jw(x[b>>2])<<24>>24,x[b>>2])}function mX(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+16>>2]](a,b,0,0,1,8)}function jv(a,b){a=a|0;b=b|0;a=dD(a,b);if(!a){Wq(b)}return a|0}function gr(a,b){a=a|0;b=b|0;a=lD(a,b);if(!a){Bv(b)}return a|0}function fM(a,b){return b>>>0>=4e3?21473:((b<<5)+a|0)+946304|0}function eE(a){w[a+12>>1]=0;x[a+8>>2]=-1;x[a>>2]=0;x[a+4>>2]=0}function ac(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function Yh(a,b){a=a|0;b=b|0;a=Wh(a,b);if(!a){vl(b)}return a|0}function WA(a,b){a=a|0;b=b|0;a=FS(a,b);if(!a){JA(b)}return a|0}function Uf(a,b){return mb[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function Tq(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function RB(a,b){a=a|0;b=b|0;a=xu(a,b);if(!a){Cu(b)}return a|0}function ON(a,b){a=a|0;b=b|0;a=bU(a,b);if(!a){ku(b)}return a|0}function It(a,b){a=a|0;b=b|0;a=NT(a,b);if(!a){iu(b)}return a|0}function IS(a){if(a>>>0>=715827883){ig();p()}return wc(D(a,6))}function I2(a,b,c){a=a|0;b=b|0;c=c|0;UN(a,0,x[b+1298404>>2],c)}function FK(a){a=a|0;return Vj(E(B[Cb(a+4208|0,4)>>2]*E(4)))|0}function CQ(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function $L(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function wl(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Nm(c)}return a}function uM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(oj(c))}}function qi(a){if(a>>>0>=1073741824){ig();p()}return wc(a<<2)}function q7(a,b,c){a=a|0;b=b|0;c=c|0;return Qv(a,b,c,0,872)|0}function pha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tE(a,b,c,d,101)}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qE(a,b,c,d,409)}function jh(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function dga(a,b,c){a=a|0;b=b|0;c=c|0;Rc(a,$R(c,Ic(b),Eb(b)))}function cl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ic(a);Ib(b)}}function Vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;qE(a,b,c,d,341)}function NI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function M6(a,b,c){a=a|0;b=b|0;c=c|0;return Qv(a,b,c,0,876)|0}function JD(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(dc(c))}}function F6(a,b,c){a=a|0;b=b|0;c=c|0;return Qv(a,b,c,1,876)|0}function Eia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tE(a,b,c,d,127)}function zI(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function tD(a){if(a>>>0>=536870912){ig();p()}return wc(a<<3)}function qs(a){a=a|0;x[a>>2]=76272;xb(a+32|0);return En(a)|0}function nc(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function jy(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function h7(a){a=a|0;return E(E(B[Cb(a+4208|0,6)>>2]*E(20)))}function gW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hc(a,x[d>>2],0)}function cE(a){if(a>>>0>=268435456){ig();p()}return wc(a<<4)}function Mi(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function Kx(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function GK(a){a=a|0;return E(E(B[Cb(a+4208|0,2)>>2]*E(10)))}function Fg(a,b,c,d){lb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function EP(a){if(a>>>0>=134217728){ig();p()}return wc(a<<5)}function CM(a){x[a>>2]=0;Qb(a+4|0);Tb(a+16|0,0,144);return a}function CH(a){return v[(D(0-a&a,124511785)>>>27|0)+72576|0]}function y4(a,b){a=a|0;b=b|0;return E(QE(a,b,6190,1075834))}function xA(a,b){if(b){xA(a,x[b>>2]);xA(a,x[b+4>>2]);Ib(b)}}function wA(a,b){if(b){wA(a,x[b>>2]);wA(a,x[b+4>>2]);Ib(b)}}function w4(a,b){a=a|0;b=b|0;return E(PE(a,b,6233,1075834))}function v4(a,b){a=a|0;b=b|0;return E(PE(a,b,6135,1075835))}function uX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb[a|0](b,c,d)}function u4(a,b){a=a|0;b=b|0;return E(QE(a,b,6091,1075835))}function tv(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function tH(a,b){if(b>>>0<=9){return sH(a,b)}return Vr(a,b)}function qx(a,b,c,d,e,f){return IE(a,b,c,d,e,f,56788,57584)}function ox(a,b,c,d,e,f){return IE(a,b,c,d,e,f,57664,58428)}function oY(a,b,c){a=a|0;b=b|0;c=c|0;return BE(b,c,80576)|0}function mY(a,b,c){a=a|0;b=b|0;c=c|0;return BE(b,c,79040)|0}function mU(a){return!Ob(a,14012,4)&(y[a+4|0]-1&255)>>>0<10}function lJ(a,b){a=a|0;b=b|0;return oi(x[b>>2],x[b+4>>2])|0}function kq(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function kJ(a,b){a=a|0;b=b|0;return qe(x[b>>2],x[b+4>>2])|0}function gY(a,b,c){a=a|0;b=b|0;c=c|0;return AE(b,c,80576)|0}function eY(a,b,c){a=a|0;b=b|0;c=c|0;return AE(b,c,79040)|0}function bu(a,b){a=Nl(a);x[a>>2]=91812;gw(a+4|0,b);return a}function bN(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(My(b))}}function ai(a,b){var c=0,d=0;c=a,d=vG(b),x[c>>2]=d;return a}function ZC(a,b){return rA(a,rd(b),Bd(x[b+4>>2],y[b+11|0]))}function Xs(a,b){if(b){Xs(a,x[b>>2]);Xs(a,x[b+4>>2]);Ib(b)}}function WR(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}function Vs(a,b){if(b){Vs(a,x[b>>2]);Vs(a,x[b+4>>2]);Ib(b)}}function R9(a){a=a|0;a=bu(a,21473);x[a>>2]=91932;return a|0}function QV(a){a=a|0;a=AD(a,13176);x[a>>2]=25932;return a|0}function O7(a){a=a|0;a=Oj(a);if(a){mb[x[x[a>>2]+96>>2]](a)}}function Lz(a,b){if(b){Lz(a,x[b>>2]);Lz(a,x[b+4>>2]);Ib(b)}}function Kz(a,b){if(b){Kz(a,x[b>>2]);Kz(a,x[b+4>>2]);Ib(b)}}function Ik(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(Vf(b))}}function G6(a){a=a|0;return E(E(B[Cb(a+4208|0,6)>>2]*E(4)))}function Fn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;return vE(a,b,c,36)|0}function pm(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function on(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function iB(a,b,c){if((a|0)!=(b|0)){b=b-a|0;Ji(c-b|0,a,b)}}function fR(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;lb=b;return a}function dX(a){a=a|0;a=fN(a,7874);x[a>>2]=41832;return a|0}function cY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function ay(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function Q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lb=0;return 0}function H2(a){a=a|0;JJ(a,2,100);zi(x[a+24>>2]+484360|0,0)}function Eb(a){if(Se(a)){return x[a+4>>2]}return y[a+11|0]}function CW(a){a=a|0;a=AD(a,8606);x[a>>2]=30340;return a|0}function wU(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function wJ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){ys(c)}}function op(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function bA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Ib(c)}}function ao(a){x[a>>2]=0;x[a+4>>2]=0;Yj(a+8|0,0);return a}function ag(a){var b=0;dP(a);b=x[a>>2];if(b){vz(a);Ib(b)}}function _w(a,b){return x[((a>>>24^b)<<2)+462560>>2]^a<<8}function _ga(a,b,c){a=a|0;b=b|0;c=c|0;Yf(a,b,Wc(b,c)+b|0)}function ZE(a,b,c){b=Ma(911,a|0,b|0,c|0)|0;lb=ib;return b}function Tt(a,b){if(Sf(y[a+11|0])){Sd(a,b);return}we(a,b)}function TH(a){while(1){if((_r(a)|0)!=-1){continue}break}}function Io(a){a=ED(a);x[a+8>>2]=0;x[a>>2]=88724;return a}function Hc(a,b){return wE(a,b,2147483647,-2147483648,-1)}function Fw(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function FF(a){if(x[a>>2]){Gc(a);DF(jw(a),x[a>>2],ti(a))}}function A2(a,b,c){a=a|0;b=b|0;c=c|0;Do(a,b,c);return a|0}function wt(a,b){nc(a,b);nc(a+4|0,b+4|0);nc(Fb(a),Fb(b))}function wF(a){a=a|0;x[a>>2]=83248;xb(a+16|0);return a|0}function vm(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function vF(a){a=a|0;x[a>>2]=83208;xb(a+12|0);return a|0}function uh(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function nH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gh(a,-1,-1)}function iz(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function _M(a,b){a=ZM(a,b);ZM(a+12|0,b+12|0);v[a+24|0]=1}function St(a){tc(a+88|0);tc(a+68|0);tc(a+48|0);return a}function S0(a,b,c){a=a|0;b=b|0;c=c|0;return Ld(D(b,c))|0}function O2(a,b,c){a=a|0;b=b|0;c=c|0;Rc(a,$R(c,b,qf(b)))}function KI(a){a=a|0;x[a>>2]=60540;dc(a+12|0);return a|0}function DW(a,b,c){a=a|0;b=b|0;c=c|0;wv(a,b,x[b+8>>2],c)}function CJ(a,b){Nm(x[b>>2]);Sm(x[a>>2]);x[a>>2]=x[b>>2]}function $i(a){return Ne(a)|Ne(a)<<8|Ne(a)<<16|Ne(a)<<24}function xD(a){a=a|0;x[a>>2]=43104;de(a+4|0);return a|0}function x6(a){a=a|0;qK(a);v[a+4202|0]=1;x[a+4224>>2]=0}function wg(a,b,c,d,e){return Oa(a|0,b|0,c|0,d|0,e|0)|0}function vv(a){a=a|0;x[a>>2]=91832;bF(a+4|0);return a|0}function paa(a,b,c){a=a|0;b=b|0;c=c|0;kE(a,b,c,751,750)}function nG(a,b,c){a=gc(a,b);gc(a+4|0,x[c>>2]);return a}function js(a){a=a|0;x[a>>2]=49284;rx(a+4|0);return a|0}function j7(a){a=a|0;return B[Cb(a+4208|0,3)>>2]<E(1)|0}function j4(a,b){a=a|0;b=b|0;return an(a,b,11640,962)|0}function h4(a,b){a=a|0;b=b|0;return VE(a,b,13148,963)|0}function bo(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function bT(a){a=a|0;x[a>>2]=91812;bF(a+4|0);return a|0}function bI(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function bF(a){a=hx(x[a>>2]);if((tv(a+8|0)|0)<0){Ib(a)}}function XE(a,b,c,d,e){return Fa(a|0,b|0,c|0,d|0,e|0)|0}function X3(a,b){a=a|0;b=b|0;return an(a,b,11675,970)|0}function Wd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function VN(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Ib(b)}}function T3(a,b){a=a|0;b=b|0;return an(a,b,11705,972)|0}function Sc(a){if(Se(a)){a=ll(a)-1|0}else{a=10}return a}function Qr(a){a=a|0;x[a>>2]=76208;Zb(a+4|0);return a|0}function Qb(a){x[a>>2]=0;x[a+4>>2]=0;Bc(a+8|0);return a}function QI(a){a=a|0;x[a>>2]=61004;dc(a+4|0);return a|0}function L3(a,b){a=a|0;b=b|0;return an(a,b,11801,975)|0}function Ko(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function I6(a){a=a|0;return B[Cb(a+4208|0,1)>>2]<E(1)|0}function I3(a,b){a=a|0;b=b|0;return an(a,b,11769,976)|0}function FL(a){return(a|0)==1179012417|(a|0)==538987841}function En(a){a=a|0;x[a>>2]=76144;Zb(a+4|0);return a|0}function D4(a,b){a=a|0;b=b|0;return an(a,b,11737,955)|0}function CF(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Sm(b)}}function $A(a){a=a&255;return Uc(a)^1|(a-49&255)>>>0<36}function u$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Yf(a,c,d)}function rn(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function r$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;rG(a,c,d)}function m9(a,b,c){a=a|0;b=b|0;c=c|0;kE(a,b,c,822,821)}function kh(a){var b=0;b=_r(a);x[a+1396>>2]=0;return b}function kH(a){a=a|0;return Sr(x[x[a>>2]-12>>2]+a|0)|0}function fp(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function fn(a){if(Se(a)){a=ll(a)-1|0}else{a=1}return a}function f_(a,b){a=a|0;b=b|0;fc(a,YG(x[b>>2]),x[b>>2])}function eH(a){a=a|0;return Rr(x[x[a>>2]-12>>2]+a|0)|0}function bx(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function Zga(a,b){a=a|0;b=b|0;return Vb(a,b?b:21473)|0}function Z$(a){a=a|0;return jp(x[x[a>>2]-12>>2]+a|0)|0}function Xb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function X$(a){a=a|0;return gf(x[x[a>>2]-12>>2]+a|0)|0}function Ng(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+20>>2]](a,b)}function KL(a,b){return D(b&65535,a&65535)+7>>>3&65535}function Hh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+24>>2]](a,b)}function Gh(a,b){a=a|0;b=b|0;mb[x[x[b>>2]+28>>2]](a,b)}function F5(a,b){a=a|0;b=b|0;return VE(a,b,6393,904)|0}function $ca(a,b){a=a|0;b=b|0;if(!dR(a,b)){Tb(b,0,40)}}function yn(a,b,c,d){return x[(c<<2)+a>>2]+(b+d<<1)|0}function yb(a){if(Sf(y[a+11|0])){Ib(x[a>>2])}return a}function t7(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4228|0,7)}function qB(a,b){a=he(a,b);Tb(a+20|0,0,1040);return a}function pv(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){Nm(c)}}function lG(a,b,c){a=tG(a,b,c,0,-2147483648);return a}function jn(a,b){return mb[x[x[a>>2]+36>>2]](a,b,0)|0}function iga(a,b,c){a=a|0;b=b|0;c=c|0;bS(a,b,Cb(b,c))}function hn(a,b){return mb[x[x[a>>2]+52>>2]](a,b,0)|0}function ef(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function dr(a,b){a=jc(a,b);Tb(a+20|0,0,1040);return a}function dc(a){if(x[a>>2]){Gc(a);Ib(x[a>>2])}return a}function d8(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,b+4260|0,8)}function Z1(a,b){a=a|0;b=b|0;MN(x[a>>2],b);return a|0}function Wi(a){a=a|0;return mb[x[x[a>>2]+16>>2]](a)|0}function Vi(a){a=a|0;return mb[x[x[a>>2]+12>>2]](a)|0}function Vb(a,b){a=a|0;b=b|0;Do(a,b,qf(b));return a|0}function SK(a){tc(a+36|0);tc(a+24|0);Bs(a+12|0);Bs(a)}function My(a){zp(a+223860|0);dc(a+223848|0);return a}function Hg(a){a=a|0;return mb[x[x[a>>2]+24>>2]](a)|0}function Hf(a,b,c,d){b=b+d|0;lb=a+c>>>0<c>>>0?b+1|0:b}function BL(a,b){return(b>>>0>15?63:v[a+b|0])<<24>>24}function AL(a,b){return(b>>>0>45?63:v[a+b|0])<<24>>24}function zz(a){a=Qb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function tU(a,b,c,d){return qr(a,b,c,d,28,153391690)}function sm(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function oD(a,b,c,d){return qr(a,b,c,d,36,119304648)}function nfa(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,13,2)}function j8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function iv(a){a=a|0;return mb[x[x[a>>2]+8>>2]](a)|0}function iq(a,b,c,d,e){fc(a,b+d|0,(e|0)==-1?c-d|0:e)}function _C(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function Via(a){if(a){return 31-G(a-1^a)|0}return 32}function M7(a){a=a|0;v[a+4202|0]=1;Cs(a);Jx(a);TK(a)}function Js(a){a=a|0;a=zh(a);x[a+20>>2]=0;return a|0}function xfa(a){a=a|0;oj(93712);oj(93704);xb(93692)}function vX(a){a=a|0;a=mb[a|0]()|0;ib=lb;return a|0}function vO(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function uD(a){return BH(a,E(15845632502852868e13))}function sZ(){Od(468728);zF(468736);x[117182]=86096}function rH(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function qZ(){Od(468744);zF(468752);x[117186]=86252}function oda(a,b,c){a=a|0;b=b|0;c=c|0;Rc(a,Dv(b,c))}function nj(a){if(!a){return 0}return x[a+44>>2]!=0}function ip(a,b){b=x[b>>2];x[a>>2]=b;Nm(b);return a}function i7(a){a=a|0;return E(B[Cb(a+4208|0,1)>>2])}function gn(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function gga(a,b,c){a=a|0;b=b|0;c=c|0;sE(a,b,c,256)}function e1(a,b,c){a=a|0;b=b|0;c=c|0;sI(a-88|0,b,c)}function dv(a){if((a|0)<0){ig();p()}return wc(a<<1)}function c1(a,b,c){a=a|0;b=b|0;c=c|0;qI(a-88|0,b,c)}function afa(a,b){a=a|0;b=b|0;return Ij(a,b,1030)|0}function Zd(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function Xca(a,b){a=a|0;b=b|0;Do(a,b,12);return a|0}function XT(a,b,c,d){return qr(a,b,c,d,48,89478486)}function WC(a){return BH(a,E(2524354896707238e-44))}function Tl(a,b,c){if(!c){return 0}return Ob(a,b,c)}function Sw(a){if(!a){return 0}x[115896]=a;return-1}function Sea(a,b){a=a|0;b=b|0;return _v(a,b,1100)|0}function SN(a,b,c,d){return qr(a,b,c,d,7,613566757)}function Rj(a){if(!a){return 0}return mj(y[a+31|0])}function P2(a){a=a|0;a=x[a+4>>2];return(a?a:4972)|0}function OC(a,b,c){v[a+8|0]=1;x[a+4>>2]=c;x[a>>2]=b}function Je(a){var b=0;b=x[a>>2];if(b){Fb(a);Ib(b)}}function JK(a){a=a|0;return E(B[Cb(a+4208|0,0)>>2])}function Iz(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function Ho(a){a=a|0;a=yc(a);mb[x[x[a>>2]>>2]](a)|0}function H6(a){a=a|0;return E(B[Cb(a+4208|0,3)>>2])}function Dv(a,b){a=a|0;b=b|0;return rA(a,b,qf(b))|0}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,5,3)}function Ao(a,b,c){fc(a,(c>>>3&536870908)+b|0,c&31)}function Ab(a,b,c){fc(a,(c>>>3&536870908)+b|0,1<<c)}function tl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function l0(a,b){a=a|0;b=b|0;return So(a,b,1051)|0}function kfa(a,b){a=a|0;b=b|0;if(!xu(a,b)){Cu(b)}}
function g1(a,b,c){a=a|0;b=b|0;c=+c;uI(a-88|0,b,c)}function g0(a,b){a=a|0;b=b|0;return So(a,b,1052)|0}function e0(a,b){a=a|0;b=b|0;return So(a,b,1053)|0}function d1(a,b){a=a|0;b=b|0;return rI(a-88|0,b)|0}function cS(a,b,c){a=a|0;b=b|0;c=c|0;Rc(a,cF(b,c))}function b1(a,b){a=a|0;b=b|0;return pI(a-88|0,b)|0}function Zl(a){hj(a+724|0);hj(a+732|0);hj(a+740|0)}function Yfa(a,b){a=a|0;b=b|0;return Ij(a,b,422)|0}function W0(a,b,c){a=a|0;b=b|0;c=+c;jI(a-92|0,b,c)}function Vn(a,b,c){if((a|0)!=(b|0)){Ji(c,a,b-a|0)}}function U0(a,b,c){a=a|0;b=b|0;c=+c;hI(a-92|0,b,c)}function Sfa(a,b){a=a|0;b=b|0;return Ij(a,b,826)|0}function H0(a,b){a=a|0;b=b|0;return So(a,b,1049)|0}function BD(a,b,c){a=a|0;b=b|0;c=c|0;Rc(a,ZC(b,c))}function B2(a,b){a=a|0;b=b|0;return So(a,b,1048)|0}function zC(a){return!Ob(a,26016,25)&y[a+34|0]<65}function zB(a){return(x[Fb(a)>>2]-x[a>>2]|0)/28|0}function wga(a,b){a=a|0;b=b|0;if(!sS(a,b)){rS(b)}}function uia(a,b){a=a|0;b=b|0;if(!bU(a,b)){ku(b)}}function uS(a){return(x[Fb(a)>>2]-x[a>>2]|0)/33|0}function o6(a,b){a=a|0;b=b|0;return E(zl(a,b,12))}function nv(a){return(x[Fb(a)>>2]-x[a>>2]|0)/36|0}function n4(a){a=a|0;return aw(a,12655,1074416)|0}function lC(a){return(x[Fb(a)>>2]-x[a>>2]|0)/20|0}function j9(a,b){a=a|0;b=b|0;return Ij(a,b,225)|0}function gT(a){if(!(a&255)){return 1}return Uc(a)}function fc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function f9(a,b){a=a|0;b=b|0;return Ij(a,b,326)|0}function cm(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function cga(a,b){a=a|0;b=b|0;if(!dD(a,b)){Wq(b)}}function Wk(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function UT(a){return(x[Fb(a)>>2]-x[a>>2]|0)/48|0}function SQ(a){return(x[Fb(a)>>2]-x[a>>2]|0)/56|0}function Rp(a,b,c){return x[(b<<2)+a>>2]+(c<<2)|0}function Ps(a){return(x[Fb(a)>>2]-x[a>>2]|0)/52|0}function Kt(a){return(x[Fb(a)>>2]-x[a>>2]|0)/24|0}function Kh(a,b){if(Se(a)){Sd(a,b);return}we(a,b)}function Iea(a,b){a=a|0;b=b|0;return Ij(a,b,71)|0}function HL(a,b){return(a|0)==1179011410&b>>>0>80}function HG(a){return(Mj(a)|0)!=0|(a|32)-97>>>0<6}function Fj(a){return(x[Fb(a)>>2]-x[a>>2]|0)/12|0}function ED(a){x[a+4>>2]=0;x[a>>2]=91284;return a}function Bp(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function Bk(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function Bga(a,b){a=a|0;b=b|0;return Ij(a,b,91)|0}function AD(a,b){a=zD(a,b);x[a>>2]=92092;return a}function $E(a){return(a<<1)+16777216>>>0<16777217}function z6(a,b){a=a|0;b=b|0;return E(zl(a,b,1))}function ux(a,b){x[a>>2]=x[b>>2];Rc(a+4|0,b+4|0)}function s4(a){a=a|0;return OE(a,8698,1074448)|0}function r9(a,b){a=a|0;b=b|0;if(!lD(a,b)){Bv(b)}}function pT(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function p4(a){a=a|0;return aw(a,5280,1074424)|0}function oz(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function nq(a,b){a=a|0;b=b|0;if(!Wh(a,b)){vl(b)}}function n7(a,b){a=a|0;b=b|0;return E(zl(a,b,6))}function lU(a,b){a=TT(a,b);if(!a){wB(b)}return a}function l9(a,b){a=a|0;b=b|0;return Ij(a,b,73)|0}function ju(a){return(x[Fb(a)>>2]-x[a>>2]|0)/6|0}function jo(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function hV(a,b){a=a|0;b=b|0;if(!WB(a,b)){Du(b)}}function h6(a,b){a=a|0;b=b|0;return E(zl(a,b,2))}function f1(a,b){a=a|0;b=b|0;return+tI(a-88|0,b)}function ed(a,b,c,d){return Cd(a,D(Dg(b),c)+d|0)}function d9(a,b){a=a|0;b=b|0;return Ij(a,b,60)|0}function cJ(a,b){a=a|0;b=b|0;qk(a,b,57624,57632)}function bJ(a,b){a=a|0;b=b|0;qk(a,b,57640,57648)}function b7(a,b){a=a|0;b=b|0;return E(zl(a,b,5))}function az(a){return(x[Fb(a)>>2]-x[a>>2]|0)/7|0}function a6(a,b){a=a|0;b=b|0;return E(zl(a,b,3))}function _I(a,b){a=a|0;b=b|0;qk(a,b,58444,58452)}function ZI(a,b){a=a|0;b=b|0;qk(a,b,58460,58468)}function YO(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function YK(a){a=a|0;dc(a+4208|0);return vf(a)|0}function YE(a,b,c,d,e){La(a|0,b|0,c|0,d|0,e|0,1)}function XM(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function XI(a,b){a=a|0;b=b|0;qk(a,b,59272,59280)}function WI(a,b){a=a|0;b=b|0;qk(a,b,59288,59296)}function W6(a,b){a=a|0;b=b|0;return E(zl(a,b,4))}function V0(a,b){a=a|0;b=b|0;return+iI(a-92|0,b)}function TI(a,b){a=a|0;b=b|0;qk(a,b,60100,60108)}function T0(a,b){a=a|0;b=b|0;return+gI(a-92|0,b)}function SI(a,b){a=a|0;b=b|0;qk(a,b,60116,60124)}function PB(a,b){a=a|0;b=b|0;if(!sD(a,b)){rD(b)}}function OT(a,b){a=a|0;b=b|0;if(!NT(a,b)){iu(b)}}function Lg(a,b,c){var d=0;d=a;a=b;gn(d,a,a+c|0)}function Jo(a,b,c){a=$d(a);x[a+4>>2]=c;x[a>>2]=b}function Jia(a,b){a=a|0;b=b|0;return qu(a,1,b)|0}function Hu(a,b){a=a|0;b=b|0;if(!Sq(a,b)){Iq(b)}}function Fs(a){a=a|0;tc(a+4208|0);return vf(a)|0}function DK(a){a=a|0;tc(a+4256|0);return vf(a)|0}function CA(a,b){a=a|0;b=b|0;if(!FS(a,b)){JA(b)}}function zF(a){var b=0,c=0;b=a,c=Ad(),x[b>>2]=c}function xS(a){return!Ob(a,13720,4)&y[a+4|0]<32}function via(a,b,c){a=a|0;b=b|0;c=c|0;XB(a,b,c)}function uk(a){return mb[x[x[a>>2]+36>>2]](a)|0}function uH(a,b){if(!a){return 0}return Qw(a,b)}function td(a,b){return $o(x[b>>2],x[a>>2])?b:a}function q4(a){a=a|0;return OE(a,7071,480214)|0}function pH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function nn(a){return mb[x[x[a>>2]+28>>2]](a)|0}function eq(a,b,c){if(b){Tb(a,Mf(c),b)}return a}function cia(a,b){a=a|0;b=b|0;Uo(a,b,340,339,8)}function Zc(a,b){return tl(z[b>>1],z[a>>1])?b:a}function Yc(a,b){return Up(x[a>>2],x[b>>2])?b:a}function Xt(a,b){a=a|0;b=b|0;return Nb(a,b,1)^1}function Ve(a,b){return tl(z[a>>1],z[b>>1])?b:a}function Uea(a,b){a=a|0;b=b|0;Uo(a,b,576,575,8)}function TB(a,b){return(b&255)==2&(a&255)>>>0<3}function SR(a){var b=0;b=x[a>>2];Be(a);return b}function S2(a){a=a|0;return JE(a,49032,12379)|0}function Rl(a,b){return Wt(B[b>>2],B[a>>2])?b:a}function Qy(a){if(y[a+24|0]){cN(a);v[a+24|0]=0}}function M3(a){a=a|0;return aw(a,5777,480272)|0}function Le(a,b){return $o(x[a>>2],x[b>>2])?b:a}function Ix(a,b){return Wt(B[a>>2],B[b>>2])?b:a}function IV(a,b){a=a|0;b=b|0;wp(a,b);return a|0}function Hb(a,b){return Up(x[b>>2],x[a>>2])?b:a}function Dga(a,b){a=a|0;b=b|0;Uo(a,b,454,453,6)}function Ch(a,b,c){return Ga(916,a|0,b|0,c|0)|0}function Cea(a,b){a=a|0;b=b|0;Uo(a,b,607,606,8)}function xr(a,b){return(a&255)>>>0<(b&255)>>>0}function vu(a,b,c){a=a|0;b=b|0;c=c|0;BU(a,b,c)}function sh(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function s7(a,b,c){a=a|0;b=b|0;c=c|0;tK(a,b,c)}function mO(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function m6(a){a=a|0;mK(a);Bx(a);v[a+4202|0]=1}function it(a){return(a>>>0<9?a:a-9|256)&65535}function hf(a,b,c){if(!(y[a|0]&32)){CB(b,c,a)}}function cg(a,b,c){a=Xia(a,b,c,c>>31);return a}function bn(a,b,c,d,e){Pa(a|0,b|0,c|0,d|0,e|0)}function _j(a,b){return(D(b,104)+a|0)+484380|0}function ZX(a,b,c){a=a|0;b=b|0;c=c|0;fc(a,c,b)}function U6(a){a=a|0;v[a+4202|0]=1;wK(a);vK(a)}function Tea(a,b){a=a|0;b=b|0;return dR(a,b)|0}function SA(a,b,c){a=a|0;b=b|0;c=c|0;UB(a,b,c)}function RU(a,b){a=a|0;b=b|0;Uo(a,b,281,280,8)}function R2(a){a=a|0;return JE(a,49052,8109)|0}function Hm(a){return(a>>>0<=127?-1:a^128)&255}function FB(a){return!Ob(a,15229,4)&y[a+4|0]<4}function Ez(a){return a>>>0<=45?y[a+43680|0]:0}function C2(a,b){a=a|0;b=b|0;Rc(a,HJ(b,17462))}function BO(a){jz(a);Tb(a+27|0,0,255);return a}function $6(a){a=a|0;v[a+4202|0]=1;yK(a);AK(a)}function zT(a){lb=0;a=(a&65535)-98|0;return a}function xc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function xb(a){if(Se(a)){Ib(x[a>>2])}return a}function xU(a,b){a=a|0;b=b|0;return cF(a,b)|0}function vga(a,b){a=a|0;b=b|0;Wv(a,b,17,3,16)}function uW(a){a=a|0;x[a>>2]=61060;return a|0}function tg(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function rw(a,b,c){a=tG(a,b,c,-1,-1);return a}function rs(a){a=xJ(a);x[a>>2]=77440;return a}function jt(a,b){a=a|0;b=b|0;return Oh(a,b)|0}function jH(a){a=a|0;Kw(x[x[a>>2]-12>>2]+a|0)}function hW(a){a=a|0;x[a>>2]=42968;return a|0}function hU(a){v[a+12|0]=y[a+12|0]|2;return a}function hQ(a){return Ie(443250/+(a>>>0)*1e4)}function fW(a){a=a|0;x[a>>2]=42728;return a|0}function eX(a,b){a=a|0;b=b|0;return ZD(a,b)|0}function dp(a,b){a=a|0;b=b|0;return iH(a,b)^1}function dH(a){a=a|0;Iw(x[x[a>>2]-12>>2]+a|0)}function _k(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function _e(a,b){return xr(y[a|0],y[b|0])?b:a}function Zia(a,b,c,d){a=Uia(a,b,c,d);return a}function Yi(a,b){a=a|0;b=b|0;return iH(a,b)|0}function Y$(a){a=a|0;VG(x[x[a>>2]-12>>2]+a|0)}function Wb(a,b){return xr(y[b|0],y[a|0])?b:a}function W$(a){a=a|0;UG(x[x[a>>2]-12>>2]+a|0)}function Vh(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function VJ(a,b){a=a|0;b=b|0;return HJ(a,b)|0}function TW(a,b){a=a|0;b=b|0;return Dv(a,b)|0}function T8(a,b){a=a|0;b=b|0;sy(wL(a+24|0,b))}function Sha(a,b){a=a|0;b=b|0;uE(a,b,344,343)}function Px(a){return x[Fb(a)>>2]-x[a>>2]>>11}function Pr(a,b){a=a|0;b=b|0;return _G(a,b)^1}function Pl(a){a=Nl(a);x[a>>2]=91696;return a}function Od(a){a=ED(a);x[a>>2]=83536;return a}function MG(a){a=xJ(a);x[a>>2]=77832;return a}function Lj(a,b){a=a|0;b=b|0;return _G(a,b)|0}function LG(a,b){a=a|0;b=b|0;return ZC(a,b)|0}function K1(a){a=a|0;x[a>>2]=60640;return a|0}function Iia(a,b){a=a|0;b=b|0;uE(a,b,287,286)}function IU(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function IQ(a){a=Wia(a&65535,0,80,0);return a}function GF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function FJ(a){a=a|0;x[a>>2]=49116;return a|0}function D1(a){a=a|0;x[a>>2]=60140;return a|0}function $d(a){x[a>>2]=0;x[a+4>>2]=0;return a}function zZ(a){a=a|0;Ud(a,468656,Pd(467064))}function yZ(a){a=a|0;Ud(a,468664,Pd(467072))}function xZ(a){a=a|0;Ud(a,468672,Pd(467080))}function wZ(a){a=a|0;Ud(a,468680,Pd(467088))}function vz(a){return x[yc(a)>>2]-x[a>>2]>>2}function vZ(a){a=a|0;Ud(a,468688,Pd(467096))}function uZ(a){a=a|0;Ud(a,468696,Pd(467008))}function tw(){ha(Pl(ba(4)|0)|0,91780,25);p()}function ti(a){return x[Fb(a)>>2]-x[a>>2]>>2}function tZ(a){a=a|0;Ud(a,468712,Pd(467016))}function rZ(a){a=a|0;Ud(a,468728,Pd(467024))}function qh(a){return x[x[a+8>>2]>>2]==(a|0)}function pZ(a){a=a|0;Ud(a,468744,Pd(467032))}function oZ(a){a=a|0;Ud(a,468760,Pd(467104))}function nZ(a){a=a|0;Ud(a,468768,Pd(467112))}function mr(a){return x[Fb(a)>>2]-x[a>>2]>>4}function lea(a,b){a=a|0;b=b|0;Xv(a,b,1042,2)}function go(a){return x[Fb(a)>>2]-x[a>>2]>>5}function fha(a,b){a=a|0;b=b|0;or(a,b,1042,2)}function fF(a,b,c){a=a|0;b=b|0;c=c|0;TG(a,c)}function f4(a){a=a|0;return RE(a,6552,967)|0}function Vj(a){return lE(a,E(4294967296),-1)}function Tm(a){return x[Fb(a)>>2]-x[a>>2]>>3}function TZ(a){a=a|0;Ud(a,468448,Pd(466960))}function SZ(a){a=a|0;Ud(a,468456,Pd(466968))}function RZ(a){a=a|0;Ud(a,468464,Pd(467164))}function QZ(a){a=a|0;Ud(a,468480,Pd(467156))}function Q1(a){a=a|0;PI(a);return x[a+16>>2]}function PZ(a){a=a|0;Ud(a,468488,Pd(467172))}function PR(a,b,c,d){return(D(b,d)+c<<1)+a|0}function Oz(a){return x[Fb(a)>>2]-x[a>>2]>>8}function Og(a,b,c,d){return(D(b,d)+c<<3)+a|0}function OU(a,b){a=a|0;b=b|0;Wv(a,b,44,2,44)}function Nj(a){a=a&255;return(a|0)==255?-1:a}function NZ(a){a=a|0;Ud(a,468496,Pd(467180))}function MZ(a){a=a|0;Ud(a,468512,Pd(467188))}function Lx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function LZ(a){a=a|0;Ud(a,468520,Pd(467204))}function Ky(a){v[a+24|0]=0;v[a|0]=0;return a}function KZ(a){a=a|0;Ud(a,468528,Pd(467196))}function K0(a){a=a|0;return gb(x[a+60>>2])|0}function JZ(a){a=a|0;Ud(a,468536,Pd(467212))}function Ih(a,b,c,d){return(D(b,d)+c<<2)+a|0}function IZ(a){a=a|0;Ud(a,468544,Pd(467220))}function HZ(a){a=a|0;Ud(a,468568,Pd(467228))}function Gm(a){return x[Fb(a)>>2]-x[a>>2]>>1}function GZ(a){a=a|0;Ud(a,468600,Pd(466976))}function Fo(a,b,c,d){a=Xia(a,b,c,d);return a}function FZ(a){a=a|0;Ud(a,468608,Pd(466984))}function Ex(a){return E(E(a*E(7900))+E(100))}function EZ(a){a=a|0;Ud(a,468616,Pd(466992))}function CZ(a){a=a|0;Ud(a,468632,Pd(467040))}function Bd(a,b){if(!Sf(b)){a=Mf(b)}return a}function BZ(a){a=a|0;Ud(a,468640,Pd(467048))}function B4(a){a=a|0;return RE(a,7015,959)|0}function AZ(a){a=a|0;Ud(a,468648,Pd(467056))}function zm(a,b,c){return of(a,b)>>>0>c>>>0}function ys(a){a=a|0;mb[x[x[a>>2]+4>>2]](a)}function sc(a){if(Se(a)){a=x[a>>2]}return a}function rj(a,b,c){if(c){Ji(a,b,c)}return a}function pn(a){a=a|0;YG(x[a>>2]);return a|0}function nf(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function lt(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0]}function jX(a,b){a=a|0;b=b|0;Sv(a,b,1058,2)}function io(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function hi(a,b){a=a|0;b=b|0;return E(E(0))}function eJ(a){v[a+4|0]=0;v[a|0]=0;return a}function bV(a,b){a=a|0;b=b|0;Xv(a,b,1025,2)}function _o(a){return x[Fb(a)>>2]-x[a>>2]|0}function Zk(a,b){return a<<24>>24<b<<24>>24}function Xj(a,b){return a<<16>>16<b<<16>>16}function R1(a){a=a|0;PI(a);return x[a+4>>2]}function R$(a,b){a=a|0;b=b|0;or(a,b,1025,4)}function MA(a,b){x[a>>2]=x[a>>2]+b;return a}function Jl(a){a=a|0;Jw(x[a>>2]);return a|0}function J8(a,b){a=a|0;b=b|0;or(a,b,1058,1)}function IF(a,b,c){return rv(HF(a),HF(b),c)}function He(a,b,c){if(c){pc(a,b,c)}return a}function H$(a,b){a=a|0;b=b|0;or(a,b,1025,2)}function DZ(a){a=a|0;Ud(a,468624,Pd(467e3))}function $J(a){return Mh(E(bK(a)*E(32768)))}function yw(a){a=a|0;return vh(a,467180)|0}function wk(a,b){mb[x[x[b>>2]+44>>2]](a,b)}function w0(a){a=a|0;return vh(a,466976)|0}function vr(a,b){mb[x[x[b>>2]+40>>2]](a,b)}function vk(a,b){mb[x[x[b>>2]+32>>2]](a,b)}function uz(a){x[a>>2]=x[a>>2]+32;return a}function uw(a){a=a|0;return vh(a,467220)|0}function um(a){x[a>>2]=x[a>>2]+28;return a}function ow(a){a=a|0;return vh(a,467228)|0}function o0(a){a=a|0;return vh(a,466992)|0}function mm(a){xz(x[a+20>>2]);x[a+20>>2]=0}function ll(a){return x[a+8>>2]&2147483647}function kX(a,b){a=a|0;b=b|0;Sv(a,b,290,0)}function id(a,b){a=a|0;b=b|0;tK(a,b,qf(b))}function h8(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function eK(a){return E(E(a*E(96))+E(-96))}function dW(a,b){a=a|0;b=b|0;Sv(a,b,257,0)}function cs(a){return(a|0)<=65535&(a|0)>=0}function co(a){x[a>>2]=x[a>>2]+16;return a}function _p(a){x[a>>2]=x[a>>2]+12;return a}function Yq(a){er(a+32|0);zb(a+12|0);yb(a)}function YM(a,b){return yE(a,b,2147483647)}function Xda(a,b){a=a|0;b=b|0;rE(a,b,2,31)}function TP(a,b,c,d){fc(a,b,(d|0)==-1?c:d)}function Sia(a,b){a=a|0;b=b|0;Aq(a+36|0,b)}function Pk(a){xb(a+36|0);tc(a+24|0);ek(a)}function PU(a,b){a=a|0;b=b|0;Xv(a,b,274,0)}function Lu(a){a=a|0;return vh(a,467164)|0}function Gw(a){a=a|0;return vh(a,467156)|0}function Gt(a){x[a>>2]=x[a>>2]+52;return a}function G7(a,b,c){a=a|0;b=b|0;c=c|0;$d(a)}function Dw(a){a=a|0;return vh(a,467172)|0}function Ct(a){Je(a+24|0);dc(a+12|0);dc(a)}function BH(a,b){return E(Gv(a?E(-b):b)*b)}function AW(a){a=a|0;return x[a+4>>2]!=0|0}function $e(a,b,c){a=Wia(c,0,a,b);return a}function x1(a,b){a=a|0;b=b|0;Om(a,b+12|0)}function sia(a,b){a=a|0;b=b|0;rE(a,b,3,8)}function sH(a,b){v[a|0]=b+48;return a+1|0}function o1(a,b){a=a|0;b=b|0;CI(a-88|0,b)}function n1(a,b){a=a|0;b=b|0;BI(a-88|0,b)}function mx(a,b,c,d){return Rp(a,c,b+d|0)}function lI(a,b){a=a|0;b=b|0;GE(a,b,2048)}function kI(a,b){a=a|0;b=b|0;GE(a,b,4096)}function jk(a){x[a>>2]=x[a>>2]+6;return a}function ifa(a,b){a=a|0;b=b|0;Oi(a,b,274)}function ft(a){x[a>>2]=x[a>>2]+8;return a}function fK(a){a=a|0;Tb(a+4296|0,0,81928)}function dfa(a,b){a=a|0;b=b|0;Oi(a,b,106)}function cF(a,b){return rr(a,Ic(b),Eb(b))}function bs(a){a=a|0;us(a+8|0);return a|0}function Y0(a,b){a=a|0;b=b|0;lI(a-92|0,b)}function XO(a){x[a>>2]=x[a>>2]-2;return a}function X0(a,b){a=a|0;b=b|0;kI(a-92|0,b)}function WE(a){a=Da(a|0)|0;lb=ib;return a}function Sr(a){a=a|0;Gk(a+8|0);return a|0}function Rr(a){a=a|0;Gk(a+4|0);return a|0}function Re(a){x[a>>2]=x[a>>2]+2;return a}function Nia(a,b){a=a|0;b=b|0;Oi(a,b,136)}function Nf(a){a=a|0;zh(a+8|0);return a|0}function MU(a,b){a=a|0;b=b|0;No(a+12|0,b)}function M8(a,b){a=a|0;b=b|0;Oh(a,b+36|0)}function KY(a,b){a=a|0;b=b|0;Oh(a,b+16|0)}function IN(a,b){if(B[a>>2]>b){B[a>>2]=b}}function Gf(a,b){x[a>>2]=x[b>>2];return a}function G9(a,b){a=a|0;b=b|0;No(a+40|0,b)}function Ek(a){a=a|0;return hH(a)<<24>>24}function EY(a,b){a=a|0;b=b|0;Oh(a,b+12|0)}function Ce(a){x[a>>2]=x[a>>2]+4;return a}function Be(a){x[a>>2]=x[a>>2]+1;return a}function $j(a,b){return x[a>>2]-x[b>>2]|0}function $0(a,b){a=a|0;b=b|0;nI(a-88|0,b)}function vJ(a){return(sc(a)+Eb(a)|0)-1|0}function uga(a,b){a=a|0;b=b|0;Fq(a,b,17)}function u7(a){a=a|0;v[a+4202|0]=1;OK(a)}function sq(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function r6(a){a=a|0;return x[a+4260>>2]}function q1(a){a=a|0;return bs(a-88|0)|0}function m1(a,b){a=a|0;b=+b;AI(a-88|0,b)}function lk(a){return D(Im(a),Gd(a))&255}function kc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function k1(a,b){a=a|0;b=+b;yI(a-88|0,b)}function iS(a,b){a=a|0;b=b|0;Oi(a,b,284)}function i1(a,b){a=a|0;b=+b;wI(a-88|0,b)}function hj(a){w[a+4>>1]=65535;x[a>>2]=0}function fga(a,b){a=a|0;b=b|0;Oi(a,b,42)}function bfa(a,b){a=a|0;b=b|0;Oi(a,b,72)}function _0(a){a=a|0;return bs(a-92|0)|0}function Zha(a,b){a=a|0;b=b|0;Oi(a,b,34)}function Td(a,b){return(b|0)!=0&(a|0)!=0}function TM(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function Or(a,b){x[a+24>>2]=x[a+24>>2]+b}function Lh(a,b){return x[a>>2]!=x[b>>2]}function Jr(a){a=a|0;Zv(a,156,92140,956)}function JY(a,b){a=a|0;b=b|0;cn(a,83280)}function IY(a,b){a=a|0;b=b|0;cn(a,83300)}function GD(a,b){nc(a,b);nc(a+4|0,b+4|0)}function DY(a,b){a=a|0;b=b|0;Vb(a,11138)}function CY(a,b){a=a|0;b=b|0;Vb(a,11255)}function Ak(a){return(a|0)==32|a-9>>>0<5}function Af(a,b){x[a+8>>2]=b|-2147483648}function wV(a,b){a=a|0;b=b|0;Oi(a,b,59)}function tga(a,b){a=a|0;b=b|0;ZB(a,b,8)}function lV(a,b){a=a|0;b=b|0;Fq(a,b,11)}function jF(a,b){a=a|0;b=b|0;return b|0}function g8(a){a=a|0;return y[a+4201|0]}function f8(a){a=a|0;return y[a+4202|0]}function Zm(a,b,c){return Yf(a,b,b+c|0)}function YS(a,b){a=a|0;b=b|0;Fq(a,b,32)}function Xy(a,b,c){return a<b?b:a>c?c:a}function Xg(a,b,c){v[a+4|0]=c;x[a>>2]=b}function Wy(a,b,c){return a<b?b:a>c?c:a}function U5(a){a=a|0;return(a|0)==277|0}function Tw(a){return(q(a),j(2))>>>20|0}function Tca(a,b){a=a|0;b=b|0;oE(a,b,3)}function Sj(a,b){return Oy(a&255,b&255)}function Rm(a){a=x[a+8>>2];if(a){Ib(a)}}function RM(a,b){return(Xk(a,b)|0)!=255}function RF(a,b){a=a|0;b=b|0;Qe(a,1,45)}function Qh(a){return(a&65535)>>>0<3999}function QF(a,b){a=a|0;b=b|0;_F(a,1,45)}function OQ(a,b,c,d){return _k(c,d,a,b)}function Lb(a){return(a<<8|a>>>8)&65535}function Hia(a){a=a|0;return x[a+12>>2]}function HH(a){x[a+4>>2]=x[a+4>>2]|8192}function DB(a,b){a=a|0;b=b|0;Oi(a,b,50)}function zt(a,b,c){return pr(a,b,c,12)}function yr(a){a=a|0;return 2147483647}function xO(a,b,c){return vE(a,b,c,41)}function sJ(a){return a?(a|0)==2?3:2:1}function sA(a,b){a=a|0;b=b|0;oE(a,b,2)}function ok(a,b){x[a+4>>2]=2;x[a>>2]=b}function mW(a){a=a|0;return x[a+16>>2]}function l1(a){a=a|0;return+zI(a-88|0)}function ke(a,b,c){gn(a,b,Wc(b,c)+b|0)}function j1(a){a=a|0;return+xI(a-88|0)}function h1(a){a=a|0;return+vI(a-88|0)}function fj(a,b){return sc(a)+(b<<2)|0}function c6(a){a=a|0;return-2013527448}function aL(a){a=a|0;return 1869112133}function _T(a,b,c){return pr(a,b,c,48)}function Zy(a,b){return wE(a,b,-1,0,0)}function Ui(a,b){x[a+4>>2]=1;x[a>>2]=b}function Ug(a){return lE(a,E(255),255)}function Sca(a){a=a|0;DQ(a);return a|0}function Ro(a,b,c){return To(a,b,c,4)}
function Pu(a,b,c){return pr(a,b,c,20)}function Kv(a,b){x[a+4>>2]=4;x[a>>2]=b}function Id(a){x[x[a+8>>2]>>2]=x[a>>2]}function Cv(a,b){x[a+4>>2]=3;x[a>>2]=b}function yS(a,b,c){hc(a,b,vc(b,c)<<2)}function yP(a){return(a&65535)==65534}function xJ(a){x[a>>2]=77468;return a}function vD(a,b,c){hc(a,b,Gg(b,c)<<3)}function s6(a){a=a|0;return-275227023}function qm(a){return(a&740327453)!=0}function ql(a,b,c){return nr(a,b,c,2)}function po(a,b){w[a+8>>1]=b;return a}function pf(a,b,c){return ed(a,b,c,0)}function p7(a){a=a|0;return-270114148}function of(a,b){return ik(a,b)&65535}function mq(a,b,c){return pr(a,b,c,6)}function mj(a){return(a-1&255)>>>0<17}function jJ(a){x[a>>2]=49364;return a}function j6(a){a=a|0;return 302837129}function iH(a,b){return gH(a)^gH(b)^1}function ei(a,b,c){Rc(Rc(a,b)+12|0,c)}function e7(a){a=a|0;return-285139079}function dJ(a){x[a>>2]=57608;return a}function dE(a,b,c){return nr(a,b,c,4)}function aE(a){a=E(a-a);return E(a/a)}function _q(a,b,c){return To(a,b,c,3)}function _G(a,b){return ZG(a)^ZG(b)^1}function _7(a){a=a|0;return 542066252}function Y6(a){a=a|0;return-284078960}function XJ(a,b){a=a|0;b=b|0;return 0}function X5(a,b){a=a|0;b=b|0;return 3}function VR(a){WH(a);re(x[a+80>>2],a)}function V5(a,b){a=a|0;b=b|0;return 2}function Tr(a,b){a=a|0;b=b|0;return-1}function Se(a){return y[a+11|0]>>>7|0}function R6(a){a=a|0;return-281111764}function Qm(a){x[a>>2]=60592;return a}function Nl(a){x[a>>2]=92392;return a}function Nh(a,b,c){return To(a,b,c,2)}function Mx(a,b){a=a|0;b=b|0;return 1}function M1(a){a=a|0;return y[a+40|0]}function Kia(a,b){a=a|0;b=b|0;Ws(a,b)}function K6(a){a=a|0;return-271958638}function J$(a){a=a|0;return JG(a,0)|0}function I$(a){a=a|0;return JG(a,1)|0}function HJ(a,b){return rr(a,b,qf(b))}function Gi(a,b,c){return To(a,b,c,1)}function Fz(a,b,c){return To(a,b,c,5)}function Fe(a,b){x[a+4>>2]=b;return a}function FP(a,b,c){return nr(a,b,c,5)}function FI(a){x[a>>2]=61832;return a}function EL(a,b){_c(a,b&4?16:8,1,0,0)}function EI(a){x[a>>2]=61856;return a}function DI(a){x[a>>2]=61936;return a}function DD(a){a=a|0;return x[a+8>>2]}function Co(a,b,c){return nr(a,b,c,1)}function Bq(a){a=a|0;return x[a+4>>2]}function B6(a){a=a|0;return-620920304}function B$(a){a=a|0;return IG(a,0)|0}function AQ(a){return(a|0)>=120?120:a}function AN(a,b){return(0-b|0)!=(a|0)}function A$(a){a=a|0;return IG(a,1)|0}function $h(a){a=x[a>>2];if(a){vG(a)}}function yx(a){a=a|0;UE(a,48952,907)}function yQ(a){return(a&255)>>>0<129}function ts(a){return z[a+480192>>1]}function tq(a,b){a=a|0;b=b|0;Dx(a,b)}function tP(a,b,c,d){pP(fc(a,b,c),d)}function ss(a){return z[a+480190>>1]}function qba(a){a=a|0;return qi(a)|0}function px(a,b){a=a|0;b=b|0;Om(a,b)}function pt(a){return x[Fb(a)>>2]<<5}function kia(a){a=a|0;return JT(a)|0}function is(a,b){a=a|0;b=b|0;px(a,b)}function iN(a){return(a+5&255)>>>0<2}function hk(a,b){a=a|0;b=b|0;iU(a,b)}function gaa(a){a=a|0;return Hg(a)|0}function fi(a,b){a=a|0;b=b|0;Oh(a,b)}function fX(a,b){a=a|0;b=b|0;ML(a,b)}function du(a,b){return y[a+b|0]!=63}function cK(a){x[a>>2]=0;x[a+4>>2]=0}function cI(a,b,c,d,e){fI(a,b,c,d,e)}function Zg(a){dl(a+44|0);dc(a+32|0)}function Xm(a,b){a=a|0;b=b|0;is(a,b)}function XV(a){a=a|0;CC(Ic(a),Eb(a))}function SW(a,b){a=a|0;b=b|0;$D(a,b)}function SP(a,b){return D(b,872)+a|0}function QJ(a){a=a|0;UE(a,48896,905)}function Nm(a){x[a+4>>2]=x[a+4>>2]+1}function Lq(a,b){a=a|0;b=b|0;lv(a,b)}function KA(a,b){a=a|0;b=b|0;OI(a,b)}function H1(a){a=a|0;return y[a+8|0]}function GY(a){a=a|0;return v[a+8|0]}function GR(a,b){if(!AR(a,b)){gA(b)}}function FY(a){a=a|0;return v[a+9|0]}function Dx(a,b){a=a|0;b=b|0;fi(a,b)}function Dg(a){return z[a+480188>>1]}function D7(a,b){a=a|0;b=b|0;jt(a,b)}function Ax(a,b){a=a|0;b=b|0;gK(a,b)}function $K(a,b,c){a=a|0;b=b|0;c=c|0}function zp(a){if(y[a+24|0]){cN(a)}}function xt(a,b){return D(b,36)+a|0}function w6(a){a=a|0;x[a+4224>>2]=0}function vd(a,b){return(b-a|0)/12|0}function vS(a,b){return D(b,33)+a|0}function uq(a,b){return(b-a|0)/28|0}function uc(a,b){return(a|0)==(b|0)}function tp(a){return aU(a,251,255)}function lq(a,b){return(b-a|0)/48|0}function le(a,b,c){return nG(a,b,c)}function jj(a,b){return fg(a,b)&255}function ik(a,b){return(b-a|0)/52|0}function iU(a,b){gU(a,x[a+16>>2]|b)}function gc(a,b){x[a>>2]=b;return a}function fl(a,b){return mu(Mc(a,b))}function f0(a){a=a|0;return Dk(a)|0}function eg(a){return E(F(a))==E(O)}function eW(a){a=a|0;mD(Tb(a,0,36))}function cW(a){a=a|0;return zh(a)|0}function bv(a){v[a+2|0]=0;w[a>>1]=0}function bl(a,b){return D(b,24)+a|0}function aq(a){return(a&255)==1?1:2}function Zq(a,b){return(b-a|0)/36|0}function Yz(a,b){return D(b,56)+a|0}function Yb(a,b){return pe(a,b&255)}function YA(a,b,c){return Ot(a,b,c)}function XC(a){a=a|0;return Eg(a)|0}function Ww(a){return!Ob(a,92712,6)}function Vt(a,b){return(b-a|0)/33|0}function Up(a,b){return a>>>0<b>>>0}function Tf(a,b){return Yj(a,Zd(b))}function TR(a,b){return _g(a,0-b|0)}function RG(a){a=a|0;return vv(a)|0}function Pf(a,b){return D(b,52)+a|0}function Op(a,b){return(b-a|0)/56|0}function IJ(a){a=a|0;return Gk(a)|0}function Hi(a,b,c){return rv(a,b,c)}function Hd(a,b){return D(b,12)+a|0}function GW(a){a=a|0;return pg(a)|0}function Ff(a,b){return(b-a|0)/20|0}function Eq(a){a=a|0;return Ee(a)|0}function ET(a){a=a|0;return wc(a)|0}function EB(a){a=a|0;return iv(a)|0}function Cn(a,b){return(b-a|0)/24|0}function Bg(a,b){return D(b,20)+a|0}function A9(a){a=a|0;return mi(a)|0}function $x(a,b){return D(b,28)+a|0}function zx(a,b,c,d){Tv(a,b,c,d,9)}function vU(a,b){return Bl(a,b,28)}function uj(a,b){return D(lk(b),a)}function ue(a,b){fc(a,Ic(b),Eb(b))}function sS(a,b){return _v(a,b,18)}function sD(a,b){return _v(a,b,20)}function qD(a,b){return Bl(a,b,36)}function pJ(a){return(Nj(a)|0)==-1}function oJ(a,b){a=a|0;b=b|0;dc(b)}function nJ(a,b){a=a|0;b=b|0;km(b)}function lT(a){return y[a+1|0]!=63}function jx(a,b,c,d){Tv(a,b,c,d,4)}function jN(a){je(a+8|0);bN(a+4|0)}function ih(a,b){x[a>>2]=x[a>>2]|b}function gi(a){a=a|0;v[a+4202|0]=0}function fE(a){C[(hb-16|0)+8>>3]=a}function ck(a,b){return(b-a|0)/6|0}function YI(a,b,c,d){Tv(a,b,c,d,2)}function Xn(a,b){return(b<<13)+a|0}function XW(a){a=a|0;Mm(a,1,13298)}function Vc(a,b){return yE(a,b,-1)}function Uq(a,b){return(b<<11)+a|0}function Ul(a){return E(F(a))<E(O)}function Sf(a){return(a&128)>>>7|0}function R0(a,b){a=a|0;b=b|0;Ib(b)}function QA(a){return a&2147483647}function OF(a){return vh(a,467048)}function O8(a){a=a|0;Fq(a,21473,1)}function NF(a){return vh(a,467040)}function LF(a){return vh(a,467064)}function Kk(a,b){return(a+b|0)-1|0}function KF(a){return vh(a,467056)}function Iv(a,b){return Bl(a,b,12)}function Is(a,b){return(a-b|0)/6|0}function Iq(a){v[a|0]=0;v[a+1|0]=0}function Ew(a){return uc(a,-1)?0:a}function Eh(a,b){a=a|0;b=b|0;Jb(a)}function Cd(a,b){return D(b,6)+a|0}function Bn(a,b){x[a+1298464>>2]=b}function $y(a,b){return(b-a|0)/7|0}function $o(a,b){return(a|0)<(b|0)}function zea(a){a=a|0;fS(a,65535)}function xz(a){if(a){Ib(a+-64|0)}}function xh(a){x[a>>2]=1;return a}function xf(a){return a!=a?E(0):a}function tx(a,b){return NL(a,b)^1}function tm(a){x[a>>2]=2;return a}function th(a){x[a>>2]=x[a>>2]+20}function pe(a,b){return(b<<5)+a|0}function oha(a){a=a|0;rg(a,16007)}function oG(a,b){return nG(a,0,b)}function ls(a){return mE(a,76144)}function im(a,b){return(b<<8)+a|0}function ee(a,b){return!Ob(a,b,4)}function dq(a,b){return ne(a,b)^1}function dd(a,b){return(b<<4)+a|0}function cw(a,b){return x[a+b>>2]}function bc(a,b){return(b<<1)+a|0}function bH(a){return mE(a,76208)}function am(a){w[a>>1]=0;return a}function YN(a,b){return Bl(a,b,8)}function YC(a){return(a&16)>>>4|0}function Xf(a,b){return Ic(a)+b|0}function WX(a){a=a|0;return 12996}function Vd(a){return x[ic(a)>>2]}function VX(a){a=a|0;return 10178}function V$(a){a=a|0;return 10298}function Uc(a){return aU(a,1,120)}function Rs(a){dc(a+4|0);return a}function Pe(a,b){return(b<<3)+a|0}function Pb(a,b){return uc(a,b)^1}function On(a){return a+1074328|0}function Nc(a,b){return sc(a)+b|0}function Mj(a){return a-48>>>0<10}function JI(a){x[a>>2]=x[a>>2]+24}function Dz(a,b){return Bl(a,b,4)}function DX(a){a=a|0;return 12882}function Cb(a,b){return(b<<2)+a|0}function CX(a){a=a|0;return 10668}function Bfa(a){a=a|0;rg(a,16638)}function Bc(a){x[a>>2]=0;return a}function vT(a,b,c){xE(a,b,c,256)}function rq(a,b,c){sE(a,b,c,128)}function qq(a){return Tb(a,0,48)}function lha(a){a=a|0;rg(a,4445)}function hea(a){a=a|0;rg(a,4126)}function gia(a){a=a|0;rg(a,3892)}function gS(a,b){pc(a,b+4|0,256)}function eha(a){a=a|0;rg(a,4339)}function aW(a){a=a|0;CC(a,qf(a))}function Zu(a,b){return _ia(a,b)}function Yy(a){v[a|0]=0;return a}function Xfa(a){a=a|0;ru(a,3883)}function Wp(a){Zv(a,24,92072,26)}function Vfa(a){a=a|0;ru(a,4848)}function Tu(a,b,c){xE(a,b,c,128)}function SX(a){a=a|0;return 6827}function Qf(a,b,c,d){ef(a,c,d,b)}function QT(a){Zv(a,24,92020,23)}function QK(a){return(a&8)>>>3|0}function PG(a){x[a+72>>2]=465976}function NW(a){a=a|0;rg(a,16665)}function NG(a){x[a+72>>2]=466060}function K9(a){a=a|0;jg(a,kj(a))}function Jg(a){return!x[a+16>>2]}function Jf(a,b){gc(Bc(a)+4|0,b)}function EX(a){a=a|0;return 9737}function Cfa(a){a=a|0;rg(a,3968)}function BX(a){a=a|0;return 5681}function zr(a){a=a|0;return 127}function zj(a,b){return b-a>>11}function zg(a,b){return Pb(a,b)}function zf(a){a=a|0;return a|0}function zb(a){de(a+12|0);de(a)}function yB(a,b){return ro(b,a)}function xG(a){if(yG(a)){Ib(a)}}function wn(a){return a<<24>>24}function tu(a,b,c){ef(a,c,30,b)}function tj(a,b,c){ef(a,c,20,b)}function sk(a,b,c){fc(a,b,1<<c)}function rf(a){yb(a+20|0);yb(a)}function qe(a,b){return vc(a,b)}function qG(a,b){return vd(a,b)}function pj(a,b){return pe(a,b)}function pi(a,b){return(a|b)!=0}function p1(a){a=a|0;gx(a-88|0)}function oy(a){w[a+480214>>1]=0}function ol(a,b){return Bd(a,b)}function oj(a){bA(a,0);return a}function oi(a,b){return Wc(a,b)}function ml(a,b,c){ef(a,c,22,b)}function mf(a,b){return Yj(a,b)}function lo(a,b){return tl(a,b)}function jw(a){return Fb(a+8|0)}function jf(a){return wn(Mf(a))}function jc(a,b){return yD(a,b)}function hp(a,b){return Cb(a,b)}function hZ(a){a=a|0;Jc(467364)}function fm(a){return em(fe(a))}function fZ(a){a=a|0;Jc(467396)}function el(a,b,c){ef(a,c,28,b)}function eh(a,b){return!Bd(a,b)}function eQ(a,b){Uv(a,b,12,-12)}function eC(a){return(a&255)==1}function dk(a,b,c){ef(a,c,12,b)}function dg(a){return ri(a)?0:a}function dZ(a){a=a|0;Jc(467300)}function cf(a,b){return ng(a,b)}function cV(a){a=a|0;rg(a,4319)}function cN(a){aN(a+12|0);$M(a)}function cA(a,b,c){ef(a,c,64,b)}function bz(a,b){return Mc(a,b)}function bm(a){xb(a+12|0);xb(a)}function bZ(a){a=a|0;Jc(467332)}function _s(a){gO(a+12|0);lO(a)}function _b(a,b){return Pf(a,b)}function Z0(a){a=a|0;gx(a-92|0)}function Yk(a){yb(a+12|0);od(a)}function Yj(a,b){return gc(a,b)}function Ye(a,b,c){ef(a,c,32,b)}function Xu(a,b){return KC(a,b)}function WT(a,b){Uv(a,b,48,-48)}function WL(a,b){return UL(a,b)}function Vv(a,b){return Pg(a,b)}function VY(a){a=a|0;xb(467348)}function Th(a,b,c){ef(a,c,13,b)}function TY(a){a=a|0;xb(467380)}function Rg(a){return iN(a&255)}function Rd(a){return(a&255)!=0}function RY(a){a=a|0;xb(467284)}function PY(a){a=a|0;xb(467316)}function OW(a){a=a|0;rg(a,4493)}function NC(a,b){return JC(a,b)}function Ln(a,b){return xr(a,b)}function Li(a,b){return a>>>b&1}function Ie(a){return hq(fe(a))}function IT(a,b){return We(b,a)}function Gs(a,b){return Xj(a,b)}function GI(a,b){return Gg(a,b)}function Ec(a,b){return Uq(a,b)}function Ci(a,b){return Uu(a,b)}function Bb(a,b){return(a&b)!=0}function yF(a){a=a|0;Ib(iw(a))}function vx(a){a=a|0;Ib(GJ(a))}function vc(a,b){return b-a>>2}function u2(a){a=a|0;Ib(js(a))}function sd(a,b){v[a|0]=y[b|0]}function ro(a,b){return a-b>>1}function re(a,b){if(!a){Ib(b)}}function rW(a){a=a|0;Ib(xD(a))}function qt(a){return a>>>27^a}function qn(a){return(a|0)==-1}function qH(){return(db()|0)>0}function q6(a){a=a|0;return 13}function ph(a,b){return b-a>>8}function nK(a){a=a|0;Ib(oK(a))}function jq(a){return a>>>0<11}function iY(a){a=a|0;Ib(iF(a))}function gx(a){a=a|0;Ib(bs(a))}function fh(a,b){return b-a>>4}function fg(a,b){return b-a>>5}function ec(a,b){x[a+100>>2]=b}function aY(a){a=a|0;Ib(hF(a))}function XK(a){a=a|0;Ib(YK(a))}function Wm(a){a=a|0;Ib(bT(a))}function VG(a){a=a|0;Ib(jp(a))}function UP(a){return a+4096|0}function UG(a){a=a|0;Ib(gf(a))}function TQ(a,b){Wv(a,b,5,3,4)}function S1(a){a=a|0;Ib(QI(a))}function Rt(a,b){return a-b>>2}function QC(a){return wc(a<<2)}function Pm(a){a=a|0;Ib(vv(a))}function Oy(a,b){return a<<8|b}function Nk(a){a=a|0;Ib(vf(a))}function Mw(a){a=a|0;Ib(Gk(a))}function Mc(a,b){return b-a>>1}function Lw(a){a=a|0;Ib(En(a))}function LY(a){a=a|0;Ib(wF(a))}function Kw(a){a=a|0;Ib(Sr(a))}function Iw(a){a=a|0;Ib(Rr(a))}function I1(a){a=a|0;Ib(KI(a))}function Hx(a){a=a|0;Ib(MK(a))}function Hw(a){a=a|0;Ib(Qr(a))}function Hn(a){a=a|0;Ib(Fs(a))}function HY(a){a=a|0;Ib(vF(a))}function Gg(a,b){return b-a>>3}function Gd(a){return a&64?2:1}function GS(a,b){gn(a,b,ud(b))}function Cz(a){return a+4896|0}function CK(a){a=a|0;Ib(DK(a))}function CD(a){return a+1024|0}function BY(a){a=a|0;Ib(nF(a))}function BK(a,b){Fx(a,sc(a),b)}function $$(a){a=a|0;Ib(qs(a))}function xK(a){a=a|0;return 5}function wo(a){return a>>>0<5}function wd(a){return(a|0)!=0}function wT(a,b){ef(a,b,40,2)}function ve(a){a=a|0;return 1}function uu(a){return!x[a>>2]}function te(a){a=a|0;return 2}function os(a,b){x[a+32>>2]=b}function mH(a){a=a|0;return-1}function lc(a){a=a|0;return 0}function hA(a,b){hc(a,b,1024)}function fq(a){return a+256|0}function fA(a){return a+128|0}function eR(a,b){hc(a,b,1108)}function d7(a){a=a|0;return 6}function bf(a){return F(a)==O}function ad(a,b){ip(a,b+28|0)}function Ze(a,b){w[a+28>>1]=b}function Z7(a){a=a|0;return 9}function Yn(a,b){x[a+36>>2]=b}function We(a,b){return a-b|0}function Wc(a,b){return b-a|0}function VQ(a,b){ef(a,b,33,1)}function Uj(a){return wd(a)^1}function S5(){return 19924737}function Rq(a,b){ef(a,b,26,3)}function RN(a,b){Uv(a,b,7,-7)}function PK(a){a=a|0;return 3}function LL(a,b,c){Wk(a,b,-c)}function LK(a){a=a|0;return 7}function Kb(a,b){return a+b|0}function Jb(a){KD(a);return a}function JB(a,b){hc(a,b,1954)}function Im(a){return a&1?2:1}function IA(a,b){hc(a,b,4896)}function Gr(a){return a>>>0<2}function Gn(a){a=a|0;return 4}function Fk(a){return(a&5)!=0}function AS(a){qq(Tb(a,0,48))}function zq(a,b){hc(a,b,192)}function zR(a,b){hc(a,b,130)}function yv(a,b){JD(a,Zd(b))}function yc(a){return a+12|0}function xR(a,b){hc(a,b,600)}function wu(a,b){hc(a,b,512)}function we(a,b){v[a+11|0]=b}function ud(a){return a+16|0}function so(a,b){he(a,b+8|0)}function rp(a,b){B[a+8>>2]=b}function rR(a,b){hc(a,b,126)}function rN(a,b,c){_l(a,c,b)}function qp(a,b){B[a+4>>2]=b}function qU(a,b){hc(a,b,610)}function qT(a,b){hc(a,b,218)}function pp(a,b){v[a+33|0]=b}function oP(a,b){hc(a,b,263)}function nT(a,b){hc(a,b,157)}function lm(a,b,c){Ao(a,b,c)}function jQ(a,b){hc(a,b,204)}function iT(a,b){hc(a,b,576)}function hy(a,b){v[a+34|0]=b}function hx(a){return a-12|0}function hc(a,b,c){fc(a,b,c)}function h0(a){a=a|0;iU(a,1)}function gy(a,b){v[a+32|0]=b}function fy(a,b){v[a+35|0]=b}function fT(a,b){hc(a,b,674)}function fO(a){eO(a,x[a>>2])}function cz(a){v[a+6152|0]=0}function bB(a,b){ef(a,b,8,2)}function ah(a,b,c){rv(a,b,c)}function aM(a){return a-32|0}function Xh(a,b,c){hD(a,b,c)}function Vz(a,b){bA(a,Zd(b))}function Vp(a){return a+14|0}function TO(a){SO(a,x[a>>2])}function Sp(a,b){return a<<b}function Sd(a,b){x[a+4>>2]=b}function Qs(a){sM(a,x[a>>2])}function Ol(a,b){x[a+8>>2]=b}function Nr(a,b){ip(a,b+4|0)}function NQ(a){return a-28|0}function Mo(a){return a+20|0}function LQ(a,b){hc(a,b,146)}function HQ(a,b){hc(a,b,608)}function Gc(a){Sd(a,x[a>>2])}function GC(a,b){hc(a,b,497)}function DS(a,b){hc(a,b,128)}function Cj(a){return a-36|0}function CO(a){return a+48|0}function BN(a,b,c){Yl(a,c,b)}function Ae(a,b){a=a|0;b=b|0}function $n(a){return a+32|0}function $S(a){return a+36|0}function yo(a,b){v[a+1|0]=b}function yT(a,b){hc(a,b,98)}function xC(a,b){hc(a,b,38)}function wy(a){Tb(a,0,4096)}function wP(a,b){return a<b}function vp(a){Tb(a,0,8192)}function vA(a,b){hc(a,b,40)}function uC(a,b){Oi(a,b,37)}function tT(a,b){hc(a,b,48)}function sC(a,b){hc(a,b,41)}function pq(a){x[a+12>>2]=0}function ou(a,b){hc(a,b,64)}function om(){Wp(10893);p()}function oB(a,b){hc(a,b,12)}function nu(a,b){hc(a,b,66)}function lS(a,b){hc(a,b,52)}function jd(a){return a+1|0}function jR(a,b){hc(a,b,32)}function ic(a){return a+4|0}function gu(a,b){hc(a,b,22)}function cC(a,b){hc(a,b,11)}function ZT(a,b){pc(a,b,48)}function YB(a,b){fc(a,b,20)}function XQ(a,b){hc(a,b,96)}function Wt(a,b){return a<b}function WJ(a){return 0-a|0}function Vq(a,b){hc(a,b,36)}function VB(a,b){hc(a,b,17)}function Ue(a){return a+2|0}function Rf(a,b){v[a+3|0]=b}function R5(){return 393223}function Pq(a){return a&127}function Ox(a){Tb(a,0,2048)}function Ou(a,b){hc(a,b,65)}function Nu(a,b){hc(a,b,16)}function ND(a,b){hc(a,b,24)}function Mf(a){return a&255}function Jn(a){return a-4|0}function IB(a){Tb(a,0,1954)}function HR(a,b){hc(a,b,30)}function Fm(a,b){fc(a,b,32)}function Fb(a){return a+8|0}function ES(a,b){hc(a,b,80)}function EA(a,b){hc(a,b,33)}function De(a){return!Eb(a)}function Bi(a){return a+3|0}function Bf(){QT(10893);p()}function AO(a,b){hc(a,b,27)}function $u(a,b){fc(a,b,22)}function zc(a){x[a+8>>2]=0}function yu(a,b){hc(a,b,5)}function yA(a){wA(a,Vd(a))}function xd(a,b){x[a>>2]=b}function wj(a,b){w[a>>1]=b}function wR(a){Tb(a,0,600)}function uo(a,b){hc(a,b,7)}function sl(a,b){hc(a,b,2)}function ri(a){return a!=a}function rV(a){a=a|0;zh(a)}function qR(a){Tb(a,0,126)}function pU(a){Tb(a,0,610)}function mT(a){Tb(a,0,157)}function kv(a,b){hc(a,b,3)}function jr(a){a=a|0;kr(a)}function iQ(a){Tb(a,0,204)}function hT(a){Tb(a,0,576)}function hC(a,b){Xh(a,2,b)}function hB(a,b){hc(a,b,6)}function gO(a){Dp(a,Vd(a))}function gA(a){Tb(a,0,130)}function cT(a){Tb(a,0,192)}function aN(a){Vs(a,Vd(a))}function Zb(a){Sm(x[a>>2])}function VS(a){NA(a,Vd(a))}function Uk(a){_y(a,Vd(a))}function Tc(){QT(7636);p()}function TS(a){OA(a,Vd(a))}function Su(){Wp(7636);p()}function Qt(a){xA(a,Vd(a))}function QL(a){dy(a,Vd(a))}function NP(a){Kz(a,Vd(a))}function Mq(a,b){hc(a,b,1)}function MP(a){Lz(a,Vd(a))}function Lm(a,b){hc(a,b,8)}function KQ(a){Tb(a,0,146)}function KK(a,b){kL(a,3,b)}function In(a,b){B[a>>2]=b}function Hz(a){Tb(a,0,256)}function GQ(a){Tb(a,0,608)}function EC(a){Tb(a,0,497)}function Cc(a){a=a|0;Ib(a)}function Bh(a,b){hc(a,b,4)}function $k(a,b){Ao(a,b,0)}function $M(a){Xs(a,Vd(a))}function xT(a){Tb(a,0,98)}function wC(a){Tb(a,0,38)}function wB(a){Tb(a,0,66)}function uT(a){Tb(a,0,48)}function rC(a){Tb(a,0,41)}function kS(a){Tb(a,0,52)}function iu(a){Tb(a,0,64)}function fv(a){return a&1}function bL(a){_m(a,2048)}function YQ(a){Tb(a,0,96)}function X2(){return 2048}function Wq(a){Tb(a,0,36)}function W3(a){a=a|0;ib=a}function T1(){return hb|0}function Q0(a){a=a|0;hb=a}function JA(a){Tb(a,0,80)}function FA(a){Tb(a,0,33)}function Dh(a,b){v[a|0]=b}function xB(a,b){gl(a,b)}function vL(a,b){sM(a,b)}function uR(a){Yv(a,512)}function tk(a,b){Dh(a,b)}function qP(a){x[a>>2]=0}function ps(a){xb(a+4|0)}function gB(a,b){jc(a,b)}function ev(a){w[a>>1]=0}function dh(a){a=a|0;p()}function dO(a){je(a+8|0)}function ct(a,b){cM(a,b)}function bi(a,b){Fh(a,b)}function aR(a,b){he(a,b)}function Yt(a,b){JS(a,b)}function Ym(a,b){gU(a,b)}function RO(a,b){SO(a,b)}function Qx(a,b){Tf(a,b)}function Qo(a,b){Rc(a,b)}function Oc(a){dc(a+8|0)}function OO(a,b){Lf(a,b)}function Nd(a,b){Sd(a,b)}function Md(a){zb(a+8|0)}function Lp(a,b){xd(a,b)}function LB(a,b){iJ(a,b)}function Hs(a,b){In(a,b)}function Eu(a,b){_B(a,b)}function DA(a,b){oS(a,b)}function $t(a){yb(a+4|0)}function zo(a){zE(a,11)}function ug(a){v[a|0]=0}function ofa(){va();p()}function nB(a){zE(a,16)}function ir(a){Rv(a,36)}function gC(a){Yv(a,16)}function _D(a){Rv(a,48)}function VT(a){_m(a,48)}function Ah(a){Rv(a,24)}function yy(a){vM(a,0)}function xy(a){uM(a,0)}function ns(a){yJ(a,0)}function hg(a){US(a,0)}function er(a){JD(a,0)}function eF(){wa();p()}function cj(a){zJ(a,0)}function bj(a){wJ(a,0)}function ZL(a){yM(a,0)}function RX(){eF();p()}function QN(a){_m(a,7)}function Pc(a){Me(a,0)}function LS(a){_m(a,6)}function Fi(a){_m(a,2)}function BS(a){Yv(a,4)}function $q(a){_m(a,8)}function mI(a){Be(a)}function km(a){tc(a)}function kf(a){a=a|0}function dA(a){jk(a)}function cc(a){yb(a)}function _N(a){ao(a)}function XP(a){Ce(a)}function Sb(a){xb(a)}function Po(a){yc(a)}function BF(a){Bc(a)}function $P(a){Qb(a)}
// EMSCRIPTEN_END_FUNCS
e=y;var mb=c([null,Vb,BD,Om,jW,Mm,dW,aW,iD,XV,TV,FC,ZU,VU,yq,hk,Oia,$,Lu,jl,cH,Hg,qo,sha,bT,zf,bga,xfa,wfa,ofa,jfa,Zea,Zz,Aea,uea,Naa,Qda,VP,E0,D0,Ur,VP,Caa,jaa,fN,Ws,wp,W9,T9,SL,B9,ET,_K,Oh,Vb,$7,s7,Dx,gK,Ax,fi,LJ,z4,o4,d4,C3,r3,o0,n0,S$,is,p2,ML,w1,t1,P0,O0,fi,L0,H0,B0,x0,p0,l0,g0,e0,R$,LG,H$,y$,sG,rA,Jw,va,Nb,mX,lX,kX,jX,iX,hX,Xm,gX,fX,LG,eX,dX,ha,bX,aX,$W,px,_W,ZW,YW,VD,UD,XW,Fv,WW,Oo,TW,jr,No,xl,rg,QW,Oo,SW,RW,PW,VW,OW,SD,NW,SD,UW,TD,MW,LW,KW,Xm,JW,$c,Nb,GW,xv,FW,Hg,EW,LD,DW,mk,LD,cr,CW,vv,uv,eW,BW,tW,sW,cW,Ki,YV,WV,iv,mD,VV,y9,z9,MN,w9,x9,ey,Js,$b,A9,Xd,jD,RV,QV,XC,OV,NV,XC,JV,Wu,IV,P8,df,Hfa,haa,PV,Eq,Ef,XU,gaa,ria,Z8,O8,AV,pC,zV,yV,oC,xV,kg,wV,vV,Fc,uV,tV,lg,$g,sV,rV,oV,aC,nV,mV,lV,Ju,UN,DC,ex,kV,jV,iV,hV,gV,Mu,fV,RB,Dd,Aq,cV,bV,Bu,QB,aV,$U,_U,PB,YU,OB,Ku,Qu,RU,xq,QU,Mb,Cf,rg,PU,vu,OU,id,wq,NU,MU,LU,EB,DB,pd,KU,to,Tia,Sia,Ria,FU,EU,Ki,ru,Qia,Pia,Xaa,Nia,bh,Mia,Iia,gk,Lia,Kia,xU,Jia,Wh,Nf,Eia,Dia,Cia,kU,zia,gk,sj,yia,xia,oq,wia,uB,via,uia,tia,sia,ST,OT,oia,lia,en,jia,jg,oU,kia,Ju,KT,iia,hia,mB,gia,uv,fia,kB,FT,Jda,cia,xq,no,bia,aia,DB,$ha,_ha,Zha,Yha,Xha,Am,Wha,Vha,Uha,Sha,gk,BT,Tha,Wh,Nf,tB,Nha,Kha,yh,Fha,Eha,Bha,Aha,zha,yha,xha,wha,nq,vha,uha,tha,WA,KV,rha,qha,rg,pha,oha,nha,HV,mha,lha,kha,jha,kB,aT,iha,hha,rg,gha,fha,jU,Gha,eha,dha,Hha,cha,bha,aha,TA,TA,SA,$ga,_ga,_S,TA,Zga,nX,Yga,Xga,Wga,Vga,Uga,Tga,Sga,XS,qd,mo,Hga,KA,Rga,A8,z8,y8,x8,w8,v8,Qga,Pga,Lf,Oga,Nga,Mga,Lga,BD,Waa,Uaa,L8,X8,Y8,Kga,Jga,Iga,I9,t8,is,Saa,Raa,Qaa,Paa,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,pga,oga,qga,pS,Nf,iS,CA,lga,BA,kga,jga,iga,hga,hS,AA,gga,Wu,oC,fga,fS,eS,Qq,zA,ega,Qe,dga,cS,nq,Hu,nq,cga,Lq,rg,kU,nq,$aa,en,_fa,Zfa,Yfa,Xfa,sA,Nt,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,qC,Pfa,Ofa,Nfa,Mfa,Lfa,Kfa,Jfa,Ifa,PA,Gfa,Ffa,Efa,Dfa,rg,ZS,YS,ZA,Cfa,Bfa,Bu,uv,Baa,Aaa,zaa,tq,Afa,wm,pu,Yf,faa,Gaa,dt,WN,eaa,daa,DN,$s,xN,caa,mN,HO,baa,lz,ij,Yh,pfa,nfa,It,yfa,Xt,kfa,wm,ifa,hfa,oR,mo,gfa,ffa,nR,efa,dfa,cfa,Ht,bfa,afa,$ea,_ea,Uea,_z,Tea,Sea,Rea,gk,Wh,Nf,Yh,Oea,Nea,Mea,Lea,BA,Iea,Hea,Ht,Gea,_8,Dea,Cea,sj,bR,_z,Ku,Bea,zea,yea,xea,Et,wea,Et,vea,fr,LV,rea,gk,sea,tea,Wz,QQ,Wh,Nf,It,oea,lea,CA,kea,hea,gea,DQ,nR,WA,fea,Bu,rg,Yda,Xda,PB,Wda,Vda,Uda,Tda,gQ,to,Pda,Oda,Nda,Mda,Lda,Kda,jm,YP,Ida,Hda,Gda,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,wda,BA,vda,uda,tda,Xt,sda,rda,xq,raa,xv,EB,yaa,xaa,xq,waa,Yh,xv,vaa,uaa,taa,oda,nda,mda,lda,kda,jda,Oq,gda,fda,eda,dda,cda,bda,ada,$ca,_ca,Zca,Yca,Xca,cX,$D,Wca,rg,Vca,Uca,nl,Daa,aba,ET,UO,Zaa,Yaa,Vaa,Taa,jt,Oaa,IO,Laa,Kaa,zO,Jaa,Iaa,Haa,Wn,jO,Faa,Eaa,oo,paa,sj,ON,gr,v9,u9,t9,g9,MV,s9,jv,gr,RB,r9,ON,naa,q9,saa,gk,Wh,Nf,qaa,gk,Wh,Nf,oaa,gk,Wh,Nf,laa,xU,tq,aaa,$9,_9,Z9,Y9,X9,_aa,Sca,GO,V9,wc,S9,S8,R9,IW,bW,UV,_V,P9,O9,SV,$V,HW,ZV,mM,N9,M9,L9,lM,uy,K9,J9,Maa,H9,G9,F9,E9,qL,J8,Dv,ZD,ID,ey,C9,is,qu,Hq,kaa,maa,n9,m9,sj,l9,_z,k9,j9,i9,It,h9,Yh,f9,e9,d9,c9,b9,gk,Wh,Nf,o9,W8,V8,U8,T8,Fh,Gl,R8,Q8,N8,H8,G8,F8,E8,D8,oL,K8,np,nL,pk,Fh,Lf,B8,af,u8,C8,I8,r8,q8,K7,p8,Pj,cL,bg,lL,a8,L7,Dl,F7,fi,E7,D7,C7,ey,jt,A7,ry,NK,f7,Z6,S6,L6,D6,t6,v6,k6,d6,YJ,xs,Z5,Y5,W1,Y1,P5,O5,M5,VJ,D9,_1,J5,YJ,I5,E2,v2,H2,G5,C1,QJ,yx,E5,S2,GJ,R2,tJ,C5,C6,z5,d5,A5,U4,x5,A2,O2,v5,C2,PJ,cS,OJ,NJ,MJ,l5,j5,QJ,yx,g5,f5,e5,c5,b5,a5,$4,_4,Z4,Y4,X4,W4,V4,T4,S4,R4,Q4,P4,O4,N4,M4,L4,K4,J4,G4,E4,C4,zD,v1,I2,A4,k4,z2,i4,g4,Mk,y1,z1,e4,B1,Y3,V3,M8,S3,yx,N3,K3,H3,Dn,x1,F3,D3,A3,y3,w3,u3,s3,p3,n3,l3,j3,h3,KJ,c3,a3,hM,Jt,JJ,Z2,Y2,W2,V2,U2,T2,kp,iaa,hr,GL,nh,M2,K2,oh,SL,G2,U9,D2,sG,rr,B2,y2,w2,Q9,F2,N2,J2,sv,aa,Z1,BJ,AJ,X1,RI,V1,U1,J1,A1,u1,bM,Tca,S0,R0,N0,M0,G0,F0,SG,RG,$X,w0,v0,u0,t0,s0,r0,q0,i0,Hg,h0,zf,TX,_X,T$,RG,P$,Jq,aH,Dw,yw,x$,w$,uw,Hh,Gh,Fr,Ib,tw,dp,Yi,Ek,sw,Jl,o$,n$,Wi,Ng,eG,Vi,Gw,ow,Hh,Gh,Dr,Pr,Lj,f0,jl,pn,Wi,Ng,aG,Vi,V_,Q_,XG,L_,Lr,qo,G_,Ar,kf,o_,Jr,n_,m_,l_,PF,j_,h_,g_,Ck,f_,PF,d_,c_,a_,$Z,YZ,XZ,TZ,SZ,RZ,QZ,PZ,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,_Y,$Y,aZ,hZ,fZ,dZ,bZ,MY,NY,OY,VY,TY,RY,PY,qba,eF,Pm,Bq,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,eba,dba,cba,bba,Pm,ida,hda,Dha,Cha,jea,iea,cea,bea,nga,mga,Yea,Xea,Fga,Ega,TU,SU,Rha,Qha,qV,pV,eV,dV,Qea,Pea,nea,mea,qda,pda,Bia,Aia,qia,pia,EV,DV,CV,BV,Fea,Eea,qea,pea,mfa,lfa,Gga,IU,Mha,Lha,Jha,Iha,Gia,Fia,eia,dia,Kea,Jea,p9,a9,$8,rfa,qfa,Sda,Rda,Wea,Vea,Pha,Oha,eea,dea,_da,Zda,nia,mia,aea,$da,zfa,tfa,sfa,GV,FV,WU,UU,aga,$fa,vfa,ufa,Wm,Bq,fW,Cc,Ho,XJ,Cc,zf,Cc,lc,ve,ve,lc,lc,gW,wW,vW,hW,Cc,Ho,Cc,xD,rW,qW,pW,oW,nW,mW,lW,kW,iW,Fs,Hn,Hn,aL,lc,kf,lc,lc,lc,Ae,Gn,o8,n8,m8,l8,k8,hi,Mx,Mx,Lx,$K,Lx,Lx,j8,kf,IU,i8,h8,g8,f8,e8,gi,ZK,H7,lc,lc,ve,Kx,te,te,ve,d8,c8,Ae,kf,Ae,kf,YK,XK,XK,_7,lc,kf,lc,lc,lc,Ae,Z7,WK,Y7,X7,W7,V7,hi,U7,T7,S7,R7,Q7,P7,O7,N7,M7,gi,TK,lc,lc,ve,te,te,ve,VK,UK,vf,dh,RX,J7,Nx,I7,lc,G7,$K,q7,g7,_6,T6,M6,E6,u6,l6,e6,F6,s8,b8,B7,Fs,Hn,Hn,aL,lc,kf,lc,lc,lc,Ae,PK,z7,y7,x7,w7,v7,hi,u7,gi,OK,lc,lc,ve,te,te,ve,t7,r7,DK,CK,CK,e7,lc,kf,lc,lc,lc,Ae,d7,c7,b7,a7,hi,$6,gi,yK,lc,lc,ve,te,te,Nk,Nk,Y6,lc,kf,lc,lc,lc,Ae,xK,X6,W6,V6,hi,U6,gi,vK,lc,lc,ve,te,te,Fs,Hn,Hn,R6,lc,kf,lc,lc,lc,Ae,xK,Q6,P6,O6,hi,N6,gi,rK,lc,lc,ve,te,te,MK,Hx,Hx,K6,lc,kf,lc,lc,lc,Ae,LK,J6,n7,m7,hi,l7,gi,k7,lc,lc,ve,te,te,Ae,kf,JK,I6,H6,IK,G6,GK,FK,Hx,ys,p7,LK,o7,JK,j7,i7,IK,h7,GK,FK,Nk,Nk,B6,lc,kf,lc,lc,lc,Ae,te,A6,z6,y6,hi,x6,gi,w6,lc,lc,ve,te,te,oK,nK,nK,s6,lc,kf,lc,lc,r6,Ae,q6,p6,o6,n6,hi,m6,gi,Bx,lc,lc,ve,te,te,Ae,kf,Nk,Nk,j6,lc,kf,lc,lc,lc,Ae,PK,i6,h6,g6,hi,f6,gi,iK,lc,lc,ve,te,te,Nk,Nk,c6,lc,kf,lc,lc,lc,Ae,Gn,b6,a6,$5,hi,_5,gi,fK,lc,lc,ve,te,te,FJ,Cc,Q2,vx,P2,vx,vx,dh,js,u2,L2,zf,dh,zf,Cc,t2,s2,dh,lJ,kJ,lJ,kJ,Ae,ks,Ae,ks,oJ,nJ,oJ,nJ,Cc,x2,zf,Cc,r2,q2,Cc,cJ,bJ,dh,m2,$I,l2,$I,o2,aJ,n2,aJ,Cc,k2,j2,Cc,_I,ZI,fs,fs,fs,fs,i2,nx,nx,nx,Cc,h2,g2,Cc,XI,WI,d2,UI,c2,UI,f2,VI,e2,VI,Cc,b2,a2,Cc,TI,SI,es,es,es,es,$1,lx,lx,lx,D1,Cc,Ho,Cc,KI,I1,ve,ve,H1,G1,Bq,F1,E1,dh,dh,K1,Cc,Ho,Cc,QI,S1,ve,lc,ve,R1,Q1,P1,O1,N1,M1,L1,dh,uW,Cc,Ho,Cc,Cc,AW,ve,ve,Bq,DD,zW,yW,xW,Ae,ks,Ae,ks,bs,gx,s1,r1,CI,BI,AI,zI,yI,xI,wI,vI,uI,tI,sI,rI,qI,pI,oI,nI,lI,kI,jI,iI,hI,gI,q1,p1,o1,n1,m1,l1,k1,j1,i1,h1,g1,f1,e1,d1,c1,b1,a1,$0,_0,Z0,Y0,X0,W0,V0,U0,T0,zf,dh,zf,dh,zf,dh,K0,J0,I0,En,Lw,Ae,pH,oH,nH,lc,lc,A0,mH,z0,Tr,y0,Tr,Qr,Hw,Ae,pH,oH,nH,lc,lc,m0,mH,k0,Tr,j0,Tr,qs,$$,a0,_$,d0,c0,b0,jp,VG,Z$,Y$,Rr,Iw,eH,dH,gf,UG,X$,W$,Sr,Kw,kH,jH,zf,Cc,V$,ZX,YX,XX,U$,Pm,C0,lc,Q$,Lw,C$,B$,A$,z$,IJ,Mw,Gk,Mw,Lw,F$,KG,E$,D$,Hw,K$,J$,I$,G$,Sr,Kw,kH,jH,IJ,Mw,Hw,N$,KG,M$,L$,Rr,Iw,eH,dH,hF,aY,ys,iF,iY,hY,gY,fY,eY,jF,dY,cY,bY,nF,BY,AY,zY,yY,xY,lc,wY,vY,vF,HY,GY,FY,EY,DY,CY,wF,LY,DD,Hia,KY,JY,IY,zf,Cc,Cc,tY,sY,rY,qY,pY,oY,nY,mY,jF,lY,kY,jY,Cc,kF,kF,Yo,ve,ve,uY,ve,Cc,qF,pF,Yo,lc,lc,oF,Gn,Cc,qF,pF,Yo,lc,lc,oF,Gn,Cc,tF,sF,Yo,lc,lc,rF,Gn,Cc,tF,sF,Yo,lc,lc,rF,Gn,zf,Cc,v$,u$,t$,zf,Cc,s$,r$,q$,Cc,p$,m$,l$,k$,iG,iG,j$,i$,h$,g$,f$,Cc,e$,d$,c$,b$,$F,$F,a$,$_,__,Z_,Y_,Cc,X_,W_,U_,T_,S_,R_,P_,O_,Cc,N_,M_,K_,J_,I_,H_,F_,E_,zf,Cc,te,D_,C_,B_,A_,z_,y_,ZY,YY,XY,WY,UY,SY,QY,zf,Cc,te,x_,w_,v_,u_,t_,s_,lZ,kZ,jZ,iZ,gZ,eZ,cZ,iw,yF,r_,iw,yF,q_,Cc,zr,zr,Eh,Eh,Eh,RF,lc,xk,xk,Cc,zr,zr,Eh,Eh,Eh,RF,lc,xk,xk,Cc,yr,yr,Eh,Eh,Eh,QF,lc,xk,xk,Cc,yr,yr,Eh,Eh,Eh,QF,lc,xk,xk,Cc,p_,k_,Cc,i_,e_,Cc,b_,_Z,Cc,ZZ,WZ,Cc,GF,VZ,Ae,Cc,GF,UZ,Ae,zf,dh,Cc,WX,fF,Cc,VX,UX,fF,Pm,dh,Cc,SX,wa,zf,Cc,kf,kf,QX,IX,KX,LX,Cc,DX,Cc,CX,Wm,Pm,Wm,Wm,Wm,Wm,Pm,Cc,BX,Cc,HX,JX,MX,Cc,PX,OX,NX,Cc,EX]);function nb(){return u.byteLength/65536|0}function sb(tb){tb=tb|0;var ob=nb()|0;var pb=ob+tb|0;if(ob<pb&&pb<65536){var qb=new ArrayBuffer(D(pb,65536));var rb=new Int8Array(qb);rb.set(v);v=new Int8Array(qb);w=new Int16Array(qb);x=new Int32Array(qb);y=new Uint8Array(qb);z=new Uint16Array(qb);A=new Uint32Array(qb);B=new Float32Array(qb);C=new Float64Array(qb);u=qb;t.buffer=u;e=y}return ob}return{"va":JU,"wa":R5,"xa":S5,"ya":Cc,"za":Ib,"Aa":Q5,"Ba":N5,"Ca":L5,"Da":xs,"Ea":Ae,"Fa":U5,"Ga":T5,"Ha":X5,"Ia":Mx,"Ja":V5,"Ka":XJ,"La":W5,"Ma":zf,"Na":_J,"Oa":ZJ,"Pa":_J,"Qa":X2,"Ra":AX,"Sa":zX,"Ta":yX,"Ua":K5,"Va":TJ,"Wa":H5,"Xa":RJ,"Ya":r5,"Za":e3,"_a":f3,"$a":p5,"ab":o5,"bb":n5,"cb":q5,"db":g3,"eb":J3,"fb":_2,"gb":M3,"hb":l4,"ib":b3,"jb":P3,"kb":d3,"lb":O3,"mb":$2,"nb":m3,"ob":i3,"pb":k3,"qb":B3,"rb":x3,"sb":z3,"tb":o3,"ub":q3,"vb":t3,"wb":v3,"xb":f4,"yb":h4,"zb":t4,"Ab":n4,"Bb":m4,"Cb":s4,"Db":r4,"Eb":p4,"Fb":q4,"Gb":x4,"Hb":y4,"Ib":u4,"Jb":w4,"Kb":v4,"Lb":Z3,"Mb":c4,"Nb":a4,"Ob":$3,"Pb":b4,"Qb":_3,"Rb":I3,"Sb":D4,"Tb":X3,"Ub":T3,"Vb":j4,"Wb":L3,"Xb":U3,"Yb":R3,"Zb":Q3,"_b":F4,"$b":E3,"ac":H4,"bc":G3,"cc":B4,"dc":F5,"ec":D5,"fc":xX,"gc":B5,"hc":y5,"ic":w5,"jc":u5,"kc":wX,"lc":t5,"mc":s5,"nc":m5,"oc":k5,"pc":i5,"qc":I4,"rc":h5,"sc":Ld,"tc":mb,"uc":O$,"vc":W3,"wc":T1,"xc":Q0,"yc":GX,"zc":FX,"Ac":vX,"Bc":tX,"Cc":oX,"Dc":uX,"Ec":tX,"Fc":sX,"Gc":pX,"Hc":rX,"Ic":qX,"Jc":pX,"Kc":oX,"Lc":oX}}return ub(wb)}
// EMSCRIPTEN_END_ASM




)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


